@@ -24,6 +24,7 @@
 #include "PreCompiled.h"
 #include <QSignalMapper>
 #include <QDockWidget>
+#include <QMessageBox>
 
 #include "Placement.h"
 #include "ui_Placement.h"
@@ -35,6 +36,8 @@
 #include <App/Document.h>
 #include <App/PropertyGeo.h>
 #include <Base/Console.h>
+#include <Base/Tools.h>
+#include <Base/UnitsApi.h>
 
 using namespace Gui::Dialog;
 
@@ -80,10 +83,16 @@ Placement::Placement(QWidget* parent, Qt::WFlags fl)
     ui = new Ui_PlacementComp(this);
     ui->applyPlacementChange->hide();
 
-    ui->angle->setSuffix(QString::fromUtf8(" \xc2\xb0"));
-    ui->yawAngle->setSuffix(QString::fromUtf8(" \xc2\xb0"));
-    ui->pitchAngle->setSuffix(QString::fromUtf8(" \xc2\xb0"));
-    ui->rollAngle->setSuffix(QString::fromUtf8(" \xc2\xb0"));
+    ui->xPos->setUnit(Base::Unit::Length);
+    ui->yPos->setUnit(Base::Unit::Length);
+    ui->zPos->setUnit(Base::Unit::Length);
+    ui->xCnt->setValue(Base::Quantity(0, Base::Unit::Length));
+    ui->yCnt->setValue(Base::Quantity(0, Base::Unit::Length));
+    ui->zCnt->setValue(Base::Quantity(0, Base::Unit::Length));
+    ui->angle->setUnit(Base::Unit::Angle);
+    ui->yawAngle->setUnit(Base::Unit::Angle);
+    ui->pitchAngle->setUnit(Base::Unit::Angle);
+    ui->rollAngle->setUnit(Base::Unit::Angle);
 
     // create a signal mapper in order to have one slot to perform the change
     signalMapper = new QSignalMapper(this);
@@ -91,8 +100,8 @@ Placement::Placement(QWidget* parent, Qt::WFlags fl)
     signalMapper->setMapping(this, 0);
 
     int id = 1;
-    QList<QDoubleSpinBox*> sb = this->findChildren<QDoubleSpinBox*>();
-    for (QList<QDoubleSpinBox*>::iterator it = sb.begin(); it != sb.end(); ++it) {
+    QList<Gui::InputField*> sb = this->findChildren<Gui::InputField*>();
+    for (QList<Gui::InputField*>::iterator it = sb.begin(); it != sb.end(); ++it) {
         connect(*it, SIGNAL(valueChanged(double)), signalMapper, SLOT(map()));
         signalMapper->setMapping(*it, id++);
     }
@@ -123,6 +132,16 @@ void Placement::slotActiveDocument(const Gui::Document& doc)
     documents.insert(doc.getDocument()->getName());
 }
 
+bool Placement::hasValidInputs() const
+{
+    QList<Gui::InputField*> sb = this->findChildren<Gui::InputField*>();
+    for (QList<Gui::InputField*>::iterator it = sb.begin(); it != sb.end(); ++it) {
+        if (!(*it)->hasValidInput())
+            return false;
+    }
+    return true;
+}
+
 void Placement::revertTransformation()
 {
     for (std::set<std::string>::iterator it = documents.begin(); it != documents.end(); ++it) {
@@ -148,7 +167,7 @@ void Placement::revertTransformation()
     }
 }
 
-void Placement::applyPlacement(const Base::Placement& p, bool incremental, bool data)
+void Placement::applyPlacement(const Base::Placement& p, bool incremental)
 {
     Gui::Document* document = Application::Instance->activeDocument();
     if (!document) return;
@@ -156,68 +175,71 @@ void Placement::applyPlacement(const Base::Placement& p, bool incremental, bool
     std::vector<App::DocumentObject*> sel = Gui::Selection().getObjectsOfType
         (App::DocumentObject::getClassTypeId(), document->getDocument()->getName());
     if (!sel.empty()) {
-        if (data) {
-            document->openCommand("Placement");
-            for (std::vector<App::DocumentObject*>::iterator it=sel.begin();it!=sel.end();++it) {
-                std::map<std::string,App::Property*> props;
-                (*it)->getPropertyMap(props);
-                // search for the placement property
-                std::map<std::string,App::Property*>::iterator jt;
-                jt = std::find_if(props.begin(), props.end(), find_placement(this->propertyName));
-                if (jt != props.end()) {
-                    Base::Placement cur = static_cast<App::PropertyPlacement*>(jt->second)->getValue();
-                    if (incremental)
-                        cur = p * cur;
-                    else
-                        cur = p;
+        // apply transformation only on view matrix not on placement property
+        for (std::vector<App::DocumentObject*>::iterator it=sel.begin();it!=sel.end();++it) {
+            std::map<std::string,App::Property*> props;
+            (*it)->getPropertyMap(props);
+            // search for the placement property
+            std::map<std::string,App::Property*>::iterator jt;
+            jt = std::find_if(props.begin(), props.end(), find_placement(this->propertyName));
+            if (jt != props.end()) {
+                Base::Placement cur = static_cast<App::PropertyPlacement*>(jt->second)->getValue();
+                if (incremental)
+                    cur = p * cur;
+                else
+                    cur = p;
 
-                    Base::Vector3d pos = cur.getPosition();
-                    const Base::Rotation& rt = cur.getRotation();
-                    QString cmd = QString::fromAscii(
-                        "App.getDocument(\"%1\").%2.Placement="
-                        "App.Placement("
-                        "App.Vector(%3,%4,%5),"
-                        "App.Rotation(%6,%7,%8,%9))\n")
-                        .arg(QLatin1String((*it)->getDocument()->getName()))
-                        .arg(QLatin1String((*it)->getNameInDocument()))
-                        .arg(pos.x,0,'g',6)
-                        .arg(pos.y,0,'g',6)
-                        .arg(pos.z,0,'g',6)
-                        .arg(rt[0],0,'g',6)
-                        .arg(rt[1],0,'g',6)
-                        .arg(rt[2],0,'g',6)
-                        .arg(rt[3],0,'g',6);
-                    Application::Instance->runPythonCode((const char*)cmd.toAscii());
-                }
-            }
-
-            document->commitCommand();
-            try {
-                document->getDocument()->recompute();
-            }
-            catch (...) {
+                Gui::ViewProvider* vp = document->getViewProvider(*it);
+                if (vp) vp->setTransformation(cur.toMatrix());
             }
         }
-        // apply transformation only on view matrix not on placement property
-        else {
-            for (std::vector<App::DocumentObject*>::iterator it=sel.begin();it!=sel.end();++it) {
-                std::map<std::string,App::Property*> props;
-                (*it)->getPropertyMap(props);
-                // search for the placement property
-                std::map<std::string,App::Property*>::iterator jt;
-                jt = std::find_if(props.begin(), props.end(), find_placement(this->propertyName));
-                if (jt != props.end()) {
-                    Base::Placement cur = static_cast<App::PropertyPlacement*>(jt->second)->getValue();
-                    if (incremental)
-                        cur = p * cur;
-                    else
-                        cur = p;
+    }
+    else {
+        Base::Console().Warning("No object selected.\n");
+    }
+}
 
-                    Gui::ViewProvider* vp = document->getViewProvider(*it);
-                    if (vp) vp->setTransformation(cur.toMatrix());
+void Placement::applyPlacement(const QString& data, bool incremental)
+{
+    Gui::Document* document = Application::Instance->activeDocument();
+    if (!document) return;
+
+    std::vector<App::DocumentObject*> sel = Gui::Selection().getObjectsOfType
+        (App::DocumentObject::getClassTypeId(), document->getDocument()->getName());
+    if (!sel.empty()) {
+        document->openCommand("Placement");
+        for (std::vector<App::DocumentObject*>::iterator it=sel.begin();it!=sel.end();++it) {
+            std::map<std::string,App::Property*> props;
+            (*it)->getPropertyMap(props);
+            // search for the placement property
+            std::map<std::string,App::Property*>::iterator jt;
+            jt = std::find_if(props.begin(), props.end(), find_placement(this->propertyName));
+            if (jt != props.end()) {
+                QString cmd;
+                if (incremental)
+                    cmd = QString::fromAscii(
+                        "App.getDocument(\"%1\").%2.Placement=%3.multiply(App.getDocument(\"%1\").%2.Placement)")
+                        .arg(QLatin1String((*it)->getDocument()->getName()))
+                        .arg(QLatin1String((*it)->getNameInDocument()))
+                        .arg(data);
+                else {
+                    cmd = QString::fromAscii(
+                        "App.getDocument(\"%1\").%2.Placement=%3")
+                        .arg(QLatin1String((*it)->getDocument()->getName()))
+                        .arg(QLatin1String((*it)->getNameInDocument()))
+                        .arg(data);
                 }
+
+                Application::Instance->runPythonCode((const char*)cmd.toAscii());
             }
         }
+
+        document->commitCommand();
+        try {
+            document->getDocument()->recompute();
+        }
+        catch (...) {
+        }
     }
     else {
         Base::Console().Warning("No object selected.\n");
@@ -232,7 +254,7 @@ void Placement::onPlacementChanged(int)
     // automatically.
     bool incr = ui->applyIncrementalPlacement->isChecked();
     Base::Placement plm = this->getPlacement();
-    applyPlacement(plm, incr, false);
+    applyPlacement(plm, incr);
 
     QVariant data = QVariant::fromValue<Base::Placement>(plm);
     /*emit*/ placementChanged(data, incr, false);
@@ -255,7 +277,7 @@ void Placement::on_applyIncrementalPlacement_toggled(bool on)
 void Placement::reject()
 {
     Base::Placement plm;
-    applyPlacement(plm, true, false);
+    applyPlacement(plm, true);
 
     QVariant data = QVariant::fromValue<Base::Placement>(plm);
     /*emit*/ placementChanged(data, true, false);
@@ -266,41 +288,57 @@ void Placement::reject()
 
 void Placement::accept()
 {
-    on_applyButton_clicked();
-
-    revertTransformation();
-    QDialog::accept();
+    if (onApply()) {
+        revertTransformation();
+        QDialog::accept();
+    }
 }
 
 void Placement::on_applyButton_clicked()
 {
+    onApply();
+}
+
+bool Placement::onApply()
+{
+    //only process things when we have valid inputs!
+    if (!hasValidInputs()) {
+        QMessageBox msg;
+        msg.setIcon(QMessageBox::Critical);
+        msg.setText(tr("There are input fields with incorrect input, please ensure valid placement values!"));
+        msg.exec();
+        return false;
+    }
+
     // If there are listeners to the 'placementChanged' signal we rely
     // on that the listener updates any placement. If no listeners
     // are connected the placement is applied to all selected objects
     // automatically.
     bool incr = ui->applyIncrementalPlacement->isChecked();
     Base::Placement plm = this->getPlacement();
-    applyPlacement(plm, incr, true);
+    applyPlacement(getPlacementString(), incr);
 
     QVariant data = QVariant::fromValue<Base::Placement>(plm);
     /*emit*/ placementChanged(data, incr, true);
 
     if (ui->applyIncrementalPlacement->isChecked()) {
-        QList<QDoubleSpinBox*> sb = this->findChildren<QDoubleSpinBox*>();
-        for (QList<QDoubleSpinBox*>::iterator it = sb.begin(); it != sb.end(); ++it) {
+        QList<Gui::InputField*> sb = this->findChildren<Gui::InputField*>();
+        for (QList<Gui::InputField*>::iterator it = sb.begin(); it != sb.end(); ++it) {
             (*it)->blockSignals(true);
-            (*it)->setValue(0.0);
+            (*it)->setValue(0);
             (*it)->blockSignals(false);
         }
     }
+
+    return true;
 }
 
 void Placement::on_resetButton_clicked()
 {
-    QList<QDoubleSpinBox*> sb = this->findChildren<QDoubleSpinBox*>();
-    for (QList<QDoubleSpinBox*>::iterator it = sb.begin(); it != sb.end(); ++it) {
+    QList<Gui::InputField*> sb = this->findChildren<Gui::InputField*>();
+    for (QList<Gui::InputField*>::iterator it = sb.begin(); it != sb.end(); ++it) {
         (*it)->blockSignals(true);
-        (*it)->setValue(0.0);
+        (*it)->setValue(0);
         (*it)->blockSignals(false);
     }
 
@@ -327,22 +365,22 @@ void Placement::setPlacement(const Base::Placement& p)
 void Placement::setPlacementData(const Base::Placement& p)
 {
     signalMapper->blockSignals(true);
-    ui->xPos->setValue(p.getPosition().x);
-    ui->yPos->setValue(p.getPosition().y);
-    ui->zPos->setValue(p.getPosition().z);
+    ui->xPos->setValue(Base::Quantity(p.getPosition().x, Base::Unit::Length));
+    ui->yPos->setValue(Base::Quantity(p.getPosition().y, Base::Unit::Length));
+    ui->zPos->setValue(Base::Quantity(p.getPosition().z, Base::Unit::Length));
 
     double Y,P,R;
     p.getRotation().getYawPitchRoll(Y,P,R);
-    ui->yawAngle->setValue(Y);
-    ui->pitchAngle->setValue(P);
-    ui->rollAngle->setValue(R);
+    ui->yawAngle->setValue(Base::Quantity(Y, Base::Unit::Angle));
+    ui->pitchAngle->setValue(Base::Quantity(P, Base::Unit::Angle));
+    ui->rollAngle->setValue(Base::Quantity(R, Base::Unit::Angle));
 
     // check if the user-defined direction is already there
     bool newitem = true;
     double angle;
     Base::Vector3d axis;
     p.getRotation().getValue(axis, angle);
-    ui->angle->setValue(angle*180.0/D_PI);
+    ui->angle->setValue(Base::Quantity(angle*180.0/D_PI, Base::Unit::Angle));
     Base::Vector3d dir(axis.x,axis.y,axis.z);
     for (int i=0; i<ui->direction->count()-1; i++) {
         QVariant data = ui->direction->itemData (i);
@@ -382,24 +420,61 @@ Base::Placement Placement::getPlacementData() const
     Base::Vector3d pos;
     Base::Vector3d cnt;
 
-    pos = Base::Vector3d(ui->xPos->value(),ui->yPos->value(),ui->zPos->value());
-    cnt = Base::Vector3d(ui->xCnt->value(),ui->yCnt->value(),ui->zCnt->value());
+    pos = Base::Vector3d(ui->xPos->getQuantity().getValue(),ui->yPos->getQuantity().getValue(),ui->zPos->getQuantity().getValue());
+    cnt = Base::Vector3d(ui->xCnt->getQuantity().getValue(),ui->yCnt->getQuantity().getValue(),ui->zCnt->getQuantity().getValue());
 
     if (index == 0) {
         Base::Vector3d dir = getDirection();
-        rot.setValue(Base::Vector3d(dir.x,dir.y,dir.z),ui->angle->value()*D_PI/180.0);
+        rot.setValue(Base::Vector3d(dir.x,dir.y,dir.z),Base::toRadians(ui->angle->getQuantity().getValue()));
     }
     else if (index == 1) {
         rot.setYawPitchRoll(
-            ui->yawAngle->value(),
-            ui->pitchAngle->value(),
-            ui->rollAngle->value());
+            ui->yawAngle->getQuantity().getValue(),
+            ui->pitchAngle->getQuantity().getValue(),
+            ui->rollAngle->getQuantity().getValue());
     }
 
     Base::Placement p(pos, rot, cnt);
     return p;
 }
 
+QString Placement::getPlacementString() const
+{
+    QString cmd;
+    int index = ui->rotationInput->currentIndex();
+
+    if (index == 0) {
+        Base::Vector3d dir = getDirection();
+        cmd = QString::fromAscii(
+            "App.Placement(App.Vector(%1,%2,%3), App.Rotation(App.Vector(%4,%5,%6),%7), App.Vector(%8,%9,%10))")
+            .arg(ui->xPos->getQuantity().getValue())
+            .arg(ui->yPos->getQuantity().getValue())
+            .arg(ui->zPos->getQuantity().getValue())
+            .arg(dir.x)
+            .arg(dir.y)
+            .arg(dir.z)
+            .arg(ui->angle->getQuantity().getValue())
+            .arg(ui->xCnt->getQuantity().getValue())
+            .arg(ui->yCnt->getQuantity().getValue())
+            .arg(ui->zCnt->getQuantity().getValue());
+    }
+    else if (index == 1) {
+        cmd = QString::fromAscii(
+            "App.Placement(App.Vector(%1,%2,%3), App.Rotation(%4,%5,%6), App.Vector(%7,%8,%9))")
+            .arg(ui->xPos->getQuantity().getValue())
+            .arg(ui->yPos->getQuantity().getValue())
+            .arg(ui->zPos->getQuantity().getValue())
+            .arg(ui->yawAngle->getQuantity().getValue())
+            .arg(ui->pitchAngle->getQuantity().getValue())
+            .arg(ui->rollAngle->getQuantity().getValue())
+            .arg(ui->xCnt->getQuantity().getValue())
+            .arg(ui->yCnt->getQuantity().getValue())
+            .arg(ui->zCnt->getQuantity().getValue());
+    }
+
+    return cmd;
+}
+
 void Placement::changeEvent(QEvent *e)
 {
     if (e->type() == QEvent::LanguageChange) {
