@@ -25,6 +25,7 @@
 #ifndef _PreComp_
 # include <qstatusbar.h>
 # include <qstring.h>
+# include <QGLWidget>
 # include <Inventor/details/SoFaceDetail.h>
 # include <Inventor/details/SoLineDetail.h>
 #endif
@@ -103,6 +104,7 @@ SoFCUnifiedSelection::SoFCUnifiedSelection() : pcDocument(0)
     SO_NODE_SET_SF_ENUM_TYPE (highlightMode, HighlightModes);
 
     highlighted = FALSE;
+    preSelection = -1;
 }
 
 /*!
@@ -353,13 +355,14 @@ SoFCUnifiedSelection::handleEvent(SoHandleEventAction * action)
             if (vp && vp->isDerivedFrom(ViewProviderDocumentObject::getClassTypeId()))
                 vpd = static_cast<ViewProviderDocumentObject*>(vp);
 
-            SbBool old_state = highlighted;
+            //SbBool old_state = highlighted;
             highlighted = FALSE;
             if (vpd && vpd->useNewSelectionModel() && vpd->isSelectable()) {
                 std::string documentName = vpd->getObject()->getDocument()->getName();
                 std::string objectName = vpd->getObject()->getNameInDocument();
                 std::string subElementName = vpd->getElement(pp ? pp->getDetail() : 0);
 
+                this->preSelection = 1;
                 static char buf[513];
                 snprintf(buf,512,"Preselected: %s.%s.%s (%f,%f,%f)",documentName.c_str()
                                            ,objectName.c_str()
@@ -388,7 +391,7 @@ SoFCUnifiedSelection::handleEvent(SoHandleEventAction * action)
                             action.apply(currenthighlight);
                             currenthighlight->unref();
                             currenthighlight = 0;
-                            old_state = !highlighted;
+                            //old_state = !highlighted;
                         }
 
                         currenthighlight = static_cast<SoFullPath*>(sa.getPath()->copy());
@@ -396,6 +399,15 @@ SoFCUnifiedSelection::handleEvent(SoHandleEventAction * action)
                     }
                 }
             }
+            // nothing picked
+            else if (!pp) {
+                if (this->preSelection > 0) {
+                    this->preSelection = 0;
+                    // touch() makes sure to call GLRenderBelowPath so that the cursor can be updated
+                    // because only from there the SoGLWidgetElement delivers the OpenGL window
+                    this->touch();
+                }
+            }
 
             if (currenthighlight/* && old_state != highlighted*/) {
                 SoHighlightElementAction action;
@@ -513,6 +525,29 @@ SoFCUnifiedSelection::handleEvent(SoHandleEventAction * action)
     inherited::handleEvent(action);
 }
 
+void SoFCUnifiedSelection::GLRenderBelowPath(SoGLRenderAction * action)
+{
+    inherited::GLRenderBelowPath(action);
+
+    // nothing picked, so restore the arrow cursor if needed
+    if (this->preSelection == 0) {
+        // this is called when a selection gate forbad to select an object
+        // and the user moved the mouse to an empty area
+        this->preSelection = -1;
+        QGLWidget* window;
+        SoState *state = action->getState();
+        SoGLWidgetElement::get(state, window);
+        QWidget* parent = window ? window->parentWidget() : 0;
+        if (parent) {
+            QCursor c = parent->cursor();
+            if (c.shape() == Qt::ForbiddenCursor) {
+                c.setShape(Qt::ArrowCursor);
+                parent->setCursor(c);
+            }
+        }
+    }
+}
+
 // ---------------------------------------------------------------
 
 SO_ACTION_SOURCE(SoHighlightElementAction);
