@@ -141,9 +141,10 @@ SOQT_OBJECT_ABSTRACT_SOURCE(View3DInventorViewer);
 // *************************************************************************
 
 View3DInventorViewer::View3DInventorViewer (QWidget *parent, const char *name, 
-                                            SbBool embed, Type type, SbBool build) 
+                                            SbBool embed, Type type, SbBool build)
   : inherited (parent, name, embed, type, build), editViewProvider(0), navigation(0),
-    framebuffer(0), editing(FALSE), redirected(FALSE), allowredir(FALSE),axisCross(0),axisGroup(0)
+    framebuffer(0), axisCross(0), axisGroup(0), editing(FALSE), redirected(FALSE),
+    allowredir(FALSE), overrideMode("As Is")
 {
     Gui::Selection().Attach(this);
 
@@ -258,7 +259,7 @@ View3DInventorViewer::View3DInventorViewer (QWidget *parent, const char *name,
 
     // This is a callback node that logs all action that traverse the Inventor tree.
 #if defined (FC_DEBUG) && defined(FC_LOGGING_CB)
-    SoCallback * cb = new SoCallback;	 	
+    SoCallback * cb = new SoCallback;
     cb->setCallback(interactionLoggerCB, this);
     pcViewProviderRoot->addChild(cb);
 #endif
@@ -351,7 +352,7 @@ SbBool View3DInventorViewer::hasViewProvider(ViewProvider* pcProvider) const
 void View3DInventorViewer::addViewProvider(ViewProvider* pcProvider)
 {
     SoSeparator* root = pcProvider->getRoot();
-    if (root){
+    if (root) {
         pcViewProviderRoot->addChild(root);
         _ViewProviderMap[root] = pcProvider;
     }
@@ -360,6 +361,7 @@ void View3DInventorViewer::addViewProvider(ViewProvider* pcProvider)
     SoSeparator* back = pcProvider->getBackRoot ();
     if (back) backgroundroot->addChild(back);
 
+    pcProvider->setOverrideMode(this->getOverrideMode());
     _ViewProviderSet.insert(pcProvider);
 }
 
@@ -369,7 +371,7 @@ void View3DInventorViewer::removeViewProvider(ViewProvider* pcProvider)
         resetEditingViewProvider();
 
     SoSeparator* root = pcProvider->getRoot();
-    if (root){
+    if (root) {
         pcViewProviderRoot->removeChild(root);
         _ViewProviderMap.erase(root);
     }
@@ -412,6 +414,24 @@ SbBool View3DInventorViewer::isEditingViewProvider() const
     return this->editViewProvider ? true : false;
 }
 
+/// display override mode
+void View3DInventorViewer::setOverrideMode(const std::string &mode)
+{
+    if (mode == overrideMode)
+        return;
+    overrideMode = mode;
+    for (std::set<ViewProvider*>::iterator it = _ViewProviderSet.begin(); it != _ViewProviderSet.end(); ++it)
+        (*it)->setOverrideMode(mode);
+}
+
+/// update override mode. doesn't affect providers
+void View3DInventorViewer::updateOverrideMode(const std::string &mode)
+{
+    if (mode == overrideMode)
+        return;
+    overrideMode = mode;
+}
+
 void View3DInventorViewer::clearBuffer(void * userdata, SoAction * action)
 {
     if (action->isOfType(SoGLRenderAction::getClassTypeId())) {
@@ -475,13 +495,13 @@ void View3DInventorViewer::setEnabledFPSCounter(bool on)
 #endif
 }
 
-void View3DInventorViewer::setAxisCross(bool b)
+void View3DInventorViewer::setAxisCross(bool on)
 {
     SoNode* scene = getSceneGraph();
     SoSeparator* sep = static_cast<SoSeparator*>(scene);
 
-    if(b){
-        if(!axisGroup){
+    if (on) {
+        if (!axisGroup) {
             axisCross = new Gui::SoShapeScale;
             Gui::SoAxisCrossKit* axisKit = new Gui::SoAxisCrossKit();
             axisKit->set("xAxis.appearance.drawStyle", "lineWidth 2");
@@ -494,19 +514,20 @@ void View3DInventorViewer::setAxisCross(bool b)
 
             sep->addChild(axisGroup);
         }
-    }else{
-        if(axisGroup){
+    }
+    else {
+        if (axisGroup) {
             sep->removeChild(axisGroup);
             axisGroup = 0;
         }
     }
 }
+
 bool View3DInventorViewer::hasAxisCross(void)
 {
     return axisGroup;
 }
 
-
 void View3DInventorViewer::setNavigationType(Base::Type t)
 {
     if (t.isBad())
@@ -991,6 +1012,10 @@ void View3DInventorViewer::renderFramebuffer()
     glEnable(GL_DEPTH_TEST);
 }
 
+//#define ENABLE_GL_DEPTH_RANGE
+// The calls of glDepthRange inside renderScene() causes problems with transparent objects
+// so that's why it is disabled now: http://forum.freecadweb.org/viewtopic.php?f=3&t=6037&hilit=transparency
+
 // Documented in superclass. Overrides this method to be able to draw
 // the axis cross, if selected, and to keep a continuous animation
 // upon spin.
@@ -1030,8 +1055,10 @@ void View3DInventorViewer::renderScene(void)
     glClearColor(col[0], col[1], col[2], 0.0f);
     glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
 
+#if defined(ENABLE_GL_DEPTH_RANGE)
     // using 90% of the z-buffer for the background and the main node
     glDepthRange(0.1,1.0);
+#endif
 
     // Render our scenegraph with the image.
     SoGLRenderAction * glra = this->getGLRenderAction();
@@ -1053,16 +1080,20 @@ void View3DInventorViewer::renderScene(void)
             QObject::tr("Not enough memory available to display the data."));
     }
 
+#if defined (ENABLE_GL_DEPTH_RANGE)
     // using 10% of the z-buffer for the foreground node
     glDepthRange(0.0,0.1);
+#endif
 
     // Render overlay front scenegraph.
     glra->apply(this->foregroundroot);
 
     if (this->axiscrossEnabled) { this->drawAxisCross(); }
-   
+
+#if defined (ENABLE_GL_DEPTH_RANGE)
     // using the main portion of z-buffer again (for frontbuffer highlighting)
     glDepthRange(0.1,1.0);
+#endif
 
     // Immediately reschedule to get continous spin animation.
     if (this->isAnimating()) { this->scheduleRedraw(); }
@@ -1276,6 +1307,14 @@ SbVec3f View3DInventorViewer::getUpDirection() const
     return upvec;
 }
 
+SbRotation View3DInventorViewer::getCameraOrientation() const
+{
+    SoCamera* cam = this->getCamera();
+    if (!cam)
+        return SbRotation(0,0,0,1); // this is the default
+    return cam->orientation.getValue();
+}
+
 SbVec3f View3DInventorViewer::getPointOnScreen(const SbVec2s& pnt) const
 {
     const SbViewportRegion& vp = this->getViewportRegion();
@@ -1481,9 +1520,6 @@ void View3DInventorViewer::moveCameraTo(const SbRotation& rot, const SbVec3f& po
 
     SbVec3f campos = cam->position.getValue();
     SbRotation camrot = cam->orientation.getValue();
-    //SbVec3f dir1, dir2;
-    //camrot.multVec(SbVec3f(0, 0, -1), dir1);
-    //rot.multVec(SbVec3f(0, 0, -1), dir2);
 
     QEventLoop loop;
     QTimer timer;
@@ -1503,6 +1539,58 @@ void View3DInventorViewer::moveCameraTo(const SbRotation& rot, const SbVec3f& po
     cam->position.setValue(pos);
 }
 
+void View3DInventorViewer::animatedViewAll(int steps, int ms)
+{
+    SoCamera* cam = this->getCamera();
+    if (!cam)
+        return;
+
+    SbVec3f campos = cam->position.getValue();
+    SbRotation camrot = cam->orientation.getValue();
+    SoGetBoundingBoxAction action(this->getViewportRegion());
+    action.apply(this->getSceneGraph());
+    SbBox3f box = action.getBoundingBox();
+    if (box.isEmpty())
+        return;
+
+    SbSphere sphere;
+    sphere.circumscribe(box);
+
+    SbVec3f direction, pos;
+    camrot.multVec(SbVec3f(0, 0, -1), direction);
+
+    bool isOrthographic = false;
+    float height = 0;
+    float diff = 0;
+    if (cam->isOfType(SoOrthographicCamera::getClassTypeId())) {
+        isOrthographic = true;
+        height = static_cast<SoOrthographicCamera*>(cam)->height.getValue();
+        diff = sphere.getRadius() * 2 - height;
+        pos = (box.getCenter() - direction * sphere.getRadius());
+    }
+    else if (cam->isOfType(SoPerspectiveCamera::getClassTypeId())) {
+        float movelength = sphere.getRadius()/float(tan(static_cast<SoPerspectiveCamera*>
+            (cam)->heightAngle.getValue() / 2.0));
+        pos = box.getCenter() - direction * movelength;
+    }
+
+    QEventLoop loop;
+    QTimer timer;
+    timer.setSingleShot(true);
+    QObject::connect(&timer, SIGNAL(timeout()), &loop, SLOT(quit()));
+    for (int i=0; i<steps; i++) {
+        float s = float(i)/float(steps);
+        if (isOrthographic) {
+            static_cast<SoOrthographicCamera*>(cam)->height.setValue(height + diff * s);
+        }
+
+        SbVec3f curpos = campos * (1.0f-s) + pos * s;
+        cam->position.setValue(curpos);
+        timer.start(Base::clamp<int>(ms,0,5000));
+        loop.exec(QEventLoop::ExcludeUserInputEvents);
+    }
+}
+
 void View3DInventorViewer::boxZoom(const SbBox2s& box)
 {
     navigation->boxZoom(box);
@@ -1529,6 +1617,9 @@ void View3DInventorViewer::viewAll()
     if (cam && cam->getTypeId().isDerivedFrom(SoPerspectiveCamera::getClassTypeId()))
         static_cast<SoPerspectiveCamera*>(cam)->heightAngle = (float)(M_PI / 4.0);
 
+    if (isAnimationEnabled())
+        animatedViewAll(10, 20);
+
     // call the default implementation first to make sure everything is visible
     SoQtViewer::viewAll();
 
@@ -1537,7 +1628,6 @@ void View3DInventorViewer::viewAll()
         SoSkipBoundingGroup * group = static_cast<SoSkipBoundingGroup*>(path->getTail());
         group->mode = SoSkipBoundingGroup::INCLUDE_BBOX;
     }
-    //navigation->viewAll();
 }
 
 void View3DInventorViewer::viewAll(float factor)
@@ -1786,158 +1876,157 @@ static GLubyte zbmp[] = { 0x1f,0x10,0x08,0x04,0x02,0x01,0x1f };
 
 void View3DInventorViewer::drawAxisCross(void)
 {
-  // FIXME: convert this to a superimposition scenegraph instead of
-  // OpenGL calls. 20020603 mortene.
+    // FIXME: convert this to a superimposition scenegraph instead of
+    // OpenGL calls. 20020603 mortene.
 
-  // Store GL state.
-  glPushAttrib(GL_ALL_ATTRIB_BITS);
-  GLfloat depthrange[2];
-  glGetFloatv(GL_DEPTH_RANGE, depthrange);
-  GLdouble projectionmatrix[16];
-  glGetDoublev(GL_PROJECTION_MATRIX, projectionmatrix);
+    // Store GL state.
+    glPushAttrib(GL_ALL_ATTRIB_BITS);
+    GLfloat depthrange[2];
+    glGetFloatv(GL_DEPTH_RANGE, depthrange);
+    GLdouble projectionmatrix[16];
+    glGetDoublev(GL_PROJECTION_MATRIX, projectionmatrix);
 
-  glDepthFunc(GL_ALWAYS);
-  glDepthMask(GL_TRUE);
-  glDepthRange(0, 0);
-  glEnable(GL_DEPTH_TEST);
-  glDisable(GL_LIGHTING);
-  glEnable(GL_COLOR_MATERIAL);
-  glDisable(GL_BLEND); // Kills transparency.
+    glDepthFunc(GL_ALWAYS);
+    glDepthMask(GL_TRUE);
+    glDepthRange(0, 0);
+    glEnable(GL_DEPTH_TEST);
+    glDisable(GL_LIGHTING);
+    glEnable(GL_COLOR_MATERIAL);
+    glDisable(GL_BLEND); // Kills transparency.
 
-  // Set the viewport in the OpenGL canvas. Dimensions are calculated
-  // as a percentage of the total canvas size.
-  SbVec2s view = this->getGLSize();
-  const int pixelarea =
-    int(float(this->axiscrossSize)/100.0f * SoQtMin(view[0], view[1]));
+    // Set the viewport in the OpenGL canvas. Dimensions are calculated
+    // as a percentage of the total canvas size.
+    SbVec2s view = this->getGLSize();
+    const int pixelarea =
+        int(float(this->axiscrossSize)/100.0f * SoQtMin(view[0], view[1]));
 #if 0 // middle of canvas
-  SbVec2s origin(view[0]/2 - pixelarea/2, view[1]/2 - pixelarea/2);
+    SbVec2s origin(view[0]/2 - pixelarea/2, view[1]/2 - pixelarea/2);
 #endif // middle of canvas
 #if 1 // lower right of canvas
-  SbVec2s origin(view[0] - pixelarea, 0);
+    SbVec2s origin(view[0] - pixelarea, 0);
 #endif // lower right of canvas
-  glViewport(origin[0], origin[1], pixelarea, pixelarea);
+    glViewport(origin[0], origin[1], pixelarea, pixelarea);
+
+    // Set up the projection matrix.
+    glMatrixMode(GL_PROJECTION);
+    glLoadIdentity();
+
+    const float NEARVAL = 0.1f;
+    const float FARVAL = 10.0f;
+    const float dim = NEARVAL * float(tan(M_PI / 8.0)); // FOV is 45 (45/360 = 1/8)
+    glFrustum(-dim, dim, -dim, dim, NEARVAL, FARVAL);
 
 
-  // Set up the projection matrix.
-  glMatrixMode(GL_PROJECTION);
-  glLoadIdentity();
+    // Set up the model matrix.
+    glMatrixMode(GL_MODELVIEW);
+    glPushMatrix();
+    SbMatrix mx;
+    SoCamera * cam = this->getCamera();
 
-  const float NEARVAL = 0.1f;
-  const float FARVAL = 10.0f;
-  const float dim = NEARVAL * float(tan(M_PI / 8.0)); // FOV is 45 (45/360 = 1/8)
-  glFrustum(-dim, dim, -dim, dim, NEARVAL, FARVAL);
+    // If there is no camera (like for an empty scene, for instance),
+    // just use an identity rotation.
+    if (cam) { mx = cam->orientation.getValue(); }
+    else { mx = SbMatrix::identity(); }
+
+    mx = mx.inverse();
+    mx[3][2] = -3.5; // Translate away from the projection point (along z axis).
+    glLoadMatrixf((float *)mx);
 
 
-  // Set up the model matrix.
-  glMatrixMode(GL_MODELVIEW);
-  glPushMatrix();
-  SbMatrix mx;
-  SoCamera * cam = this->getCamera();
+    // Find unit vector end points.
+    SbMatrix px;
+    glGetFloatv(GL_PROJECTION_MATRIX, (float *)px);
+    SbMatrix comb = mx.multRight(px);
 
-  // If there is no camera (like for an empty scene, for instance),
-  // just use an identity rotation.
-  if (cam) { mx = cam->orientation.getValue(); }
-  else { mx = SbMatrix::identity(); }
-
-  mx = mx.inverse();
-  mx[3][2] = -3.5; // Translate away from the projection point (along z axis).
-  glLoadMatrixf((float *)mx);
+    SbVec3f xpos;
+    comb.multVecMatrix(SbVec3f(1,0,0), xpos);
+    xpos[0] = (1 + xpos[0]) * view[0]/2;
+    xpos[1] = (1 + xpos[1]) * view[1]/2;
+    SbVec3f ypos;
+    comb.multVecMatrix(SbVec3f(0,1,0), ypos);
+    ypos[0] = (1 + ypos[0]) * view[0]/2;
+    ypos[1] = (1 + ypos[1]) * view[1]/2;
+    SbVec3f zpos;
+    comb.multVecMatrix(SbVec3f(0,0,1), zpos);
+    zpos[0] = (1 + zpos[0]) * view[0]/2;
+    zpos[1] = (1 + zpos[1]) * view[1]/2;
 
 
-  // Find unit vector end points.
-  SbMatrix px;
-  glGetFloatv(GL_PROJECTION_MATRIX, (float *)px);
-  SbMatrix comb = mx.multRight(px);
+    // Render the cross.
+    {
+        glLineWidth(2.0);
 
-  SbVec3f xpos;
-  comb.multVecMatrix(SbVec3f(1,0,0), xpos);
-  xpos[0] = (1 + xpos[0]) * view[0]/2;
-  xpos[1] = (1 + xpos[1]) * view[1]/2;
-  SbVec3f ypos;
-  comb.multVecMatrix(SbVec3f(0,1,0), ypos);
-  ypos[0] = (1 + ypos[0]) * view[0]/2;
-  ypos[1] = (1 + ypos[1]) * view[1]/2;
-  SbVec3f zpos;
-  comb.multVecMatrix(SbVec3f(0,0,1), zpos);
-  zpos[0] = (1 + zpos[0]) * view[0]/2;
-  zpos[1] = (1 + zpos[1]) * view[1]/2;
+        enum { XAXIS, YAXIS, ZAXIS };
+        int idx[3] = { XAXIS, YAXIS, ZAXIS };
+        float val[3] = { xpos[2], ypos[2], zpos[2] };
 
+        // Bubble sort.. :-}
+        if (val[0] < val[1]) { SoQtSwap(val[0], val[1]); SoQtSwap(idx[0], idx[1]); }
+        if (val[1] < val[2]) { SoQtSwap(val[1], val[2]); SoQtSwap(idx[1], idx[2]); }
+        if (val[0] < val[1]) { SoQtSwap(val[0], val[1]); SoQtSwap(idx[0], idx[1]); }
+        assert((val[0] >= val[1]) && (val[1] >= val[2])); // Just checking..
 
-  // Render the cross.
-  {
-    glLineWidth(2.0);
-
-    enum { XAXIS, YAXIS, ZAXIS };
-    int idx[3] = { XAXIS, YAXIS, ZAXIS };
-    float val[3] = { xpos[2], ypos[2], zpos[2] };
-
-    // Bubble sort.. :-}
-    if (val[0] < val[1]) { SoQtSwap(val[0], val[1]); SoQtSwap(idx[0], idx[1]); }
-    if (val[1] < val[2]) { SoQtSwap(val[1], val[2]); SoQtSwap(idx[1], idx[2]); }
-    if (val[0] < val[1]) { SoQtSwap(val[0], val[1]); SoQtSwap(idx[0], idx[1]); }
-    assert((val[0] >= val[1]) && (val[1] >= val[2])); // Just checking..
-
-    for (int i=0; i < 3; i++) {
-      glPushMatrix();
-      if (idx[i] == XAXIS) {                       // X axis.
-        if (isStereoViewing())
-          glColor3f(0.500f, 0.5f, 0.5f);
-        else
-          glColor3f(0.500f, 0.125f, 0.125f);
-      } else if (idx[i] == YAXIS) {                // Y axis.
-        glRotatef(90, 0, 0, 1);
-        if (isStereoViewing())
-          glColor3f(0.400f, 0.4f, 0.4f);
-        else
-          glColor3f(0.125f, 0.500f, 0.125f);
-      } else {                                     // Z axis.
-        glRotatef(-90, 0, 1, 0);
-        if (isStereoViewing())
-          glColor3f(0.300f, 0.3f, 0.3f);
-        else
-          glColor3f(0.125f, 0.125f, 0.500f);
-      }
-      this->drawArrow(); 
-      glPopMatrix();
+        for (int i=0; i < 3; i++) {
+            glPushMatrix();
+            if (idx[i] == XAXIS) {                       // X axis.
+                if (isStereoViewing())
+                    glColor3f(0.500f, 0.5f, 0.5f);
+                else
+                    glColor3f(0.500f, 0.125f, 0.125f);
+            } else if (idx[i] == YAXIS) {                // Y axis.
+                glRotatef(90, 0, 0, 1);
+                if (isStereoViewing())
+                    glColor3f(0.400f, 0.4f, 0.4f);
+                else
+                    glColor3f(0.125f, 0.500f, 0.125f);
+            } else {                                     // Z axis.
+                glRotatef(-90, 0, 1, 0);
+                if (isStereoViewing())
+                    glColor3f(0.300f, 0.3f, 0.3f);
+                else
+                    glColor3f(0.125f, 0.125f, 0.500f);
+            }
+            this->drawArrow(); 
+            glPopMatrix();
+        }
     }
-  }
 
-  // Render axis notation letters ("X", "Y", "Z").
-  glMatrixMode(GL_PROJECTION);
-  glLoadIdentity();
-  glOrtho(0, view[0], 0, view[1], -1, 1);
+    // Render axis notation letters ("X", "Y", "Z").
+    glMatrixMode(GL_PROJECTION);
+    glLoadIdentity();
+    glOrtho(0, view[0], 0, view[1], -1, 1);
 
-  glMatrixMode(GL_MODELVIEW);
-  glLoadIdentity();
+    glMatrixMode(GL_MODELVIEW);
+    glLoadIdentity();
 
-  GLint unpack;
-  glGetIntegerv(GL_UNPACK_ALIGNMENT, &unpack);
-  glPixelStorei(GL_UNPACK_ALIGNMENT, 1);
+    GLint unpack;
+    glGetIntegerv(GL_UNPACK_ALIGNMENT, &unpack);
+    glPixelStorei(GL_UNPACK_ALIGNMENT, 1);
 
-  if(isStereoViewing())
-    glColor3fv(SbVec3f(1.0f, 1.0f, 1.0f).getValue());
-  else
-    glColor3fv(SbVec3f(0.0f, 0.0f, 0.0f).getValue());
+    if(isStereoViewing())
+        glColor3fv(SbVec3f(1.0f, 1.0f, 1.0f).getValue());
+    else
+        glColor3fv(SbVec3f(0.0f, 0.0f, 0.0f).getValue());
 
-  glRasterPos2d(xpos[0], xpos[1]);
-  glBitmap(8, 7, 0, 0, 0, 0, xbmp);
-  glRasterPos2d(ypos[0], ypos[1]);
-  glBitmap(8, 7, 0, 0, 0, 0, ybmp);
-  glRasterPos2d(zpos[0], zpos[1]);
-  glBitmap(8, 7, 0, 0, 0, 0, zbmp);
+    glRasterPos2d(xpos[0], xpos[1]);
+    glBitmap(8, 7, 0, 0, 0, 0, xbmp);
+    glRasterPos2d(ypos[0], ypos[1]);
+    glBitmap(8, 7, 0, 0, 0, 0, ybmp);
+    glRasterPos2d(zpos[0], zpos[1]);
+    glBitmap(8, 7, 0, 0, 0, 0, zbmp);
 
-  glPixelStorei(GL_UNPACK_ALIGNMENT, unpack);
-  glPopMatrix();
+    glPixelStorei(GL_UNPACK_ALIGNMENT, unpack);
+    glPopMatrix();
 
-  // Reset original state.
+    // Reset original state.
 
-  // FIXME: are these 3 lines really necessary, as we push
-  // GL_ALL_ATTRIB_BITS at the start? 20000604 mortene.
-  glDepthRange(depthrange[0], depthrange[1]);
-  glMatrixMode(GL_PROJECTION);
-  glLoadMatrixd(projectionmatrix);
+    // FIXME: are these 3 lines really necessary, as we push
+    // GL_ALL_ATTRIB_BITS at the start? 20000604 mortene.
+    glDepthRange(depthrange[0], depthrange[1]);
+    glMatrixMode(GL_PROJECTION);
+    glLoadMatrixd(projectionmatrix);
 
-  glPopAttrib();
+    glPopAttrib();
 }
 
 // Draw an arrow for the axis representation directly through OpenGL.
@@ -1995,16 +2084,17 @@ static unsigned char hand_mask_bitmap[] = {
 #define CROSS_HOT_Y 7
 
 static unsigned char cross_bitmap[] = {
-  0xc0, 0x03, 0x40, 0x02, 0x40, 0x02, 0x40, 0x02,
-  0x40, 0x02, 0x40, 0x02, 0x7f, 0xfe, 0x01, 0x80,
-  0x01, 0x80, 0x7f, 0xfe, 0x40, 0x02, 0x40, 0x02,
-  0x40, 0x02, 0x40, 0x02, 0x40, 0x02, 0xc0, 0x03
+    0xc0, 0x03, 0x40, 0x02, 0x40, 0x02, 0x40, 0x02,
+    0x40, 0x02, 0x40, 0x02, 0x7f, 0xfe, 0x01, 0x80,
+    0x01, 0x80, 0x7f, 0xfe, 0x40, 0x02, 0x40, 0x02,
+    0x40, 0x02, 0x40, 0x02, 0x40, 0x02, 0xc0, 0x03
 };
 
 static unsigned char cross_mask_bitmap[] = {
- 0xc0,0x03,0xc0,0x03,0xc0,0x03,0xc0,0x03,0xc0,0x03,0xc0,0x03,0xff,0xff,0xff,
- 0xff,0xff,0xff,0xff,0xff,0xc0,0x03,0xc0,0x03,0xc0,0x03,0xc0,0x03,0xc0,0x03,
- 0xc0,0x03
+    0xc0, 0x03, 0xc0, 0x03, 0xc0, 0x03, 0xc0, 0x03,
+    0xc0, 0x03, 0xc0, 0x03, 0xff, 0xff, 0xff, 0xff,
+    0xff, 0xff, 0xff, 0xff, 0xc0, 0x03, 0xc0, 0x03,
+    0xc0, 0x03, 0xc0, 0x03, 0xc0, 0x03, 0xc0, 0x03
 };
 
 // Set cursor graphics according to mode.
@@ -2190,46 +2280,105 @@ std::vector<ViewProvider*> View3DInventorViewer::getViewProvidersOfType(const Ba
 
 void View3DInventorViewer::turnAllDimensionsOn()
 {
-  dimensionRoot->whichChild = SO_SWITCH_ALL;
+    dimensionRoot->whichChild = SO_SWITCH_ALL;
 }
 
 void View3DInventorViewer::turnAllDimensionsOff()
 {
-  dimensionRoot->whichChild = SO_SWITCH_NONE;
+    dimensionRoot->whichChild = SO_SWITCH_NONE;
 }
 
 void View3DInventorViewer::eraseAllDimensions()
 {
-  static_cast<SoSwitch *>(dimensionRoot->getChild(0))->removeAllChildren();
-  static_cast<SoSwitch *>(dimensionRoot->getChild(1))->removeAllChildren();
+    static_cast<SoSwitch *>(dimensionRoot->getChild(0))->removeAllChildren();
+    static_cast<SoSwitch *>(dimensionRoot->getChild(1))->removeAllChildren();
 }
 
 void View3DInventorViewer::turn3dDimensionsOn()
 {
-  static_cast<SoSwitch *>(dimensionRoot->getChild(0))->whichChild = SO_SWITCH_ALL;
+    static_cast<SoSwitch *>(dimensionRoot->getChild(0))->whichChild = SO_SWITCH_ALL;
 }
 
 void View3DInventorViewer::turn3dDimensionsOff()
 {
-  static_cast<SoSwitch *>(dimensionRoot->getChild(0))->whichChild = SO_SWITCH_NONE;
+    static_cast<SoSwitch *>(dimensionRoot->getChild(0))->whichChild = SO_SWITCH_NONE;
 }
 
 void View3DInventorViewer::addDimension3d(SoNode *node)
 {
-  static_cast<SoSwitch *>(dimensionRoot->getChild(0))->addChild(node);
+    static_cast<SoSwitch *>(dimensionRoot->getChild(0))->addChild(node);
 }
 
 void View3DInventorViewer::addDimensionDelta(SoNode *node)
 {
-  static_cast<SoSwitch *>(dimensionRoot->getChild(1))->addChild(node);
+    static_cast<SoSwitch *>(dimensionRoot->getChild(1))->addChild(node);
 }
 
 void View3DInventorViewer::turnDeltaDimensionsOn()
 {
-  static_cast<SoSwitch *>(dimensionRoot->getChild(1))->whichChild = SO_SWITCH_ALL;
+    static_cast<SoSwitch *>(dimensionRoot->getChild(1))->whichChild = SO_SWITCH_ALL;
 }
 
 void View3DInventorViewer::turnDeltaDimensionsOff()
 {
-  static_cast<SoSwitch *>(dimensionRoot->getChild(1))->whichChild = SO_SWITCH_NONE;
+    static_cast<SoSwitch *>(dimensionRoot->getChild(1))->whichChild = SO_SWITCH_NONE;
+}
+
+void View3DInventorViewer::setAntiAliasingMode(View3DInventorViewer::AntiAliasing mode)
+{
+    int buffers = 1;
+    SbBool smoothing = false;
+
+    switch( mode ) {
+      case Smoothing:
+          smoothing = true;
+          break;
+      case MSAA2x:
+          buffers = 2;
+          break;
+      case MSAA4x:
+          buffers = 4;
+          break;
+      case MSAA8x:
+          buffers = 8;
+          break;
+      case None:
+      default:
+          break;
+    };
+
+    if (getGLRenderAction()->isSmoothing() != smoothing)
+        getGLRenderAction()->setSmoothing(smoothing);
+#if SOQT_MAJOR_VERSION > 1 || (SOQT_MAJOR_VERSION == 1 && SOQT_MINOR_VERSION >= 5)
+    if (getSampleBuffers() != buffers)
+        setSampleBuffers(buffers);
+#else
+    if (buffers > 1)
+        Base::Console().Warning("Multisampling is not supported by SoQT < 1.5, this anti-aliasing mode is disabled");
+#endif
+}
+
+View3DInventorViewer::AntiAliasing View3DInventorViewer::getAntiAliasingMode() const
+{
+    if (getGLRenderAction()->isSmoothing())
+        return Smoothing;
+
+#if SOQT_MAJOR_VERSION > 1 || (SOQT_MAJOR_VERSION == 1 && SOQT_MINOR_VERSION >= 5)
+    int buffers = getSampleBuffers();
+    switch(buffers) {
+      case 1:
+          return None;
+      case 2:
+          return MSAA2x;
+      case 4:
+          return MSAA4x;
+      case 8:
+          return MSAA8x;
+      default:
+          const_cast<View3DInventorViewer*>(this)->setSampleBuffers(1);
+          return None;
+    };
+#else
+    return None;
+#endif
 }
