@@ -52,6 +52,8 @@
 #include <Base/Exception.h>
 #include <Base/Interpreter.h>
 #include <Base/PlacementPy.h>
+#include <Base/Rotation.h>
+#include <Base/RotationPy.h>
 #include <Base/VectorPy.h>
 #include <Base/GeometryPyCXX.h>
 
@@ -83,6 +85,8 @@ void View3DInventorPy::init_type()
     add_varargs_method("viewAxometric",&View3DInventorPy::viewAxometric,"viewAxometric()");
     add_varargs_method("viewRotateLeft",&View3DInventorPy::viewRotateLeft,"viewRotateLeft()");
     add_varargs_method("viewRotateRight",&View3DInventorPy::viewRotateRight,"viewRotateRight()");
+    add_varargs_method("zoomIn",&View3DInventorPy::zoomIn,"zoomIn()");
+    add_varargs_method("zoomOut",&View3DInventorPy::zoomOut,"zoomOut()");
     add_varargs_method("viewPosition",&View3DInventorPy::viewPosition,"viewPosition()");
     add_varargs_method("startAnimating",&View3DInventorPy::startAnimating,"startAnimating()");
     add_varargs_method("stopAnimating",&View3DInventorPy::stopAnimating,"stopAnimating()");
@@ -100,6 +104,7 @@ void View3DInventorPy::init_type()
     add_varargs_method("getViewDirection",&View3DInventorPy::getViewDirection,"getViewDirection()");
     add_varargs_method("setCamera",&View3DInventorPy::setCamera,"setCamera()");
     add_varargs_method("setCameraOrientation",&View3DInventorPy::setCameraOrientation,"setCameraOrientation()");
+    add_varargs_method("getCameraOrientation",&View3DInventorPy::getCameraOrientation,"getCameraOrientation()");
     add_varargs_method("getCameraType",&View3DInventorPy::getCameraType,"getCameraType()");
     add_varargs_method("setCameraType",&View3DInventorPy::setCameraType,"setCameraType()");
     add_varargs_method("listCameraTypes",&View3DInventorPy::listCameraTypes,"listCameraTypes()");
@@ -146,7 +151,16 @@ void View3DInventorPy::init_type()
     add_varargs_method("setNavigationType",&View3DInventorPy::setNavigationType,"setNavigationType()");
     add_varargs_method("setAxisCross",&View3DInventorPy::setAxisCross,"switch the big axis-cross on and off");
     add_varargs_method("hasAxisCross",&View3DInventorPy::hasAxisCross,"check if the big axis-cross is on or off()");
-
+    add_varargs_method("addDraggerCallback",&View3DInventorPy::addDraggerCallback,
+        "addDraggerCallback(SoDragger, String CallbackType, function)\n"
+        "Add a DraggerCalback function to the coin node\n"
+        "Possibles types :\n"
+        "'addFinishCallback','addStartCallback','addMotionCallback','addValueChangedCallback'\n");
+    add_varargs_method("removeDraggerCallback",&View3DInventorPy::removeDraggerCallback,
+        "removeDraggerCallback(SoDragger, String CallbackType, function)\n"
+        "Remove the DraggerCalback function from the coin node\n"
+        "Possibles types :\n"
+        "'addFinishCallback','addStartCallback','addMotionCallback','addValueChangedCallback'\n");
 }
 
 View3DInventorPy::View3DInventorPy(View3DInventor *vi)
@@ -473,20 +487,13 @@ Py::Object View3DInventorPy::viewRotateRight(const Py::Tuple& args)
     return Py::None();
 }
 
-Py::Object View3DInventorPy::setCameraOrientation(const Py::Tuple& args)
+Py::Object View3DInventorPy::zoomIn(const Py::Tuple& args)
 {
-    PyObject* o;
-    PyObject* m=Py_False;
-    if (!PyArg_ParseTuple(args.ptr(), "O!|O!", &PyTuple_Type, &o, &PyBool_Type, &m))
+    if (!PyArg_ParseTuple(args.ptr(), ""))
         throw Py::Exception();
 
     try {
-        Py::Tuple tuple(o);
-        float q0 = (float)Py::Float(tuple[0]);
-        float q1 = (float)Py::Float(tuple[1]);
-        float q2 = (float)Py::Float(tuple[2]);
-        float q3 = (float)Py::Float(tuple[3]);
-        _view->getViewer()->setCameraOrientation(SbRotation(q0, q1, q2, q3), PyObject_IsTrue(m));
+        _view->getViewer()->navigationStyle()->zoomIn();
     }
     catch (const Base::Exception& e) {
         throw Py::Exception(e.what());
@@ -501,6 +508,79 @@ Py::Object View3DInventorPy::setCameraOrientation(const Py::Tuple& args)
     return Py::None();
 }
 
+Py::Object View3DInventorPy::zoomOut(const Py::Tuple& args)
+{
+    if (!PyArg_ParseTuple(args.ptr(), ""))
+        throw Py::Exception();
+
+    try {
+        _view->getViewer()->navigationStyle()->zoomOut();
+    }
+    catch (const Base::Exception& e) {
+        throw Py::Exception(e.what());
+    }
+    catch (const std::exception& e) {
+        throw Py::Exception(e.what());
+    }
+    catch(...) {
+        throw Py::Exception("Unknown C++ exception");
+    }
+
+    return Py::None();
+}
+
+Py::Object View3DInventorPy::setCameraOrientation(const Py::Tuple& args)
+{
+    PyObject* o;
+    PyObject* m=Py_False;
+    if (!PyArg_ParseTuple(args.ptr(), "O|O!", &o, &PyBool_Type, &m))
+        throw Py::Exception();
+
+    try {
+        if (PyTuple_Check(o)) {
+            Py::Tuple tuple(o);
+            float q0 = (float)Py::Float(tuple[0]);
+            float q1 = (float)Py::Float(tuple[1]);
+            float q2 = (float)Py::Float(tuple[2]);
+            float q3 = (float)Py::Float(tuple[3]);
+            _view->getViewer()->setCameraOrientation(SbRotation(q0, q1, q2, q3), PyObject_IsTrue(m));
+        }
+        else if (PyObject_TypeCheck(o, &Base::RotationPy::Type)) {
+            Base::Rotation r = (Base::Rotation)Py::Rotation(o,false);
+            double q0, q1, q2, q3;
+            r.getValue(q0, q1, q2, q3);
+            _view->getViewer()->setCameraOrientation(SbRotation((float)q0, (float)q1, (float)q2, (float)q3), PyObject_IsTrue(m));
+        }
+        else {
+            throw Py::ValueError("Neither tuple nor rotation object");
+        }
+    }
+    catch (const Py::Exception&) {
+        throw; // re-throw
+    }
+    catch (const Base::Exception& e) {
+        throw Py::Exception(e.what());
+    }
+    catch (const std::exception& e) {
+        throw Py::Exception(e.what());
+    }
+    catch(...) {
+        throw Py::Exception("Unknown C++ exception");
+    }
+
+    return Py::None();
+}
+
+Py::Object View3DInventorPy::getCameraOrientation(const Py::Tuple& args)
+{
+    if (!PyArg_ParseTuple(args.ptr(), ""))
+        throw Py::Exception();
+    SbRotation rot = _view->getViewer()->getCameraOrientation();
+    float q0,q1,q2,q3;
+    rot.getValue(q0,q1,q2,q3);
+    return Py::Rotation(Base::Rotation(q0,q1,q2,q3));
+}
+
 Py::Object View3DInventorPy::viewPosition(const Py::Tuple& args)
 {
     PyObject* p=0;
@@ -2120,4 +2200,135 @@ Py::Object View3DInventorPy::hasAxisCross(const Py::Tuple& args)
         throw Py::Exception();
     SbBool ok = _view->getViewer()->hasAxisCross();
     return Py::Boolean(ok ? true : false);
-}
\ No newline at end of file
+}
+
+void View3DInventorPy::draggerCallback(void * ud, SoDragger* n)
+{
+    Base::PyGILStateLocker lock;
+    PyObject* proxy = 0;
+    try {
+        proxy = Base::Interpreter().createSWIGPointerObj("pivy.coin", "SoDragger *", (void*)n, 0);
+        //call the method
+        Py::Object dragger(proxy,true);
+        Py::Callable method(reinterpret_cast<PyObject*>(ud));
+        Py::Tuple args(1);
+        args.setItem(0, dragger);
+        method.apply(args);
+    }
+    catch (const Base::Exception& e) {
+        throw Py::Exception(e.what());
+    }
+    catch (const Py::Exception& e) {
+        Py::Object o = Py::type(e);
+        if (o.isString()) {
+            Py::String s(o);
+            Base::Console().Warning("%s\n", s.as_std_string().c_str());
+        }
+        else {
+            Py::String s(o.repr());
+            Base::Console().Warning("%s\n", s.as_std_string().c_str());
+        }
+        // Prints message to console window if we are in interactive mode
+        PyErr_Print();
+    }
+}
+
+Py::Object View3DInventorPy::addDraggerCallback(const Py::Tuple& args)
+{
+    PyObject* dragger;
+    char* type;
+    PyObject* method;
+    if (!PyArg_ParseTuple(args.ptr(), "OsO", &dragger,&type, &method))
+        throw Py::Exception();
+
+
+    //Check if dragger is a SoDragger object and cast
+    void* ptr = 0;
+    try {
+        Base::Interpreter().convertSWIGPointerObj("pivy.coin", "SoDragger *", dragger, &ptr, 0);
+    }
+    catch (const Base::Exception&) {
+        throw Py::Exception("The first argument must be of type SoDragger");
+    }
+    SoDragger* drag = reinterpret_cast<SoDragger*>(ptr);
+
+    //Check if method is callable
+    if (PyCallable_Check(method) == 0) {
+        throw Py::Exception("the method is not callable");
+    }
+
+    try {
+        if (strcmp(type,"addFinishCallback")==0) {
+            drag->addFinishCallback(draggerCallback,method);
+        }
+        else if (strcmp(type,"addStartCallback")==0) {
+            drag->addStartCallback(draggerCallback,method);
+        }
+        else if (strcmp(type,"addMotionCallback")==0) {
+            drag->addMotionCallback(draggerCallback,method);
+        }
+        else if (strcmp(type,"addValueChangedCallback")==0) {
+            drag->addValueChangedCallback(draggerCallback,method);
+        }
+        else {
+            std::string s;
+            std::ostringstream s_out;
+            s_out << type << " is not a valid dragger callback type";
+            throw Py::Exception(s_out.str());
+        }
+
+        callbacks.push_back(method);
+        Py_INCREF(method);
+        return Py::Callable(method, false);
+    }
+    catch (const Py::Exception&) {
+        throw;
+    }
+}
+
+Py::Object View3DInventorPy::removeDraggerCallback(const Py::Tuple& args)
+{
+    PyObject* dragger;
+    char* type;
+    PyObject* method;
+    if (!PyArg_ParseTuple(args.ptr(), "OsO", &dragger,&type, &method))
+        throw Py::Exception();
+
+    //Check if dragger is a SoDragger object and cast
+    void* ptr = 0;
+    try {
+        Base::Interpreter().convertSWIGPointerObj("pivy.coin", "SoDragger *", dragger, &ptr, 0);
+    }
+    catch (const Base::Exception&) {
+        throw Py::Exception("The first argument must be of type SoDragger");
+    }
+
+    SoDragger* drag = reinterpret_cast<SoDragger*>(ptr);
+    try {
+        if (strcmp(type,"addFinishCallback")==0) {
+            drag->removeFinishCallback(draggerCallback,method);
+        }
+        else if (strcmp(type,"addStartCallback")==0) {
+            drag->removeStartCallback(draggerCallback,method);
+        }
+        else if (strcmp(type,"addMotionCallback")==0) {
+            drag->removeMotionCallback(draggerCallback,method);
+        }
+        else if (strcmp(type,"addValueChangedCallback")==0) {
+            drag->removeValueChangedCallback(draggerCallback,method);
+        }
+        else {
+            std::string s;
+            std::ostringstream s_out;
+            s_out << type << " is not a valid dragger callback type";
+            throw Py::Exception(s_out.str());
+        }
+
+        callbacks.remove(method);
+        Py_DECREF(method);
+        return Py::Callable(method, false);
+    }
+    catch (const Py::Exception&) {
+        throw;
+    }
+}
