@@ -32,10 +32,10 @@
 # include <QPixmap>
 # include <QSpinBox>
 # include <QTextStream>
+# include <QTimer>
 #endif
 
 #include <Base/Tools.h>
-#include <Base/UnitsApi.h>
 #include <App/Application.h>
 #include <App/Document.h>
 #include <App/DocumentObject.h>
@@ -49,6 +49,8 @@
 #include <Gui/ViewProviderDocumentObject.h>
 #include <Gui/Placement.h>
 #include <Gui/FileDialog.h>
+#include <Gui/DlgPropertyLink.h>
+#include <Gui/InputField.h>
 
 #include "PropertyItem.h"
 
@@ -546,30 +548,6 @@ QVariant PropertyFloatItem::toString(const QVariant& prop) const
 {
     double value = prop.toDouble();
     QString data = QLocale::system().toString(value, 'f', decimals());
-    const std::vector<App::Property*>& props = getPropertyData();
-    if (!props.empty()) {
-        if (props.front()->getTypeId().isDerivedFrom(App::PropertyDistance::getClassTypeId())) {
-            QString unit = QString::fromAscii("mm");
-            unit.prepend(QLatin1String(" "));
-            data += unit;
-        }
-        else if (props.front()->getTypeId().isDerivedFrom(App::PropertyLength::getClassTypeId())) {
-            QString unit = QString::fromAscii("mm");
-            unit.prepend(QLatin1String(" "));
-            data += unit;
-        }
-        else if (props.front()->getTypeId().isDerivedFrom(App::PropertySpeed::getClassTypeId())) {
-            //QString unit = Base::UnitsApi::getPrefUnitOf(Base::Acceleration);
-            //unit.prepend(QLatin1String(" "));
-            //data += unit;
-        }
-        else if (props.front()->getTypeId().isDerivedFrom(App::PropertyAcceleration::getClassTypeId())) {
-            QString unit = QString::fromAscii("mm/s^2");
-            unit.prepend(QLatin1String(" "));
-            data += unit;
-        }
-    }
-
     return QVariant(data);
 }
 
@@ -604,32 +582,6 @@ void PropertyFloatItem::setEditorData(QWidget *editor, const QVariant& data) con
     QDoubleSpinBox *sb = qobject_cast<QDoubleSpinBox*>(editor);
     sb->setRange((double)INT_MIN, (double)INT_MAX);
     sb->setValue(data.toDouble());
-    const std::vector<App::Property*>& prop = getPropertyData();
-    if (prop.empty())
-        return;
-    else if (prop.front()->getTypeId().isDerivedFrom(App::PropertyDistance::getClassTypeId())) {
-        QString unit = QString::fromAscii("mm");
-        unit.prepend(QLatin1String(" "));
-        sb->setSuffix(unit);
-    }
-    else if (prop.front()->getTypeId().isDerivedFrom(App::PropertyLength::getClassTypeId())) {
-        sb->setMinimum(0.0);
-        QString unit = QString::fromAscii("mm");
-        unit.prepend(QLatin1String(" "));
-        sb->setSuffix(unit);
-    }
-    else if (prop.front()->getTypeId().isDerivedFrom(App::PropertySpeed::getClassTypeId())) {
-        //sb->setMinimum(0.0);
-        //QString unit = Base::UnitsApi::getPrefUnitOf(Base::Acceleration);
-        //unit.prepend(QLatin1String(" "));
-        //sb->setSuffix(unit);
-    }
-    else if (prop.front()->getTypeId().isDerivedFrom(App::PropertyAcceleration::getClassTypeId())) {
-        sb->setMinimum(0.0);
-        QString unit = QString::fromAscii("mm/s^2");
-        unit.prepend(QLatin1String(" "));
-        sb->setSuffix(unit);
-    }
 }
 
 QVariant PropertyFloatItem::editorData(QWidget *editor) const
@@ -647,77 +599,86 @@ PropertyUnitItem::PropertyUnitItem()
 {
 }
 
-QVariant PropertyUnitItem::toString(const QVariant& Value) const
+QVariant PropertyUnitItem::toString(const QVariant& prop) const
 {
-    double val = Value.toDouble();
-
-    QString unit;
-    const std::vector<App::Property*>& prop = getPropertyData();
-    if (!prop.empty() && prop.front()->getTypeId().isDerivedFrom(App::PropertyQuantity::getClassTypeId())) {
-        Base::Quantity value = static_cast<const App::PropertyQuantity*>(prop.front())->getQuantityValue();
-        unit = value.getUserString();        
-    }
-
-    return QVariant(unit);
+    const Base::Quantity& unit = prop.value<Base::Quantity>();
+    return QVariant(unit.getUserString());
 }
 
 QVariant PropertyUnitItem::value(const App::Property* prop) const
 {
     assert(prop && prop->getTypeId().isDerivedFrom(App::PropertyQuantity::getClassTypeId()));
+
     Base::Quantity value = static_cast<const App::PropertyQuantity*>(prop)->getQuantityValue();
-    QString unitString;
-    return QVariant(value.getValue());
+    return QVariant::fromValue<Base::Quantity>(value);
 }
 
 void PropertyUnitItem::setValue(const QVariant& value)
 {
-    if (!value.canConvert(QVariant::Double))
+    if (!value.canConvert<Base::Quantity>())
         return;
-    double val = value.toDouble();
-
-    QString unit;
-    const std::vector<App::Property*>& prop = getPropertyData();
-    if (prop.empty())
-        return;
-    else if (prop.front()->getTypeId().isDerivedFrom(App::PropertyQuantity::getClassTypeId())) {
-        Base::Quantity value = static_cast<const App::PropertyQuantity*>(prop.front())->getQuantityValue();
-        unit = value.getUserString();
-    }
+    const Base::Quantity& val = value.value<Base::Quantity>();
 
+    QString unit = QString::fromLatin1("'%1 %2'").arg(val.getValue()).arg(val.getUnit().getString()); 
     setPropertyValue(unit);
 }
 
 QWidget* PropertyUnitItem::createEditor(QWidget* parent, const QObject* receiver, const char* method) const
 {
-    QDoubleSpinBox *sb = new QDoubleSpinBox(parent);
-    sb->setFrame(false);
-    sb->setDecimals(decimals());
-    QObject::connect(sb, SIGNAL(valueChanged(double)), receiver, method);
-    return sb;
+    Gui::InputField *infield = new Gui::InputField(parent);
+    infield->setFrame(false);
+    infield->setMinimumHeight(0);
+    QObject::connect(infield, SIGNAL(valueChanged(double)), receiver, method);
+    return infield;
 }
 
 void PropertyUnitItem::setEditorData(QWidget *editor, const QVariant& data) const
 {
-    QDoubleSpinBox *sb = qobject_cast<QDoubleSpinBox*>(editor);
-    sb->setRange((double)INT_MIN, (double)INT_MAX);
-    sb->setValue(data.toDouble());
-    const std::vector<App::Property*>& prop = getPropertyData();
-    if (prop.empty())
-        return;
-    else if (prop.front()->getTypeId().isDerivedFrom(App::PropertyQuantity::getClassTypeId())) {
-        Base::Quantity value = static_cast<const App::PropertyQuantity*>(prop.front())->getQuantityValue();
-        QString unitString;
-        //double factor;
-        //value.getUserString(unitString);
-        //unitString.prepend(QLatin1String(" "));
-        //sb->setSuffix(unitString);
-    }
+    const Base::Quantity& value = data.value<Base::Quantity>();
+
+    Gui::InputField *infield = qobject_cast<Gui::InputField*>(editor);
+    infield->setValue(value);
 }
 
 QVariant PropertyUnitItem::editorData(QWidget *editor) const
 {
-    QDoubleSpinBox *sb = qobject_cast<QDoubleSpinBox*>(editor);
-    return QVariant(sb->value());
+    Gui::InputField *infield = qobject_cast<Gui::InputField*>(editor);
+    Base::Quantity value = infield->getQuantity();
+    return QVariant::fromValue<Base::Quantity>(value);
+}
+
+// --------------------------------------------------------------------
+
+
+TYPESYSTEM_SOURCE(Gui::PropertyEditor::PropertyUnitConstraintItem, Gui::PropertyEditor::PropertyUnitItem);
+
+PropertyUnitConstraintItem::PropertyUnitConstraintItem()
+{
+
+}
+
+void PropertyUnitConstraintItem::setEditorData(QWidget *editor, const QVariant& data) const
+{
+    const Base::Quantity& value = data.value<Base::Quantity>();
+
+    Gui::InputField *infield = qobject_cast<Gui::InputField*>(editor);
+    infield->setValue(value);
+
+    const std::vector<App::Property*>& items = getPropertyData();
+    App::PropertyQuantityConstraint* prop = (App::PropertyQuantityConstraint*)items[0];
+
+    const App::PropertyQuantityConstraint::Constraints* c = 
+        ((App::PropertyQuantityConstraint*)prop)->getConstraints();
+
+    if (c) {
+        infield->setMinimum(c->LowerBound);
+        infield->setMaximum(c->UpperBound);
+        infield->setSingleStep(c->StepSize);
+    }
+    else {
+        infield->setMinimum((double)INT_MIN);
+        infield->setMaximum((double)INT_MAX);
+    }
 }
 
 // --------------------------------------------------------------------
@@ -797,7 +758,7 @@ PropertyAngleItem::PropertyAngleItem()
 
 void PropertyAngleItem::setEditorData(QWidget *editor, const QVariant& data) const
 {
-    const App::PropertyFloatConstraint::Constraints* c = 0;
+    const App::PropertyQuantityConstraint::Constraints* c = 0;
     const std::vector<App::Property*>& items = getPropertyData();
     if (!items.empty()) {
         App::PropertyAngle* prop = static_cast<App::PropertyAngle*>(items[0]);
@@ -980,6 +941,113 @@ void PropertyVectorItem::setZ(double z)
     setData(QVariant::fromValue(Base::Vector3d(x(), y(), z)));
 }
 
+
+// ---------------------------------------------------------------
+
+TYPESYSTEM_SOURCE(Gui::PropertyEditor::PropertyVectorDistanceItem, Gui::PropertyEditor::PropertyItem);
+
+PropertyVectorDistanceItem::PropertyVectorDistanceItem()
+{
+    m_x = static_cast<PropertyUnitItem*>(PropertyUnitItem::create());
+    m_x->setParent(this);
+    m_x->setPropertyName(QLatin1String("x"));
+    this->appendChild(m_x);
+    m_y = static_cast<PropertyUnitItem*>(PropertyUnitItem::create());
+    m_y->setParent(this);
+    m_y->setPropertyName(QLatin1String("y"));
+    this->appendChild(m_y);
+    m_z = static_cast<PropertyUnitItem*>(PropertyUnitItem::create());
+    m_z->setParent(this);
+    m_z->setPropertyName(QLatin1String("z"));
+    this->appendChild(m_z);
+}
+
+QVariant PropertyVectorDistanceItem::toString(const QVariant& prop) const
+{
+    const Base::Vector3d& value = prop.value<Base::Vector3d>();
+    QString data = QString::fromAscii("[") + 
+           Base::Quantity(value.x, Base::Unit::Length).getUserString() + QString::fromAscii("  ") +
+           Base::Quantity(value.y, Base::Unit::Length).getUserString() + QString::fromAscii("  ") +
+           Base::Quantity(value.z, Base::Unit::Length).getUserString() + QString::fromAscii("]");
+    return QVariant(data);
+}
+
+
+QVariant PropertyVectorDistanceItem::value(const App::Property* prop) const
+{
+    assert(prop && prop->getTypeId().isDerivedFrom(App::PropertyVector::getClassTypeId()));
+
+    const Base::Vector3d& value = static_cast<const App::PropertyVector*>(prop)->getValue();
+    return QVariant::fromValue<Base::Vector3d>(value);
+}
+
+void PropertyVectorDistanceItem::setValue(const QVariant& variant)
+{
+    if (!variant.canConvert<Base::Vector3d>())
+        return;
+    const Base::Vector3d& value = variant.value<Base::Vector3d>();
+
+    Base::Quantity q = Base::Quantity(value.x, Base::Unit::Length);
+    QString unit = QString::fromLatin1("('%1 %2'").arg(q.getValue()).arg(q.getUnit().getString());
+    q = Base::Quantity(value.y, Base::Unit::Length);
+    unit + QString::fromLatin1("'%1 %2'").arg(q.getValue()).arg(q.getUnit().getString());
+    q = Base::Quantity(value.z, Base::Unit::Length);
+    QString::fromLatin1("'%1 %2')").arg(q.getValue()).arg(q.getUnit().getString());
+
+    setPropertyValue(unit);
+}
+
+void PropertyVectorDistanceItem::setEditorData(QWidget *editor, const QVariant& data) const
+{
+    QLineEdit* le = qobject_cast<QLineEdit*>(editor);
+    le->setText(toString(data).toString());
+}
+
+QWidget* PropertyVectorDistanceItem::createEditor(QWidget* parent, const QObject* /*receiver*/, const char* /*method*/) const
+{
+    QLineEdit *le = new QLineEdit(parent);
+    le->setFrame(false);
+    le->setReadOnly(true);
+    return le;
+}
+
+QVariant PropertyVectorDistanceItem::editorData(QWidget *editor) const
+{
+    QLineEdit *le = qobject_cast<QLineEdit*>(editor);
+    return QVariant(le->text());
+}
+
+Base::Quantity PropertyVectorDistanceItem::x() const
+{
+    return Base::Quantity(data(1,Qt::EditRole).value<Base::Vector3d>().x, Base::Unit::Length);
+}
+
+void PropertyVectorDistanceItem::setX(Base::Quantity x)
+{
+    setData(QVariant::fromValue(Base::Vector3d(x.getValue(), y().getValue(), z().getValue())));
+}
+
+Base::Quantity PropertyVectorDistanceItem::y() const
+{
+    return Base::Quantity(data(1,Qt::EditRole).value<Base::Vector3d>().y, Base::Unit::Length);
+}
+
+void PropertyVectorDistanceItem::setY(Base::Quantity y)
+{
+    setData(QVariant::fromValue(Base::Vector3d(x().getValue(), y.getValue(), z().getValue())));
+}
+
+Base::Quantity PropertyVectorDistanceItem::z() const
+{
+    return Base::Quantity(data(1,Qt::EditRole).value<Base::Vector3d>().z, Base::Unit::Length);
+}
+
+void PropertyVectorDistanceItem::setZ(Base::Quantity z)
+{
+    setData(QVariant::fromValue(Base::Vector3d(x().getValue(), y().getValue(), z.getValue())));
+}
+
+
 // ---------------------------------------------------------------
 
 TYPESYSTEM_SOURCE(Gui::PropertyEditor::PropertyMatrixItem, Gui::PropertyEditor::PropertyItem);
@@ -1405,9 +1473,9 @@ void PlacementEditor::updateValue(const QVariant& v, bool incr, bool data)
 
 TYPESYSTEM_SOURCE(Gui::PropertyEditor::PropertyPlacementItem, Gui::PropertyEditor::PropertyItem);
 
-PropertyPlacementItem::PropertyPlacementItem() : init_axis(false), changed_value(false), rot_axis(0,0,1)
+PropertyPlacementItem::PropertyPlacementItem() : init_axis(false), changed_value(false), rot_angle(0), rot_axis(0,0,1)
 {
-    m_a = static_cast<PropertyAngleItem*>(PropertyAngleItem::create());
+    m_a = static_cast<PropertyUnitItem*>(PropertyUnitItem::create());
     m_a->setParent(this);
     m_a->setPropertyName(QLatin1String("Angle"));
     this->appendChild(m_a);
@@ -1416,7 +1484,7 @@ PropertyPlacementItem::PropertyPlacementItem() : init_axis(false), changed_value
     m_d->setPropertyName(QLatin1String("Axis"));
     m_d->setReadOnly(true);
     this->appendChild(m_d);
-    m_p = static_cast<PropertyVectorItem*>(PropertyVectorItem::create());
+    m_p = static_cast<PropertyVectorDistanceItem*>(PropertyVectorDistanceItem::create());
     m_p->setParent(this);
     m_p->setPropertyName(QLatin1String("Position"));
     m_p->setReadOnly(true);
@@ -1427,7 +1495,7 @@ PropertyPlacementItem::~PropertyPlacementItem()
 {
 }
 
-double PropertyPlacementItem::getAngle() const
+Base::Quantity PropertyPlacementItem::getAngle() const
 {
     QVariant value = data(1, Qt::EditRole);
     if (!value.canConvert<Base::Placement>())
@@ -1438,10 +1506,10 @@ double PropertyPlacementItem::getAngle() const
     val.getRotation().getValue(dir, angle);
     if (dir * this->rot_axis < 0.0)
         angle = -angle;
-    return Base::toDegrees<double>(angle);
+    return Base::Quantity(Base::toDegrees<double>(angle), Base::Unit::Angle);
 }
 
-void PropertyPlacementItem::setAngle(double angle)
+void PropertyPlacementItem::setAngle(Base::Quantity angle)
 {
     QVariant value = data(1, Qt::EditRole);
     if (!value.canConvert<Base::Placement>())
@@ -1449,9 +1517,10 @@ void PropertyPlacementItem::setAngle(double angle)
 
     Base::Placement val = value.value<Base::Placement>();
     Base::Rotation rot;
-    rot.setValue(this->rot_axis, Base::toRadians<double>(angle));
+    rot.setValue(this->rot_axis, Base::toRadians<double>(angle.getValue()));
     val.setRotation(rot);
     changed_value = true;
+    rot_angle = angle.getValue();
     setValue(QVariant::fromValue(val));
 }
 
@@ -1512,6 +1581,7 @@ QVariant PropertyPlacementItem::value(const App::Property* prop) const
     value.getRotation().getValue(dir, angle);
     if (!init_axis) {
         const_cast<PropertyPlacementItem*>(this)->rot_axis = dir;
+        const_cast<PropertyPlacementItem*>(this)->rot_angle = Base::toDegrees(angle);
         const_cast<PropertyPlacementItem*>(this)->init_axis = true;
     }
     return QVariant::fromValue<Base::Placement>(value);
@@ -1528,15 +1598,15 @@ QVariant PropertyPlacementItem::toolTip(const App::Property* prop) const
     angle = Base::toDegrees<double>(angle);
     pos = p.getPosition();
     QString data = QString::fromUtf8("Axis: (%1 %2 %3)\n"
-                                     "Angle: %4 \xc2\xb0\n"
-                                     "Position: (%5 %6 %7)")
+                                     "Angle: %4\n"
+                                     "Position: (%5  %6  %7)")
                     .arg(QLocale::system().toString(dir.x,'f',decimals()))
                     .arg(QLocale::system().toString(dir.y,'f',decimals()))
                     .arg(QLocale::system().toString(dir.z,'f',decimals()))
-                    .arg(QLocale::system().toString(angle,'f',decimals()))
-                    .arg(QLocale::system().toString(pos.x,'f',decimals()))
-                    .arg(QLocale::system().toString(pos.y,'f',decimals()))
-                    .arg(QLocale::system().toString(pos.z,'f',decimals()));
+                    .arg(Base::Quantity(angle, Base::Unit::Angle).getUserString())
+                    .arg(Base::Quantity(pos.x, Base::Unit::Length).getUserString())
+                    .arg(Base::Quantity(pos.y, Base::Unit::Length).getUserString())
+                    .arg(Base::Quantity(pos.z, Base::Unit::Length).getUserString());
     return QVariant(data);
 }
 
@@ -1548,14 +1618,14 @@ QVariant PropertyPlacementItem::toString(const QVariant& prop) const
     p.getRotation().getValue(dir, angle);
     angle = Base::toDegrees<double>(angle);
     pos = p.getPosition();
-    QString data = QString::fromUtf8("[(%1 %2 %3);%4 \xc2\xb0;(%5 %6 %7)]")
+    QString data = QString::fromUtf8("[(%1 %2 %3); %4; (%5  %6  %7)]")
                     .arg(QLocale::system().toString(dir.x,'f',2))
                     .arg(QLocale::system().toString(dir.y,'f',2))
                     .arg(QLocale::system().toString(dir.z,'f',2))
-                    .arg(QLocale::system().toString(angle,'f',2))
-                    .arg(QLocale::system().toString(pos.x,'f',2))
-                    .arg(QLocale::system().toString(pos.y,'f',2))
-                    .arg(QLocale::system().toString(pos.z,'f',2));
+                    .arg(Base::Quantity(angle, Base::Unit::Angle).getUserString())
+                    .arg(Base::Quantity(pos.x, Base::Unit::Length).getUserString())
+                    .arg(Base::Quantity(pos.y, Base::Unit::Length).getUserString())
+                    .arg(Base::Quantity(pos.z, Base::Unit::Length).getUserString());
     return QVariant(data);
 }
 
@@ -1570,17 +1640,17 @@ void PropertyPlacementItem::setValue(const QVariant& value)
     changed_value = false;
     const Base::Placement& val = value.value<Base::Placement>();
     Base::Vector3d pos = val.getPosition();
-    const Base::Rotation& rt = val.getRotation();
+
     QString data = QString::fromAscii("App.Placement("
                                       "App.Vector(%1,%2,%3),"
-                                      "App.Rotation(%4,%5,%6,%7))")
-                    .arg(pos.x,0,'g',6)
-                    .arg(pos.y,0,'g',6)
-                    .arg(pos.z,0,'g',6)
-                    .arg(rt[0],0,'g',6)
-                    .arg(rt[1],0,'g',6)
-                    .arg(rt[2],0,'g',6)
-                    .arg(rt[3],0,'g',6);
+                                      "App.Rotation(App.Vector(%4,%5,%6),%7))")
+                    .arg(pos.x)
+                    .arg(pos.y)
+                    .arg(pos.z)
+                    .arg(rot_axis.x)
+                    .arg(rot_axis.y)
+                    .arg(rot_axis.z)
+                    .arg(rot_angle,0);
     setPropertyValue(data);
 }
 
@@ -1981,6 +2051,24 @@ QVariant PropertyTransientFileItem::editorData(QWidget *editor) const
 
 // ---------------------------------------------------------------
 
+LinkSelection::LinkSelection(const QStringList& list) : link(list)
+{
+}
+
+LinkSelection::~LinkSelection()
+{
+}
+
+void LinkSelection::select()
+{
+    Gui::Selection().clearSelection();
+    Gui::Selection().addSelection((const char*)link[0].toAscii(),
+                                  (const char*)link[1].toAscii());
+    this->deleteLater();
+}
+
+// ---------------------------------------------------------------
+
 LinkLabel::LinkLabel (QWidget * parent) : QLabel(parent)
 {
     setTextFormat(Qt::RichText);
@@ -1994,7 +2082,8 @@ LinkLabel::~LinkLabel()
 
 void LinkLabel::setPropertyLink(const QStringList& o)
 {
-    object = o;
+    link = o;
+
     QString text = QString::fromAscii(
         "<html><head><style type=\"text/css\">"
         "p, li { white-space: pre-wrap; }"
@@ -2004,21 +2093,32 @@ void LinkLabel::setPropertyLink(const QStringList& o)
         "<span>	</span>"
         "<a href=\"@__edit_link_prop__@\"><span style=\" text-decoration: underline; color:#0000ff;\">%4</span></a>"
         "</p></body></html>"
-    ).arg(o[0]).arg(o[1]).arg(o[2]).arg(tr("Edit..."));
+    )
+    .arg(link[0])
+    .arg(link[1])
+    .arg(link[2])
+    .arg(tr("Edit..."));
     setText(text);
 }
 
 QStringList LinkLabel::propertyLink() const
 {
-    return object;
+    return link;
 }
 
 void LinkLabel::onLinkActivated (const QString& s)
 {
-    if (s == QLatin1String("@__edit_link_prop__@"))
-        QMessageBox::warning(this, QLatin1String("Not yet implemented"), QLatin1String("Not yet implemented"));
-    else
-        Gui::Selection().addSelection((const char*)object[0].toAscii(), (const char*)object[1].toAscii());
+    if (s == QLatin1String("@__edit_link_prop__@")) {
+        Gui::Dialog::DlgPropertyLink dlg(link, this);
+        if (dlg.exec() == QDialog::Accepted) {
+            setPropertyLink(dlg.propertyLink());
+            /*emit*/ linkChanged(link);
+        }
+    }
+    else {
+        LinkSelection* select = new LinkSelection(link);
+        QTimer::singleShot(50, select, SLOT(select()));
+    }
 }
 
 TYPESYSTEM_SOURCE(Gui::PropertyEditor::PropertyLinkItem, Gui::PropertyEditor::PropertyItem);
@@ -2038,6 +2138,8 @@ QVariant PropertyLinkItem::value(const App::Property* prop) const
     assert(prop && prop->getTypeId().isDerivedFrom(App::PropertyLink::getClassTypeId()));
 
     const App::PropertyLink* prop_link = static_cast<const App::PropertyLink*>(prop);
+    App::PropertyContainer* c = prop_link->getContainer();
+
     App::DocumentObject* obj = prop_link->getValue();
     QStringList list;
     if (obj) {
@@ -2046,7 +2148,8 @@ QVariant PropertyLinkItem::value(const App::Property* prop) const
         list << QString::fromUtf8(obj->Label.getValue());
     }
     else {
-        App::PropertyContainer* c = prop_link->getContainer();
+        // no object assigned
+        // the document name
         if (c->getTypeId().isDerivedFrom(App::DocumentObject::getClassTypeId())) {
             App::DocumentObject* obj = static_cast<App::DocumentObject*>(c);
             list << QString::fromAscii(obj->getDocument()->getName());
@@ -2054,10 +2157,21 @@ QVariant PropertyLinkItem::value(const App::Property* prop) const
         else {
             list << QString::fromAscii("");
         }
+        // the internal object name
         list << QString::fromAscii("Null");
+        // the object label
         list << QString::fromAscii("");
     }
 
+    // the name of this object
+    if (c->getTypeId().isDerivedFrom(App::DocumentObject::getClassTypeId())) {
+        App::DocumentObject* obj = static_cast<App::DocumentObject*>(c);
+        list << QString::fromAscii(obj->getNameInDocument());
+    }
+    else {
+        list << QString::fromAscii("Null");
+    }
+
     return QVariant(list);
 }
 
@@ -2078,7 +2192,7 @@ QWidget* PropertyLinkItem::createEditor(QWidget* parent, const QObject* receiver
 {
     LinkLabel *ll = new LinkLabel(parent);
     ll->setAutoFillBackground(true);
-    //QObject::connect(cb, SIGNAL(activated(int)), receiver, method);
+    QObject::connect(ll, SIGNAL(linkChanged(const QStringList&)), receiver, method);
     return ll;
 }
 
