@@ -21,17 +21,22 @@
 #*                                                                         *
 #***************************************************************************
 
-import FreeCAD,FreeCADGui,Draft,math,DraftVecUtils,ArchCommands
+import FreeCAD,Draft,math,DraftVecUtils,ArchCommands
 from FreeCAD import Vector
-from PyQt4 import QtCore, QtGui
-from pivy import coin
-from DraftTools import translate
+if FreeCAD.GuiUp:
+    import FreeCADGui
+    from PySide import QtCore, QtGui
+    from DraftTools import translate
+    from pivy import coin
+else:
+    def translate(ctxt,txt):
+        return txt
 
 __title__="FreeCAD Axis System"
 __author__ = "Yorik van Havre"
 __url__ = "http://www.freecadweb.org"
 
-def makeAxis(num=5,size=1,name=str(translate("Arch","Axes"))):
+def makeAxis(num=5,size=1000,name=translate("Arch","Axes")):
     '''makeAxis(num,size): makes an Axis System
     based on the given number of axes and interval distances'''
     obj = FreeCAD.ActiveDocument.addObject("App::FeaturePython",name)
@@ -57,7 +62,7 @@ class _CommandAxis:
                 'ToolTip': QtCore.QT_TRANSLATE_NOOP("Arch_Axis","Creates an axis system.")}
         
     def Activated(self):
-        FreeCAD.ActiveDocument.openTransaction(str(translate("Arch","Create Axis")))
+        FreeCAD.ActiveDocument.openTransaction(translate("Arch","Create Axis"))
         FreeCADGui.doCommand("import Arch")
         sel = FreeCADGui.Selection.getSelection()
         st = Draft.getObjectsOfType(sel,"Structure")
@@ -67,13 +72,16 @@ class _CommandAxis:
         else:
             FreeCADGui.doCommand("Arch.makeAxis()")
         FreeCAD.ActiveDocument.commitTransaction()
+
+    def IsActive(self):
+        return not FreeCAD.ActiveDocument is None
        
 class _Axis:
     "The Axis object"
     def __init__(self,obj):
-        obj.addProperty("App::PropertyFloatList","Distances","Arch", str(translate("Arch","The intervals between axes")))
-        obj.addProperty("App::PropertyFloatList","Angles","Arch", str(translate("Arch","The angles of each axis")))
-        obj.addProperty("App::PropertyFloat","Length","Arch", str(translate("Arch","The length of the axes")))
+        obj.addProperty("App::PropertyFloatList","Distances","Arch", translate("Arch","The intervals between axes"))
+        obj.addProperty("App::PropertyFloatList","Angles","Arch", translate("Arch","The angles of each axis"))
+        obj.addProperty("App::PropertyFloat","Length","Arch", translate("Arch","The length of the axes"))
         obj.addProperty("App::PropertyPlacement","Placement","Base","")
         obj.addProperty("Part::PropertyPartShape","Shape","Base","")
         self.Type = "Axis"
@@ -112,8 +120,8 @@ class _ViewProviderAxis:
     "A View Provider for the Axis object"
 
     def __init__(self,vobj):
-        vobj.addProperty("App::PropertyLength","BubbleSize","Arch", str(translate("Arch","The size of the axis bubbles")))
-        vobj.addProperty("App::PropertyEnumeration","NumberingStyle","Arch", str(translate("Arch","The numbering style")))
+        vobj.addProperty("App::PropertyFloat","BubbleSize","Arch", translate("Arch","The size of the axis bubbles"))
+        vobj.addProperty("App::PropertyEnumeration","NumberingStyle","Arch", translate("Arch","The numbering style"))
         vobj.addProperty("App::PropertyEnumeration","DrawStyle","Base","")
         vobj.addProperty("App::PropertyFloat","LineWidth","Base","")
         vobj.addProperty("App::PropertyColor","LineColor","Base","")
@@ -295,7 +303,7 @@ class _ViewProviderAxis:
                     num += 1
             
   
-    def setEdit(self,vobj,mode):
+    def setEdit(self,vobj,mode=0):
         taskd = _AxisTaskPanel()
         taskd.obj = vobj.Object
         taskd.update()
@@ -306,6 +314,9 @@ class _ViewProviderAxis:
         FreeCADGui.Control.closeDialog()
         return
 
+    def doubleClicked(self,vobj):
+        self.setEdit(vobj)
+
     def __getstate__(self):
         return None
 
@@ -360,7 +371,7 @@ class _AxisTaskPanel:
         return True
 
     def getStandardButtons(self):
-        return int(QtGui.QDialogButtonBox.Ok)
+        return int(QtGui.QDialogButtonBox.Close)
     
     def update(self):
         'fills the treewidget'
@@ -403,17 +414,19 @@ class _AxisTaskPanel:
         self.obj.touch()
         FreeCAD.ActiveDocument.recompute()
     
-    def accept(self):
-        self.resetObject()
+    def reject(self):
+        FreeCAD.ActiveDocument.recompute()
         FreeCADGui.ActiveDocument.resetEdit()
+        return True
                     
     def retranslateUi(self, TaskPanel):
         TaskPanel.setWindowTitle(QtGui.QApplication.translate("Arch", "Axes", None, QtGui.QApplication.UnicodeUTF8))
         self.delButton.setText(QtGui.QApplication.translate("Arch", "Remove", None, QtGui.QApplication.UnicodeUTF8))
         self.addButton.setText(QtGui.QApplication.translate("Arch", "Add", None, QtGui.QApplication.UnicodeUTF8))
-        self.title.setText(QtGui.QApplication.translate("Arch", "Distances and angles between axes", None, QtGui.QApplication.UnicodeUTF8))
+        self.title.setText(QtGui.QApplication.translate("Arch", "Distances (mm) and angles (deg) between axes", None, QtGui.QApplication.UnicodeUTF8))
         self.tree.setHeaderLabels([QtGui.QApplication.translate("Arch", "Axis", None, QtGui.QApplication.UnicodeUTF8),
                                    QtGui.QApplication.translate("Arch", "Distance", None, QtGui.QApplication.UnicodeUTF8),
                                    QtGui.QApplication.translate("Arch", "Angle", None, QtGui.QApplication.UnicodeUTF8)])
-          
-FreeCADGui.addCommand('Arch_Axis',_CommandAxis())
+ 
+if FreeCAD.GuiUp:          
+    FreeCADGui.addCommand('Arch_Axis',_CommandAxis())
