@@ -1,3 +1,5 @@
+# -*- coding: utf8 -*-
+
 #***************************************************************************
 #*                                                                         *
 #*   Copyright (c) 2011                                                    *  
@@ -21,15 +23,22 @@
 #*                                                                         *
 #***************************************************************************
 
-import FreeCAD,FreeCADGui,Draft,ArchComponent,DraftVecUtils
+import FreeCAD,Draft,ArchComponent,DraftVecUtils
 from FreeCAD import Vector
-from PyQt4 import QtCore
-from DraftTools import translate
+if FreeCAD.GuiUp:
+    import FreeCADGui
+    from PySide import QtGui,QtCore
+    from DraftTools import translate
+else:
+    def translate(ctxt,txt):
+        return txt
 
 __title__="FreeCAD Arch Commands"
 __author__ = "Yorik van Havre"
 __url__ = "http://www.freecadweb.org"
 
+CURVEMODE = "PARAMETER" # For trimmed curves. CARTESIAN or PARAMETER
+
 # module functions ###############################################
 
 def getStringList(objects):
@@ -76,22 +85,23 @@ def addComponents(objectsList,host):
             if not o in c:
                 c.append(o)
         host.Group = c
-    elif hostType in ["Wall","Structure","Window","Roof"]:
+    elif hostType in ["Wall","Structure","Window","Roof","Stairs","StructuralSystem"]:
         import DraftGeomUtils
         a = host.Additions
         if hasattr(host,"Axes"):
             x = host.Axes
         for o in objectsList:
-            if DraftGeomUtils.isValidPath(o.Shape) and (hostType == "Structure"):
-                if o.Support == host:
-                    o.Support = None
-                host.Tool = o
-            elif Draft.getType(o) == "Axis":
-                if not o in x:
-                    x.append(o) 
-            elif not o in a:
-                if hasattr(o,"Shape"):
-                    a.append(o)
+            if o.isDerivedFrom("Part::Feature"):
+                if DraftGeomUtils.isValidPath(o.Shape) and (hostType == "Structure"):
+                    if o.Support == host:
+                        o.Support = None
+                    host.Tool = o
+                elif Draft.getType(o) == "Axis":
+                    if not o in x:
+                        x.append(o) 
+                elif not o in a:
+                    if hasattr(o,"Shape"):
+                        a.append(o)
         host.Additions = a
         if hasattr(host,"Axes"):
             host.Axes = x
@@ -99,8 +109,7 @@ def addComponents(objectsList,host):
         a = host.Objects
         for o in objectsList:
             if not o in a:
-                if hasattr(o,"Shape"):
-                    a.append(o)
+                a.append(o)
         host.Objects = a
     elif host.isDerivedFrom("App::DocumentObjectGroup"):
         c = host.Group
@@ -117,7 +126,7 @@ def removeComponents(objectsList,host=None):
     if not isinstance(objectsList,list):
         objectsList = [objectsList]
     if host:
-        if Draft.getType(host) in ["Wall","Structure"]:
+        if Draft.getType(host) in ["Wall","Structure","Window","Roof","Stairs","StructuralSystem"]:
             if hasattr(host,"Tool"):
                 if objectsList[0] == host.Tool:
                     host.Tool = None
@@ -137,16 +146,16 @@ def removeComponents(objectsList,host=None):
                             if o.Base.Support:
                                 if isinstance(o.Base.Support,tuple):
                                    if o.Base.Support[0].Name == host.Name:
-                                       FreeCAD.Console.PrintMessage(str(translate("Arch","removing sketch support to avoid cross-referencing")))
+                                       FreeCAD.Console.PrintMessage(translate("Arch","removing sketch support to avoid cross-referencing"))
                                        o.Base.Support = None
                                 elif o.Base.Support.Name == host.Name:
-                                    FreeCAD.Console.PrintMessage(str(translate("Arch","removing sketch support to avoid cross-referencing")))
+                                    FreeCAD.Console.PrintMessage(translate("Arch","removing sketch support to avoid cross-referencing"))
                                     o.Base.Support = None
                             elif o.Base.ExternalGeometry:
                                 for i in range(len(o.Base.ExternalGeometry)):
                                     if o.Base.ExternalGeometry[i][0].Name == host.Name:
                                         o.Base.delExternal(i)
-                                        FreeCAD.Console.PrintMessage(str(translate("Arch","removing sketch support to avoid cross-referencing")))
+                                        FreeCAD.Console.PrintMessage(translate("Arch","removing sketch support to avoid cross-referencing"))
                                         break                                        
             host.Subtractions = s
     else:
@@ -189,16 +198,16 @@ def fixWindow(obj):
                 if obj.Base.Support:
                     if isinstance(o.Base.Support,tuple):
                        if obj.Base.Support[0]:
-                           FreeCAD.Console.PrintMessage(str(translate("Arch","removing sketch support to avoid cross-referencing")))
+                           FreeCAD.Console.PrintMessage(translate("Arch","removing sketch support to avoid cross-referencing"))
                            obj.Base.Support = None
                     elif obj.Base.Support:
-                        FreeCAD.Console.PrintMessage(str(translate("Arch","removing sketch support to avoid cross-referencing")))
+                        FreeCAD.Console.PrintMessage(translate("Arch","removing sketch support to avoid cross-referencing"))
                         obj.Base.Support = None
             if hasattr(obj.Base,"ExternalGeometry"):
                 if obj.Base.ExternalGeometry:
                     for i in range(len(obj.Base.ExternalGeometry)):
                         obj.Base.delExternal(0)
-                        FreeCAD.Console.PrintMessage(str(translate("Arch","removing sketch external references to avoid cross-referencing")))
+                        FreeCAD.Console.PrintMessage(translate("Arch","removing sketch external references to avoid cross-referencing"))
 
 def copyProperties(obj1,obj2):
     '''copyProperties(obj1,obj2): Copies properties values from obj1 to obj2,
@@ -320,6 +329,8 @@ def closeHole(shape):
 def getCutVolume(cutplane,shapes):
     """getCutVolume(cutplane,shapes): returns a cut face and a cut volume
     from the given shapes and the given cutting plane"""
+    if not shapes:
+        return None,None,None
     import Part
     if not isinstance(shapes,list):
         shapes = [shapes]
@@ -337,14 +348,14 @@ def getCutVolume(cutplane,shapes):
         else:
             p = cutplane.copy().Faces[0]
     except:
-        FreeCAD.Console.PrintMessage(str(translate("Arch","Invalid cutplane")))
+        FreeCAD.Console.PrintMessage(translate("Arch","Invalid cutplane"))
         return None,None,None 
     ce = p.CenterOfMass
     ax = p.normalAt(0,0)
     u = p.Vertexes[1].Point.sub(p.Vertexes[0].Point).normalize()
     v = u.cross(ax)
     if not bb.isCutPlane(ce,ax):
-        FreeCAD.Console.PrintMessage(str(translate("Arch","No objects are cut by the plane")))
+        FreeCAD.Console.PrintMessage(translate("Arch","No objects are cut by the plane"))
         return None,None,None
     else:
         corners = [FreeCAD.Vector(bb.XMin,bb.YMin,bb.ZMin),
@@ -537,10 +548,14 @@ def mergeCells(objectslist):
 
 def download(url,force=False):
     '''downloads a file from the given URL and saves it in the
-    user directory. Returns the path to the saved file'''
+    macro path. Returns the path to the saved file'''
     import urllib2, os
     name = url.split('/')[-1]
-    filepath = os.path.join(FreeCAD.ConfigGet("UserAppData"),name)
+    p = FreeCAD.ParamGet("User parameter:BaseApp/Preferences/Macro")
+    macropath = p.GetString("MacroPath","")
+    if not macropath:
+        macropath = FreeCAD.ConfigGet("UserAppData")
+    filepath = os.path.join(macropath,name)
     if os.path.exists(filepath) and not(force):
         return filepath
     try:
@@ -567,41 +582,31 @@ def check(objectslist,includehidden=False):
         else:
             s = o.Shape
             if (not s.isClosed()) and (not (Draft.getType(o) == "Axis")):
-                bad.append([o,str(translate("Arch","is not closed"))])
+                bad.append([o,translate("Arch","is not closed")])
             elif not s.isValid():
-                bad.append([o,str(translate("Arch","is not valid"))])
+                bad.append([o,translate("Arch","is not valid")])
             elif (not s.Solids) and (not (Draft.getType(o) == "Axis")):
-                bad.append([o,str(translate("Arch","doesn't contain any solid"))])
+                bad.append([o,translate("Arch","doesn't contain any solid")])
             else:
                 f = 0
                 for sol in s.Solids:
                     f += len(sol.Faces)
                     if not sol.isClosed():
-                        bad.append([o,str(translate("Arch","contains a non-closed solid"))])
+                        bad.append([o,translate("Arch","contains a non-closed solid")])
                 if len(s.Faces) != f:
-                    bad.append([o,str(translate("Arch","contains faces that are not part of any solid"))])
+                    bad.append([o,translate("Arch","contains faces that are not part of any solid")])
     return bad
 
-
-def addFixture(fixture,baseobject):
-    '''addFixture(fixture,baseobject): adds the given object as a 
-    fixture to the given base object'''
-    if hasattr(baseobject,"Fixtures"):
-        f = baseobject.Fixtures
-        f.append(fixture)
-        baseobject.Fixtures = f
-        if baseobject.ViewObject.DisplayMode != "Detailed":
-            fixture.ViewObject.hide()
-    else:
-        FreeCAD.Console.PrintMessage(str(translate("Arch","This object has no support for fixtures")))
-
-def getTuples(data,scale=1,placement=None):
-    """getTuples(data,[scale,placement]): returns a tuple or a list of tuples from a vector
+def getTuples(data,scale=1,placement=None,normal=None,close=True):
+    """getTuples(data,[scale,placement,normal,close]): returns a tuple or a list of tuples from a vector
     or from the vertices of a shape. Scale can indicate a scale factor"""
+    rnd = True
     import Part
     if isinstance(data,FreeCAD.Vector):
         if placement:
             data = placement.multVec(data)
+        if rnd:
+            data = DraftVecUtils.rounded(data)
         return (data.x*scale,data.y*scale,data.z*scale)
     elif isinstance(data,Part.Shape):
         t = []
@@ -609,58 +614,174 @@ def getTuples(data,scale=1,placement=None):
             import Part,DraftGeomUtils
             data = Part.Wire(DraftGeomUtils.sortEdges(data.Wires[0].Edges))
             verts = data.Vertexes
-            #verts.reverse()
+            try:
+                c = data.CenterOfMass
+                v1 = verts[0].Point.sub(c)
+                v2 = verts[1].Point.sub(c)
+                if DraftVecUtils.angle(v2,v1,normal) >= 0:
+                    # inverting verts order if the direction is couterclockwise
+                    verts.reverse()
+            except:
+                pass
             for v in verts:
                 pt = v.Point
                 if placement:
-                    pt = placement.multVec(pt)
+                    if not placement.isNull():
+                        pt = placement.multVec(pt)
+                if rnd:
+                    pt = DraftVecUtils.rounded(pt)
                 t.append((pt.x*scale,pt.y*scale,pt.z*scale))
-            t.append(t[0]) # for IFC verts lists must be closed
+
+            if close: # faceloops must not be closed, but ifc profiles must.
+                t.append(t[0])
         else:
             print "Arch.getTuples(): Wrong profile data"
         return t
 
-def getExtrusionData(obj,scale=1):
-    """getExtrusionData(obj,[scale]): returns a closed path (a list of tuples) and a tuple expressing an extrusion
-    vector, or None, if a base loop and an extrusion direction cannot be extracted. Scale can indicate a scale factor."""
+def getIfcExtrusionData(obj,scale=1,nosubs=False):
+    """getIfcExtrusionData(obj,[scale,nosubs]): returns a closed path (a list of tuples), a tuple expressing an extrusion
+    vector, and a list of 3 tuples for base position, x axis and z axis. Or returns None, if a base loop and 
+    an extrusion direction cannot be extracted. Scale can indicate a scale factor."""
     if hasattr(obj,"Additions"):
         if obj.Additions:
-            # provisorily treat objs with additions as breps
+            # TODO provisorily treat objs with additions as breps
             return None
-    if hasattr(obj,"Subtractions"):
+    if hasattr(obj,"Subtractions") and not nosubs:
         if obj.Subtractions:
-            # provisorily treat objs with subtractions as breps
             return None
     if hasattr(obj,"Proxy"):
-        if hasattr(obj.Proxy,"BaseProfile") and hasattr(obj.Proxy,"ExtrusionVector"):
-            pl = FreeCAD.Placement(obj.Placement)
-            r = FreeCAD.Rotation(obj.Placement.Rotation)
-            if pl.isNull():
-                pl = r = None
-            return getTuples(obj.Proxy.BaseProfile,scale,pl), getTuples(obj.Proxy.ExtrusionVector,scale,r)
+        if hasattr(obj.Proxy,"getProfiles"):
+            p = obj.Proxy.getProfiles(obj,noplacement=True)
+            v = obj.Proxy.getExtrusionVector(obj,noplacement=True)
+            if (len(p) == 1) and v:
+                p = p[0]
+                r = FreeCAD.Placement()
+                #b = p.CenterOfMass
+                r = obj.Proxy.getPlacement(obj)
+                #b = obj.Placement.multVec(FreeCAD.Vector())
+                #r.Rotation = DraftVecUtils.getRotation(v,FreeCAD.Vector(0,0,1))
+                d = [r.Base,DraftVecUtils.rounded(r.Rotation.multVec(FreeCAD.Vector(1,0,0))),DraftVecUtils.rounded(r.Rotation.multVec(FreeCAD.Vector(0,0,1)))]
+                #r = r.inverse()
+                #print "getExtrusionData: computed placement:",r
+                import Part
+                if len(p.Edges) == 1:
+                    if isinstance(p.Edges[0].Curve,Part.Circle):
+                        # Circle profile
+                        r1 = p.Edges[0].Curve.Radius*scale
+                        return "circle", [getTuples(p.Edges[0].Curve.Center,scale), r1], getTuples(v,scale), d
+                    elif isinstance(p.Edges[0].Curve,Part.Ellipse):
+                        # Ellipse profile
+                        r1 = p.Edges[0].Curve.MajorRadius*scale
+                        r2 = p.Edges[0].Curve.MinorRadius*scale
+                        return "ellipse", [getTuples(p.Edges[0].Curve.Center,scale), r1, r2], getTuples(v,scale), d
+                curves = False
+                for e in p.Edges:
+                    if isinstance(e.Curve,Part.Circle):
+                        curves = True
+                    elif not isinstance(e.Curve,Part.Line):
+                        print "Arch.getIfcExtrusionData: Warning: unsupported edge type in profile"
+                if curves:
+                    # Composite profile
+                    ecurves = []
+                    last = None
+                    import DraftGeomUtils
+                    edges = DraftGeomUtils.sortEdges(p.Edges)
+                    for e in edges:
+                        if isinstance(e.Curve,Part.Circle):
+                            import math
+                            follow = True
+                            if last:
+                                if not DraftVecUtils.equals(last,e.Vertexes[0].Point):
+                                    follow = False
+                                    last = e.Vertexes[0].Point
+                                else:
+                                    last = e.Vertexes[-1].Point
+                            else:
+                                last = e.Vertexes[-1].Point
+                            p1 = math.degrees(-DraftVecUtils.angle(e.Vertexes[0].Point.sub(e.Curve.Center)))
+                            p2 = math.degrees(-DraftVecUtils.angle(e.Vertexes[-1].Point.sub(e.Curve.Center)))
+                            da = DraftVecUtils.angle(e.valueAt(e.FirstParameter+0.1).sub(e.Curve.Center),e.Vertexes[0].Point.sub(e.Curve.Center))
+                            if p1 < 0: 
+                                p1 = 360 + p1
+                            if p2 < 0:
+                                p2 = 360 + p2
+                            if da > 0:
+                                follow = not(follow)
+                            if CURVEMODE == "CARTESIAN":
+                                # BUGGY
+                                p1 = getTuples(e.Vertexes[0].Point,scale)
+                                p2 = getTuples(e.Vertexes[-1].Point,scale)
+                            ecurves.append(["arc",getTuples(e.Curve.Center,scale),e.Curve.Radius*scale,[p1,p2],follow,CURVEMODE])
+                        else:
+                            verts = [vertex.Point for vertex in e.Vertexes]
+                            if last:
+                                if not DraftVecUtils.equals(last,verts[0]):
+                                    verts.reverse()
+                                    last = e.Vertexes[0].Point
+                                else:
+                                    last = e.Vertexes[-1].Point
+                            else:
+                                last = e.Vertexes[-1].Point
+                            ecurves.append(["line",[getTuples(vert,scale) for vert in verts]])
+                    return "composite", ecurves, getTuples(v,scale), d
+                else:
+                    # Polyline profile
+                    return "polyline", getTuples(p,scale), getTuples(v,scale), d
     return None   
     
-def getBrepFacesData(obj,scale=1):
-    """getBrepFacesData(obj,[scale]): returns a list(0) of lists(1) of lists(2) of lists(3), 
+def getIfcBrepFacesData(obj,scale=1,sub=False,tessellation=1):
+    """getIfcBrepFacesData(obj,[scale,tesselation]): returns a list(0) of lists(1) of lists(2) of lists(3), 
     list(3) being a list of vertices defining a loop, list(2) describing a face from one or 
     more loops, list(1) being the whole solid made of several faces, list(0) being the list
-    of solids inside the object. Scale can indicate a scaling factor"""
-    if hasattr(obj,"Shape"):
-        if obj.Shape:
-            if obj.Shape.isValid():
+    of solids inside the object. Scale can indicate a scaling factor. Tesselation is the tesselation
+    factor to apply on curved faces."""
+    shape = None
+    if sub:
+        if hasattr(obj,"Proxy"):
+            if hasattr(obj.Proxy,"getSubVolume"):
+                shape = obj.Proxy.getSubVolume(obj)
+    if not shape:
+        if hasattr(obj,"Shape"):
+            if obj.Shape:
                 if not obj.Shape.isNull():
-                    sols = []
-                    for sol in obj.Shape.Solids:
-                        s = []
-                        for face in obj.Shape.Faces:
-                            f = []
-                            for wire in face.Wires:
-                                f.append(getTuples(wire,scale))
-                            s.append(f)
-                        sols.append(s)
-                    return sols
+                    if obj.Shape.isValid():
+                        shape = obj.Shape
+    if shape:
+        import Part
+        sols = []
+        for sol in shape.Solids:
+            s = []
+            curves = False
+            for face in sol.Faces:
+                for e in face.Edges:
+                    if not isinstance(e.Curve,Part.Line):
+                        curves = True
+            if curves:
+                tris = sol.tessellate(tessellation)
+                for tri in tris[1]:
+                    f = []
+                    for i in tri:
+                        f.append(getTuples(tris[0][i],scale))
+                    s.append([f])
+            else:
+                for face in sol.Faces:
+                    f = []
+                    f.append(getTuples(face.OuterWire,scale,normal=face.normalAt(0,0),close=False))
+                    for wire in face.Wires:
+                        if wire.hashCode() != face.OuterWire.hashCode():
+                            f.append(getTuples(wire,scale,normal=DraftVecUtils.neg(face.normalAt(0,0)),close=False))
+                    s.append(f)
+            sols.append(s)
+        return sols
     return None
     
+def getIfcElevation(obj):
+    """getIfcElevation(obj): Returns the lowest height (Z coordinate) of this object"""
+    if obj.isDerivedFrom("Part::Feature"):
+        b = obj.Shape.BoundBox
+        return b.ZMin
+    return 0
+    
 def getHost(obj,strict=True):
     """getHost(obj,[strict]): returns the host of the current object. If strict is true (default),
     the host can only be an object of a higher level than the given one, or in other words, if a wall
@@ -668,7 +789,7 @@ def getHost(obj,strict=True):
     import Draft
     t = Draft.getType(obj)
     for par in obj.InList:
-        if par.isDerivedFrom("Part::Feature"):
+        if par.isDerivedFrom("Part::Feature") or par.isDerivedFrom("App::DocumentObjectGroup"):
             if strict:
                 if Draft.getType(par) != t:
                     return par
@@ -689,10 +810,141 @@ def pruneIncluded(objectslist):
             if not (Draft.getType(obj) in ["Window","Clone"]):
                 for parent in obj.InList:
                     if parent.isDerivedFrom("Part::Feature"):
-                        toplevel = False
+                        if not parent.isDerivedFrom("Part::Part2DObject"):
+                            # don't consider 2D objects based on arch elements
+                            toplevel = False
         if toplevel:
             newlist.append(obj)
     return newlist
+
+class _SurveyObserver:
+    "an observer for the survey() function"
+    def __init__(self,callback):
+        self.callback = callback
+        self.cancellable = False
+        self.selection = []
+        self.labels = []
+        
+    def addSelection(self,document, object, element, position):
+        self.cancellable = False
+        self.callback(True)
+
+    def clearSelection(self,document):
+        if self.cancellable:
+            self.callback(True)
+        else:
+            self.cancellable = True
+
+def survey(callback=False):
+    """survey(): starts survey mode, where you can click edges and faces to get their lengths or area.
+    Clicking on no object (on an empty area) stops survey mode."""
+    if not callback:
+        if hasattr(FreeCAD,"SurveyObserver"):
+            for label in FreeCAD.SurveyObserver.labels:
+                FreeCAD.ActiveDocument.removeObject(label)
+            FreeCADGui.Selection.removeObserver(FreeCAD.SurveyObserver)
+            del FreeCAD.SurveyObserver
+            if FreeCAD.GuiUp:
+                if hasattr(FreeCADGui,"draftToolBar"):
+                    FreeCADGui.draftToolBar.offUi()
+        else:
+            FreeCAD.SurveyObserver = _SurveyObserver(callback=survey)
+            FreeCADGui.Selection.addObserver(FreeCAD.SurveyObserver)
+            if FreeCAD.GuiUp:
+                if hasattr(FreeCADGui,"draftToolBar"):
+                    FreeCADGui.draftToolBar.selectUi(callback=survey)
+    else:
+        sel = FreeCADGui.Selection.getSelectionEx()
+        if not sel:
+            if hasattr(FreeCAD,"SurveyObserver"):
+                for label in FreeCAD.SurveyObserver.labels:
+                    FreeCAD.ActiveDocument.removeObject(label)
+                FreeCADGui.Selection.removeObserver(FreeCAD.SurveyObserver)
+                del FreeCAD.SurveyObserver
+                if FreeCAD.GuiUp:
+                    if hasattr(FreeCADGui,"draftToolBar"):
+                        FreeCADGui.draftToolBar.offUi()
+        else:
+            if hasattr(FreeCAD,"SurveyObserver"):
+                basesel = FreeCAD.SurveyObserver.selection
+                newsels = []
+                for o in sel:
+                    found = False
+                    for eo in basesel:
+                        if o.ObjectName == eo.ObjectName:
+                            if o.SubElementNames == eo.SubElementNames:
+                                found = True
+                    if not found:
+                        newsels.append(o)
+                if newsels:
+                    for o in newsels:
+                        if o.Object.isDerivedFrom("Part::Feature"):
+                            n = o.Object.Label
+                            if not o.HasSubObjects:
+                                # entire object
+                                anno = FreeCAD.ActiveDocument.addObject("App::AnnotationLabel","surveyLabel")
+                                if hasattr(o.Object.Shape,"CenterOfMass"):
+                                    anno.BasePosition = o.Object.Shape.CenterOfMass
+                                else:
+                                    anno.BasePosition = o.Object.Shape.BoundBox.Center
+                                FreeCAD.SurveyObserver.labels.append(anno.Name)
+                                t = ""
+                                if o.Object.Shape.Solids:
+                                    t = FreeCAD.Units.Quantity(o.Object.Shape.Volume,FreeCAD.Units.Volume)
+                                    t = t.getUserPreferred()[0]
+                                    t = t.replace("^3","³")
+                                    anno.LabelText = "v " + t
+                                    FreeCAD.Console.PrintMessage("Object: " + n + ", Element: Whole, Volume: " + t.decode("utf8") + "\n")
+                                elif o.Object.Shape.Faces:
+                                    t = FreeCAD.Units.Quantity(o.Object.Shape.Area,FreeCAD.Units.Area)
+                                    t = t.getUserPreferred()[0]
+                                    t = t.replace("^2","²")
+                                    anno.LabelText = "a " + t
+                                    FreeCAD.Console.PrintMessage("Object: " + n + ", Element: Whole, Area: " + t.decode("utf8") + "\n")
+                                else:
+                                    t = FreeCAD.Units.Quantity(o.Object.Shape.Length,FreeCAD.Units.Length)
+                                    t = t.getUserPreferred()[0]
+                                    anno.LabelText = "l " + t
+                                    FreeCAD.Console.PrintMessage("Object: " + n + ", Element: Whole, Length: " + t + "\n")
+                                if FreeCAD.GuiUp and t:
+                                    QtGui.qApp.clipboard().setText(t)
+                            else:
+                                # single element(s)
+                                for el in o.SubElementNames:
+                                    e = getattr(o.Object.Shape,el)
+                                    anno = FreeCAD.ActiveDocument.addObject("App::AnnotationLabel","surveyLabel")
+                                    if "Vertex" in el:
+                                        anno.BasePosition = e.Point
+                                    else:
+                                        if hasattr(e,"CenterOfMass"):
+                                            anno.BasePosition = e.CenterOfMass
+                                        else:
+                                            anno.BasePosition = e.BoundBox.Center
+                                    FreeCAD.SurveyObserver.labels.append(anno.Name)
+                                    t = ""
+                                    if "Face" in el:
+                                        t = FreeCAD.Units.Quantity(e.Area,FreeCAD.Units.Area)
+                                        t = t.getUserPreferred()[0]
+                                        t = t.replace("^2","²")
+                                        anno.LabelText = "a " + t
+                                        FreeCAD.Console.PrintMessage("Object: " + n + ", Element: " + el + ", Area: "+ t.decode("utf8")  + "\n")
+                                    elif "Edge" in el:
+                                        t = FreeCAD.Units.Quantity(e.Length,FreeCAD.Units.Length)
+                                        t = t.getUserPreferred()[0]
+                                        anno.LabelText = "l " + t
+                                        FreeCAD.Console.PrintMessage("Object: " + n + ", Element: " + el + ", Length: " + t + "\n")
+                                    elif "Vertex" in el:
+                                        t = FreeCAD.Units.Quantity(e.Z,FreeCAD.Units.Length)
+                                        t = t.getUserPreferred()[0]
+                                        anno.LabelText = "z " + t
+                                        FreeCAD.Console.PrintMessage("Object: " + n + ", Element: " + el + ", Zcoord: " + t + "\n")
+                                    if FreeCAD.GuiUp and t:
+                                        QtGui.qApp.clipboard().setText(t)
+
+                    FreeCAD.SurveyObserver.selection.extend(newsels)
+
+
+
     
 # command definitions ###############################################
                        
@@ -704,10 +956,7 @@ class _CommandAdd:
                 'ToolTip': QtCore.QT_TRANSLATE_NOOP("Arch_Add","Adds the selected components to the active object")}
 
     def IsActive(self):
-        if len(FreeCADGui.Selection.getSelection()) > 1:
-            return True
-        else:
-            return False
+        return len(FreeCADGui.Selection.getSelection()) > 1
         
     def Activated(self):
         sel = FreeCADGui.Selection.getSelection()
@@ -739,10 +988,7 @@ class _CommandRemove:
                 'ToolTip': QtCore.QT_TRANSLATE_NOOP("Arch_Remove","Remove the selected components from their parents, or create a hole in a component")}
 
     def IsActive(self):
-        if FreeCADGui.Selection.getSelection():
-            return True
-        else:
-            return False
+        return bool(FreeCADGui.Selection.getSelection())
         
     def Activated(self):
         sel = FreeCADGui.Selection.getSelection()
@@ -752,7 +998,7 @@ class _CommandRemove:
             FreeCADGui.doCommand("Arch.removeSpaceBoundaries( FreeCAD.ActiveDocument."+sel[-1].Name+", FreeCADGui.Selection.getSelection() )")
         else:
             FreeCAD.ActiveDocument.openTransaction(str(translate("Arch","Ungrouping")))
-            if (Draft.getType(sel[-1]) in ["Wall","Structure"]) and (len(sel) > 1):
+            if (Draft.getType(sel[-1]) in ["Wall","Structure","Stairs","Roof","Window"]) and (len(sel) > 1):
                 host = sel.pop()
                 ss = "["
                 for o in sel:
@@ -764,7 +1010,7 @@ class _CommandRemove:
                 FreeCADGui.doCommand("Arch.removeComponents("+ss+",FreeCAD.ActiveDocument."+host.Name+")")
             else:
                 FreeCADGui.doCommand("import Arch")
-                FreeCADGui.doCommand("Arch.removeComponents(Arch.ActiveDocument."+sel[-1].Name+")")
+                FreeCADGui.doCommand("Arch.removeComponents(FreeCAD.ActiveDocument."+sel[-1].Name+")")
         FreeCAD.ActiveDocument.commitTransaction()
         FreeCAD.ActiveDocument.recompute()
 
@@ -777,10 +1023,7 @@ class _CommandSplitMesh:
                 'ToolTip': QtCore.QT_TRANSLATE_NOOP("Arch_SplitMesh","Splits selected meshes into independent components")}
 
     def IsActive(self):
-        if len(FreeCADGui.Selection.getSelection()):
-            return True
-        else:
-            return False
+        return bool(FreeCADGui.Selection.getSelection())
         
     def Activated(self):
         if FreeCADGui.Selection.getSelection():
@@ -805,10 +1048,7 @@ class _CommandMeshToShape:
                 'ToolTip': QtCore.QT_TRANSLATE_NOOP("Arch_MeshToShape","Turns selected meshes into Part Shape objects")}
 
     def IsActive(self):
-        if FreeCADGui.Selection.getSelection():
-            return True
-        else:
-            return False
+        return bool(FreeCADGui.Selection.getSelection())
         
     def Activated(self):
         if FreeCADGui.Selection.getSelection():
@@ -841,6 +1081,9 @@ class _CommandSelectNonSolidMeshes:
         return {'Pixmap': 'Arch_SelectNonManifold.svg',
                 'MenuText': QtCore.QT_TRANSLATE_NOOP("Arch_SelectNonSolidMeshes","Select non-manifold meshes"),
                 'ToolTip': QtCore.QT_TRANSLATE_NOOP("Arch_SelectNonSolidMeshes","Selects all non-manifold meshes from the document or from the selected groups")}
+
+    def IsActive(self):
+        return not FreeCAD.ActiveDocument is None
         
     def Activated(self):
         msel = []
@@ -868,10 +1111,7 @@ class _CommandRemoveShape:
                 'ToolTip': QtCore.QT_TRANSLATE_NOOP("Arch_RemoveShape","Removes cubic shapes from Arch components")}
 
     def IsActive(self):
-        if FreeCADGui.Selection.getSelection():
-            return True
-        else:
-            return False
+        return bool(FreeCADGui.Selection.getSelection())
         
     def Activated(self):
         sel = FreeCADGui.Selection.getSelection()
@@ -885,10 +1125,7 @@ class _CommandCloseHoles:
                 'ToolTip': QtCore.QT_TRANSLATE_NOOP("Arch_CloseHoles","Closes holes in open shapes, turning them solids")}
 
     def IsActive(self):
-        if FreeCADGui.Selection.getSelection():
-            return True
-        else:
-            return False
+        return bool(FreeCADGui.Selection.getSelection())
         
     def Activated(self):
         for o in FreeCADGui.Selection.getSelection():
@@ -904,10 +1141,7 @@ class _CommandCheck:
                 'ToolTip': QtCore.QT_TRANSLATE_NOOP("Arch_Check","Checks the selected objects for problems")}
 
     def IsActive(self):
-        if FreeCADGui.Selection.getSelection():
-            return True
-        else:
-            return False
+        return bool(FreeCADGui.Selection.getSelection())
         
     def Activated(self):
         result = check(FreeCADGui.Selection.getSelection())
@@ -920,37 +1154,43 @@ class _CommandCheck:
                 FreeCADGui.Selection.addSelection(i[0])
 
 
-class _CommandFixture:
-    # OBSOLETE - To be removed
-    "the Arch Fixture command definition"
+class _CommandIfcExplorer:
+    "the Arch Ifc Explorer command definition"
     def GetResources(self):
-        return {'Pixmap'  : 'Arch_Fixture',
-                'MenuText': QtCore.QT_TRANSLATE_NOOP("Arch_Fixture","Add fixture"),
-                'ToolTip': QtCore.QT_TRANSLATE_NOOP("Arch_Fixture","Adds the selected components as fixtures to the active object")}
+        return {'Pixmap'  : 'IFC',
+                'MenuText': QtCore.QT_TRANSLATE_NOOP("Arch_IfcExplorer","Ifc Explorer"),
+                'ToolTip': QtCore.QT_TRANSLATE_NOOP("Arch_Check","Explore the contents of an Ifc file")}
+
+    def Activated(self):
+        if hasattr(self,"dialog"):
+            del self.dialog
+        import importIFC
+        self.dialog = importIFC.explore()
+
+
+class _CommandSurvey:
+    "the Arch Survey command definition"
+    def GetResources(self):
+        return {'Pixmap'  : 'Arch_Survey',
+                'MenuText': QtCore.QT_TRANSLATE_NOOP("Arch_Survey","Survey"),
+                'ToolTip': QtCore.QT_TRANSLATE_NOOP("Arch_Survey","Starts survey")}
 
     def IsActive(self):
-        if len(FreeCADGui.Selection.getSelection()) > 1:
-            return True
-        else:
-            return False
+        return not FreeCAD.ActiveDocument is None
         
     def Activated(self):
-        sel = FreeCADGui.Selection.getSelection()
-        FreeCAD.ActiveDocument.openTransaction(str(translate("Arch","Grouping")))
-        host = sel.pop()
-        for o in sel:
-            FreeCADGui.doCommand("import Arch")
-            FreeCADGui.doCommand("Arch.addFixture(FreeCAD.ActiveDocument."+o.Name+",FreeCAD.ActiveDocument."+host.Name+")")
-        FreeCAD.ActiveDocument.commitTransaction()
-        FreeCAD.ActiveDocument.recompute()
+        FreeCADGui.doCommand("import Arch")
+        FreeCADGui.doCommand("Arch.survey()")
 
 
-FreeCADGui.addCommand('Arch_Add',_CommandAdd())
-FreeCADGui.addCommand('Arch_Remove',_CommandRemove())
-FreeCADGui.addCommand('Arch_SplitMesh',_CommandSplitMesh())
-FreeCADGui.addCommand('Arch_MeshToShape',_CommandMeshToShape())
-FreeCADGui.addCommand('Arch_SelectNonSolidMeshes',_CommandSelectNonSolidMeshes())
-FreeCADGui.addCommand('Arch_RemoveShape',_CommandRemoveShape())
-FreeCADGui.addCommand('Arch_CloseHoles',_CommandCloseHoles())
-FreeCADGui.addCommand('Arch_Check',_CommandCheck())
-#FreeCADGui.addCommand('Arch_Fixture',_CommandFixture())
+if FreeCAD.GuiUp:
+    FreeCADGui.addCommand('Arch_Add',_CommandAdd())
+    FreeCADGui.addCommand('Arch_Remove',_CommandRemove())
+    FreeCADGui.addCommand('Arch_SplitMesh',_CommandSplitMesh())
+    FreeCADGui.addCommand('Arch_MeshToShape',_CommandMeshToShape())
+    FreeCADGui.addCommand('Arch_SelectNonSolidMeshes',_CommandSelectNonSolidMeshes())
+    FreeCADGui.addCommand('Arch_RemoveShape',_CommandRemoveShape())
+    FreeCADGui.addCommand('Arch_CloseHoles',_CommandCloseHoles())
+    FreeCADGui.addCommand('Arch_Check',_CommandCheck())
+    FreeCADGui.addCommand('Arch_IfcExplorer',_CommandIfcExplorer())
+    FreeCADGui.addCommand('Arch_Survey',_CommandSurvey())
