@@ -21,21 +21,27 @@
 #*                                                                         *
 #***************************************************************************
 
-import FreeCAD,FreeCADGui,Draft,ArchComponent,DraftVecUtils,ArchCommands
+import FreeCAD,Draft,ArchComponent,DraftVecUtils,ArchCommands
 from FreeCAD import Vector
-from PyQt4 import QtCore
-from DraftTools import translate
+if FreeCAD.GuiUp:
+    import FreeCADGui
+    from PySide import QtCore, QtGui
+    from DraftTools import translate
+else:
+    def translate(ctxt,txt):
+        return txt
 
 __title__="FreeCAD Structure"
 __author__ = "Yorik van Havre"
 __url__ = "http://www.freecadweb.org"
 
 # Make some strings picked by the translator
-QtCore.QT_TRANSLATE_NOOP("Arch","Wood")
-QtCore.QT_TRANSLATE_NOOP("Arch","Steel")
+if FreeCAD.GuiUp:
+    QtCore.QT_TRANSLATE_NOOP("Arch","Wood")
+    QtCore.QT_TRANSLATE_NOOP("Arch","Steel")
 
 # Possible roles for structural elements
-Roles = ["Beam","Column","Slab","Wall","Containment wall","Roof","Foundation"]
+Roles = ["Beam","Column","Slab","Wall","Curtain Wall","Roof","Foundation","Pile","Tendon"]
 
 # Presets in the form: Class, Name, Width, Height, [Web thickness, Flange thickness]
 Presets = [None,
@@ -281,11 +287,12 @@ Presets = [None,
 
             ]
 
-def makeStructure(baseobj=None,length=0,width=0,height=0,name=str(translate("Arch","Structure"))):
+def makeStructure(baseobj=None,length=None,width=None,height=None,name=translate("Arch","Structure")):
     '''makeStructure([obj],[length],[width],[heigth],[swap]): creates a
     structure element based on the given profile object and the given
     extrusion height. If no base object is given, you can also specify
     length and width for a cubic object.'''
+    p = FreeCAD.ParamGet("User parameter:BaseApp/Preferences/Mod/Arch")
     obj = FreeCAD.ActiveDocument.addObject("Part::FeaturePython",name)
     _Structure(obj)
     _ViewProviderStructure(obj.ViewObject)
@@ -294,26 +301,45 @@ def makeStructure(baseobj=None,length=0,width=0,height=0,name=str(translate("Arc
         obj.Base.ViewObject.hide()
     if width:
         obj.Width = width
+    else:
+        obj.Width = p.GetFloat("StructureWidth",100)
     if height:
         obj.Height = height
+    else:
+        obj.Height = p.GetFloat("StructureHeight",1000)
     if length:
         obj.Length = length
+    else:
+        if not baseobj:
+            # don't set the length if we have a base object, otherwise the lenght X height calc
+            # gets wrong
+            obj.Length = p.GetFloat("StructureLength",100)
     if height > length:
         obj.Role = "Column"
     obj.ViewObject.ShapeColor = ArchCommands.getDefaultColor("Structure")
     return obj
 
-def makeStructuralSystem(objects,axes):
+def makeStructuralSystem(objects,axes,name=translate("Arch","StructuralSystem")):
     '''makeStructuralSystem(objects,axes): makes a structural system
     based on the given objects and axes'''
     result = []
     if objects and axes:
+        if not isinstance(objects,list):
+            objects = [objects]
         for o in objects:
-            s = makeStructure(o)
-            s.Axes = axes
-            result.append(s)
+            obj = FreeCAD.ActiveDocument.addObject("Part::FeaturePython",name)
+            _StructuralSystem(obj)
+            _ViewProviderStructuralSystem(obj.ViewObject)
+            obj.Base = o
+            obj.Axes = axes
+            result.append(obj)
+            o.ViewObject.hide()
+            Draft.formatObject(obj,o)
         FreeCAD.ActiveDocument.recompute()
-    return result
+    if len(result) == 1:
+        return result[0]
+    else:
+        return result
     
 def makeProfile(W=46,H=80,tw=3.8,tf=5.2,name="Profile"):
     '''makeProfile(W,H,tw,tf): returns a shape with one face describing 
@@ -330,7 +356,6 @@ def makeProfile(W=46,H=80,tw=3.8,tf=5.2,name="Profile"):
     Draft._ViewProviderDraft(obj.ViewObject)
     return obj
 
-
 class _CommandStructure:
     "the Arch Structure command definition"
     def GetResources(self):
@@ -338,33 +363,36 @@ class _CommandStructure:
                 'MenuText': QtCore.QT_TRANSLATE_NOOP("Arch_Structure","Structure"),
                 'Accel': "S, T",
                 'ToolTip': QtCore.QT_TRANSLATE_NOOP("Arch_Structure","Creates a structure object from scratch or from a selected object (sketch, wire, face or solid)")}
+
+    def IsActive(self):
+        return not FreeCAD.ActiveDocument is None
         
-    def Activated(self):
-        
-        global QtGui, QtCore
-        from PyQt4 import QtGui, QtCore
-        
+    def Activated(self):    
         p = FreeCAD.ParamGet("User parameter:BaseApp/Preferences/Mod/Arch")
         self.Length = p.GetFloat("StructureLength",100)
         self.Width = p.GetFloat("StructureWidth",100)
         self.Height = p.GetFloat("StructureHeight",1000)
         self.Profile = 0
         self.continueCmd = False
+        self.DECIMALS = FreeCAD.ParamGet("User parameter:BaseApp/Preferences/Units").GetInt("Decimals",2)
+        import DraftGui
+        self.FORMAT = DraftGui.makeFormatSpec(self.DECIMALS,'Length')
         sel = FreeCADGui.Selection.getSelection()
         if sel:
-            if Draft.getType(sel[0]) != "Structure":
-                # direct creation
+            st = Draft.getObjectsOfType(sel,"Structure")
+            ax = Draft.getObjectsOfType(sel,"Axis")
+            if st and ax:
+                FreeCAD.ActiveDocument.openTransaction(str(translate("Arch","Create Structural System")))
+                FreeCADGui.doCommand("import Arch")
+                FreeCADGui.doCommand("Arch.makeStructuralSystem(" + ArchCommands.getStringList(st) + "," + ArchCommands.getStringList(ax) + ")")
+                FreeCAD.ActiveDocument.commitTransaction()
+                FreeCAD.ActiveDocument.recompute()
+                return
+            elif not(ax) and not(st):
                 FreeCAD.ActiveDocument.openTransaction(str(translate("Arch","Create Structure")))
                 FreeCADGui.doCommand("import Arch")
-                # if selection contains structs and axes, make a system
-                st = Draft.getObjectsOfType(sel,"Structure")
-                ax = Draft.getObjectsOfType(sel,"Axis")
-                if st and ax:
-                    FreeCADGui.doCommand("Arch.makeStructuralSystem(" + ArchCommands.getStringList(st) + "," + ArchCommands.getStringList(ax) + ")")
-                else:
-                    # else, do normal structs
-                    for obj in sel:
-                        FreeCADGui.doCommand("Arch.makeStructure(FreeCAD.ActiveDocument." + obj.Name + ")")
+                for obj in sel:
+                    FreeCADGui.doCommand("Arch.makeStructure(FreeCAD.ActiveDocument." + obj.Name + ")")
                 FreeCAD.ActiveDocument.commitTransaction()
                 FreeCAD.ActiveDocument.recompute()
                 return
@@ -398,6 +426,7 @@ class _CommandStructure:
                 # horizontal
                 FreeCADGui.doCommand('s = Arch.makeStructure(p,height='+str(self.Length)+')')
                 FreeCADGui.doCommand('s.Placement.Rotation = FreeCAD.Rotation(-0.5,0.5,-0.5,0.5)')
+            FreeCADGui.doCommand('s.Profile = "'+pr[1]+'"')
         else:
             FreeCADGui.doCommand('s = Arch.makeStructure(length='+str(self.Length)+',width='+str(self.Width)+',height='+str(self.Height)+')')
         FreeCADGui.doCommand('s.Placement.Base = '+DraftVecUtils.toString(point))
@@ -408,64 +437,58 @@ class _CommandStructure:
 
     def taskbox(self):
         "sets up a taskbox widget"
-        d = FreeCAD.ParamGet("User parameter:BaseApp/Preferences/Units").GetInt("Decimals",2)
         w = QtGui.QWidget()
-        w.setWindowTitle(unicode(translate("Arch","Structure options")))
-        lay0 = QtGui.QVBoxLayout(w)
+        ui = FreeCADGui.UiLoader()
+        w.setWindowTitle(translate("Arch","Structure options").decode("utf8"))
+        grid = QtGui.QGridLayout(w)
         
         # presets box
-        layp = QtGui.QHBoxLayout()
-        lay0.addLayout(layp)
-        labelp = QtGui.QLabel(unicode(translate("Arch","Preset")))
-        layp.addWidget(labelp)
+        labelp = QtGui.QLabel(translate("Arch","Preset").decode("utf8"))
         valuep = QtGui.QComboBox()
         fpresets = [" "]
         for p in Presets[1:]:
             fpresets.append(str(translate("Arch",p[0]))+" "+p[1]+" ("+str(p[2])+"x"+str(p[3])+"mm)")
         valuep.addItems(fpresets)
-        layp.addWidget(valuep)
+        grid.addWidget(labelp,0,0,1,1)
+        grid.addWidget(valuep,0,1,1,1)
         
         # length
-        lay1 = QtGui.QHBoxLayout()
-        lay0.addLayout(lay1)
-        label1 = QtGui.QLabel(unicode(translate("Arch","Length")))
-        lay1.addWidget(label1)
-        self.vLength = QtGui.QDoubleSpinBox()
-        self.vLength.setDecimals(d)
-        self.vLength.setMaximum(99999.99)
-        self.vLength.setValue(self.Length)
-        lay1.addWidget(self.vLength)
+        label1 = QtGui.QLabel(translate("Arch","Length").decode("utf8"))
+        self.vLength = ui.createWidget("Gui::InputField")
+        self.vLength.setText(self.FORMAT % self.Length)
+        grid.addWidget(label1,1,0,1,1)
+        grid.addWidget(self.vLength,1,1,1,1)
         
         # width
-        lay2 = QtGui.QHBoxLayout()
-        lay0.addLayout(lay2)
-        label2 = QtGui.QLabel(unicode(translate("Arch","Width")))
-        lay2.addWidget(label2)
-        self.vWidth = QtGui.QDoubleSpinBox()
-        self.vWidth.setDecimals(d)
-        self.vWidth.setMaximum(99999.99)
-        self.vWidth.setValue(self.Width)
-        lay2.addWidget(self.vWidth)
+        label2 = QtGui.QLabel(translate("Arch","Width").decode("utf8"))
+        self.vWidth = ui.createWidget("Gui::InputField")
+        self.vWidth.setText(self.FORMAT % self.Width)
+        grid.addWidget(label2,2,0,1,1)
+        grid.addWidget(self.vWidth,2,1,1,1)
 
         # height
-        lay3 = QtGui.QHBoxLayout()
-        lay0.addLayout(lay3)
-        label3 = QtGui.QLabel(unicode(translate("Arch","Height")))
-        lay3.addWidget(label3)
-        self.vHeight = QtGui.QDoubleSpinBox()
-        self.vHeight.setDecimals(d)
-        self.vHeight.setMaximum(99999.99)
-        self.vHeight.setValue(self.Height)
-        lay3.addWidget(self.vHeight)
+        label3 = QtGui.QLabel(translate("Arch","Height").decode("utf8"))
+        self.vHeight = ui.createWidget("Gui::InputField")
+        self.vHeight.setText(self.FORMAT % self.Height)
+        grid.addWidget(label3,3,0,1,1)
+        grid.addWidget(self.vHeight,3,1,1,1)
         
         # horizontal button
-        value5 = QtGui.QPushButton(unicode(translate("Arch","Rotate")))
-        lay0.addWidget(value5)
+        value5 = QtGui.QPushButton(translate("Arch","Rotate").decode("utf8"))
+        grid.addWidget(value5,4,0,1,2)
 
         # continue button
-        value4 = QtGui.QCheckBox(unicode(translate("Arch","Continue")))
-        lay0.addWidget(value4)
-        
+        label4 = QtGui.QLabel(translate("Arch","Con&tinue").decode("utf8"))
+        value4 = QtGui.QCheckBox()
+        value4.setObjectName("ContinueCmd")
+        value4.setLayoutDirection(QtCore.Qt.RightToLeft)
+        label4.setBuddy(value4)
+        if hasattr(FreeCADGui,"draftToolBar"):
+            value4.setChecked(FreeCADGui.draftToolBar.continueMode)
+            self.continueCmd = FreeCADGui.draftToolBar.continueMode
+        grid.addWidget(label4,5,0,1,1)
+        grid.addWidget(value4,5,1,1,1)
+
         QtCore.QObject.connect(valuep,QtCore.SIGNAL("currentIndexChanged(int)"),self.setPreset)
         QtCore.QObject.connect(self.vLength,QtCore.SIGNAL("valueChanged(double)"),self.setLength)
         QtCore.QObject.connect(self.vWidth,QtCore.SIGNAL("valueChanged(double)"),self.setWidth)
@@ -476,11 +499,12 @@ class _CommandStructure:
         
     def update(self,point,info):
         "this function is called by the Snapper when the mouse is moved"
-        if self.Height >= self.Length:
-            delta = Vector(0,0,self.Height/2)
-        else:
-            delta = Vector(self.Length/2,0,0)
-        self.tracker.pos(point.add(delta))
+        if FreeCADGui.Control.activeDialog():
+            if self.Height >= self.Length:
+                delta = Vector(0,0,self.Height/2)
+            else:
+                delta = Vector(self.Length/2,0,0)
+            self.tracker.pos(point.add(delta))
         
     def setWidth(self,d):
         self.Width = d
@@ -496,11 +520,13 @@ class _CommandStructure:
 
     def setContinue(self,i):
         self.continueCmd = bool(i)
+        if hasattr(FreeCADGui,"draftToolBar"):
+            FreeCADGui.draftToolBar.continueMode = bool(i)
         
     def setPreset(self,i):
         if i > 0:
-            self.vLength.setValue(float(Presets[i][2]))
-            self.vWidth.setValue(float(Presets[i][3]))
+            self.vLength.setText(self.FORMAT % float(Presets[i][2]))
+            self.vWidth.setText(self.FORMAT % float(Presets[i][3]))
         if len(Presets[i]) == 6:
             self.Profile = i
         else:
@@ -510,38 +536,24 @@ class _CommandStructure:
         l = self.Length
         w = self.Width
         h = self.Height
-        self.vLength.setValue(h)
-        self.vHeight.setValue(w)
-        self.vWidth.setValue(l)
+        self.vLength.setText(self.FORMAT % h)
+        self.vHeight.setText(self.FORMAT % w)
+        self.vWidth.setText(self.FORMAT % l)
        
 class _Structure(ArchComponent.Component):
     "The Structure object"
     def __init__(self,obj):
         ArchComponent.Component.__init__(self,obj)
-        obj.addProperty("App::PropertyLink","Tool","Arch",
-                        "An optional extrusion path for this element")
-        obj.addProperty("App::PropertyLength","Length","Arch",
-                        str(translate("Arch","The length of this element, if not based on a profile")))
-        obj.addProperty("App::PropertyLength","Width","Arch",
-                        str(translate("Arch","The width of this element, if not based on a profile")))
-        obj.addProperty("App::PropertyLength","Height","Arch",
-                        str(translate("Arch","The height or extrusion depth of this element. Keep 0 for automatic")))
-        obj.addProperty("App::PropertyLinkList","Axes","Arch",
-                        str(translate("Arch","Axes systems this structure is built on")))
-        obj.addProperty("App::PropertyLinkList","Armatures","Arch",
-                        str(translate("Arch","Armatures contained in this element")))
-        obj.addProperty("App::PropertyVector","Normal","Arch",
-                        str(translate("Arch","The normal extrusion direction of this object (keep (0,0,0) for automatic normal)")))
-        obj.addProperty("App::PropertyIntegerList","Exclude","Arch",
-                        str(translate("Arch","The element numbers to exclude when this structure is based on axes")))
-        obj.addProperty("App::PropertyEnumeration","Role","Arch",
-                        str(translate("Arch","The role of this structural element")))
-        obj.addProperty("App::PropertyVectorList","Nodes","Arch",
-                        str(translate("Arch","The structural nodes of this element")))
+        obj.addProperty("App::PropertyLink","Tool","Arch",translate("Arch","An optional extrusion path for this element"))
+        obj.addProperty("App::PropertyLength","Length","Arch",translate("Arch","The length of this element, if not based on a profile"))
+        obj.addProperty("App::PropertyLength","Width","Arch",translate("Arch","The width of this element, if not based on a profile"))
+        obj.addProperty("App::PropertyLength","Height","Arch",translate("Arch","The height or extrusion depth of this element. Keep 0 for automatic"))
+        obj.addProperty("App::PropertyLinkList","Armatures","Arch",translate("Arch","Armatures contained in this element"))
+        obj.addProperty("App::PropertyVector","Normal","Arch",translate("Arch","The normal extrusion direction of this object (keep (0,0,0) for automatic normal)"))
+        obj.addProperty("App::PropertyEnumeration","Role","Arch",translate("Arch","The role of this structural element"))
+        obj.addProperty("App::PropertyVectorList","Nodes","Arch",translate("Arch","The structural nodes of this element"))
+        obj.addProperty("App::PropertyString","Profile","Arch","A description of the standard profile this element is based upon")
         self.Type = "Structure"
-        obj.Length = 1
-        obj.Width = 1
-        obj.Height = 1
         obj.Role = Roles
         
     def execute(self,obj):
@@ -549,34 +561,32 @@ class _Structure(ArchComponent.Component):
         
         import Part, DraftGeomUtils
         
-        # getting default values
-        height = width = length = 1
-        if hasattr(obj,"Length"):
-            if obj.Length:
-                length = obj.Length
-        if hasattr(obj,"Width"):
-            if obj.Width:
-                width = obj.Width
-        if hasattr(obj,"Height"):
-            if obj.Height:
-                height = obj.Height
+        normal,length,width,height = self.getDefaultValues(obj)
 
         # creating base shape
         pl = obj.Placement
         base = None
         if obj.Base:
             if obj.Base.isDerivedFrom("Part::Feature"):
+                if obj.Base.Shape.isNull():
+                    return
+                if not obj.Base.Shape.isValid():
+                    if not obj.Base.Shape.Solids:
+                        # let pass invalid objects if they have solids...
+                        return
                 if hasattr(obj,"Tool"):
                     if obj.Tool:
                         try:
                             base = obj.Tool.Shape.copy().makePipe(obj.Base.Shape.copy())
                         except:
-                            FreeCAD.Console.PrintError(str(translate("Arch","Error: The base shape couldn't be extruded along this tool object")))
+                            FreeCAD.Console.PrintError(translate("Arch","Error: The base shape couldn't be extruded along this tool object"))
                             return
                 if not base:
+                    if not height:
+                        return
                     if obj.Normal == Vector(0,0,0):
                         p = FreeCAD.Placement(obj.Base.Placement)
-                        normal = p.Rotation.multVec(Vector(0,0,1))
+                        normal = p.Rotation.multVec(normal)
                     else:
                         normal = Vector(obj.Normal)
                     normal = normal.multiply(height)
@@ -584,128 +594,58 @@ class _Structure(ArchComponent.Component):
                     if base.Solids:
                         pass
                     elif base.Faces:
-                        self.BaseProfile = base
-                        self.ExtrusionVector = normal
                         base = base.extrude(normal)
                     elif (len(base.Wires) == 1):
                         if base.Wires[0].isClosed():
                             base = Part.Face(base.Wires[0])
-                            self.BaseProfile = base
-                            self.ExtrusionVector = normal
                             base = base.extrude(normal)
                             
             elif obj.Base.isDerivedFrom("Mesh::Feature"):
                 if obj.Base.Mesh.isSolid():
                     if obj.Base.Mesh.countComponents() == 1:
                         sh = ArchCommands.getShapeFromMesh(obj.Base.Mesh)
-                        if sh.isClosed() and sh.isValid() and sh.Solids:
+                        if sh.isClosed() and sh.isValid() and sh.Solids and (not sh.isNull()):
                             base = sh
+                        else:
+                            FreeCAD.Console.PrintWarning(str(translate("Arch","This mesh is an invalid solid")))
+                            obj.Base.ViewObject.show()
         else:
-            if obj.Normal == Vector(0,0,0):
+            base = self.getProfiles(obj)
+            if base:
                 if length > height:
-                    normal = Vector(1,0,0).multiply(length)
+                    normal = normal.multiply(length)
                 else:
-                    normal = Vector(0,0,1).multiply(height)
-            else:
-                normal = Vector(obj.Normal).multiply(height)
-            self.ExtrusionVector = normal
-            if length > height:
-                h2 = height/2 or 0.5
-                w2 = width/2 or 0.5
-                v1 = Vector(0,-w2,-h2)
-                v2 = Vector(0,-w2,h2)
-                v3 = Vector(0,w2,h2)
-                v4 = Vector(0,w2,-h2)
-            else:
-                l2 = length/2 or 0.5
-                w2 = width/2 or 0.5
-                v1 = Vector(-l2,-w2,0)
-                v2 = Vector(l2,-w2,0)
-                v3 = Vector(l2,w2,0)
-                v4 = Vector(-l2,w2,0)
-            base = Part.makePolygon([v1,v2,v3,v4,v1])
-            base = Part.Face(base)
-            self.BaseProfile = base
-            base = base.extrude(self.ExtrusionVector)
+                    normal = normal.multiply(height)
+                base = Part.Face(base[0])
+                base = base.extrude(normal)
             
         base = self.processSubShapes(obj,base,pl)
-            
-        if base:
-            # applying axes
-            pts = self.getAxisPoints(obj)
-            apl = self.getAxisPlacement(obj)
-            if pts:
-                fsh = []
-                for i in range(len(pts)):
-                    if hasattr(obj,"Exclude"):
-                        if i in obj.Exclude:
-                            continue
-                    sh = base.copy()
-                    if apl:
-                        sh.Placement.Rotation = apl.Rotation
-                    sh.translate(pts[i])
-                    fsh.append(sh)
-                    obj.Shape = Part.makeCompound(fsh)
-
-            # finalizing
-            else:
-                if base:
-                    if not base.isNull():
-                        if base.isValid() and base.Solids:
-                            if base.Volume < 0:
-                                base.reverse()
-                            if base.Volume < 0:
-                                FreeCAD.Console.PrintError(str(translate("Arch","Couldn't compute a shape")))
-                                return
-                            base = base.removeSplitter()
-                            obj.Shape = base
-                if not pl.isNull():
-                    obj.Placement = pl
+        self.applyShape(obj,base,pl)
 
     def onChanged(self,obj,prop):
         self.hideSubobjects(obj,prop)
         if prop == "Shape":
-            if obj.Nodes:
-                if hasattr(self,"nodes"):
-                    if self.nodes:
-                        if obj.Nodes != self.nodes:
-                            # nodes are set manually: don't touch them
+            if hasattr(obj,"Nodes"):
+                # update structural nodes
+                if obj.Nodes:
+                    if hasattr(self,"nodes"):
+                        if self.nodes:
+                            if obj.Nodes != self.nodes:
+                                # nodes are set manually: don't touch them
+                                return
+                    else:
+                        # nodes haven't been calculated yet, but are set (file load)
+                        # we calculate the nodes now but don't change the property
+                        axis = self.getAxis(obj)
+                        if axis:
+                            self.nodes = [v.Point for v in axis.Vertexes]
                             return
-                else:
-                    # nodes haven't been calculated yet, but are set (file load)
-                    # we calculate the nodes now but don't change the property
-                    if hasattr(self,"BaseProfile")  and hasattr(self,"ExtrusionVector"):
-                        p1 = self.BaseProfile.CenterOfMass
-                        p2 = p1.add(self.ExtrusionVector)
-                        self.nodes = [p1,p2]
-                        return
-            if hasattr(self,"BaseProfile")  and hasattr(self,"ExtrusionVector"):
-                p1 = self.BaseProfile.CenterOfMass
-                p2 = p1.add(self.ExtrusionVector)
-                self.nodes = [p1,p2]
-                #print "calculating nodes: ",self.nodes
-                obj.Nodes = self.nodes
-        
-    def getAxisPoints(self,obj):
-        "returns the gridpoints of linked axes"
-        import DraftGeomUtils
-        pts = []
-        if len(obj.Axes) == 1:
-            for e in obj.Axes[0].Shape.Edges:
-                pts.append(e.Vertexes[0].Point)
-        elif len(obj.Axes) >= 2:
-            set1 = obj.Axes[0].Shape.Edges
-            set2 = obj.Axes[1].Shape.Edges
-            for e1 in set1:
-                for e2 in set2: 
-                    pts.extend(DraftGeomUtils.findIntersection(e1,e2))
-        return pts
+                # we calculate and set the nodes
+                axis = self.getAxis(obj)
+                if axis:
+                    self.nodes = [v.Point for v in axis.Vertexes]
+                    obj.Nodes = self.nodes
 
-    def getAxisPlacement(self,obj):
-        "returns an axis placement"
-        if obj.Axes:
-            return obj.Axes[0].Placement
-        return None
 
 class _ViewProviderStructure(ArchComponent.ViewProviderComponent):
     "A View Provider for the Structure object"
@@ -773,40 +713,122 @@ class _ViewProviderStructure(ArchComponent.ViewProviderComponent):
                 self.pointstyle.pointSize = vobj.NodeSize
         ArchComponent.ViewProviderComponent.onChanged(self,vobj,prop)
 
-
 class _Profile(Draft._DraftObject):
     "A parametric beam profile object"
     
     def __init__(self,obj):
-        obj.addProperty("App::PropertyDistance","Width","Draft","Width of the beam").Width = 10
-        obj.addProperty("App::PropertyDistance","Height","Draft","Height of the beam").Height = 30
-        obj.addProperty("App::PropertyDistance","WebThickness","Draft","Thickness of the webs").WebThickness = 3
-        obj.addProperty("App::PropertyDistance","FlangeThickness","Draft","Thickness of the flange").FlangeThickness = 2
+        obj.addProperty("App::PropertyLength","Width","Draft","Width of the beam").Width = 10
+        obj.addProperty("App::PropertyLength","Height","Draft","Height of the beam").Height = 30
+        obj.addProperty("App::PropertyLength","WebThickness","Draft","Thickness of the webs").WebThickness = 3
+        obj.addProperty("App::PropertyLength","FlangeThickness","Draft","Thickness of the flange").FlangeThickness = 2
         Draft._DraftObject.__init__(self,obj,"Profile")
         
     def execute(self,obj):
         import Part
         pl = obj.Placement
-        p1 = Vector(-obj.Width/2,-obj.Height/2,0)
-        p2 = Vector(obj.Width/2,-obj.Height/2,0)
-        p3 = Vector(obj.Width/2,(-obj.Height/2)+obj.FlangeThickness,0)
-        p4 = Vector(obj.WebThickness/2,(-obj.Height/2)+obj.FlangeThickness,0)
-        p5 = Vector(obj.WebThickness/2,obj.Height/2-obj.FlangeThickness,0)
-        p6 = Vector(obj.Width/2,obj.Height/2-obj.FlangeThickness,0)
-        p7 = Vector(obj.Width/2,obj.Height/2,0)
-        p8 = Vector(-obj.Width/2,obj.Height/2,0)
-        p9 = Vector(-obj.Width/2,obj.Height/2-obj.FlangeThickness,0)
-        p10 = Vector(-obj.WebThickness/2,obj.Height/2-obj.FlangeThickness,0)
-        p11 = Vector(-obj.WebThickness/2,(-obj.Height/2)+obj.FlangeThickness,0)
-        p12 = Vector(-obj.Width/2,(-obj.Height/2)+obj.FlangeThickness,0)
+        p1 = Vector(-obj.Width.Value/2,-obj.Height.Value/2,0)
+        p2 = Vector(obj.Width.Value/2,-obj.Height.Value/2,0)
+        p3 = Vector(obj.Width.Value/2,(-obj.Height.Value/2)+obj.FlangeThickness.Value,0)
+        p4 = Vector(obj.WebThickness.Value/2,(-obj.Height.Value/2)+obj.FlangeThickness.Value,0)
+        p5 = Vector(obj.WebThickness.Value/2,obj.Height.Value/2-obj.FlangeThickness.Value,0)
+        p6 = Vector(obj.Width.Value/2,obj.Height.Value/2-obj.FlangeThickness.Value,0)
+        p7 = Vector(obj.Width.Value/2,obj.Height.Value/2,0)
+        p8 = Vector(-obj.Width.Value/2,obj.Height.Value/2,0)
+        p9 = Vector(-obj.Width.Value/2,obj.Height.Value/2-obj.FlangeThickness.Value,0)
+        p10 = Vector(-obj.WebThickness.Value/2,obj.Height.Value/2-obj.FlangeThickness.Value,0)
+        p11 = Vector(-obj.WebThickness.Value/2,(-obj.Height.Value/2)+obj.FlangeThickness.Value,0)
+        p12 = Vector(-obj.Width.Value/2,(-obj.Height.Value/2)+obj.FlangeThickness.Value,0)
         p = Part.makePolygon([p1,p2,p3,p4,p5,p6,p7,p8,p9,p10,p11,p12,p1])
         p = Part.Face(p)
         obj.Shape = p
         obj.Placement = pl
+
+class _StructuralSystem(ArchComponent.Component):
+    "The Structural System object"
+    def __init__(self,obj):
+        ArchComponent.Component.__init__(self,obj)
+        obj.addProperty("App::PropertyLinkList","Axes","Arch",translate("Arch","Axes systems this structure is built on"))
+        obj.addProperty("App::PropertyIntegerList","Exclude","Arch",translate("Arch","The element numbers to exclude when this structure is based on axes"))
+        self.Type = "StructuralSystem"
         
-    def onChanged(self,obj,prop):
-        if prop in ["Width","Height","WebThickness","FlangeThickness"]:
-            self.execute(obj)
+    def execute(self,obj):
+        "creates the structure shape"
+        
+        import Part, DraftGeomUtils
+        
+        # creating base shape
+        pl = obj.Placement
+        if obj.Base:
+            if obj.Base.isDerivedFrom("Part::Feature"):
+                if obj.Base.Shape.isNull():
+                    return
+                if not obj.Base.Shape.Solids:
+                    return
+
+                base = None
+                                
+                # applying axes
+                pts = self.getAxisPoints(obj)
+                apl = self.getAxisPlacement(obj)
+
+                if pts:
+                    fsh = []
+                    for i in range(len(pts)):
+                        sh = obj.Base.Shape.copy()
+                        if hasattr(obj,"Exclude"):
+                            if i in obj.Exclude:
+                                continue
+                        if apl:
+                            sh.Placement.Rotation = sh.Placement.Rotation.multiply(apl.Rotation)
+                        sh.translate(pts[i])
+                        fsh.append(sh)
+
+                    if fsh:
+                        base = Part.makeCompound(fsh)
+                        base = self.processSubShapes(obj,base,pl)
+
+                if base:
+                    if not base.isNull():
+                        if base.isValid() and base.Solids:
+                            if base.Volume < 0:
+                                base.reverse()
+                            if base.Volume < 0:
+                                FreeCAD.Console.PrintError(translate("Arch","Couldn't compute a shape"))
+                                return
+                            base = base.removeSplitter()
+                            obj.Shape = base
+                            if not pl.isNull():
+                                obj.Placement = pl
+        
+    def getAxisPoints(self,obj):
+        "returns the gridpoints of linked axes"
+        import DraftGeomUtils
+        pts = []
+        if len(obj.Axes) == 1:
+            for e in obj.Axes[0].Shape.Edges:
+                pts.append(e.Vertexes[0].Point)
+        elif len(obj.Axes) >= 2:
+            set1 = obj.Axes[0].Shape.Edges
+            set2 = obj.Axes[1].Shape.Edges
+            for e1 in set1:
+                for e2 in set2: 
+                    pts.extend(DraftGeomUtils.findIntersection(e1,e2))
+        return pts
+
+    def getAxisPlacement(self,obj):
+        "returns an axis placement"
+        if obj.Axes:
+            return obj.Axes[0].Placement
+        return None
 
 
-FreeCADGui.addCommand('Arch_Structure',_CommandStructure())
+class _ViewProviderStructuralSystem(ArchComponent.ViewProviderComponent):
+    "A View Provider for the Structural System object"
+
+    def getIcon(self):
+        import Arch_rc
+        return ":/icons/Arch_StructuralSystem_Tree.svg"
+
+
+if FreeCAD.GuiUp:
+    FreeCADGui.addCommand('Arch_Structure',_CommandStructure())
