@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS>
+<TS version="2.0" language="cs" sourcelanguage="en">
   <context>
     <name>AssemblyGui::Workbench</name>
     <message>
@@ -17,19 +17,21 @@
       <translation>Sestava</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Constraint Axle...</source>
       <translation>Vazba osy...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>set a axle constraint between two objects</source>
-      <translation>Vlož osovou vazbu mezi dva objekty</translation>
+      <translation>Nastavit vazbu os mezi dvěma objekty</translation>
     </message>
   </context>
   <context>
     <name>Workbench</name>
     <message>
       <source>Assembly</source>
-      <translation>Sestava</translation>
+      <translation type="obsolete">Sestava</translation>
     </message>
   </context>
 </TS>
