@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS>
+<TS version="2.0" language="pt-BR" sourcelanguage="en">
   <context>
     <name>AssemblyGui::Workbench</name>
     <message>
@@ -17,19 +17,21 @@
       <translation>Assemblagem</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Constraint Axle...</source>
       <translation>Restrição de eixo...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>set a axle constraint between two objects</source>
-      <translation>definir uma restrição de eixo entre dois objetos</translation>
+      <translation>colocar uma restrição de eixo entre dois objetos</translation>
     </message>
   </context>
   <context>
     <name>Workbench</name>
     <message>
       <source>Assembly</source>
-      <translation>Assemblagem</translation>
+      <translation type="obsolete">Assemblagem</translation>
     </message>
   </context>
 </TS>
