@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS>
+<TS version="2.0" language="ro" sourcelanguage="en">
   <context>
     <name>AssemblyGui::Workbench</name>
     <message>
@@ -17,11 +17,13 @@
       <translation>Ansamblu</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Constraint Axle...</source>
       <translation>Axul de restricție...
 </translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>set a axle constraint between two objects</source>
       <translation>setează o restricție axială între două obiecte</translation>
     </message>
@@ -30,7 +32,7 @@
     <name>Workbench</name>
     <message>
       <source>Assembly</source>
-      <translation>Ansamblu</translation>
+      <translation type="obsolete">Ansamblu</translation>
     </message>
   </context>
 </TS>
