@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS>
+<TS version="2.0" language="zh-TW" sourcelanguage="en">
   <context>
     <name>AssemblyGui::Workbench</name>
     <message>
@@ -17,10 +17,12 @@
       <translation>程式集</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Constraint Axle...</source>
       <translation>約束軸 ...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>set a axle constraint between two objects</source>
       <translation>在兩個物件之間設置軸約束</translation>
     </message>
@@ -29,7 +31,7 @@
     <name>Workbench</name>
     <message>
       <source>Assembly</source>
-      <translation>程式集</translation>
+      <translation type="obsolete">程式集</translation>
     </message>
   </context>
 </TS>
