@@ -85,37 +85,11 @@ def isNull(something):
 
 def isPtOnEdge(pt,edge) :
     '''isPtOnEdge(Vector,edge): Tests if a point is on an edge'''
-    if isinstance(edge.Curve,Part.Line) :
-        orig = edge.Vertexes[0].Point
-        #if DraftVecUtils.isNull(pt.sub(orig).cross(vec(edge))) : <== can give unprecise results
-        if round(pt.sub(orig).getAngle(vec(edge)),precision()) == 0:
-            return pt.sub(orig).Length <= vec(edge).Length and pt.sub(orig).dot(vec(edge)) >= 0
-        else : 
-            return False
-        
-    elif isinstance(edge.Curve,Part.Circle) :
-        center = edge.Curve.Center
-        axis   = edge.Curve.Axis ; axis.normalize()
-        radius = edge.Curve.Radius
-        if  round(pt.sub(center).dot(axis),precision()) == 0 \
-        and round(pt.sub(center).Length - radius,precision()) == 0 :
-            if len(edge.Vertexes) == 1 :
-                return True # edge is a complete circle
-            else :
-                begin = edge.Vertexes[0].Point
-                end   = edge.Vertexes[-1].Point
-                if DraftVecUtils.isNull(pt.sub(begin)) or DraftVecUtils.isNull(pt.sub(end)) :
-                    return True
-                else :
-                    # newArc = Part.Arc(begin,pt,end)
-                    # return DraftVecUtils.isNull(newArc.Center.sub(center)) \
-                    #    and DraftVecUtils.isNull(newArc.Axis-axis) \
-                    #    and round(newArc.Radius-radius,precision()) == 0
-                    angle1 = DraftVecUtils.angle(begin.sub(center))
-                    angle2 = DraftVecUtils.angle(end.sub(center))
-                    anglept = DraftVecUtils.angle(pt.sub(center))
-                    if (angle1 < anglept) and (anglept < angle2):
-                        return True
+    v = Part.Vertex(pt)
+    d = v.distToShape(edge)
+    if d:
+        if round(d[0],precision()) == 0:
+            return True
     return False
 
 def hasCurves(shape):
@@ -152,7 +126,7 @@ def isAligned(edge,axis="x"):
             if edge.StartPoint.z == edge.EndPoint.z:
                     return True
     return False
-    
+
 def areColinear(e1,e2):
     """areColinear(e1,e2): returns True if both edges are colinear"""
     if not isinstance(e1.Curve,Part.Line):
@@ -171,7 +145,6 @@ def areColinear(e1,e2):
             if (a2 == 0) or (a2 == round(math.pi,precision())):
                 return True
     return False
-    
 
 def hasOnlyWires(shape):
     "hasOnlyWires(shape): returns True if all the edges are inside a wire"
@@ -181,7 +154,7 @@ def hasOnlyWires(shape):
     if ne == len(shape.Edges):
         return True
     return False
-    
+
 def geomType(edge):
     "returns the type of geom this edge is based on"
     try:
@@ -191,13 +164,15 @@ def geomType(edge):
             return "Circle"
         elif isinstance(edge.Curve,Part.BSplineCurve):
             return "BSplineCurve"
+        elif isinstance(edge.Curve,Part.BezierCurve):
+            return "BezierCurve"
         elif isinstance(edge.Curve,Part.Ellipse):
             return "Ellipse"
         else:
             return "Unknown"
     except:
         return "Unknown"
-        
+
 def isValidPath(shape):
     "isValidPath(shape): returns True if the shape can be used as an extrusion path"
     if shape.isNull():
@@ -278,6 +253,14 @@ def findIntersection(edge1,edge2,infinite1=False,infinite2=False,ex1=False,ex2=F
         else :
             return [] # Lines aren't on same plane
 
+    # First, try to use distToShape if possible
+    if isinstance(edge1,Part.Edge) and isinstance(edge2,Part.Edge) and (not infinite1) and (not infinite2):
+        dist, pts, geom = edge1.distToShape(edge2)
+        sol = []
+        for p in pts:
+            sol.append(p[0])
+        return sol
+
     pt1 = None
 
     if isinstance(edge1,FreeCAD.Vector) and isinstance(edge2,FreeCAD.Vector):
@@ -327,21 +310,25 @@ def findIntersection(edge1,edge2,infinite1=False,infinite2=False,ex1=False,ex2=F
             # Line and Arc are on same plane
             
             dOnLine = center.sub(pt1).dot(dirVec)
-            onLine  = Vector(dirVec) ; onLine.scale(dOnLine,dOnLine,dOnLine)
+            onLine  = Vector(dirVec)
+            onLine.scale(dOnLine,dOnLine,dOnLine)
             toLine  = pt1.sub(center).add(onLine)
             
             if toLine.Length < arc.Curve.Radius :
                 dOnLine = (arc.Curve.Radius**2 - toLine.Length**2)**(0.5)
-                onLine  = Vector(dirVec) ; onLine.scale(dOnLine,dOnLine,dOnLine)
+                onLine  = Vector(dirVec)
+                onLine.scale(dOnLine,dOnLine,dOnLine)
                 int = [center.add(toLine).add(onLine)]
-                onLine  = Vector(dirVec) ; onLine.scale(-dOnLine,-dOnLine,-dOnLine)
+                onLine  = Vector(dirVec)
+                onLine.scale(-dOnLine,-dOnLine,-dOnLine)
                 int += [center.add(toLine).add(onLine)]
             elif round(toLine.Length-arc.Curve.Radius,precision()) == 0 :
                 int = [center.add(toLine)]
             else :
                 return []
                 
-        else : # Line isn't on Arc's plane
+        else : 
+            # Line isn't on Arc's plane
             if dirVec.dot(arc.Curve.Axis) != 0 :
                 toPlane  = Vector(arc.Curve.Axis) ; toPlane.normalize()
                 d = pt1.dot(toPlane)
@@ -607,7 +594,8 @@ def sortEdges(lEdges, aVertex=None):
                     elif geomType(result[3]) == "Circle":
                         mp = findMidpoint(result[3])
                         return [Part.Arc(aVertex.Point,mp,result[3].Vertexes[0].Point).toShape()]
-                    elif geomType(result[3]) == "BSplineCurve":
+                    elif geomType(result[3]) == "BSplineCurve" or\
+                        geomType(result[3]) == "BezierCurve":
                         if isLine(result[3].Curve):
                             return [Part.Line(aVertex.Point,result[3].Vertexes[0].Point).toShape()]
                         else:
@@ -645,7 +633,8 @@ def sortEdges(lEdges, aVertex=None):
                     mp = findMidpoint(result[3])
                     newedge = Part.Arc(aVertex.Point,mp,result[3].Vertexes[0].Point).toShape()
                     olEdges += [newedge] + next
-                elif geomType(result[3]) == "BSplineCurve":
+                elif geomType(result[3]) == "BSplineCurve" or \
+                    geomType(result[3]) == "BezierCurve":
                     if isLine(result[3].Curve):
                         newedge = Part.Line(aVertex.Point,result[3].Vertexes[0].Point).toShape()
                         olEdges += [newedge] + next
@@ -958,95 +947,103 @@ def calculatePlacement(shape):
     return pla
 
 def offsetWire(wire,dvec,bind=False,occ=False):
-        '''
-        offsetWire(wire,vector,[bind]): offsets the given wire along the
-        given vector. The vector will be applied at the first vertex of
-        the wire. If bind is True (and the shape is open), the original
-        wire and the offsetted one are bound by 2 edges, forming a face.
-        '''
-        edges = sortEdges(wire.Edges)
-        norm = getNormal(wire)
-        closed = isReallyClosed(wire)
-        nedges = []
-        if occ:
-                l=abs(dvec.Length)
-                if not l: return None
-                if wire.Wires:
-                        wire = wire.Wires[0]
-                else:
-                        wire = Part.Wire(edges)
-                try:
-                        off = wire.makeOffset(l)
-                except:
-                        return None
-                else:
-                        return off
-        for i in range(len(edges)):
-                curredge = edges[i]
-                delta = dvec
-                if i != 0:
-                        angle = DraftVecUtils.angle(vec(edges[0]),vec(curredge),norm)
-                        delta = DraftVecUtils.rotate(delta,angle,norm)
-                nedge = offset(curredge,delta)
-                nedges.append(nedge)
-        nedges = connect(nedges,closed)
-        if bind and not closed:
-                e1 = Part.Line(edges[0].Vertexes[0].Point,nedges[0].Vertexes[0].Point).toShape()
-                e2 = Part.Line(edges[-1].Vertexes[-1].Point,nedges[-1].Vertexes[-1].Point).toShape()
-                alledges = edges.extend(nedges)
-                alledges = alledges.extend([e1,e2])
-                w = Part.Wire(alledges)
-                return w
+    '''
+    offsetWire(wire,vector,[bind]): offsets the given wire along the
+    given vector. The vector will be applied at the first vertex of
+    the wire. If bind is True (and the shape is open), the original
+    wire and the offsetted one are bound by 2 edges, forming a face.
+    '''
+    edges = sortEdges(wire.Edges)
+    norm = getNormal(wire)
+    closed = isReallyClosed(wire)
+    nedges = []
+    if occ:
+        l=abs(dvec.Length)
+        if not l: return None
+        if wire.Wires:
+            wire = wire.Wires[0]
         else:
-                return nedges
+            wire = Part.Wire(edges)
+        try:
+            off = wire.makeOffset(l)
+        except:
+            return None
+        else:
+            return off
+    for i in range(len(edges)):
+        curredge = edges[i]
+        delta = dvec
+        if i != 0:
+            if isinstance(curredge.Curve,Part.Circle):
+                v = curredge.tangentAt(curredge.FirstParameter)
+            else:
+                v = vec(curredge)
+            angle = DraftVecUtils.angle(vec(edges[0]),v,norm)
+            delta = DraftVecUtils.rotate(delta,angle,norm)
+        nedge = offset(curredge,delta)
+        if isinstance(curredge.Curve,Part.Circle):
+            nedge = Part.ArcOfCircle(nedge.Curve,curredge.FirstParameter,curredge.LastParameter).toShape()
+        nedges.append(nedge)
+        FreeCAD.n=nedges
+    nedges = connect(nedges,closed)
+    if bind and not closed:
+        e1 = Part.Line(edges[0].Vertexes[0].Point,nedges[0].Vertexes[0].Point).toShape()
+        e2 = Part.Line(edges[-1].Vertexes[-1].Point,nedges[-1].Vertexes[-1].Point).toShape()
+        alledges = edges.extend(nedges)
+        alledges = alledges.extend([e1,e2])
+        w = Part.Wire(alledges)
+        return w
+    else:
+        return nedges
 
 def connect(edges,closed=False):
         '''connects the edges in the given list by their intersections'''
         nedges = []
         for i in range(len(edges)):
-                curr = edges[i]
-                # print "DraftGeomUtils.connect edge ",i," : ",curr.Vertexes[0].Point,curr.Vertexes[-1].Point
-                if i > 0:
-                        prev = edges[i-1]
+            curr = edges[i]
+            #print "debug: DraftGeomUtils.connect edge ",i," : ",curr.Vertexes[0].Point,curr.Vertexes[-1].Point
+            if i > 0:
+                prev = edges[i-1]
+            else:
+                if closed:
+                    prev = edges[-1]
                 else:
-                        if closed:
-                                prev = edges[-1]
-                        else:
-                                prev = None
-                if i < (len(edges)-1):
-                        next = edges[i+1]
+                    prev = None
+            if i < (len(edges)-1):
+                next = edges[i+1]
+            else:
+                if closed: next = edges[0]
                 else:
-                        if closed: next = edges[0]
-                        else:
-                                next = None
-                if prev:
-                        # print "debug: DraftGeomUtils.connect prev : ",prev.Vertexes[0].Point,prev.Vertexes[-1].Point
-                        i = findIntersection(curr,prev,True,True)
-                        if i:
-                                v1 = i[0]
-                        else:
-                                v1 = curr.Vertexes[0].Point
+                    next = None
+            if prev:
+                #print "debug: DraftGeomUtils.connect prev : ",prev.Vertexes[0].Point,prev.Vertexes[-1].Point
+                i = findIntersection(curr,prev,True,True)
+                if i:
+                    v1 = i[0]
+                else:    
+                    v1 = curr.Vertexes[0].Point
+            else:
+                v1 = curr.Vertexes[0].Point
+            if next:
+                #print "debug: DraftGeomUtils.connect next : ",next.Vertexes[0].Point,next.Vertexes[-1].Point
+                i = findIntersection(curr,next,True,True)
+                if i:
+                    v2 = i[0]
                 else:
-                        v1 = curr.Vertexes[0].Point
-                if next:
-                        # print "debug: DraftGeomUtils.connect next : ",next.Vertexes[0].Point,next.Vertexes[-1].Point
-                        i = findIntersection(curr,next,True,True)
-                        if i:
-                                v2 = i[0]
-                        else:
-                                v2 = curr.Vertexes[-1].Point 
-                else:
-                        v2 = curr.Vertexes[-1].Point
-                if geomType(curr) == "Line":
-                        if v1 != v2:
-                                nedges.append(Part.Line(v1,v2).toShape())
-                elif geomType(curr) == "Circle":
-                        if v1 != v2:
-                                nedges.append(Part.Arc(v1,findMidpoint(curr),v2))
+                    v2 = curr.Vertexes[-1].Point 
+            else:
+                v2 = curr.Vertexes[-1].Point
+            if geomType(curr) == "Line":
+                if v1 != v2:
+                    nedges.append(Part.Line(v1,v2).toShape())
+            elif geomType(curr) == "Circle":
+                if v1 != v2:
+                    nedges.append(Part.Arc(v1,findMidpoint(curr),v2).toShape())
         try:
-                return Part.Wire(nedges)
+            return Part.Wire(nedges)
         except:
-                return None
+            print "DraftGeomUtils.connect: unable to connect edges:",nedges
+            return None
 
 def findDistance(point,edge,strict=False):
     '''
@@ -1096,7 +1093,8 @@ def findDistance(point,edge,strict=False):
                     return None
             else:
                 return dist
-        elif geomType(edge) == "BSplineCurve":
+        elif geomType(edge) == "BSplineCurve" or \
+            geomType(edge) == "BezierCurve":
             try:
                     pr = edge.Curve.parameter(point)
                     np = edge.Curve.value(pr)
@@ -1211,7 +1209,8 @@ def getTangent(edge,frompoint=None):
         '''
         if geomType(edge) == "Line":
                 return vec(edge)
-        elif geomType(edge) == "BSplineCurve":
+        elif geomType(edge) == "BSplineCurve" or \
+            geomType(edge) == "BezierCurve":
                 if not frompoint:
                         return None
                 cp = edge.Curve.parameter(frompoint)
@@ -1225,21 +1224,25 @@ def getTangent(edge,frompoint=None):
         return None
 
 def bind(w1,w2):
-        '''bind(wire1,wire2): binds 2 wires by their endpoints and
-        returns a face'''
-        if w1.isClosed() and w2.isClosed():
-                d1 = w1.BoundBox.DiagonalLength
-                d2 = w2.BoundBox.DiagonalLength
-                if d1 > d2:
-                        #w2.reverse()
-                        return Part.Face([w1,w2])
-                else:
-                        #w1.reverse()
-                        return Part.Face([w2,w1])
+    '''bind(wire1,wire2): binds 2 wires by their endpoints and
+    returns a face'''
+    if w1.isClosed() and w2.isClosed():
+        d1 = w1.BoundBox.DiagonalLength
+        d2 = w2.BoundBox.DiagonalLength
+        if d1 > d2:
+            #w2.reverse()
+            return Part.Face([w1,w2])
         else:
-                w3 = Part.Line(w1.Vertexes[0].Point,w2.Vertexes[0].Point).toShape()
-                w4 = Part.Line(w1.Vertexes[-1].Point,w2.Vertexes[-1].Point).toShape()
-                return Part.Face(Part.Wire(w1.Edges+[w3]+w2.Edges+[w4]))
+            #w1.reverse()
+            return Part.Face([w2,w1])
+    else:
+        try:
+            w3 = Part.Line(w1.Vertexes[0].Point,w2.Vertexes[0].Point).toShape()
+            w4 = Part.Line(w1.Vertexes[-1].Point,w2.Vertexes[-1].Point).toShape()
+            return Part.Face(Part.Wire(w1.Edges+[w3]+w2.Edges+[w4]))
+        except:
+            print "DraftGeomUtils: unable to bind wires"
+            return None
 
 def cleanFaces(shape):
         "removes inner edges from coplanar faces"
@@ -1780,11 +1783,23 @@ def getCircleFromSpline(edge):
     circle = Part.makeCircle(r,c,n)
     #print circle.Curve
     return circle
-    
-def cleanProjection(shape):
+
+def curvetowire(obj,steps):
+    points = obj.copy().discretize(steps)
+    p0 = points[0]
+    edgelist = []
+    for p in points[1:]:
+        edge = Part.makeLine((p0.x,p0.y,p0.z),(p.x,p.y,p.z))
+        edgelist.append(edge)
+        p0 = p
+    return edgelist
+
+def cleanProjection(shape,tessellate=True,seglength=.05):
     "returns a valid compound of edges, by recreating them"
     # this is because the projection algorithm somehow creates wrong shapes.
     # they dispay fine, but on loading the file the shape is invalid
+    # Now with tanderson's fix to ProjectionAlgos, that isn't the case, but this
+    # can be used for tessellating ellipses and splines for DXF output-DF
     oldedges = shape.Edges
     newedges = []
     for e in oldedges:
@@ -1799,23 +1814,60 @@ def cleanProjection(shape):
                 else:
                     newedges.append(e.Curve.toShape())
             elif geomType(e) == "Ellipse":
-                if len(e.Vertexes) > 1:
-                    a = Part.Arc(e.Curve,e.FirstParameter,e.LastParameter).toShape()
-                    newedges.append(a)
+                if tessellate:
+                    newedges.append(Part.Wire(curvetowire(e, seglength)))
                 else:
-                    newedges.append(e.Curve.toShape())
-            elif geomType(e) == "BSplineCurve":
-                if isLine(e.Curve):
-                    l = Part.Line(e.Vertexes[0].Point,e.Vertexes[-1].Point).toShape()
-                    newedges.append(l)
+                    if len(e.Vertexes) > 1:
+                        a = Part.Arc(e.Curve,e.FirstParameter,e.LastParameter).toShape()
+                        newedges.append(a)
+                    else:
+                        newedges.append(e.Curve.toShape())
+            elif geomType(e) == "BSplineCurve" or \
+                 geomType(e) == "BezierCurve":
+                if tessellate:
+                    newedges.append(Part.Wire(curvetowire(e,seglength)))
                 else:
-                    newedges.append(e.Curve.toShape())
+                    if isLine(e.Curve):
+                        l = Part.Line(e.Vertexes[0].Point,e.Vertexes[-1].Point).toShape()
+                        newedges.append(l)
+                    else:
+                        newedges.append(e.Curve.toShape())
             else:
                 newedges.append(e)
         except:
             print "Debug: error cleaning edge ",e
     return Part.makeCompound(newedges)
     
+def curvetosegment(curve,seglen):
+    points = curve.discretize(seglen)
+    p0 = points[0]
+    edgelist = []
+    for p in points[1:]:
+        edge = Part.makeLine((p0.x,p0.y,p0.z),(p.x,p.y,p.z))
+        edgelist.append(edge)
+        p0 = p
+    return edgelist
+
+def tessellateProjection(shape,seglen):
+    ''' Returns projection with BSplines and Ellipses broken into line segments.
+        Useful for exporting projected views to *dxf files.'''
+    oldedges = shape.Edges
+    newedges = []
+    for e in oldedges:
+        try:
+            if geomType(e) == "Line":
+                newedges.append(e.Curve.toShape())
+            elif geomType(e) == "Circle":
+                newedges.append(e.Curve.toShape())
+            elif geomType(e) == "Ellipse":
+                newedges.append(Part.Wire(curvetosegment(e,seglen)))
+            elif geomType(e) == "BSplineCurve":
+                newedges.append(Part.Wire(curvetosegment(e,seglen)))
+            else:
+                newedges.append(e)
+        except:
+            print "Debug: error cleaning edge ",e
+    return Part.makeCompound(newedges)
 
 # circle functions *********************************************************
 
