@@ -29,7 +29,7 @@ __url__ = "http://www.freecadweb.org"
 import FreeCAD, FreeCADGui, math, Draft, DraftGui, DraftTrackers, DraftVecUtils
 from FreeCAD import Vector
 from pivy import coin
-from PyQt4 import QtCore,QtGui
+from PySide import QtCore,QtGui
 
 class Snapper:
     """The Snapper objects contains all the functionality used by draft
@@ -53,7 +53,6 @@ class Snapper:
 
     def __init__(self):
         self.lastObj = [None,None]
-        self.views = []
         self.maxEdges = 0
         self.radius = 0
         self.constraintAxis = None
@@ -137,7 +136,7 @@ class Snapper:
 
         if not hasattr(self,"toolbar"):
             self.makeSnapToolBar()
-        mw = DraftGui.getMainWindow()
+        mw = FreeCADGui.getMainWindow()
         bt = mw.findChild(QtGui.QToolBar,"Draft Snap")
         if not bt:
             mw.addToolBar(self.toolbar)
@@ -263,7 +262,9 @@ class Snapper:
                 # active snapping
                 comp = self.snapInfo['Component']
 
-                if (Draft.getType(obj) == "Wall") and not oldActive:
+                archSnap = FreeCAD.ParamGet("User parameter:BaseApp/Preferences/Mod/Arch").GetBool("ArchSnapToBase",True)
+
+                if (Draft.getType(obj) == "Wall") and (not oldActive) and archSnap:
                     # special snapping for wall: only to its base shape (except when CTRL is pressed)
                     edges = []
                     for o in [obj]+obj.Additions:
@@ -277,7 +278,7 @@ class Snapper:
                         snaps.extend(self.snapToIntersection(edge))
                         snaps.extend(self.snapToElines(edge,eline))
                         
-                elif (Draft.getType(obj) == "Structure") and not oldActive:
+                elif (Draft.getType(obj) == "Structure") and (not oldActive) and archSnap:
                     # special snapping for struct: only to its base point (except when CTRL is pressed)
                     if obj.Base:
                         for edge in obj.Base.Shape.Edges:
@@ -288,7 +289,7 @@ class Snapper:
                             snaps.extend(self.snapToElines(edge,eline))
                     else:
                         b = obj.Placement.Base
-                        snaps.append([b,'endpoint',b])
+                        snaps.append([b,'endpoint',self.toWP(b)])
 
                 elif obj.isDerivedFrom("Part::Feature"):
                     if Draft.getType(obj) == "Polygon":
@@ -306,11 +307,15 @@ class Snapper:
                                 #snaps.extend(self.snapToOrtho(edge,lastpoint,constrain)) # now part of snapToPolar
                                 snaps.extend(self.snapToIntersection(edge))
                                 snaps.extend(self.snapToElines(edge,eline))
-
-                                if DraftGeomUtils.geomType(edge) == "Circle":
+                                
+                                et = DraftGeomUtils.geomType(edge)
+                                if et == "Circle":
                                     # the edge is an arc, we have extra options
                                     snaps.extend(self.snapToAngles(edge))
                                     snaps.extend(self.snapToCenter(edge))
+                                elif et == "Ellipse":
+                                    # extra ellipse options
+                                    snaps.extend(self.snapToCenter(edge))
 
                         elif "Vertex" in comp:
                             # directly snapped to a vertex
@@ -326,14 +331,19 @@ class Snapper:
                     # for dimensions we snap to their 2 points:
                     if obj.ViewObject:
                         if hasattr(obj.ViewObject.Proxy,"p2") and hasattr(obj.ViewObject.Proxy,"p3"):
-                            snaps.append([obj.ViewObject.Proxy.p2,'endpoint',obj.ViewObject.Proxy.p2])
-                            snaps.append([obj.ViewObject.Proxy.p3,'endpoint',obj.ViewObject.Proxy.p3])
+                            snaps.append([obj.ViewObject.Proxy.p2,'endpoint',self.toWP(obj.ViewObject.Proxy.p2)])
+                            snaps.append([obj.ViewObject.Proxy.p3,'endpoint',self.toWP(obj.ViewObject.Proxy.p3)])
                     #for pt in [obj.Start,obj.End,obj.Dimline]:
-                    #    snaps.append([pt,'endpoint',pt])
+                    #    snaps.append([pt,'endpoint',self.toWP(pt)])
+
+                elif Draft.getType(obj) == "Axis":
+                    for edge in obj.Shape.Edges:
+                        snaps.extend(self.snapToEndpoints(edge))
                         
                 elif Draft.getType(obj) == "Mesh":
                     # for meshes we only snap to vertices
                     snaps.extend(self.snapToEndpoints(obj.Mesh))
+
                 elif Draft.getType(obj) == "Points":
                     # for points we only snap to points
                     snaps.extend(self.snapToEndpoints(obj.Points))
@@ -395,6 +405,13 @@ class Snapper:
             # return the final point
             return fp
 
+    def toWP(self,point):
+        "projects the given point on the working plane, if needed"
+        if self.isEnabled("WorkingPlane"):
+            if hasattr(FreeCAD,"DraftWorkingPlane"):
+                return FreeCAD.DraftWorkingPlane.projectPoint(point)
+        return point
+
     def getApparentPoint(self,x,y):
         "returns a 3D point, projected on the current working plane"
         view = Draft.get3DView()
@@ -557,16 +574,17 @@ class Snapper:
                             v = DraftVecUtils.rotate(ax[1],math.radians(a),ax[2])
                             vecs.extend([v,v.negative()])
                 for v in vecs:
-                    de = Part.Line(last,last.add(v)).toShape()  
-                    np = self.getPerpendicular(de,point)
-                    if ((self.radius == 0) and (point.sub(last).getAngle(v) < 0.087)) \
-                    or ((np.sub(point)).Length < self.radius):
-                        if self.tracker and not self.selectMode:
-                            self.tracker.setCoords(np)
-                            self.tracker.setMarker(self.mk['parallel'])
-                            self.tracker.on()
-                            self.setCursor('ortho')
-                        return np,de
+                    if not DraftVecUtils.isNull(v):
+                        de = Part.Line(last,last.add(v)).toShape()  
+                        np = self.getPerpendicular(de,point)
+                        if ((self.radius == 0) and (point.sub(last).getAngle(v) < 0.087)) \
+                        or ((np.sub(point)).Length < self.radius):
+                            if self.tracker and not self.selectMode:
+                                self.tracker.setCoords(np)
+                                self.tracker.setMarker(self.mk['parallel'])
+                                self.tracker.on()
+                                self.setCursor('ortho')
+                            return np,de
         return point,None
 
     def snapToGrid(self,point):
@@ -592,16 +610,16 @@ class Snapper:
         if self.isEnabled("endpoint"):
             if hasattr(shape,"Vertexes"):
                 for v in shape.Vertexes:
-                    snaps.append([v.Point,'endpoint',v.Point])
+                    snaps.append([v.Point,'endpoint',self.toWP(v.Point)])
             elif hasattr(shape,"Point"):
-                snaps.append([shape.Point,'endpoint',shape.Point])
+                snaps.append([shape.Point,'endpoint',self.toWP(shape.Point)])
             elif hasattr(shape,"Points"):
                 if len(shape.Points) and hasattr(shape.Points[0],"Vector"):
                     for v in shape.Points:
-                        snaps.append([v.Vector,'endpoint',v.Vector])
+                        snaps.append([v.Vector,'endpoint',self.toWP(v.Vector)])
                 else:
                     for v in shape.Points:
-                        snaps.append([v,'endpoint',v])
+                        snaps.append([v,'endpoint',self.toWP(v)])
         return snaps
 
     def snapToMidpoint(self,shape):
@@ -611,7 +629,7 @@ class Snapper:
             if isinstance(shape,Part.Edge):
                 mp = DraftGeomUtils.findMidpoint(shape)
                 if mp:
-                    snaps.append([mp,'midpoint',mp])
+                    snaps.append([mp,'midpoint',self.toWP(mp)])
         return snaps
 
     def snapToPerpendicular(self,shape,last):
@@ -634,7 +652,7 @@ class Snapper:
                             return snaps
                     else:
                         return snaps
-                    snaps.append([np,'perpendicular',np])
+                    snaps.append([np,'perpendicular',self.toWP(np)])
         return snaps
 
     def snapToOrtho(self,shape,last,constrain):
@@ -651,7 +669,7 @@ class Snapper:
                                 pt = DraftGeomUtils.findIntersection(tmpEdge,shape,True,True)
                                 if pt:
                                     for p in pt:
-                                        snaps.append([p,'ortho',p])
+                                        snaps.append([p,'ortho',self.toWP(p)])
         return snaps
 
     def snapToExtOrtho(self,last,constrain,eline):
@@ -694,7 +712,7 @@ class Snapper:
                 pts = DraftGeomUtils.findIntersection(e1,e2,True,True)
                 if pts:
                     for p in pts:
-                        snaps.append([p,'intersection',p])
+                        snaps.append([p,'intersection',self.toWP(p)])
         return snaps
             
     
@@ -707,19 +725,23 @@ class Snapper:
             for i in [0,30,45,60,90,120,135,150,180,210,225,240,270,300,315,330]:
                 ang = math.radians(i)
                 cur = Vector(math.sin(ang)*rad+pos.x,math.cos(ang)*rad+pos.y,pos.z)
-                snaps.append([cur,'angle',cur])
+                snaps.append([cur,'angle',self.toWP(cur)])
         return snaps
 
     def snapToCenter(self,shape):
         "returns a list of center snap locations"
         snaps = []
         if self.isEnabled("center"):
-            rad = shape.Curve.Radius
             pos = shape.Curve.Center
-            for i in [15,37.5,52.5,75,105,127.5,142.5,165,195,217.5,232.5,255,285,307.5,322.5,345]:
-                ang = math.radians(i)
-                cur = Vector(math.sin(ang)*rad+pos.x,math.cos(ang)*rad+pos.y,pos.z)
-                snaps.append([cur,'center',pos])
+            c = self.toWP(pos)
+            if hasattr(shape.Curve,"Radius"):
+                rad = shape.Curve.Radius
+                for i in [15,37.5,52.5,75,105,127.5,142.5,165,195,217.5,232.5,255,285,307.5,322.5,345]:
+                    ang = math.radians(i)
+                    cur = Vector(math.sin(ang)*rad+pos.x,math.cos(ang)*rad+pos.y,pos.z)
+                    snaps.append([cur,'center',c])
+            else:
+                snaps.append([c,'center',c])
         return snaps
 
     def snapToIntersection(self,shape):
@@ -737,7 +759,7 @@ class Snapper:
                                 pt = DraftGeomUtils.findIntersection(e,shape)
                                 if pt:
                                     for p in pt:
-                                        snaps.append([p,'intersection',p])
+                                        snaps.append([p,'intersection',self.toWP(p)])
         return snaps
         
     def snapToPolygon(self,obj):
@@ -749,8 +771,8 @@ class Snapper:
             p2 = edge.Vertexes[-1].Point
             v1 = p1.add((p2-p1).scale(.25,.25,.25))
             v2 = p1.add((p2-p1).scale(.75,.75,.75))
-            snaps.append([v1,'center',c])
-            snaps.append([v2,'center',c])
+            snaps.append([v1,'center',self.toWP(c)])
+            snaps.append([v2,'center',self.toWP(c)])
         return snaps
 
     def snapToVertex(self,info,active=False):
@@ -797,21 +819,20 @@ class Snapper:
 
     def setCursor(self,mode=None):
         "setCursor(self,mode=None): sets or resets the cursor to the given mode or resets"
-        if self.selectMode: 
-            for v in self.views:
-                v.unsetCursor()
-            self.views = []
+        if self.selectMode:
+            mw = FreeCADGui.getMainWindow()
+            for w in mw.findChild(QtGui.QMdiArea).findChildren(QtGui.QWidget):
+                if w.metaObject().className() == "SoQtGLArea":
+                    w.unsetCursor()
             self.cursorMode = None
         elif not mode:
-            for v in self.views:
-                v.unsetCursor()
-            self.views = []
+            mw = FreeCADGui.getMainWindow()
+            for w in mw.findChild(QtGui.QMdiArea).findChildren(QtGui.QWidget):
+                if w.metaObject().className() == "SoQtGLArea":
+                    w.unsetCursor()
             self.cursorMode = None
         else:
             if mode != self.cursorMode:
-                if not self.views:
-                    mw = DraftGui.getMainWindow()
-                    self.views = mw.findChildren(QtGui.QWidget,"QtGLArea")
                 baseicon = QtGui.QPixmap(":/icons/Draft_Cursor.svg")
                 newicon = QtGui.QPixmap(32,24)
                 newicon.fill(QtCore.Qt.transparent)
@@ -823,8 +844,10 @@ class Snapper:
                     qp.drawPixmap(QtCore.QPoint(16, 8), tp);
                 qp.end()
                 cur = QtGui.QCursor(newicon,8,8)
-                for v in self.views:
-                    v.setCursor(cur)
+                mw = FreeCADGui.getMainWindow()
+                for w in mw.findChild(QtGui.QMdiArea).findChildren(QtGui.QWidget):
+                    if w.metaObject().className() == "SoQtGLArea":
+                        w.setCursor(cur)
                 self.cursorMode = mode
 
     def restack(self):
@@ -1017,7 +1040,7 @@ class Snapper:
             FreeCADGui.Snapper.off()
             self.ui.offUi()
             if callback:
-                if len(inspect.getargspec(callback).args) > 2:
+                if len(inspect.getargspec(callback).args) > 1:
                     callback(self.pt,obj)
                 else:
                     callback(self.pt)
@@ -1065,22 +1088,24 @@ class Snapper:
                 self.toolbar.addWidget(b)
                 self.toolbarButtons.append(b)
                 QtCore.QObject.connect(b,QtCore.SIGNAL("toggled(bool)"),self.saveSnapModes)
-        # adding dimensions button
-        self.dimbutton = QtGui.QPushButton(None)
-        self.dimbutton.setIcon(QtGui.QIcon(":/icons/Snap_Dimensions.svg"))
-        self.dimbutton.setIconSize(QtCore.QSize(16, 16))
-        self.dimbutton.setMaximumSize(QtCore.QSize(26,26))
-        self.dimbutton.setToolTip(c)
-        self.dimbutton.setObjectName("SnapButtonDimensions")
-        self.dimbutton.setCheckable(True)
-        self.dimbutton.setChecked(True)
-        self.toolbar.addWidget(self.dimbutton)
-        QtCore.QObject.connect(self.dimbutton,QtCore.SIGNAL("toggled(bool)"),self.saveSnapModes)
+        # adding non-snap button
+        for n in ["Dimensions","WorkingPlane"]:
+            b = QtGui.QPushButton(None)
+            b.setIcon(QtGui.QIcon(":/icons/Snap_"+n+".svg"))
+            b.setIconSize(QtCore.QSize(16, 16))
+            b.setMaximumSize(QtCore.QSize(26,26))
+            b.setToolTip(n)
+            b.setObjectName("SnapButton"+n)
+            b.setCheckable(True)
+            b.setChecked(True)
+            self.toolbar.addWidget(b)
+            QtCore.QObject.connect(b,QtCore.SIGNAL("toggled(bool)"),self.saveSnapModes)
+            self.toolbarButtons.append(b)
         # restoring states 
-        t = Draft.getParam("snapModes","1111111111011")
+        t = Draft.getParam("snapModes","11111111110111")
         if t:
             c = 0
-            for b in [self.masterbutton]+self.toolbarButtons+[self.dimbutton]:
+            for b in [self.masterbutton]+self.toolbarButtons:
                 if len(t) > c:
                     b.setChecked(bool(int(t[c])))
                     c += 1
@@ -1090,7 +1115,7 @@ class Snapper:
     def saveSnapModes(self):
         "saves the snap modes for next sessions"
         t = ''
-        for b in [self.masterbutton]+self.toolbarButtons+[self.dimbutton]:
+        for b in [self.masterbutton]+self.toolbarButtons:
             t += str(int(b.isChecked()))
         Draft.setParam("snapModes",t)
 
@@ -1120,7 +1145,7 @@ class Snapper:
 
     def isEnabled(self,but):
         "returns true if the given button is turned on"
-        for b in self.toolbarButtons+[self.dimbutton]:
+        for b in self.toolbarButtons:
             if str(b.objectName()) == "SnapButton" + but:
                 return (b.isEnabled() and b.isChecked())
         return False
@@ -1129,7 +1154,7 @@ class Snapper:
         "shows the toolbar and the grid"
         if not hasattr(self,"toolbar"):
             self.makeSnapToolBar()
-        mw = DraftGui.getMainWindow()
+        mw = FreeCADGui.getMainWindow()
         bt = mw.findChild(QtGui.QToolBar,"Draft Snap")
         if not bt:
             mw.addToolBar(self.toolbar)
