@@ -1,18 +1,21 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS>
+<TS version="2.0" language="es-ES" sourcelanguage="en">
   <context>
     <name>CmdDrawingAnnotation</name>
     <message>
-      <location filename="../../Command.cpp" line="+365"/>
+      <location filename="../../Command.cpp" line="+389"/>
       <source>Drawing</source>
       <translation>Dibujo</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>&amp;Annotation</source>
       <translation>&amp;Anotación</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+2"/>
       <source>Inserts an Annotation view in the active drawing</source>
       <translation>Inserta una nota en el actual dibujo</translation>
     </message>
@@ -20,14 +23,18 @@
   <context>
     <name>CmdDrawingClip</name>
     <message>
+      <location line="+41"/>
       <source>Drawing</source>
       <translation>Dibujo</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>&amp;Clip</source>
       <translation>&amp;Clip</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+2"/>
       <source>Inserts a clip group in the active drawing</source>
       <translation>Inserta un clip de grupo en el actual dibujo</translation>
     </message>
@@ -35,14 +42,18 @@
   <context>
     <name>CmdDrawingExportPage</name>
     <message>
+      <location line="+91"/>
       <source>File</source>
       <translation>Archivo</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>&amp;Export page...</source>
       <translation>&amp;Exportar página...</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+2"/>
       <source>Export a page to an SVG file</source>
       <translation>Exportar una página a un archivo SVG</translation>
     </message>
@@ -50,10 +61,13 @@
   <context>
     <name>CmdDrawingNewA3Landscape</name>
     <message>
+      <location line="-314"/>
       <source>Drawing</source>
       <translation>Dibujo</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+1"/>
       <source>Insert new A3 landscape drawing</source>
       <translation>Inserta un nuevo dibujo en formato A3</translation>
     </message>
@@ -61,10 +75,13 @@
   <context>
     <name>CmdDrawingNewPage</name>
     <message>
+      <location line="-133"/>
       <source>Drawing</source>
       <translation>Dibujo</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+1"/>
       <source>Insert new drawing</source>
       <translation>Insertar nuevo dibujo</translation>
     </message>
@@ -72,14 +89,17 @@
   <context>
     <name>CmdDrawingNewView</name>
     <message>
+      <location line="+166"/>
       <source>Drawing</source>
       <translation>Dibujo</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert view in drawing</source>
       <translation>Insertar vista en el dibujo</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert a new View of a Part in the active drawing</source>
       <translation>Insertar una nueva Vista de una Pieza en el dibujo activo</translation>
     </message>
@@ -87,14 +107,17 @@
   <context>
     <name>CmdDrawingOpen</name>
     <message>
+      <location line="-202"/>
       <source>Drawing</source>
       <translation>Dibujo</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Open SVG...</source>
       <translation>Abrir SVG...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Open a scalable vector graphic</source>
       <translation>Abre una imagen vectorial escalable</translation>
     </message>
@@ -102,14 +125,18 @@
   <context>
     <name>CmdDrawingOpenBrowserView</name>
     <message>
+      <location line="+294"/>
       <source>Drawing</source>
       <translation>Dibujo</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Open &amp;browser view</source>
       <translation>Abrir &amp;vista de navegador</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+2"/>
       <source>Opens the selected page in a browser view</source>
       <translation>Abre la página seleccionada en una vista de navegador</translation>
     </message>
@@ -117,14 +144,17 @@
   <context>
     <name>CmdDrawingOrthoViews</name>
     <message>
+      <location line="-49"/>
       <source>Drawing</source>
       <translation>Dibujo</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert orthographic views</source>
       <translation>Insertar vistas ortogonales</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert an orthographic projection of a part in the active drawing</source>
       <translation>Insertar una proyección ortogonal de una parte in el actual dibujo</translation>
     </message>
@@ -132,18 +162,41 @@
   <context>
     <name>CmdDrawingProjectShape</name>
     <message>
+      <location line="+271"/>
       <source>Drawing</source>
       <translation>Dibujo</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Project shape...</source>
       <translation>Formas del proyecto...</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+1"/>
       <source>Project shape onto a user-defined plane</source>
       <translation>Forma de proyecto en un plano definido por el usuario</translation>
     </message>
   </context>
+  <context>
+    <name>CmdDrawingSymbol</name>
+    <message>
+      <location line="-107"/>
+      <source>Drawing</source>
+      <translation type="unfinished">Dibujo</translation>
+    </message>
+    <message>
+      <location line="+1"/>
+      <source>&amp;Symbol</source>
+      <translation type="unfinished">&amp;Símbolo</translation>
+    </message>
+    <message>
+      <location line="+1"/>
+      <location line="+2"/>
+      <source>Inserts a symbol from a svg file in the active drawing</source>
+      <translation type="unfinished">Inserta un símbolo desde un archivo svg en el dibujo activo</translation>
+    </message>
+  </context>
   <context>
     <name>DrawingGui::DrawingView</name>
     <message>
@@ -152,70 +205,87 @@
       <translation>&amp;Fondo</translation>
     </message>
     <message>
+      <location line="+6"/>
       <source>&amp;Outline</source>
       <translation>&amp;Contorno</translation>
     </message>
     <message>
+      <location line="+6"/>
       <source>&amp;Native</source>
       <translation>&amp;Nativo</translation>
     </message>
     <message>
+      <location line="+4"/>
       <source>&amp;OpenGL</source>
       <translation>&amp;OpenGL</translation>
     </message>
     <message>
+      <location line="+3"/>
       <source>&amp;Image</source>
       <translation>&amp;Imagen</translation>
     </message>
     <message>
+      <location line="+4"/>
       <source>&amp;High Quality Antialiasing</source>
       <translation>&amp;Antialiasing alta calidad</translation>
     </message>
     <message>
+      <location line="+26"/>
       <source>Open SVG File</source>
       <translation>Abrir archivo SVG</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Could not open file '%1'.</source>
       <translation>No se pudo abrir el archivo '%1'.</translation>
     </message>
     <message>
+      <location line="+24"/>
       <source>&amp;Renderer</source>
       <translation>&amp;Renderizador</translation>
     </message>
     <message>
+      <location line="+55"/>
       <source>Export PDF</source>
       <translation>Exportar PDF</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>PDF file (*.pdf)</source>
       <translation>Archivo PDF (*.pdf)</translation>
     </message>
     <message>
+      <location line="+16"/>
       <source>Page sizes</source>
       <translation>Tamaños de página</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>A0</source>
       <translation>A0</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>A1</source>
       <translation>A1</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>A2</source>
       <translation>A2</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>A3</source>
       <translation>A3</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>A4</source>
       <translation>A4</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>A5</source>
       <translation>A5</translation>
     </message>
@@ -228,98 +298,236 @@
       <translation>Proyección ortogonal</translation>
     </message>
     <message>
+      <location line="+20"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+31"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+60"/>
+      <source>Right click for axonometric settings</source>
+      <translation type="unfinished">Click derecho para configuración axonométrica</translation>
+    </message>
+    <message>
+      <location line="+106"/>
+      <source>Top left x / y</source>
+      <translation type="unfinished">Arriba izquierda x / y</translation>
+    </message>
+    <message>
+      <location line="+48"/>
+      <source>Spacing dx / dy   </source>
+      <translation type="unfinished">Espaciado dx / dy   </translation>
+    </message>
+    <message>
+      <location line="+71"/>
+      <source> Axis out and right</source>
+      <translation type="unfinished"> Axis out and right</translation>
+    </message>
+    <message>
+      <location line="+7"/>
+      <source> Vertical tilt</source>
+      <translation type="unfinished"> Inclinación vertical</translation>
+    </message>
+    <message>
+      <location line="+11"/>
+      <location line="+200"/>
+      <source>X +ve</source>
+      <translation type="unfinished">X +ve</translation>
+    </message>
+    <message>
+      <location line="-195"/>
+      <location line="+75"/>
+      <location line="+125"/>
+      <source>Y +ve</source>
+      <translation type="unfinished">Y +ve</translation>
+    </message>
+    <message>
+      <location line="-195"/>
+      <location line="+75"/>
+      <location line="+125"/>
+      <source>Z +ve</source>
+      <translation type="unfinished">Z +ve</translation>
+    </message>
+    <message>
+      <location line="-195"/>
+      <location line="+200"/>
+      <source>X -ve</source>
+      <translation type="unfinished">X -ve</translation>
+    </message>
+    <message>
+      <location line="-195"/>
+      <location line="+70"/>
+      <location line="+130"/>
+      <source>Y -ve</source>
+      <translation type="unfinished">Y -ve</translation>
+    </message>
+    <message>
+      <location line="-195"/>
+      <location line="+70"/>
+      <location line="+130"/>
+      <source>Z -ve</source>
+      <translation type="unfinished">Z -ve</translation>
+    </message>
+    <message>
+      <location line="-188"/>
+      <source>Isometric</source>
+      <translation type="unfinished">Isométrico</translation>
+    </message>
+    <message>
+      <location line="+5"/>
+      <source>Dimetric</source>
+      <translation type="unfinished">Dimétrica</translation>
+    </message>
+    <message>
+      <location line="+5"/>
+      <source>Trimetric</source>
+      <translation type="unfinished">Trimétrica</translation>
+    </message>
+    <message>
+      <location line="+8"/>
+      <source> Scale</source>
+      <translation type="unfinished"> Escala</translation>
+    </message>
+    <message>
+      <location line="+7"/>
+      <source> View projection   </source>
+      <translation type="unfinished"> Proyección de la vista   </translation>
+    </message>
+    <message>
+      <location line="+7"/>
+      <source> Axis aligned up</source>
+      <translation type="unfinished"> Eje alineado arriba</translation>
+    </message>
+    <message>
+      <location line="+41"/>
+      <location line="+23"/>
+      <source>Flip</source>
+      <translation type="unfinished">Voltear</translation>
+    </message>
+    <message>
+      <location line="-10"/>
+      <source> Trimetric</source>
+      <translation type="unfinished"> Trimétrica</translation>
+    </message>
+    <message>
+      <location line="+28"/>
       <source>Projection</source>
       <translation>Proyección</translation>
     </message>
     <message>
+      <location line="+11"/>
       <source>Third Angle</source>
       <translation>Tercer ángulo</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>First Angle</source>
       <translation>Primer ángulo</translation>
     </message>
+    <message>
+      <location line="+19"/>
+      <source>View from:</source>
+      <translation type="unfinished">Vista desde:</translation>
+    </message>
+    <message>
+      <location line="+47"/>
+      <source>Axis aligned right:</source>
+      <translation type="unfinished">Eje alineado a la derecha:</translation>
+    </message>
     <message>
       <source>Primary View</source>
-      <translation>Vista principal</translation>
+      <translation type="obsolete">Vista principal</translation>
     </message>
     <message>
       <source>Front</source>
-      <translation>Alzado</translation>
+      <translation type="obsolete">Alzado</translation>
     </message>
     <message>
       <source>Right</source>
-      <translation>Derecha</translation>
+      <translation type="obsolete">Derecha</translation>
     </message>
     <message>
       <source>Back</source>
-      <translation>Volver</translation>
+      <translation type="obsolete">Volver</translation>
     </message>
     <message>
       <source>Left</source>
-      <translation>Izquierda</translation>
+      <translation type="obsolete">Izquierda</translation>
     </message>
     <message>
       <source>Top</source>
-      <translation>Planta</translation>
+      <translation type="obsolete">Planta</translation>
     </message>
     <message>
       <source>Bottom</source>
-      <translation>Inferior</translation>
+      <translation type="obsolete">Inferior</translation>
     </message>
     <message>
       <source>- Rotate</source>
-      <translation>- Rotar</translation>
+      <translation type="obsolete">- Rotar</translation>
     </message>
     <message>
       <source>90</source>
-      <translation>90</translation>
+      <translation type="obsolete">90</translation>
     </message>
     <message>
       <source>180</source>
-      <translation>180</translation>
+      <translation type="obsolete">180</translation>
     </message>
     <message>
       <source>270</source>
-      <translation>270</translation>
+      <translation type="obsolete">270</translation>
     </message>
     <message>
+      <location line="-514"/>
       <source>Primary view</source>
       <translation>Vista principal</translation>
     </message>
     <message>
+      <location line="+16"/>
       <source>Secondary Views</source>
       <translation>Vistas Secundarias</translation>
     </message>
     <message>
+      <location line="+72"/>
       <source>General</source>
       <translation>General</translation>
     </message>
     <message>
+      <location line="+9"/>
       <source>Auto scale / position</source>
       <translation>Auto Escalar / Situar</translation>
     </message>
     <message>
+      <location line="+15"/>
       <source>Scale</source>
       <translation>Escalar</translation>
     </message>
     <message>
       <source>Primary x / y</source>
-      <translation>x / y primario</translation>
+      <translation type="obsolete">x / y primario</translation>
     </message>
     <message>
       <source>Secondary dx / dy</source>
-      <translation>dx / dy secundario</translation>
+      <translation type="obsolete">dx / dy secundario</translation>
     </message>
     <message>
+      <location line="+125"/>
       <source>Show hidden</source>
       <translation>Mostrar ocultos</translation>
     </message>
     <message>
+      <location line="+7"/>
       <source>Show smooth</source>
       <translation>Mostrar alisado</translation>
     </message>
     <message>
+      <location line="+11"/>
       <source>Axonometric</source>
       <translation>Axonométrica</translation>
     </message>
@@ -332,42 +540,52 @@
       <translation>Aristas visibles</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Visible smooth edges</source>
       <translation>Bordes suavizados visibles</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Visible sewn edges</source>
       <translation>Bordes cosidos visibles</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Visible outline edges</source>
       <translation>Aristas de contorno visibles</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Visible isoparameters</source>
       <translation>Isoparámetros visibles</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Hidden sharp edges</source>
       <translation>Aristas ocultas</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Hidden smooth edges</source>
-      <translation>Bordes suavizados ocultos</translation>
+      <translation>oculta aristas no vivas</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Hidden sewn edges</source>
       <translation>Aristas ocultas cosidas</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Hidden outline edges</source>
       <translation>Aristas de contorno ocultas</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Hidden isoparameters</source>
       <translation>Isoparámetros ocultos</translation>
     </message>
     <message>
+      <location line="+17"/>
       <source>Project shapes</source>
       <translation>Formas del proyecto</translation>
     </message>
@@ -376,103 +594,148 @@
     <name>Drawing_NewPage</name>
     <message>
       <source>A0 landscape</source>
-      <translation>A0 horizontal</translation>
+      <translation type="obsolete">A0 horizontal</translation>
     </message>
     <message>
       <source>Insert new A0 landscape drawing</source>
-      <translation>Insertar nuevo dibujo A0 horizontal</translation>
+      <translation type="obsolete">Insertar nuevo dibujo A0 horizontal</translation>
     </message>
     <message>
       <source>A1 landscape</source>
-      <translation>A1 horizontal</translation>
+      <translation type="obsolete">A1 horizontal</translation>
     </message>
     <message>
       <source>Insert new A1 landscape drawing</source>
-      <translation>Insertar nuevo dibujo A1 horizontal</translation>
+      <translation type="obsolete">Insertar nuevo dibujo A1 horizontal</translation>
     </message>
     <message>
       <source>A2 landscape</source>
-      <translation>A2 horizontal</translation>
+      <translation type="obsolete">A2 horizontal</translation>
     </message>
     <message>
       <source>Insert new A2 landscape drawing</source>
-      <translation>Insertar nuevo dibujo A2 horizontal</translation>
+      <translation type="obsolete">Insertar nuevo dibujo A2 horizontal</translation>
     </message>
     <message>
       <source>A3 landscape</source>
-      <translation>A3 horizontal</translation>
+      <translation type="obsolete">A3 horizontal</translation>
     </message>
     <message>
       <source>Insert new A3 landscape drawing</source>
-      <translation>Inserta un nuevo dibujo en formato A3</translation>
+      <translation type="obsolete">Inserta un nuevo dibujo en formato A3</translation>
     </message>
     <message>
       <source>A4 landscape</source>
-      <translation>A4 horizontal</translation>
+      <translation type="obsolete">A4 horizontal</translation>
     </message>
     <message>
       <source>Insert new A4 landscape drawing</source>
-      <translation>Insertar nuevo dibujo A4 horizontal</translation>
+      <translation type="obsolete">Insertar nuevo dibujo A4 horizontal</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="-327"/>
       <source>Insert new A%1 landscape drawing</source>
-      <translation>Insertar nuevo dibujo A%1 horizontal</translation>
+      <translation type="obsolete">Insertar nuevo dibujo A%1 horizontal</translation>
     </message>
     <message>
       <source>A%1 landscape</source>
-      <translation>A%1 horizontal</translation>
+      <translation type="obsolete">A%1 horizontal</translation>
+    </message>
+    <message>
+      <location filename="../../Command.cpp" line="-298"/>
+      <source>Landscape</source>
+      <translation type="unfinished">Apaisado</translation>
+    </message>
+    <message>
+      <location line="+2"/>
+      <source>Portrait</source>
+      <translation type="unfinished">Vertical</translation>
+    </message>
+    <message>
+      <location line="+2"/>
+      <source>%1%2 %3</source>
+      <translation type="unfinished">%1 %2 %3</translation>
+    </message>
+    <message>
+      <location line="+6"/>
+      <source>Insert new %1%2 %3 drawing</source>
+      <translation type="unfinished">Inserte el nuevo dibujo de %1 %2 %3</translation>
     </message>
   </context>
   <context>
     <name>QObject</name>
     <message>
+      <location line="-124"/>
+      <location line="+426"/>
       <source>Choose an SVG file to open</source>
       <translation>Seleccionar un archivo SVG para abrir</translation>
     </message>
     <message>
       <location filename="../../AppDrawingGuiPy.cpp" line="+64"/>
+      <location line="+30"/>
+      <location filename="../../ViewProviderPage.cpp" line="+139"/>
       <source>Drawing viewer</source>
       <translation>Visor de dibujos</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="+1"/>
+      <location filename="../../Command.cpp" line="-425"/>
+      <location line="+426"/>
       <source>Scalable Vector Graphics (*.svg *.svgz)</source>
       <translation>Imagen vectorial escalable (*.svg *.svgz)</translation>
     </message>
     <message>
+      <location line="-227"/>
+      <location line="+51"/>
+      <location line="+45"/>
+      <location line="+177"/>
       <source>Wrong selection</source>
       <translation>Selección incorrecta</translation>
     </message>
     <message>
+      <location line="-272"/>
+      <location line="+51"/>
       <source>Select a Part object.</source>
       <translation>Seleccionar un objeto Pieza.</translation>
     </message>
     <message>
+      <location line="-45"/>
+      <location line="+51"/>
+      <location line="+76"/>
+      <location line="+45"/>
+      <location line="+42"/>
       <source>No page to insert</source>
       <translation>Ninguna página para insertar</translation>
     </message>
     <message>
+      <location line="-213"/>
+      <location line="+127"/>
+      <location line="+45"/>
+      <location line="+42"/>
       <source>Create a page to insert.</source>
       <translation>Crear una página para insertar.</translation>
     </message>
     <message>
+      <location line="-163"/>
       <source>Create a page to insert views into.</source>
       <translation>Crear una página para insertar vistas.</translation>
     </message>
     <message>
+      <location line="+38"/>
+      <location line="+177"/>
       <source>Select one Page object.</source>
       <translation>Seleccionar una página de objetos.</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>SVG(*.svg)</source>
       <translation>SVG(*.svg)</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>All Files (*.*)</source>
       <translation>Todos los archivos (*.*)</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>Export page</source>
       <translation>Exportar página</translation>
     </message>
@@ -482,29 +745,46 @@
       <translation>Mostrar dibujo</translation>
     </message>
     <message>
-      <location filename="../../TaskOrthoViews.cpp" line="+49"/>
       <source>Front</source>
-      <translation>Alzado</translation>
+      <translation type="obsolete">Alzado</translation>
     </message>
     <message>
       <source>Back</source>
-      <translation>Volver</translation>
+      <translation type="obsolete">Volver</translation>
     </message>
     <message>
       <source>Right</source>
-      <translation>Derecha</translation>
+      <translation type="obsolete">Derecha</translation>
     </message>
     <message>
       <source>Left</source>
-      <translation>Izquierda</translation>
+      <translation type="obsolete">Izquierda</translation>
     </message>
     <message>
       <source>Top</source>
-      <translation>Planta</translation>
+      <translation type="obsolete">Planta</translation>
     </message>
     <message>
       <source>Bottom</source>
-      <translation>Inferior</translation>
+      <translation type="obsolete">Inferior</translation>
+    </message>
+    <message>
+      <location filename="../../TaskOrthoViews.cpp" line="+45"/>
+      <location line="+908"/>
+      <source>Make axonometric...</source>
+      <translation type="unfinished">Hacer axonométricas...</translation>
+    </message>
+    <message>
+      <location line="-907"/>
+      <location line="+908"/>
+      <source>Edit axonometric settings...</source>
+      <translation type="unfinished">Editar configuración axonométricas...</translation>
+    </message>
+    <message>
+      <location line="-907"/>
+      <location line="+908"/>
+      <source>Make orthographic</source>
+      <translation type="unfinished">Hacer ortográfica</translation>
     </message>
   </context>
   <context>
