@@ -1,18 +1,21 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS>
+<TS version="2.0" language="it" sourcelanguage="en">
   <context>
     <name>CmdDrawingAnnotation</name>
     <message>
-      <location filename="../../Command.cpp" line="+365"/>
+      <location filename="../../Command.cpp" line="+389"/>
       <source>Drawing</source>
       <translation>Disegno</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>&amp;Annotation</source>
       <translation>&amp;Annotazione</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+2"/>
       <source>Inserts an Annotation view in the active drawing</source>
       <translation>Inserisce un'annotazione nel disegno attivo</translation>
     </message>
@@ -20,14 +23,18 @@
   <context>
     <name>CmdDrawingClip</name>
     <message>
+      <location line="+41"/>
       <source>Drawing</source>
       <translation>Disegno</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>&amp;Clip</source>
       <translation>&amp;Clip</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+2"/>
       <source>Inserts a clip group in the active drawing</source>
       <translation>Iserisce un gruppo clip nel disegno attivo</translation>
     </message>
@@ -35,14 +42,18 @@
   <context>
     <name>CmdDrawingExportPage</name>
     <message>
+      <location line="+91"/>
       <source>File</source>
       <translation>File</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>&amp;Export page...</source>
       <translation>&amp;Esporta pagina...</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+2"/>
       <source>Export a page to an SVG file</source>
       <translation>Esporta una pagina in un file SVG</translation>
     </message>
@@ -50,10 +61,13 @@
   <context>
     <name>CmdDrawingNewA3Landscape</name>
     <message>
+      <location line="-314"/>
       <source>Drawing</source>
       <translation>Disegno</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+1"/>
       <source>Insert new A3 landscape drawing</source>
       <translation>Inserisci un nuovo disegno A3 orizzontale</translation>
     </message>
@@ -61,10 +75,13 @@
   <context>
     <name>CmdDrawingNewPage</name>
     <message>
+      <location line="-133"/>
       <source>Drawing</source>
       <translation>Disegno</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+1"/>
       <source>Insert new drawing</source>
       <translation>Inserisci nuovo disegno</translation>
     </message>
@@ -72,14 +89,17 @@
   <context>
     <name>CmdDrawingNewView</name>
     <message>
+      <location line="+166"/>
       <source>Drawing</source>
       <translation>Disegno</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert view in drawing</source>
       <translation>Inserisci vista nel disegno</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert a new View of a Part in the active drawing</source>
       <translation>Inserisce una nuova vista di una parte del disegno attivo</translation>
     </message>
@@ -87,14 +107,17 @@
   <context>
     <name>CmdDrawingOpen</name>
     <message>
+      <location line="-202"/>
       <source>Drawing</source>
       <translation>Disegno</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Open SVG...</source>
       <translation>Apri SVG...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Open a scalable vector graphic</source>
       <translation>Apre una grafica vettoriale scalabile</translation>
     </message>
@@ -102,14 +125,18 @@
   <context>
     <name>CmdDrawingOpenBrowserView</name>
     <message>
+      <location line="+294"/>
       <source>Drawing</source>
       <translation>Disegno</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Open &amp;browser view</source>
       <translation>Apri finestra &amp;browser</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+2"/>
       <source>Opens the selected page in a browser view</source>
       <translation>Visualizza la pagina selezionata in una nuova vista browser</translation>
     </message>
@@ -117,14 +144,17 @@
   <context>
     <name>CmdDrawingOrthoViews</name>
     <message>
+      <location line="-49"/>
       <source>Drawing</source>
       <translation>Disegno</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert orthographic views</source>
       <translation>Inserisci viste ortogonali</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert an orthographic projection of a part in the active drawing</source>
       <translation>Inserisce una proiezione ortogonale di una parte del disegno attivo</translation>
     </message>
@@ -132,18 +162,41 @@
   <context>
     <name>CmdDrawingProjectShape</name>
     <message>
+      <location line="+271"/>
       <source>Drawing</source>
       <translation>Disegno</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Project shape...</source>
       <translation>Proietta le forme...</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+1"/>
       <source>Project shape onto a user-defined plane</source>
       <translation>Proietta una forma su di un piano definito dall'utente</translation>
     </message>
   </context>
+  <context>
+    <name>CmdDrawingSymbol</name>
+    <message>
+      <location line="-107"/>
+      <source>Drawing</source>
+      <translation type="unfinished">Disegno</translation>
+    </message>
+    <message>
+      <location line="+1"/>
+      <source>&amp;Symbol</source>
+      <translation type="unfinished">&amp;Symbol</translation>
+    </message>
+    <message>
+      <location line="+1"/>
+      <location line="+2"/>
+      <source>Inserts a symbol from a svg file in the active drawing</source>
+      <translation type="unfinished">Inserisce un simbolo da un file svg nel disegno attivo</translation>
+    </message>
+  </context>
   <context>
     <name>DrawingGui::DrawingView</name>
     <message>
@@ -152,70 +205,87 @@
       <translation>&amp;Sfondo</translation>
     </message>
     <message>
+      <location line="+6"/>
       <source>&amp;Outline</source>
       <translation>C&amp;ontorno</translation>
     </message>
     <message>
+      <location line="+6"/>
       <source>&amp;Native</source>
       <translation>&amp;Nativo</translation>
     </message>
     <message>
+      <location line="+4"/>
       <source>&amp;OpenGL</source>
       <translation>&amp;OpenGL</translation>
     </message>
     <message>
+      <location line="+3"/>
       <source>&amp;Image</source>
       <translation>&amp;Immagine</translation>
     </message>
     <message>
+      <location line="+4"/>
       <source>&amp;High Quality Antialiasing</source>
       <translation>&amp;Antialiasing di qualità elevata</translation>
     </message>
     <message>
+      <location line="+26"/>
       <source>Open SVG File</source>
       <translation>Apri file SVG</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Could not open file '%1'.</source>
       <translation>Impossibile aprire il file '%1'.</translation>
     </message>
     <message>
+      <location line="+24"/>
       <source>&amp;Renderer</source>
       <translation>&amp;Render</translation>
     </message>
     <message>
+      <location line="+55"/>
       <source>Export PDF</source>
       <translation>Esporta PDF</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>PDF file (*.pdf)</source>
       <translation>File PDF (*.pdf)</translation>
     </message>
     <message>
+      <location line="+16"/>
       <source>Page sizes</source>
       <translation>Dimensioni pagina</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>A0</source>
       <translation>A0</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>A1</source>
       <translation>A1</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>A2</source>
       <translation>A2</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>A3</source>
       <translation>A3</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>A4</source>
       <translation>A4</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>A5</source>
       <translation>A5</translation>
     </message>
@@ -228,98 +298,236 @@
       <translation>Proiezione ortogonale</translation>
     </message>
     <message>
+      <location line="+20"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+31"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+60"/>
+      <source>Right click for axonometric settings</source>
+      <translation type="unfinished">Fare clic con il pulsante destro per le impostazioni assonometriche</translation>
+    </message>
+    <message>
+      <location line="+106"/>
+      <source>Top left x / y</source>
+      <translation type="unfinished">In alto a sinistra x / y</translation>
+    </message>
+    <message>
+      <location line="+48"/>
+      <source>Spacing dx / dy   </source>
+      <translation type="unfinished">Spaziatura dx / dy   </translation>
+    </message>
+    <message>
+      <location line="+71"/>
+      <source> Axis out and right</source>
+      <translation type="unfinished"> Asse fuori e a sinistra</translation>
+    </message>
+    <message>
+      <location line="+7"/>
+      <source> Vertical tilt</source>
+      <translation type="unfinished"> Inclinazione verticale</translation>
+    </message>
+    <message>
+      <location line="+11"/>
+      <location line="+200"/>
+      <source>X +ve</source>
+      <translation type="unfinished">X +ve</translation>
+    </message>
+    <message>
+      <location line="-195"/>
+      <location line="+75"/>
+      <location line="+125"/>
+      <source>Y +ve</source>
+      <translation type="unfinished">Y +ve</translation>
+    </message>
+    <message>
+      <location line="-195"/>
+      <location line="+75"/>
+      <location line="+125"/>
+      <source>Z +ve</source>
+      <translation type="unfinished">Z +ve</translation>
+    </message>
+    <message>
+      <location line="-195"/>
+      <location line="+200"/>
+      <source>X -ve</source>
+      <translation type="unfinished">X -ve</translation>
+    </message>
+    <message>
+      <location line="-195"/>
+      <location line="+70"/>
+      <location line="+130"/>
+      <source>Y -ve</source>
+      <translation type="unfinished">Y -ve</translation>
+    </message>
+    <message>
+      <location line="-195"/>
+      <location line="+70"/>
+      <location line="+130"/>
+      <source>Z -ve</source>
+      <translation type="unfinished">Z -ve</translation>
+    </message>
+    <message>
+      <location line="-188"/>
+      <source>Isometric</source>
+      <translation type="unfinished">Isometrica</translation>
+    </message>
+    <message>
+      <location line="+5"/>
+      <source>Dimetric</source>
+      <translation type="unfinished">Dimetrica</translation>
+    </message>
+    <message>
+      <location line="+5"/>
+      <source>Trimetric</source>
+      <translation type="unfinished">Trimetrica</translation>
+    </message>
+    <message>
+      <location line="+8"/>
+      <source> Scale</source>
+      <translation type="unfinished"> Scala</translation>
+    </message>
+    <message>
+      <location line="+7"/>
+      <source> View projection   </source>
+      <translation type="unfinished"> Proiezione della vista   </translation>
+    </message>
+    <message>
+      <location line="+7"/>
+      <source> Axis aligned up</source>
+      <translation type="unfinished"> Asse allineato verso l'alto</translation>
+    </message>
+    <message>
+      <location line="+41"/>
+      <location line="+23"/>
+      <source>Flip</source>
+      <translation type="unfinished">Specchia</translation>
+    </message>
+    <message>
+      <location line="-10"/>
+      <source> Trimetric</source>
+      <translation type="unfinished"> Trimetrica</translation>
+    </message>
+    <message>
+      <location line="+28"/>
       <source>Projection</source>
       <translation>Proiezione</translation>
     </message>
     <message>
+      <location line="+11"/>
       <source>Third Angle</source>
       <translation>Terzo angolo</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>First Angle</source>
       <translation>Primo angolo</translation>
     </message>
+    <message>
+      <location line="+19"/>
+      <source>View from:</source>
+      <translation type="unfinished">Vista da:</translation>
+    </message>
+    <message>
+      <location line="+47"/>
+      <source>Axis aligned right:</source>
+      <translation type="unfinished">Asse allineato a destra:</translation>
+    </message>
     <message>
       <source>Primary View</source>
-      <translation>Vista primaria</translation>
+      <translation type="obsolete">Vista primaria</translation>
     </message>
     <message>
       <source>Front</source>
-      <translation>Di fronte</translation>
+      <translation type="obsolete">Di fronte</translation>
     </message>
     <message>
       <source>Right</source>
-      <translation>Destra</translation>
+      <translation type="obsolete">Destra</translation>
     </message>
     <message>
       <source>Back</source>
-      <translation>Indietro</translation>
+      <translation type="obsolete">Indietro</translation>
     </message>
     <message>
       <source>Left</source>
-      <translation>Da sinistra</translation>
+      <translation type="obsolete">Da sinistra</translation>
     </message>
     <message>
       <source>Top</source>
-      <translation>Dall'alto</translation>
+      <translation type="obsolete">Dall'alto</translation>
     </message>
     <message>
       <source>Bottom</source>
-      <translation>Dal basso</translation>
+      <translation type="obsolete">Dal basso</translation>
     </message>
     <message>
       <source>- Rotate</source>
-      <translation>-Ruotare</translation>
+      <translation type="obsolete">-Ruotare</translation>
     </message>
     <message>
       <source>90</source>
-      <translation>90</translation>
+      <translation type="obsolete">90</translation>
     </message>
     <message>
       <source>180</source>
-      <translation>180</translation>
+      <translation type="obsolete">180</translation>
     </message>
     <message>
       <source>270</source>
-      <translation>270</translation>
+      <translation type="obsolete">270</translation>
     </message>
     <message>
+      <location line="-514"/>
       <source>Primary view</source>
       <translation>Vista primaria</translation>
     </message>
     <message>
+      <location line="+16"/>
       <source>Secondary Views</source>
       <translation>Vista secondaria</translation>
     </message>
     <message>
+      <location line="+72"/>
       <source>General</source>
       <translation>Generale</translation>
     </message>
     <message>
+      <location line="+9"/>
       <source>Auto scale / position</source>
       <translation>Scala/posiziona automaticamente</translation>
     </message>
     <message>
+      <location line="+15"/>
       <source>Scale</source>
       <translation>Scala</translation>
     </message>
     <message>
       <source>Primary x / y</source>
-      <translation>Primario x / y</translation>
+      <translation type="obsolete">Primario x / y</translation>
     </message>
     <message>
       <source>Secondary dx / dy</source>
-      <translation>Secondario dx / dy</translation>
+      <translation type="obsolete">Secondario dx / dy</translation>
     </message>
     <message>
+      <location line="+125"/>
       <source>Show hidden</source>
       <translation>Visualizza linee nascoste</translation>
     </message>
     <message>
+      <location line="+7"/>
       <source>Show smooth</source>
       <translation>Visualizzazione lisciata</translation>
     </message>
     <message>
+      <location line="+11"/>
       <source>Axonometric</source>
       <translation>Assonometrica</translation>
     </message>
@@ -332,42 +540,52 @@
       <translation>mostra gli spigoli vivi</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Visible smooth edges</source>
       <translation>Mostra i bordi smussati</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Visible sewn edges</source>
       <translation>Mostra i bordi cuciti</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Visible outline edges</source>
       <translation>Mostra i bordi esterni</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Visible isoparameters</source>
       <translation>Mostra le isoparametriche</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Hidden sharp edges</source>
       <translation>Nascondi gli spigoli vivi</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Hidden smooth edges</source>
       <translation>Nascondi i bordi smussati</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Hidden sewn edges</source>
       <translation>Nascondi i bordi cuciti</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Hidden outline edges</source>
       <translation>Nascondi i bordi esterni</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Hidden isoparameters</source>
       <translation>Nascondi le isoparametriche</translation>
     </message>
     <message>
+      <location line="+17"/>
       <source>Project shapes</source>
       <translation>Proietta le forme</translation>
     </message>
@@ -376,103 +594,148 @@
     <name>Drawing_NewPage</name>
     <message>
       <source>A0 landscape</source>
-      <translation>A0 orizzontale</translation>
+      <translation type="obsolete">A0 orizzontale</translation>
     </message>
     <message>
       <source>Insert new A0 landscape drawing</source>
-      <translation>Inserisce nuovo disegno A0 orizzontale</translation>
+      <translation type="obsolete">Inserisce nuovo disegno A0 orizzontale</translation>
     </message>
     <message>
       <source>A1 landscape</source>
-      <translation>A1 orizzontale</translation>
+      <translation type="obsolete">A1 orizzontale</translation>
     </message>
     <message>
       <source>Insert new A1 landscape drawing</source>
-      <translation>Inserisce nuovo disegno A2 orizzontale</translation>
+      <translation type="obsolete">Inserisce nuovo disegno A2 orizzontale</translation>
     </message>
     <message>
       <source>A2 landscape</source>
-      <translation>A2 orizzontale</translation>
+      <translation type="obsolete">A2 orizzontale</translation>
     </message>
     <message>
       <source>Insert new A2 landscape drawing</source>
-      <translation>Inserisce nuovo disegno A2 orizzontale</translation>
+      <translation type="obsolete">Inserisce nuovo disegno A2 orizzontale</translation>
     </message>
     <message>
       <source>A3 landscape</source>
-      <translation>A3 orizzontale</translation>
+      <translation type="obsolete">A3 orizzontale</translation>
     </message>
     <message>
       <source>Insert new A3 landscape drawing</source>
-      <translation>Inserisci un nuovo disegno A3 orizzontale</translation>
+      <translation type="obsolete">Inserisci un nuovo disegno A3 orizzontale</translation>
     </message>
     <message>
       <source>A4 landscape</source>
-      <translation>A4 orizzontale</translation>
+      <translation type="obsolete">A4 orizzontale</translation>
     </message>
     <message>
       <source>Insert new A4 landscape drawing</source>
-      <translation>Inserisce nuovo disegno A4 orizzontale</translation>
+      <translation type="obsolete">Inserisce nuovo disegno A4 orizzontale</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="-327"/>
       <source>Insert new A%1 landscape drawing</source>
-      <translation>Inserisce nuovo disegno A%1 orizzontale</translation>
+      <translation type="obsolete">Inserisce nuovo disegno A%1 orizzontale</translation>
     </message>
     <message>
       <source>A%1 landscape</source>
-      <translation>A%1 orizzontale</translation>
+      <translation type="obsolete">A%1 orizzontale</translation>
+    </message>
+    <message>
+      <location filename="../../Command.cpp" line="-298"/>
+      <source>Landscape</source>
+      <translation type="unfinished">Orizzontale</translation>
+    </message>
+    <message>
+      <location line="+2"/>
+      <source>Portrait</source>
+      <translation type="unfinished">Verticale</translation>
+    </message>
+    <message>
+      <location line="+2"/>
+      <source>%1%2 %3</source>
+      <translation type="unfinished">%1%2 %3</translation>
+    </message>
+    <message>
+      <location line="+6"/>
+      <source>Insert new %1%2 %3 drawing</source>
+      <translation type="unfinished">Inserisci nuovo disegno %1 %2 %3</translation>
     </message>
   </context>
   <context>
     <name>QObject</name>
     <message>
+      <location line="-124"/>
+      <location line="+426"/>
       <source>Choose an SVG file to open</source>
       <translation>Seleziona un file SVG da aprire</translation>
     </message>
     <message>
       <location filename="../../AppDrawingGuiPy.cpp" line="+64"/>
+      <location line="+30"/>
+      <location filename="../../ViewProviderPage.cpp" line="+139"/>
       <source>Drawing viewer</source>
       <translation>Visualizzatore disegno</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="+1"/>
+      <location filename="../../Command.cpp" line="-425"/>
+      <location line="+426"/>
       <source>Scalable Vector Graphics (*.svg *.svgz)</source>
       <translation>Grafica Vettoriale Scalabile (*.svg *.svgz)</translation>
     </message>
     <message>
+      <location line="-227"/>
+      <location line="+51"/>
+      <location line="+45"/>
+      <location line="+177"/>
       <source>Wrong selection</source>
       <translation>Selezione errata</translation>
     </message>
     <message>
+      <location line="-272"/>
+      <location line="+51"/>
       <source>Select a Part object.</source>
       <translation>Seleziona un oggetto Parte.</translation>
     </message>
     <message>
+      <location line="-45"/>
+      <location line="+51"/>
+      <location line="+76"/>
+      <location line="+45"/>
+      <location line="+42"/>
       <source>No page to insert</source>
       <translation>Nessuna pagina da inserire</translation>
     </message>
     <message>
+      <location line="-213"/>
+      <location line="+127"/>
+      <location line="+45"/>
+      <location line="+42"/>
       <source>Create a page to insert.</source>
       <translation>Crea una pagina da inserire.</translation>
     </message>
     <message>
+      <location line="-163"/>
       <source>Create a page to insert views into.</source>
       <translation>Crea una pagina per inserirvi delle viste.</translation>
     </message>
     <message>
+      <location line="+38"/>
+      <location line="+177"/>
       <source>Select one Page object.</source>
       <translation>Seleziona un oggetto Pagina.</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>SVG(*.svg)</source>
       <translation>SVG (*.svg)</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>All Files (*.*)</source>
       <translation>Tutti i file (*.*)</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>Export page</source>
       <translation>Esporta pagina</translation>
     </message>
@@ -482,29 +745,46 @@
       <translation>Mostra disegno</translation>
     </message>
     <message>
-      <location filename="../../TaskOrthoViews.cpp" line="+49"/>
       <source>Front</source>
-      <translation>Di fronte</translation>
+      <translation type="obsolete">Di fronte</translation>
     </message>
     <message>
       <source>Back</source>
-      <translation>Indietro</translation>
+      <translation type="obsolete">Indietro</translation>
     </message>
     <message>
       <source>Right</source>
-      <translation>Destra</translation>
+      <translation type="obsolete">Destra</translation>
     </message>
     <message>
       <source>Left</source>
-      <translation>Da sinistra</translation>
+      <translation type="obsolete">Da sinistra</translation>
     </message>
     <message>
       <source>Top</source>
-      <translation>Dall'alto</translation>
+      <translation type="obsolete">Dall'alto</translation>
     </message>
     <message>
       <source>Bottom</source>
-      <translation>Dal basso</translation>
+      <translation type="obsolete">Dal basso</translation>
+    </message>
+    <message>
+      <location filename="../../TaskOrthoViews.cpp" line="+45"/>
+      <location line="+908"/>
+      <source>Make axonometric...</source>
+      <translation type="unfinished">Rendi assonometrica...</translation>
+    </message>
+    <message>
+      <location line="-907"/>
+      <location line="+908"/>
+      <source>Edit axonometric settings...</source>
+      <translation type="unfinished">Modifica impostazioni assonometriche...</translation>
+    </message>
+    <message>
+      <location line="-907"/>
+      <location line="+908"/>
+      <source>Make orthographic</source>
+      <translation type="unfinished">Rendi ortografica</translation>
     </message>
   </context>
   <context>
