@@ -1,18 +1,21 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS>
+<TS version="2.0" language="no" sourcelanguage="en">
   <context>
     <name>CmdDrawingAnnotation</name>
     <message>
-      <location filename="../../Command.cpp" line="+365"/>
+      <location filename="../../Command.cpp" line="+389"/>
       <source>Drawing</source>
       <translation>Tegning</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>&amp;Annotation</source>
       <translation>&amp;Annotation</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+2"/>
       <source>Inserts an Annotation view in the active drawing</source>
       <translation>Inserts an Annotation view in the active drawing</translation>
     </message>
@@ -20,14 +23,18 @@
   <context>
     <name>CmdDrawingClip</name>
     <message>
+      <location line="+41"/>
       <source>Drawing</source>
       <translation>Tegning</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>&amp;Clip</source>
       <translation>&amp;Clip</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+2"/>
       <source>Inserts a clip group in the active drawing</source>
       <translation>Inserts a clip group in the active drawing</translation>
     </message>
@@ -35,14 +42,18 @@
   <context>
     <name>CmdDrawingExportPage</name>
     <message>
+      <location line="+91"/>
       <source>File</source>
       <translation>Fil</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>&amp;Export page...</source>
       <translation>&amp;Eksporter side...</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+2"/>
       <source>Export a page to an SVG file</source>
       <translation>Eksportere en side til en SVG-fil</translation>
     </message>
@@ -50,10 +61,13 @@
   <context>
     <name>CmdDrawingNewA3Landscape</name>
     <message>
+      <location line="-314"/>
       <source>Drawing</source>
       <translation>Tegning</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+1"/>
       <source>Insert new A3 landscape drawing</source>
       <translation>Sett inn ny A3 landskapstegning</translation>
     </message>
@@ -61,10 +75,13 @@
   <context>
     <name>CmdDrawingNewPage</name>
     <message>
+      <location line="-133"/>
       <source>Drawing</source>
       <translation>Tegning</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+1"/>
       <source>Insert new drawing</source>
       <translation>Insert new drawing</translation>
     </message>
@@ -72,14 +89,17 @@
   <context>
     <name>CmdDrawingNewView</name>
     <message>
+      <location line="+166"/>
       <source>Drawing</source>
       <translation>Tegning</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert view in drawing</source>
       <translation>Sett inn visning i tegning</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert a new View of a Part in the active drawing</source>
       <translation>Sett inn en ny visning av et komponent i den aktive tegningen</translation>
     </message>
@@ -87,14 +107,17 @@
   <context>
     <name>CmdDrawingOpen</name>
     <message>
+      <location line="-202"/>
       <source>Drawing</source>
       <translation>Tegning</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Open SVG...</source>
       <translation>Åpne SVG...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Open a scalable vector graphic</source>
       <translation>Åpne skalerbar vektorgrafikk</translation>
     </message>
@@ -102,14 +125,18 @@
   <context>
     <name>CmdDrawingOpenBrowserView</name>
     <message>
+      <location line="+294"/>
       <source>Drawing</source>
       <translation>Tegning</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Open &amp;browser view</source>
       <translation>Open &amp;browser view</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+2"/>
       <source>Opens the selected page in a browser view</source>
       <translation>Opens the selected page in a browser view</translation>
     </message>
@@ -117,14 +144,17 @@
   <context>
     <name>CmdDrawingOrthoViews</name>
     <message>
+      <location line="-49"/>
       <source>Drawing</source>
       <translation>Tegning</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert orthographic views</source>
       <translation>Insert orthographic views</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert an orthographic projection of a part in the active drawing</source>
       <translation>Insert an orthographic projection of a part in the active drawing</translation>
     </message>
@@ -132,18 +162,41 @@
   <context>
     <name>CmdDrawingProjectShape</name>
     <message>
+      <location line="+271"/>
       <source>Drawing</source>
       <translation>Tegning</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Project shape...</source>
       <translation>Project shape...</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+1"/>
       <source>Project shape onto a user-defined plane</source>
       <translation>Project shape onto a user-defined plane</translation>
     </message>
   </context>
+  <context>
+    <name>CmdDrawingSymbol</name>
+    <message>
+      <location line="-107"/>
+      <source>Drawing</source>
+      <translation type="unfinished">Tegning</translation>
+    </message>
+    <message>
+      <location line="+1"/>
+      <source>&amp;Symbol</source>
+      <translation type="unfinished">&amp;Symbol</translation>
+    </message>
+    <message>
+      <location line="+1"/>
+      <location line="+2"/>
+      <source>Inserts a symbol from a svg file in the active drawing</source>
+      <translation type="unfinished">Inserts a symbol from a svg file in the active drawing</translation>
+    </message>
+  </context>
   <context>
     <name>DrawingGui::DrawingView</name>
     <message>
@@ -152,70 +205,87 @@
       <translation>&amp;Bakgrunn</translation>
     </message>
     <message>
+      <location line="+6"/>
       <source>&amp;Outline</source>
       <translation>&amp;Disposisjon</translation>
     </message>
     <message>
+      <location line="+6"/>
       <source>&amp;Native</source>
       <translation>&amp;Opprinnelig</translation>
     </message>
     <message>
+      <location line="+4"/>
       <source>&amp;OpenGL</source>
       <translation>&amp;OpenGL</translation>
     </message>
     <message>
+      <location line="+3"/>
       <source>&amp;Image</source>
       <translation>&amp;Bilde</translation>
     </message>
     <message>
+      <location line="+4"/>
       <source>&amp;High Quality Antialiasing</source>
       <translation>&amp;Høykvalitets kantutjevning</translation>
     </message>
     <message>
+      <location line="+26"/>
       <source>Open SVG File</source>
       <translation>Åpne SVG-fil</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Could not open file '%1'.</source>
       <translation>Kunne ikke åpne filen '%1'.</translation>
     </message>
     <message>
+      <location line="+24"/>
       <source>&amp;Renderer</source>
       <translation>&amp;Bildegenerering</translation>
     </message>
     <message>
+      <location line="+55"/>
       <source>Export PDF</source>
       <translation>Eksporter PDF</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>PDF file (*.pdf)</source>
       <translation>PDF-fil (*.pdf)</translation>
     </message>
     <message>
+      <location line="+16"/>
       <source>Page sizes</source>
       <translation>Page sizes</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>A0</source>
       <translation>A0</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>A1</source>
       <translation>A1</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>A2</source>
       <translation>A2</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>A3</source>
       <translation>A3</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>A4</source>
       <translation>A4</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>A5</source>
       <translation>A5</translation>
     </message>
@@ -228,98 +298,236 @@
       <translation>Orthographic Projection</translation>
     </message>
     <message>
+      <location line="+20"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+31"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+60"/>
+      <source>Right click for axonometric settings</source>
+      <translation type="unfinished">Right click for axonometric settings</translation>
+    </message>
+    <message>
+      <location line="+106"/>
+      <source>Top left x / y</source>
+      <translation type="unfinished">Top left x / y</translation>
+    </message>
+    <message>
+      <location line="+48"/>
+      <source>Spacing dx / dy   </source>
+      <translation type="unfinished">Spacing dx / dy   </translation>
+    </message>
+    <message>
+      <location line="+71"/>
+      <source> Axis out and right</source>
+      <translation type="unfinished"> Axis out and right</translation>
+    </message>
+    <message>
+      <location line="+7"/>
+      <source> Vertical tilt</source>
+      <translation type="unfinished"> Vertical tilt</translation>
+    </message>
+    <message>
+      <location line="+11"/>
+      <location line="+200"/>
+      <source>X +ve</source>
+      <translation type="unfinished">X +ve</translation>
+    </message>
+    <message>
+      <location line="-195"/>
+      <location line="+75"/>
+      <location line="+125"/>
+      <source>Y +ve</source>
+      <translation type="unfinished">Y +ve</translation>
+    </message>
+    <message>
+      <location line="-195"/>
+      <location line="+75"/>
+      <location line="+125"/>
+      <source>Z +ve</source>
+      <translation type="unfinished">Z +ve</translation>
+    </message>
+    <message>
+      <location line="-195"/>
+      <location line="+200"/>
+      <source>X -ve</source>
+      <translation type="unfinished">X -ve</translation>
+    </message>
+    <message>
+      <location line="-195"/>
+      <location line="+70"/>
+      <location line="+130"/>
+      <source>Y -ve</source>
+      <translation type="unfinished">Y -ve</translation>
+    </message>
+    <message>
+      <location line="-195"/>
+      <location line="+70"/>
+      <location line="+130"/>
+      <source>Z -ve</source>
+      <translation type="unfinished">Z -ve</translation>
+    </message>
+    <message>
+      <location line="-188"/>
+      <source>Isometric</source>
+      <translation type="unfinished">Isometric</translation>
+    </message>
+    <message>
+      <location line="+5"/>
+      <source>Dimetric</source>
+      <translation type="unfinished">Dimetric</translation>
+    </message>
+    <message>
+      <location line="+5"/>
+      <source>Trimetric</source>
+      <translation type="unfinished">Trimetric</translation>
+    </message>
+    <message>
+      <location line="+8"/>
+      <source> Scale</source>
+      <translation type="unfinished"> Scale</translation>
+    </message>
+    <message>
+      <location line="+7"/>
+      <source> View projection   </source>
+      <translation type="unfinished"> View projection   </translation>
+    </message>
+    <message>
+      <location line="+7"/>
+      <source> Axis aligned up</source>
+      <translation type="unfinished"> Axis aligned up</translation>
+    </message>
+    <message>
+      <location line="+41"/>
+      <location line="+23"/>
+      <source>Flip</source>
+      <translation type="unfinished">Flip</translation>
+    </message>
+    <message>
+      <location line="-10"/>
+      <source> Trimetric</source>
+      <translation type="unfinished"> Trimetric</translation>
+    </message>
+    <message>
+      <location line="+28"/>
       <source>Projection</source>
       <translation>Projection</translation>
     </message>
     <message>
+      <location line="+11"/>
       <source>Third Angle</source>
       <translation>Third Angle</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>First Angle</source>
       <translation>First Angle</translation>
     </message>
+    <message>
+      <location line="+19"/>
+      <source>View from:</source>
+      <translation type="unfinished">View from:</translation>
+    </message>
+    <message>
+      <location line="+47"/>
+      <source>Axis aligned right:</source>
+      <translation type="unfinished">Axis aligned right:</translation>
+    </message>
     <message>
       <source>Primary View</source>
-      <translation>Primary View</translation>
+      <translation type="obsolete">Primary View</translation>
     </message>
     <message>
       <source>Front</source>
-      <translation>Front</translation>
+      <translation type="obsolete">Front</translation>
     </message>
     <message>
       <source>Right</source>
-      <translation>Høyre</translation>
+      <translation type="obsolete">Høyre</translation>
     </message>
     <message>
       <source>Back</source>
-      <translation>Back</translation>
+      <translation type="obsolete">Back</translation>
     </message>
     <message>
       <source>Left</source>
-      <translation>Venstre</translation>
+      <translation type="obsolete">Venstre</translation>
     </message>
     <message>
       <source>Top</source>
-      <translation>Topp</translation>
+      <translation type="obsolete">Topp</translation>
     </message>
     <message>
       <source>Bottom</source>
-      <translation>Bunn</translation>
+      <translation type="obsolete">Bunn</translation>
     </message>
     <message>
       <source>- Rotate</source>
-      <translation>- Rotate</translation>
+      <translation type="obsolete">- Rotate</translation>
     </message>
     <message>
       <source>90</source>
-      <translation>90</translation>
+      <translation type="obsolete">90</translation>
     </message>
     <message>
       <source>180</source>
-      <translation>180</translation>
+      <translation type="obsolete">180</translation>
     </message>
     <message>
       <source>270</source>
-      <translation>270</translation>
+      <translation type="obsolete">270</translation>
     </message>
     <message>
+      <location line="-514"/>
       <source>Primary view</source>
       <translation>Primary view</translation>
     </message>
     <message>
+      <location line="+16"/>
       <source>Secondary Views</source>
       <translation>Secondary Views</translation>
     </message>
     <message>
+      <location line="+72"/>
       <source>General</source>
       <translation>Generelle</translation>
     </message>
     <message>
+      <location line="+9"/>
       <source>Auto scale / position</source>
       <translation>Auto scale / position</translation>
     </message>
     <message>
+      <location line="+15"/>
       <source>Scale</source>
       <translation>Skaler</translation>
     </message>
     <message>
       <source>Primary x / y</source>
-      <translation>Primary x / y</translation>
+      <translation type="obsolete">Primary x / y</translation>
     </message>
     <message>
       <source>Secondary dx / dy</source>
-      <translation>Secondary dx / dy</translation>
+      <translation type="obsolete">Secondary dx / dy</translation>
     </message>
     <message>
+      <location line="+125"/>
       <source>Show hidden</source>
       <translation>Show hidden</translation>
     </message>
     <message>
+      <location line="+7"/>
       <source>Show smooth</source>
       <translation>Show smooth</translation>
     </message>
     <message>
+      <location line="+11"/>
       <source>Axonometric</source>
       <translation>Axonometric</translation>
     </message>
@@ -332,42 +540,52 @@
       <translation>Visible sharp edges</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Visible smooth edges</source>
       <translation>Visible smooth edges</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Visible sewn edges</source>
       <translation>Visible sewn edges</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Visible outline edges</source>
       <translation>Visible outline edges</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Visible isoparameters</source>
       <translation>Visible isoparameters</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Hidden sharp edges</source>
       <translation>Hidden sharp edges</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Hidden smooth edges</source>
       <translation>Hidden smooth edges</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Hidden sewn edges</source>
       <translation>Hidden sewn edges</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Hidden outline edges</source>
       <translation>Hidden outline edges</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Hidden isoparameters</source>
       <translation>Hidden isoparameters</translation>
     </message>
     <message>
+      <location line="+17"/>
       <source>Project shapes</source>
       <translation>Project shapes</translation>
     </message>
@@ -376,103 +594,148 @@
     <name>Drawing_NewPage</name>
     <message>
       <source>A0 landscape</source>
-      <translation>A0 landscape</translation>
+      <translation type="obsolete">A0 landscape</translation>
     </message>
     <message>
       <source>Insert new A0 landscape drawing</source>
-      <translation>Insert new A0 landscape drawing</translation>
+      <translation type="obsolete">Insert new A0 landscape drawing</translation>
     </message>
     <message>
       <source>A1 landscape</source>
-      <translation>A1 landscape</translation>
+      <translation type="obsolete">A1 landscape</translation>
     </message>
     <message>
       <source>Insert new A1 landscape drawing</source>
-      <translation>Insert new A1 landscape drawing</translation>
+      <translation type="obsolete">Insert new A1 landscape drawing</translation>
     </message>
     <message>
       <source>A2 landscape</source>
-      <translation>A2 landscape</translation>
+      <translation type="obsolete">A2 landscape</translation>
     </message>
     <message>
       <source>Insert new A2 landscape drawing</source>
-      <translation>Insert new A2 landscape drawing</translation>
+      <translation type="obsolete">Insert new A2 landscape drawing</translation>
     </message>
     <message>
       <source>A3 landscape</source>
-      <translation>A3 landscape</translation>
+      <translation type="obsolete">A3 landscape</translation>
     </message>
     <message>
       <source>Insert new A3 landscape drawing</source>
-      <translation>Sett inn ny A3 landskapstegning</translation>
+      <translation type="obsolete">Sett inn ny A3 landskapstegning</translation>
     </message>
     <message>
       <source>A4 landscape</source>
-      <translation>A4 landscape</translation>
+      <translation type="obsolete">A4 landscape</translation>
     </message>
     <message>
       <source>Insert new A4 landscape drawing</source>
-      <translation>Insert new A4 landscape drawing</translation>
+      <translation type="obsolete">Insert new A4 landscape drawing</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="-327"/>
       <source>Insert new A%1 landscape drawing</source>
-      <translation>Insert new A%1 landscape drawing</translation>
+      <translation type="obsolete">Insert new A%1 landscape drawing</translation>
     </message>
     <message>
       <source>A%1 landscape</source>
-      <translation>A%1 landscape</translation>
+      <translation type="obsolete">A%1 landscape</translation>
+    </message>
+    <message>
+      <location filename="../../Command.cpp" line="-298"/>
+      <source>Landscape</source>
+      <translation type="unfinished">Landscape</translation>
+    </message>
+    <message>
+      <location line="+2"/>
+      <source>Portrait</source>
+      <translation type="unfinished">Portrait</translation>
+    </message>
+    <message>
+      <location line="+2"/>
+      <source>%1%2 %3</source>
+      <translation type="unfinished">%1%2 %3</translation>
+    </message>
+    <message>
+      <location line="+6"/>
+      <source>Insert new %1%2 %3 drawing</source>
+      <translation type="unfinished">Insert new %1%2 %3 drawing</translation>
     </message>
   </context>
   <context>
     <name>QObject</name>
     <message>
+      <location line="-124"/>
+      <location line="+426"/>
       <source>Choose an SVG file to open</source>
       <translation>Velg en SVG-fil å åpne</translation>
     </message>
     <message>
       <location filename="../../AppDrawingGuiPy.cpp" line="+64"/>
+      <location line="+30"/>
+      <location filename="../../ViewProviderPage.cpp" line="+139"/>
       <source>Drawing viewer</source>
       <translation>Tegningsviser</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="+1"/>
+      <location filename="../../Command.cpp" line="-425"/>
+      <location line="+426"/>
       <source>Scalable Vector Graphics (*.svg *.svgz)</source>
       <translation>Skalerbar Vektor Grafikk (SVG *. *. svgz)</translation>
     </message>
     <message>
+      <location line="-227"/>
+      <location line="+51"/>
+      <location line="+45"/>
+      <location line="+177"/>
       <source>Wrong selection</source>
       <translation>Feil valg</translation>
     </message>
     <message>
+      <location line="-272"/>
+      <location line="+51"/>
       <source>Select a Part object.</source>
       <translation>Velg et komponentobjekt.</translation>
     </message>
     <message>
+      <location line="-45"/>
+      <location line="+51"/>
+      <location line="+76"/>
+      <location line="+45"/>
+      <location line="+42"/>
       <source>No page to insert</source>
       <translation>Ingen side å sette inn</translation>
     </message>
     <message>
+      <location line="-213"/>
+      <location line="+127"/>
+      <location line="+45"/>
+      <location line="+42"/>
       <source>Create a page to insert.</source>
       <translation>Lag en side å sette inn.</translation>
     </message>
     <message>
+      <location line="-163"/>
       <source>Create a page to insert views into.</source>
       <translation>Create a page to insert views into.</translation>
     </message>
     <message>
+      <location line="+38"/>
+      <location line="+177"/>
       <source>Select one Page object.</source>
       <translation>Velg ett objekt på siden.</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>SVG(*.svg)</source>
       <translation>SVG (*.svg)</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>All Files (*.*)</source>
       <translation>Alle filer (*.*)</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>Export page</source>
       <translation>Eksporter side</translation>
     </message>
@@ -482,29 +745,46 @@
       <translation>Show drawing</translation>
     </message>
     <message>
-      <location filename="../../TaskOrthoViews.cpp" line="+49"/>
       <source>Front</source>
-      <translation>Front</translation>
+      <translation type="obsolete">Front</translation>
     </message>
     <message>
       <source>Back</source>
-      <translation>Back</translation>
+      <translation type="obsolete">Back</translation>
     </message>
     <message>
       <source>Right</source>
-      <translation>Høyre</translation>
+      <translation type="obsolete">Høyre</translation>
     </message>
     <message>
       <source>Left</source>
-      <translation>Venstre</translation>
+      <translation type="obsolete">Venstre</translation>
     </message>
     <message>
       <source>Top</source>
-      <translation>Topp</translation>
+      <translation type="obsolete">Topp</translation>
     </message>
     <message>
       <source>Bottom</source>
-      <translation>Bunn</translation>
+      <translation type="obsolete">Bunn</translation>
+    </message>
+    <message>
+      <location filename="../../TaskOrthoViews.cpp" line="+45"/>
+      <location line="+908"/>
+      <source>Make axonometric...</source>
+      <translation type="unfinished">Make axonometric...</translation>
+    </message>
+    <message>
+      <location line="-907"/>
+      <location line="+908"/>
+      <source>Edit axonometric settings...</source>
+      <translation type="unfinished">Edit axonometric settings...</translation>
+    </message>
+    <message>
+      <location line="-907"/>
+      <location line="+908"/>
+      <source>Make orthographic</source>
+      <translation type="unfinished">Make orthographic</translation>
     </message>
   </context>
   <context>
