@@ -1,18 +1,21 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS>
+<TS version="2.0" language="pt-BR" sourcelanguage="en">
   <context>
     <name>CmdDrawingAnnotation</name>
     <message>
-      <location filename="../../Command.cpp" line="+365"/>
+      <location filename="../../Command.cpp" line="+389"/>
       <source>Drawing</source>
       <translation>Desenho</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>&amp;Annotation</source>
       <translation>&amp;Anotação</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+2"/>
       <source>Inserts an Annotation view in the active drawing</source>
       <translation>Inserir uma anotação no desenho ativo</translation>
     </message>
@@ -20,40 +23,51 @@
   <context>
     <name>CmdDrawingClip</name>
     <message>
+      <location line="+41"/>
       <source>Drawing</source>
       <translation>Desenho</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>&amp;Clip</source>
       <translation>&amp;Recorte</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+2"/>
       <source>Inserts a clip group in the active drawing</source>
-      <translation>Inserir um grupo de clipe no desenho ativo</translation>
+      <translation>Inserir um grupo de Apara no desenho ativo</translation>
     </message>
   </context>
   <context>
     <name>CmdDrawingExportPage</name>
     <message>
+      <location line="+91"/>
       <source>File</source>
       <translation>Arquivo</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>&amp;Export page...</source>
       <translation>&amp;Exportar página...</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+2"/>
       <source>Export a page to an SVG file</source>
-      <translation>Exportar página para um arquivo SVG</translation>
+      <translation>Exportar página para formato SVG</translation>
     </message>
   </context>
   <context>
     <name>CmdDrawingNewA3Landscape</name>
     <message>
+      <location line="-314"/>
       <source>Drawing</source>
       <translation>Desenho</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+1"/>
       <source>Insert new A3 landscape drawing</source>
       <translation>Inserir um novo desenho A3 paisagem</translation>
     </message>
@@ -61,10 +75,13 @@
   <context>
     <name>CmdDrawingNewPage</name>
     <message>
+      <location line="-133"/>
       <source>Drawing</source>
       <translation>Desenho</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+1"/>
       <source>Insert new drawing</source>
       <translation>Inserir novo desenho</translation>
     </message>
@@ -72,14 +89,17 @@
   <context>
     <name>CmdDrawingNewView</name>
     <message>
+      <location line="+166"/>
       <source>Drawing</source>
       <translation>Desenho</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert view in drawing</source>
-      <translation>Inserir uma vista no desenho</translation>
+      <translation>Inserir vista no desenho</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert a new View of a Part in the active drawing</source>
       <translation>Inserir uma nova Vista de uma peça no desenho ativo</translation>
     </message>
@@ -87,14 +107,17 @@
   <context>
     <name>CmdDrawingOpen</name>
     <message>
+      <location line="-202"/>
       <source>Drawing</source>
       <translation>Desenho</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Open SVG...</source>
       <translation>Abrir SVG...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Open a scalable vector graphic</source>
       <translation>Abrir um gráfico vetorial escalável</translation>
     </message>
@@ -102,14 +125,18 @@
   <context>
     <name>CmdDrawingOpenBrowserView</name>
     <message>
+      <location line="+294"/>
       <source>Drawing</source>
       <translation>Desenho</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Open &amp;browser view</source>
       <translation>Abrir visualização no navegador</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+2"/>
       <source>Opens the selected page in a browser view</source>
       <translation>Abrir a página selecionada no navegador</translation>
     </message>
@@ -117,31 +144,57 @@
   <context>
     <name>CmdDrawingOrthoViews</name>
     <message>
+      <location line="-49"/>
       <source>Drawing</source>
       <translation>Desenho</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert orthographic views</source>
       <translation>Inserir visualizações ortográficas</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert an orthographic projection of a part in the active drawing</source>
-      <translation>Inserir uma projeção ortográfica em uma parte do desenho ativo</translation>
+      <translation>Inserir uma projeção ortogonal de uma peça no desenho ativo</translation>
     </message>
   </context>
   <context>
     <name>CmdDrawingProjectShape</name>
     <message>
+      <location line="+271"/>
       <source>Drawing</source>
       <translation>Desenho</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Project shape...</source>
-      <translation>Projetar uma forma...</translation>
+      <translation>Projetar forma...</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+1"/>
       <source>Project shape onto a user-defined plane</source>
-      <translation>Projeta uma forma sobre um plano definido pelo usuário</translation>
+      <translation>Projeta forma sobre um plano definido pelo usuário</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdDrawingSymbol</name>
+    <message>
+      <location line="-107"/>
+      <source>Drawing</source>
+      <translation type="unfinished">Desenho</translation>
+    </message>
+    <message>
+      <location line="+1"/>
+      <source>&amp;Symbol</source>
+      <translation type="unfinished">&amp;Símbolo</translation>
+    </message>
+    <message>
+      <location line="+1"/>
+      <location line="+2"/>
+      <source>Inserts a symbol from a svg file in the active drawing</source>
+      <translation type="unfinished">Insere um símbolo de um arquivo svg no desenho ativo</translation>
     </message>
   </context>
   <context>
@@ -152,70 +205,87 @@
       <translation>Plano de &amp;Fundo</translation>
     </message>
     <message>
+      <location line="+6"/>
       <source>&amp;Outline</source>
       <translation>&amp;Contorno</translation>
     </message>
     <message>
+      <location line="+6"/>
       <source>&amp;Native</source>
       <translation>&amp;Nativo</translation>
     </message>
     <message>
+      <location line="+4"/>
       <source>&amp;OpenGL</source>
       <translation>&amp;OpenGL</translation>
     </message>
     <message>
+      <location line="+3"/>
       <source>&amp;Image</source>
       <translation>&amp;Imagem</translation>
     </message>
     <message>
+      <location line="+4"/>
       <source>&amp;High Quality Antialiasing</source>
       <translation>Antialiasing de alta qualidade</translation>
     </message>
     <message>
+      <location line="+26"/>
       <source>Open SVG File</source>
       <translation>Abrir arquivo SVG</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Could not open file '%1'.</source>
       <translation>Não foi possível abrir o arquivo "%1".</translation>
     </message>
     <message>
+      <location line="+24"/>
       <source>&amp;Renderer</source>
       <translation>&amp;Renderizador</translation>
     </message>
     <message>
+      <location line="+55"/>
       <source>Export PDF</source>
       <translation>Exportar PDF</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>PDF file (*.pdf)</source>
       <translation>Arquivo PDF (*.pdf)</translation>
     </message>
     <message>
+      <location line="+16"/>
       <source>Page sizes</source>
       <translation>Tamanhos de página</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>A0</source>
       <translation>A0</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>A1</source>
       <translation>A1</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>A2</source>
       <translation>A2</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>A3</source>
       <translation>A3</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>A4</source>
       <translation>A4</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>A5</source>
       <translation>A5</translation>
     </message>
@@ -228,98 +298,236 @@
       <translation>Projeção ortográfica</translation>
     </message>
     <message>
+      <location line="+20"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+31"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+60"/>
+      <source>Right click for axonometric settings</source>
+      <translation type="unfinished">Clique com o botão direito para configurações axonométricas</translation>
+    </message>
+    <message>
+      <location line="+106"/>
+      <source>Top left x / y</source>
+      <translation type="unfinished">Superior à esquerda x / y</translation>
+    </message>
+    <message>
+      <location line="+48"/>
+      <source>Spacing dx / dy   </source>
+      <translation type="unfinished">Espaçamento dx / dy   </translation>
+    </message>
+    <message>
+      <location line="+71"/>
+      <source> Axis out and right</source>
+      <translation type="unfinished"> Fora do eixo à direita</translation>
+    </message>
+    <message>
+      <location line="+7"/>
+      <source> Vertical tilt</source>
+      <translation type="unfinished"> Inclinação vertical</translation>
+    </message>
+    <message>
+      <location line="+11"/>
+      <location line="+200"/>
+      <source>X +ve</source>
+      <translation type="unfinished">X +ve</translation>
+    </message>
+    <message>
+      <location line="-195"/>
+      <location line="+75"/>
+      <location line="+125"/>
+      <source>Y +ve</source>
+      <translation type="unfinished">Y +ve</translation>
+    </message>
+    <message>
+      <location line="-195"/>
+      <location line="+75"/>
+      <location line="+125"/>
+      <source>Z +ve</source>
+      <translation type="unfinished">Z +ve</translation>
+    </message>
+    <message>
+      <location line="-195"/>
+      <location line="+200"/>
+      <source>X -ve</source>
+      <translation type="unfinished">X -ve</translation>
+    </message>
+    <message>
+      <location line="-195"/>
+      <location line="+70"/>
+      <location line="+130"/>
+      <source>Y -ve</source>
+      <translation type="unfinished">Y -ve</translation>
+    </message>
+    <message>
+      <location line="-195"/>
+      <location line="+70"/>
+      <location line="+130"/>
+      <source>Z -ve</source>
+      <translation type="unfinished">Z -ve</translation>
+    </message>
+    <message>
+      <location line="-188"/>
+      <source>Isometric</source>
+      <translation type="unfinished">Isométrico</translation>
+    </message>
+    <message>
+      <location line="+5"/>
+      <source>Dimetric</source>
+      <translation type="unfinished">Diamétrico</translation>
+    </message>
+    <message>
+      <location line="+5"/>
+      <source>Trimetric</source>
+      <translation type="unfinished">Trimétrico</translation>
+    </message>
+    <message>
+      <location line="+8"/>
+      <source> Scale</source>
+      <translation type="unfinished"> Escala</translation>
+    </message>
+    <message>
+      <location line="+7"/>
+      <source> View projection   </source>
+      <translation type="unfinished"> Visualizar projeção   </translation>
+    </message>
+    <message>
+      <location line="+7"/>
+      <source> Axis aligned up</source>
+      <translation type="unfinished"> Eixo alinhado acima</translation>
+    </message>
+    <message>
+      <location line="+41"/>
+      <location line="+23"/>
+      <source>Flip</source>
+      <translation type="unfinished">Girar</translation>
+    </message>
+    <message>
+      <location line="-10"/>
+      <source> Trimetric</source>
+      <translation type="unfinished"> Trimétrico</translation>
+    </message>
+    <message>
+      <location line="+28"/>
       <source>Projection</source>
       <translation>Projeção</translation>
     </message>
     <message>
+      <location line="+11"/>
       <source>Third Angle</source>
       <translation>Terceiro ângulo</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>First Angle</source>
       <translation>Primeiro ângulo</translation>
     </message>
+    <message>
+      <location line="+19"/>
+      <source>View from:</source>
+      <translation type="unfinished">Visualização de:</translation>
+    </message>
+    <message>
+      <location line="+47"/>
+      <source>Axis aligned right:</source>
+      <translation type="unfinished">Eixo alinhado à direita:</translation>
+    </message>
     <message>
       <source>Primary View</source>
-      <translation>Visão primária</translation>
+      <translation type="obsolete">Visão primária</translation>
     </message>
     <message>
       <source>Front</source>
-      <translation>Frente</translation>
+      <translation type="obsolete">Frente</translation>
     </message>
     <message>
       <source>Right</source>
-      <translation>Direito</translation>
+      <translation type="obsolete">Direito</translation>
     </message>
     <message>
       <source>Back</source>
-      <translation>Voltar</translation>
+      <translation type="obsolete">Voltar</translation>
     </message>
     <message>
       <source>Left</source>
-      <translation>Esquerda</translation>
+      <translation type="obsolete">Esquerda</translation>
     </message>
     <message>
       <source>Top</source>
-      <translation>Topo</translation>
+      <translation type="obsolete">Topo</translation>
     </message>
     <message>
       <source>Bottom</source>
-      <translation>De baixo</translation>
+      <translation type="obsolete">De baixo</translation>
     </message>
     <message>
       <source>- Rotate</source>
-      <translation>- Rotacionar</translation>
+      <translation type="obsolete">- Rotacionar</translation>
     </message>
     <message>
       <source>90</source>
-      <translation>90</translation>
+      <translation type="obsolete">90</translation>
     </message>
     <message>
       <source>180</source>
-      <translation>180</translation>
+      <translation type="obsolete">180</translation>
     </message>
     <message>
       <source>270</source>
-      <translation>270</translation>
+      <translation type="obsolete">270</translation>
     </message>
     <message>
+      <location line="-514"/>
       <source>Primary view</source>
       <translation>Vista principal</translation>
     </message>
     <message>
+      <location line="+16"/>
       <source>Secondary Views</source>
       <translation>Vista secundária</translation>
     </message>
     <message>
+      <location line="+72"/>
       <source>General</source>
       <translation>Geral</translation>
     </message>
     <message>
+      <location line="+9"/>
       <source>Auto scale / position</source>
       <translation>Auto escala / posição</translation>
     </message>
     <message>
+      <location line="+15"/>
       <source>Scale</source>
       <translation>Escalar</translation>
     </message>
     <message>
       <source>Primary x / y</source>
-      <translation>Primária x / y</translation>
+      <translation type="obsolete">x / y primário</translation>
     </message>
     <message>
       <source>Secondary dx / dy</source>
-      <translation>Secundária dx / dy</translation>
+      <translation type="obsolete"> dx / dy secundário</translation>
     </message>
     <message>
+      <location line="+125"/>
       <source>Show hidden</source>
       <translation>Exibir ocultos</translation>
     </message>
     <message>
+      <location line="+7"/>
       <source>Show smooth</source>
       <translation>Exibir suavização</translation>
     </message>
     <message>
+      <location line="+11"/>
       <source>Axonometric</source>
       <translation>Axonométrica</translation>
     </message>
@@ -329,45 +537,55 @@
     <message>
       <location filename="../../TaskDialog.cpp" line="+49"/>
       <source>Visible sharp edges</source>
-      <translation>Bordas afiadas visíveis</translation>
+      <translation>Bordas vivas visíveis</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Visible smooth edges</source>
-      <translation>Bordas alisadas visíveis</translation>
+      <translation>Bordas suaves visíveis</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Visible sewn edges</source>
-      <translation>Bordas costuradas visíveis</translation>
+      <translation>Bordas emendadas visíveis</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Visible outline edges</source>
       <translation>Bordas de contorno visíveis</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Visible isoparameters</source>
       <translation>Isoparâmetros visíveis</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Hidden sharp edges</source>
-      <translation>Bordas afiadas escondidas</translation>
+      <translation>Bordas vivas escondidas</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Hidden smooth edges</source>
-      <translation>Bordas alisadas escondidas</translation>
+      <translation>Bordas suaves escondidas</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Hidden sewn edges</source>
-      <translation>Bordas costuradas escondidas</translation>
+      <translation>Bordas emendadas escondidas</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Hidden outline edges</source>
       <translation>Bordas de contorno escondidas</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Hidden isoparameters</source>
       <translation>Isoparâmetros escondidos</translation>
     </message>
     <message>
+      <location line="+17"/>
       <source>Project shapes</source>
       <translation>Projetar formas</translation>
     </message>
@@ -376,103 +594,148 @@
     <name>Drawing_NewPage</name>
     <message>
       <source>A0 landscape</source>
-      <translation>A0 paisagem</translation>
+      <translation type="obsolete">A0 paisagem</translation>
     </message>
     <message>
       <source>Insert new A0 landscape drawing</source>
-      <translation>Inserir uma nova página A0 paisagem</translation>
+      <translation type="obsolete">Inserir uma nova página A0 paisagem</translation>
     </message>
     <message>
       <source>A1 landscape</source>
-      <translation>A1 paisagem</translation>
+      <translation type="obsolete">A1 paisagem</translation>
     </message>
     <message>
       <source>Insert new A1 landscape drawing</source>
-      <translation>Inserir uma nova página A1 paisagem</translation>
+      <translation type="obsolete">Inserir uma nova página A1 paisagem</translation>
     </message>
     <message>
       <source>A2 landscape</source>
-      <translation>A2 paisagem</translation>
+      <translation type="obsolete">A2 paisagem</translation>
     </message>
     <message>
       <source>Insert new A2 landscape drawing</source>
-      <translation>Inserir uma nova página A2 paisagem</translation>
+      <translation type="obsolete">Inserir uma nova página A2 paisagem</translation>
     </message>
     <message>
       <source>A3 landscape</source>
-      <translation>A3 paisagem</translation>
+      <translation type="obsolete">A3 paisagem</translation>
     </message>
     <message>
       <source>Insert new A3 landscape drawing</source>
-      <translation>Inserir um novo desenho A3 paisagem</translation>
+      <translation type="obsolete">Inserir um novo desenho A3 paisagem</translation>
     </message>
     <message>
       <source>A4 landscape</source>
-      <translation>A4 paisagem</translation>
+      <translation type="obsolete">A4 paisagem</translation>
     </message>
     <message>
       <source>Insert new A4 landscape drawing</source>
-      <translation>Inserir uma nova página A4 paisagem</translation>
+      <translation type="obsolete">Inserir uma nova página A4 paisagem</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="-327"/>
       <source>Insert new A%1 landscape drawing</source>
-      <translation>Inserir uma nova página A%1 paisagem</translation>
+      <translation type="obsolete">Inserir uma nova página A%1 paisagem</translation>
     </message>
     <message>
       <source>A%1 landscape</source>
-      <translation>A%1 paisagem</translation>
+      <translation type="obsolete">A%1 paisagem</translation>
+    </message>
+    <message>
+      <location filename="../../Command.cpp" line="-298"/>
+      <source>Landscape</source>
+      <translation type="unfinished">Paisagem</translation>
+    </message>
+    <message>
+      <location line="+2"/>
+      <source>Portrait</source>
+      <translation type="unfinished">Retrato</translation>
+    </message>
+    <message>
+      <location line="+2"/>
+      <source>%1%2 %3</source>
+      <translation type="unfinished">%1%2 %3</translation>
+    </message>
+    <message>
+      <location line="+6"/>
+      <source>Insert new %1%2 %3 drawing</source>
+      <translation type="unfinished">Inserir novo %1%2 %3 desenho</translation>
     </message>
   </context>
   <context>
     <name>QObject</name>
     <message>
+      <location line="-124"/>
+      <location line="+426"/>
       <source>Choose an SVG file to open</source>
       <translation>Escolha um arquivo SVG para abrir</translation>
     </message>
     <message>
       <location filename="../../AppDrawingGuiPy.cpp" line="+64"/>
+      <location line="+30"/>
+      <location filename="../../ViewProviderPage.cpp" line="+139"/>
       <source>Drawing viewer</source>
       <translation>Visualizador de desenho</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="+1"/>
+      <location filename="../../Command.cpp" line="-425"/>
+      <location line="+426"/>
       <source>Scalable Vector Graphics (*.svg *.svgz)</source>
       <translation>Scalable Vector Graphics (*.svg *.svgz)</translation>
     </message>
     <message>
+      <location line="-227"/>
+      <location line="+51"/>
+      <location line="+45"/>
+      <location line="+177"/>
       <source>Wrong selection</source>
       <translation>Seleção errada</translation>
     </message>
     <message>
+      <location line="-272"/>
+      <location line="+51"/>
       <source>Select a Part object.</source>
-      <translation>Selecione um objeto Part.</translation>
+      <translation>Selecione um objeto Peça</translation>
     </message>
     <message>
+      <location line="-45"/>
+      <location line="+51"/>
+      <location line="+76"/>
+      <location line="+45"/>
+      <location line="+42"/>
       <source>No page to insert</source>
       <translation>Nenhuma página para inserir</translation>
     </message>
     <message>
+      <location line="-213"/>
+      <location line="+127"/>
+      <location line="+45"/>
+      <location line="+42"/>
       <source>Create a page to insert.</source>
-      <translation>Criar uma página para inserir.</translation>
+      <translation>Crie uma página para inserir.</translation>
     </message>
     <message>
+      <location line="-163"/>
       <source>Create a page to insert views into.</source>
       <translation>Crie uma página para inserir as vistas.</translation>
     </message>
     <message>
+      <location line="+38"/>
+      <location line="+177"/>
       <source>Select one Page object.</source>
       <translation>Selecione um objeto de tipo Página.</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>SVG(*.svg)</source>
       <translation>SVG (*.svg)</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>All Files (*.*)</source>
       <translation>Todos os arquivos (*.*)</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>Export page</source>
       <translation>Exportar uma página</translation>
     </message>
@@ -482,29 +745,46 @@
       <translation>Mostrar o desenho</translation>
     </message>
     <message>
-      <location filename="../../TaskOrthoViews.cpp" line="+49"/>
       <source>Front</source>
-      <translation>Frente</translation>
+      <translation type="obsolete">Frente</translation>
     </message>
     <message>
       <source>Back</source>
-      <translation>Voltar</translation>
+      <translation type="obsolete">Voltar</translation>
     </message>
     <message>
       <source>Right</source>
-      <translation>Direito</translation>
+      <translation type="obsolete">Direito</translation>
     </message>
     <message>
       <source>Left</source>
-      <translation>Esquerda</translation>
+      <translation type="obsolete">Esquerda</translation>
     </message>
     <message>
       <source>Top</source>
-      <translation>Topo</translation>
+      <translation type="obsolete">Topo</translation>
     </message>
     <message>
       <source>Bottom</source>
-      <translation>De baixo</translation>
+      <translation type="obsolete">De baixo</translation>
+    </message>
+    <message>
+      <location filename="../../TaskOrthoViews.cpp" line="+45"/>
+      <location line="+908"/>
+      <source>Make axonometric...</source>
+      <translation type="unfinished">Fazer axonométrico...</translation>
+    </message>
+    <message>
+      <location line="-907"/>
+      <location line="+908"/>
+      <source>Edit axonometric settings...</source>
+      <translation type="unfinished">Editar configurações axonométricas...</translation>
+    </message>
+    <message>
+      <location line="-907"/>
+      <location line="+908"/>
+      <source>Make orthographic</source>
+      <translation type="unfinished">Fazer ortográfico</translation>
     </message>
   </context>
   <context>
