@@ -1,33 +1,40 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS>
+<TS version="2.0" language="pt-PT" sourcelanguage="en">
   <context>
     <name>CmdDrawingAnnotation</name>
     <message>
-      <location filename="../../Command.cpp" line="+365"/>
+      <location filename="../../Command.cpp" line="+389"/>
       <source>Drawing</source>
       <translation>Desenho</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>&amp;Annotation</source>
       <translation>&amp;Anotação</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+2"/>
       <source>Inserts an Annotation view in the active drawing</source>
-      <translation>Insere uam vista de Anotação no desenho ativo</translation>
+      <translation>Insere uma visualização da Anotação no desenho ativo</translation>
     </message>
   </context>
   <context>
     <name>CmdDrawingClip</name>
     <message>
+      <location line="+41"/>
       <source>Drawing</source>
       <translation>Desenho</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>&amp;Clip</source>
       <translation>&amp;Cortar</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+2"/>
       <source>Inserts a clip group in the active drawing</source>
       <translation>Insere um grupo de corte no desenho ativo</translation>
     </message>
@@ -35,14 +42,18 @@
   <context>
     <name>CmdDrawingExportPage</name>
     <message>
+      <location line="+91"/>
       <source>File</source>
       <translation>Ficheiro</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>&amp;Export page...</source>
-      <translation>Exportar página...</translation>
+      <translation>Exportar página ...</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+2"/>
       <source>Export a page to an SVG file</source>
       <translation>Exportar página para um ficheiro SVG</translation>
     </message>
@@ -50,10 +61,13 @@
   <context>
     <name>CmdDrawingNewA3Landscape</name>
     <message>
+      <location line="-314"/>
       <source>Drawing</source>
       <translation>Desenho</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+1"/>
       <source>Insert new A3 landscape drawing</source>
       <translation>Inserir novo desenho A3 deitado</translation>
     </message>
@@ -61,10 +75,13 @@
   <context>
     <name>CmdDrawingNewPage</name>
     <message>
+      <location line="-133"/>
       <source>Drawing</source>
       <translation>Desenho</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+1"/>
       <source>Insert new drawing</source>
       <translation>Inserir novo desenho</translation>
     </message>
@@ -72,14 +89,17 @@
   <context>
     <name>CmdDrawingNewView</name>
     <message>
+      <location line="+166"/>
       <source>Drawing</source>
       <translation>Desenho</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert view in drawing</source>
-      <translation>Inserir uma vista no desenho</translation>
+      <translation>Inserir uma visualização no desenho</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert a new View of a Part in the active drawing</source>
       <translation>Inserir uma nova Vista de uma peça no desenho ativo</translation>
     </message>
@@ -87,14 +107,17 @@
   <context>
     <name>CmdDrawingOpen</name>
     <message>
+      <location line="-202"/>
       <source>Drawing</source>
       <translation>Desenho</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Open SVG...</source>
       <translation>Abrir SVG...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Open a scalable vector graphic</source>
       <translation>Abrir um gráfico vetorial escalável</translation>
     </message>
@@ -102,29 +125,36 @@
   <context>
     <name>CmdDrawingOpenBrowserView</name>
     <message>
+      <location line="+294"/>
       <source>Drawing</source>
       <translation>Desenho</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Open &amp;browser view</source>
-      <translation>Abrir uma vista &amp;browser</translation>
+      <translation>Abrir &amp;Navegador de Visualização</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+2"/>
       <source>Opens the selected page in a browser view</source>
-      <translation>Abre a página selecionada numa vista do navegador</translation>
+      <translation>Abre a página selecionada num navegador de visualização</translation>
     </message>
   </context>
   <context>
     <name>CmdDrawingOrthoViews</name>
     <message>
+      <location line="-49"/>
       <source>Drawing</source>
       <translation>Desenho</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert orthographic views</source>
       <translation>Inserir vistas ortográficas</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert an orthographic projection of a part in the active drawing</source>
       <translation>Inserir uma projeção ortográfica de uma parte no desenho ativo</translation>
     </message>
@@ -132,18 +162,41 @@
   <context>
     <name>CmdDrawingProjectShape</name>
     <message>
+      <location line="+271"/>
       <source>Drawing</source>
       <translation>Desenho</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Project shape...</source>
       <translation>Forma de projeto...</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+1"/>
       <source>Project shape onto a user-defined plane</source>
       <translation>Forma de projeto num plano definido pelo utilizador</translation>
     </message>
   </context>
+  <context>
+    <name>CmdDrawingSymbol</name>
+    <message>
+      <location line="-107"/>
+      <source>Drawing</source>
+      <translation type="unfinished">Desenho</translation>
+    </message>
+    <message>
+      <location line="+1"/>
+      <source>&amp;Symbol</source>
+      <translation type="unfinished">&amp;Símbolo</translation>
+    </message>
+    <message>
+      <location line="+1"/>
+      <location line="+2"/>
+      <source>Inserts a symbol from a svg file in the active drawing</source>
+      <translation type="unfinished">Insere um símbolo de um arquivo svg no desenho ativo</translation>
+    </message>
+  </context>
   <context>
     <name>DrawingGui::DrawingView</name>
     <message>
@@ -152,70 +205,87 @@
       <translation>&amp;Fundo</translation>
     </message>
     <message>
+      <location line="+6"/>
       <source>&amp;Outline</source>
       <translation>&amp;Contorno</translation>
     </message>
     <message>
+      <location line="+6"/>
       <source>&amp;Native</source>
       <translation>Nativo</translation>
     </message>
     <message>
+      <location line="+4"/>
       <source>&amp;OpenGL</source>
-      <translation>OPenGl</translation>
+      <translation>&amp;OPenGl</translation>
     </message>
     <message>
+      <location line="+3"/>
       <source>&amp;Image</source>
-      <translation>imagem</translation>
+      <translation>&amp;Imagem</translation>
     </message>
     <message>
+      <location line="+4"/>
       <source>&amp;High Quality Antialiasing</source>
-      <translation>Antialiasing de alta qualidade</translation>
+      <translation>Suavização de &amp;Alta Qualidade</translation>
     </message>
     <message>
+      <location line="+26"/>
       <source>Open SVG File</source>
-      <translation>Abrir ficheiro SVG</translation>
+      <translation>Abrir Ficheiro SVG</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Could not open file '%1'.</source>
-      <translation>Não foi possível abrir o arquivo "%1".</translation>
+      <translation>Não foi possível abrir o ficheiro "%1".</translation>
     </message>
     <message>
+      <location line="+24"/>
       <source>&amp;Renderer</source>
-      <translation>&amp;Processador</translation>
+      <translation>&amp;Renderização</translation>
     </message>
     <message>
+      <location line="+55"/>
       <source>Export PDF</source>
       <translation>Exportar PDF</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>PDF file (*.pdf)</source>
       <translation>Ficheiro PDF (*pdf)</translation>
     </message>
     <message>
+      <location line="+16"/>
       <source>Page sizes</source>
       <translation>Tamanhos de página</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>A0</source>
       <translation>A0</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>A1</source>
       <translation>A1</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>A2</source>
       <translation>A2</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>A3</source>
       <translation>A3</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>A4</source>
       <translation>A4</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>A5</source>
       <translation>A5</translation>
     </message>
@@ -225,103 +295,241 @@
     <message>
       <location filename="../../TaskOrthoViews.ui" line="+26"/>
       <source>Orthographic Projection</source>
-      <translation>Projeção ortográfica</translation>
+      <translation>Projeção Ortográfica</translation>
     </message>
     <message>
+      <location line="+20"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+31"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+60"/>
+      <source>Right click for axonometric settings</source>
+      <translation type="unfinished">Clique com o botão direito para configurações axonométricas</translation>
+    </message>
+    <message>
+      <location line="+106"/>
+      <source>Top left x / y</source>
+      <translation type="unfinished">Superior esquerda x / y</translation>
+    </message>
+    <message>
+      <location line="+48"/>
+      <source>Spacing dx / dy   </source>
+      <translation type="unfinished">Espaçamento dx / dy   </translation>
+    </message>
+    <message>
+      <location line="+71"/>
+      <source> Axis out and right</source>
+      <translation type="unfinished"> Eixo para fora e à direita</translation>
+    </message>
+    <message>
+      <location line="+7"/>
+      <source> Vertical tilt</source>
+      <translation type="unfinished"> Inclinação vertical</translation>
+    </message>
+    <message>
+      <location line="+11"/>
+      <location line="+200"/>
+      <source>X +ve</source>
+      <translation type="unfinished">X +ve</translation>
+    </message>
+    <message>
+      <location line="-195"/>
+      <location line="+75"/>
+      <location line="+125"/>
+      <source>Y +ve</source>
+      <translation type="unfinished">Y +ve</translation>
+    </message>
+    <message>
+      <location line="-195"/>
+      <location line="+75"/>
+      <location line="+125"/>
+      <source>Z +ve</source>
+      <translation type="unfinished">Z +ve</translation>
+    </message>
+    <message>
+      <location line="-195"/>
+      <location line="+200"/>
+      <source>X -ve</source>
+      <translation type="unfinished">X -ve</translation>
+    </message>
+    <message>
+      <location line="-195"/>
+      <location line="+70"/>
+      <location line="+130"/>
+      <source>Y -ve</source>
+      <translation type="unfinished">Y -ve</translation>
+    </message>
+    <message>
+      <location line="-195"/>
+      <location line="+70"/>
+      <location line="+130"/>
+      <source>Z -ve</source>
+      <translation type="unfinished">Z -ve</translation>
+    </message>
+    <message>
+      <location line="-188"/>
+      <source>Isometric</source>
+      <translation type="unfinished">Isométrica</translation>
+    </message>
+    <message>
+      <location line="+5"/>
+      <source>Dimetric</source>
+      <translation type="unfinished">Dimetrica</translation>
+    </message>
+    <message>
+      <location line="+5"/>
+      <source>Trimetric</source>
+      <translation type="unfinished">Trimétrica</translation>
+    </message>
+    <message>
+      <location line="+8"/>
+      <source> Scale</source>
+      <translation type="unfinished"> Escala</translation>
+    </message>
+    <message>
+      <location line="+7"/>
+      <source> View projection   </source>
+      <translation type="unfinished">Vista de projeção</translation>
+    </message>
+    <message>
+      <location line="+7"/>
+      <source> Axis aligned up</source>
+      <translation type="unfinished"> Eixo alinhado cima</translation>
+    </message>
+    <message>
+      <location line="+41"/>
+      <location line="+23"/>
+      <source>Flip</source>
+      <translation type="unfinished">Virar</translation>
+    </message>
+    <message>
+      <location line="-10"/>
+      <source> Trimetric</source>
+      <translation type="unfinished"> Trimétrica</translation>
+    </message>
+    <message>
+      <location line="+28"/>
       <source>Projection</source>
       <translation>Projeção</translation>
     </message>
     <message>
+      <location line="+11"/>
       <source>Third Angle</source>
-      <translation>Terceiro ângulo</translation>
+      <translation>Terceiro Ângulo</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>First Angle</source>
-      <translation>Primeiro ângulo</translation>
+      <translation>Primeiro Ângulo</translation>
+    </message>
+    <message>
+      <location line="+19"/>
+      <source>View from:</source>
+      <translation type="unfinished">Vista de:</translation>
+    </message>
+    <message>
+      <location line="+47"/>
+      <source>Axis aligned right:</source>
+      <translation type="unfinished">Eixo alinhado à direita:</translation>
     </message>
     <message>
       <source>Primary View</source>
-      <translation>Vista principal</translation>
+      <translation type="obsolete">Visualização Principal</translation>
     </message>
     <message>
       <source>Front</source>
-      <translation>Front</translation>
+      <translation type="obsolete">Front</translation>
     </message>
     <message>
       <source>Right</source>
-      <translation>Direita</translation>
+      <translation type="obsolete">Direita</translation>
     </message>
     <message>
       <source>Back</source>
-      <translation>Voltar</translation>
+      <translation type="obsolete">Voltar</translation>
     </message>
     <message>
       <source>Left</source>
-      <translation>Left</translation>
+      <translation type="obsolete">Left</translation>
     </message>
     <message>
       <source>Top</source>
-      <translation>Topo</translation>
+      <translation type="obsolete">Topo</translation>
     </message>
     <message>
       <source>Bottom</source>
-      <translation>Bottom</translation>
+      <translation type="obsolete">Bottom</translation>
     </message>
     <message>
       <source>- Rotate</source>
-      <translation>- Rodar</translation>
+      <translation type="obsolete">- Rodar</translation>
     </message>
     <message>
       <source>90</source>
-      <translation>90</translation>
+      <translation type="obsolete">90</translation>
     </message>
     <message>
       <source>180</source>
-      <translation>180</translation>
+      <translation type="obsolete">180</translation>
     </message>
     <message>
       <source>270</source>
-      <translation>270</translation>
+      <translation type="obsolete">270</translation>
     </message>
     <message>
+      <location line="-514"/>
       <source>Primary view</source>
-      <translation>Vista principal</translation>
+      <translation>Visualização principal</translation>
     </message>
     <message>
+      <location line="+16"/>
       <source>Secondary Views</source>
-      <translation>Vistas secundárias</translation>
+      <translation>Visualização Secundária</translation>
     </message>
     <message>
+      <location line="+72"/>
       <source>General</source>
-      <translation>Geral</translation>
+      <translation> Geral </translation>
     </message>
     <message>
+      <location line="+9"/>
       <source>Auto scale / position</source>
-      <translation>Auto escalar / posição</translation>
+      <translation>Escala / Posição Automática</translation>
     </message>
     <message>
+      <location line="+15"/>
       <source>Scale</source>
       <translation>Escala</translation>
     </message>
     <message>
       <source>Primary x / y</source>
-      <translation>x / y prymário</translation>
+      <translation type="obsolete">x / y Primário</translation>
     </message>
     <message>
       <source>Secondary dx / dy</source>
-      <translation>dx / dy secundário</translation>
+      <translation type="obsolete">dx / dy Secundário</translation>
     </message>
     <message>
+      <location line="+125"/>
       <source>Show hidden</source>
-      <translation>Mostrar oculto</translation>
+      <translation>Mostrar ocultado</translation>
     </message>
     <message>
+      <location line="+7"/>
       <source>Show smooth</source>
       <translation>Mostrar suave</translation>
     </message>
     <message>
+      <location line="+11"/>
       <source>Axonometric</source>
-      <translation>Axonométrica</translation>
+      <translation>Axanométrico</translation>
     </message>
   </context>
   <context>
@@ -329,45 +537,55 @@
     <message>
       <location filename="../../TaskDialog.cpp" line="+49"/>
       <source>Visible sharp edges</source>
-      <translation>Arestas agudas visíveis</translation>
+      <translation>Arestas cortantes visíveis</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Visible smooth edges</source>
-      <translation>Arestas suaves visíveis</translation>
+      <translation>Arestas planas visíveis</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Visible sewn edges</source>
       <translation>Arestas costuradas visíveis</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Visible outline edges</source>
       <translation>Arestas de contorno visiveis</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Visible isoparameters</source>
       <translation>Isoparâmetros visíveis</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Hidden sharp edges</source>
-      <translation>Arestas agudas ocultas</translation>
+      <translation>Arestas cortantes ocultas</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Hidden smooth edges</source>
-      <translation>Arestas suaves ocultas</translation>
+      <translation>Arestas planas ocultas</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Hidden sewn edges</source>
       <translation>Arestas costuradas ocultas</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Hidden outline edges</source>
       <translation>Arestas de contorno ocultas</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Hidden isoparameters</source>
       <translation>Isoparâmetros ocultos</translation>
     </message>
     <message>
+      <location line="+17"/>
       <source>Project shapes</source>
       <translation>Formas de projeto</translation>
     </message>
@@ -376,103 +594,148 @@
     <name>Drawing_NewPage</name>
     <message>
       <source>A0 landscape</source>
-      <translation>A0 landscape</translation>
+      <translation type="obsolete">A0 landscape</translation>
     </message>
     <message>
       <source>Insert new A0 landscape drawing</source>
-      <translation>Insert new A0 landscape drawing</translation>
+      <translation type="obsolete">Insert new A0 landscape drawing</translation>
     </message>
     <message>
       <source>A1 landscape</source>
-      <translation>A1 landscape</translation>
+      <translation type="obsolete">A1 landscape</translation>
     </message>
     <message>
       <source>Insert new A1 landscape drawing</source>
-      <translation>Insert new A1 landscape drawing</translation>
+      <translation type="obsolete">Insert new A1 landscape drawing</translation>
     </message>
     <message>
       <source>A2 landscape</source>
-      <translation>A2 landscape</translation>
+      <translation type="obsolete">A2 landscape</translation>
     </message>
     <message>
       <source>Insert new A2 landscape drawing</source>
-      <translation>Insert new A2 landscape drawing</translation>
+      <translation type="obsolete">Insert new A2 landscape drawing</translation>
     </message>
     <message>
       <source>A3 landscape</source>
-      <translation>A3 landscape</translation>
+      <translation type="obsolete">A3 landscape</translation>
     </message>
     <message>
       <source>Insert new A3 landscape drawing</source>
-      <translation>Inserir novo desenho A3 deitado</translation>
+      <translation type="obsolete">Inserir novo desenho A3 deitado</translation>
     </message>
     <message>
       <source>A4 landscape</source>
-      <translation>A4 landscape</translation>
+      <translation type="obsolete">A4 landscape</translation>
     </message>
     <message>
       <source>Insert new A4 landscape drawing</source>
-      <translation>Insert new A4 landscape drawing</translation>
+      <translation type="obsolete">Insert new A4 landscape drawing</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="-327"/>
       <source>Insert new A%1 landscape drawing</source>
-      <translation>Inserir novo desenho paisagem A%1</translation>
+      <translation type="obsolete">Inserir novo desenho paisagem A%1</translation>
     </message>
     <message>
       <source>A%1 landscape</source>
-      <translation>Paisagem A%1</translation>
+      <translation type="obsolete">Paisagem A%1</translation>
+    </message>
+    <message>
+      <location filename="../../Command.cpp" line="-298"/>
+      <source>Landscape</source>
+      <translation type="unfinished">Paisagem</translation>
+    </message>
+    <message>
+      <location line="+2"/>
+      <source>Portrait</source>
+      <translation type="unfinished">Retrato</translation>
+    </message>
+    <message>
+      <location line="+2"/>
+      <source>%1%2 %3</source>
+      <translation type="unfinished">%1%2 %3</translation>
+    </message>
+    <message>
+      <location line="+6"/>
+      <source>Insert new %1%2 %3 drawing</source>
+      <translation type="unfinished">Inserir novo desenho %1%2 %3</translation>
     </message>
   </context>
   <context>
     <name>QObject</name>
     <message>
+      <location line="-124"/>
+      <location line="+426"/>
       <source>Choose an SVG file to open</source>
       <translation>Escolha um arquivo SVG para abrir</translation>
     </message>
     <message>
       <location filename="../../AppDrawingGuiPy.cpp" line="+64"/>
+      <location line="+30"/>
+      <location filename="../../ViewProviderPage.cpp" line="+139"/>
       <source>Drawing viewer</source>
       <translation>Visualizador de desenho</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="+1"/>
+      <location filename="../../Command.cpp" line="-425"/>
+      <location line="+426"/>
       <source>Scalable Vector Graphics (*.svg *.svgz)</source>
       <translation>Grafico Vetorial Escalável (SVG *.svgz)</translation>
     </message>
     <message>
+      <location line="-227"/>
+      <location line="+51"/>
+      <location line="+45"/>
+      <location line="+177"/>
       <source>Wrong selection</source>
       <translation>Seleção errada</translation>
     </message>
     <message>
+      <location line="-272"/>
+      <location line="+51"/>
       <source>Select a Part object.</source>
       <translation>Selecione um objeto parte.</translation>
     </message>
     <message>
+      <location line="-45"/>
+      <location line="+51"/>
+      <location line="+76"/>
+      <location line="+45"/>
+      <location line="+42"/>
       <source>No page to insert</source>
       <translation>Nenhuma página para inserir</translation>
     </message>
     <message>
+      <location line="-213"/>
+      <location line="+127"/>
+      <location line="+45"/>
+      <location line="+42"/>
       <source>Create a page to insert.</source>
       <translation>Criar uma página para inserir.</translation>
     </message>
     <message>
+      <location line="-163"/>
       <source>Create a page to insert views into.</source>
-      <translation>Criar uma página onde inserir vistas.</translation>
+      <translation>Cria uma página para inserir as visualizações.</translation>
     </message>
     <message>
+      <location line="+38"/>
+      <location line="+177"/>
       <source>Select one Page object.</source>
       <translation>Selecione um objeto Página.</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>SVG(*.svg)</source>
       <translation>SVG (*. svg)</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>All Files (*.*)</source>
-      <translation>All Files (*.*)</translation>
+      <translation>Todos os Ficheiros (*. *)</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>Export page</source>
       <translation>Exportar página</translation>
     </message>
@@ -482,29 +745,46 @@
       <translation>Mostrar desenho</translation>
     </message>
     <message>
-      <location filename="../../TaskOrthoViews.cpp" line="+49"/>
       <source>Front</source>
-      <translation>Front</translation>
+      <translation type="obsolete">Front</translation>
     </message>
     <message>
       <source>Back</source>
-      <translation>Voltar</translation>
+      <translation type="obsolete">Voltar</translation>
     </message>
     <message>
       <source>Right</source>
-      <translation>Direita</translation>
+      <translation type="obsolete">Direita</translation>
     </message>
     <message>
       <source>Left</source>
-      <translation>Left</translation>
+      <translation type="obsolete">Left</translation>
     </message>
     <message>
       <source>Top</source>
-      <translation>Topo</translation>
+      <translation type="obsolete">Topo</translation>
     </message>
     <message>
       <source>Bottom</source>
-      <translation>Bottom</translation>
+      <translation type="obsolete">Bottom</translation>
+    </message>
+    <message>
+      <location filename="../../TaskOrthoViews.cpp" line="+45"/>
+      <location line="+908"/>
+      <source>Make axonometric...</source>
+      <translation type="unfinished">Fazer axonométria...</translation>
+    </message>
+    <message>
+      <location line="-907"/>
+      <location line="+908"/>
+      <source>Edit axonometric settings...</source>
+      <translation type="unfinished">Editar configurações axonométricas...</translation>
+    </message>
+    <message>
+      <location line="-907"/>
+      <location line="+908"/>
+      <source>Make orthographic</source>
+      <translation type="unfinished">Make orthographic</translation>
     </message>
   </context>
   <context>
