@@ -1,18 +1,21 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS>
+<TS version="2.0" language="ru" sourcelanguage="en">
   <context>
     <name>CmdDrawingAnnotation</name>
     <message>
-      <location filename="../../Command.cpp" line="+365"/>
+      <location filename="../../Command.cpp" line="+389"/>
       <source>Drawing</source>
       <translation>Чертеж</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>&amp;Annotation</source>
       <translation>&amp;Аннотация</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+2"/>
       <source>Inserts an Annotation view in the active drawing</source>
       <translation>Вставляет представление аннотации в активном документе</translation>
     </message>
@@ -20,29 +23,37 @@
   <context>
     <name>CmdDrawingClip</name>
     <message>
+      <location line="+41"/>
       <source>Drawing</source>
       <translation>Чертеж</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>&amp;Clip</source>
-      <translation>&amp;Clip</translation>
+      <translation>&amp;Клип</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+2"/>
       <source>Inserts a clip group in the active drawing</source>
-      <translation>Inserts a clip group in the active drawing</translation>
+      <translation>Вставить группу клипов в активный чертёж </translation>
     </message>
   </context>
   <context>
     <name>CmdDrawingExportPage</name>
     <message>
+      <location line="+91"/>
       <source>File</source>
       <translation>Файл</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>&amp;Export page...</source>
       <translation>&amp;Экспортировать страницу...</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+2"/>
       <source>Export a page to an SVG file</source>
       <translation>Экспорт страницу в файл SVG</translation>
     </message>
@@ -50,10 +61,13 @@
   <context>
     <name>CmdDrawingNewA3Landscape</name>
     <message>
+      <location line="-314"/>
       <source>Drawing</source>
       <translation>Чертеж</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+1"/>
       <source>Insert new A3 landscape drawing</source>
       <translation>Вставить новый фоновый чертеж А3</translation>
     </message>
@@ -61,10 +75,13 @@
   <context>
     <name>CmdDrawingNewPage</name>
     <message>
+      <location line="-133"/>
       <source>Drawing</source>
       <translation>Чертеж</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+1"/>
       <source>Insert new drawing</source>
       <translation>Вставить новый чертеж</translation>
     </message>
@@ -72,14 +89,17 @@
   <context>
     <name>CmdDrawingNewView</name>
     <message>
+      <location line="+166"/>
       <source>Drawing</source>
       <translation>Чертеж</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert view in drawing</source>
       <translation>Вставить вид в чертеж</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert a new View of a Part in the active drawing</source>
       <translation>Вставить новый вид детали в текущий чертеж</translation>
     </message>
@@ -87,14 +107,17 @@
   <context>
     <name>CmdDrawingOpen</name>
     <message>
+      <location line="-202"/>
       <source>Drawing</source>
       <translation>Чертеж</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Open SVG...</source>
       <translation>Открыть SVG...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Open a scalable vector graphic</source>
       <translation>Открыть масштабируемую векторную графику</translation>
     </message>
@@ -102,14 +125,18 @@
   <context>
     <name>CmdDrawingOpenBrowserView</name>
     <message>
+      <location line="+294"/>
       <source>Drawing</source>
       <translation>Чертеж</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Open &amp;browser view</source>
-      <translation>Open &amp;browser view</translation>
+      <translation>Открыть в &amp;браузере</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+2"/>
       <source>Opens the selected page in a browser view</source>
       <translation>Открыть выбранную страницу для просмотра в браузере</translation>
     </message>
@@ -117,14 +144,17 @@
   <context>
     <name>CmdDrawingOrthoViews</name>
     <message>
+      <location line="-49"/>
       <source>Drawing</source>
       <translation>Чертеж</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert orthographic views</source>
       <translation>Вставить ортографические виды</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert an orthographic projection of a part in the active drawing</source>
       <translation>Вставить ортографическую проекцию детали в активный рисунок</translation>
     </message>
@@ -132,18 +162,41 @@
   <context>
     <name>CmdDrawingProjectShape</name>
     <message>
+      <location line="+271"/>
       <source>Drawing</source>
       <translation>Чертеж</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Project shape...</source>
       <translation>Проекция фигуры...</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+1"/>
       <source>Project shape onto a user-defined plane</source>
       <translation>Проекция фигуры на выбранную плоскость</translation>
     </message>
   </context>
+  <context>
+    <name>CmdDrawingSymbol</name>
+    <message>
+      <location line="-107"/>
+      <source>Drawing</source>
+      <translation type="unfinished">Чертеж</translation>
+    </message>
+    <message>
+      <location line="+1"/>
+      <source>&amp;Symbol</source>
+      <translation type="unfinished">&amp;Symbol</translation>
+    </message>
+    <message>
+      <location line="+1"/>
+      <location line="+2"/>
+      <source>Inserts a symbol from a svg file in the active drawing</source>
+      <translation type="unfinished">Inserts a symbol from a svg file in the active drawing</translation>
+    </message>
+  </context>
   <context>
     <name>DrawingGui::DrawingView</name>
     <message>
@@ -152,70 +205,87 @@
       <translation>&amp;Фон</translation>
     </message>
     <message>
+      <location line="+6"/>
       <source>&amp;Outline</source>
       <translation>&amp;Контур</translation>
     </message>
     <message>
+      <location line="+6"/>
       <source>&amp;Native</source>
       <translation>&amp;Собственный</translation>
     </message>
     <message>
+      <location line="+4"/>
       <source>&amp;OpenGL</source>
       <translation>&amp;OpenGL</translation>
     </message>
     <message>
+      <location line="+3"/>
       <source>&amp;Image</source>
       <translation>&amp;Изображение</translation>
     </message>
     <message>
+      <location line="+4"/>
       <source>&amp;High Quality Antialiasing</source>
       <translation>&amp;Высокое качество сглаживания</translation>
     </message>
     <message>
+      <location line="+26"/>
       <source>Open SVG File</source>
       <translation>Открыть файл SVG </translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Could not open file '%1'.</source>
       <translation>Не удалось открыть файл '% 1'.</translation>
     </message>
     <message>
+      <location line="+24"/>
       <source>&amp;Renderer</source>
       <translation>Рендерер</translation>
     </message>
     <message>
+      <location line="+55"/>
       <source>Export PDF</source>
       <translation>Экспорт в PDF</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>PDF file (*.pdf)</source>
       <translation>PDF-файл (*. PDF)</translation>
     </message>
     <message>
+      <location line="+16"/>
       <source>Page sizes</source>
       <translation>Размеры страницы</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>A0</source>
       <translation>А0</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>A1</source>
       <translation>А1</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>A2</source>
       <translation>А2</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>A3</source>
       <translation>А3</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>A4</source>
       <translation>А4</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>A5</source>
       <translation>А5</translation>
     </message>
@@ -228,98 +298,236 @@
       <translation>Ортографическая проекция</translation>
     </message>
     <message>
+      <location line="+20"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+31"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+25"/>
+      <location line="+60"/>
+      <source>Right click for axonometric settings</source>
+      <translation type="unfinished">Right click for axonometric settings</translation>
+    </message>
+    <message>
+      <location line="+106"/>
+      <source>Top left x / y</source>
+      <translation type="unfinished">Top left x / y</translation>
+    </message>
+    <message>
+      <location line="+48"/>
+      <source>Spacing dx / dy   </source>
+      <translation type="unfinished">Spacing dx / dy   </translation>
+    </message>
+    <message>
+      <location line="+71"/>
+      <source> Axis out and right</source>
+      <translation type="unfinished"> Axis out and right</translation>
+    </message>
+    <message>
+      <location line="+7"/>
+      <source> Vertical tilt</source>
+      <translation type="unfinished"> Vertical tilt</translation>
+    </message>
+    <message>
+      <location line="+11"/>
+      <location line="+200"/>
+      <source>X +ve</source>
+      <translation type="unfinished">X +ve</translation>
+    </message>
+    <message>
+      <location line="-195"/>
+      <location line="+75"/>
+      <location line="+125"/>
+      <source>Y +ve</source>
+      <translation type="unfinished">Y +ve</translation>
+    </message>
+    <message>
+      <location line="-195"/>
+      <location line="+75"/>
+      <location line="+125"/>
+      <source>Z +ve</source>
+      <translation type="unfinished">Z +ve</translation>
+    </message>
+    <message>
+      <location line="-195"/>
+      <location line="+200"/>
+      <source>X -ve</source>
+      <translation type="unfinished">X -ve</translation>
+    </message>
+    <message>
+      <location line="-195"/>
+      <location line="+70"/>
+      <location line="+130"/>
+      <source>Y -ve</source>
+      <translation type="unfinished">Y -ve</translation>
+    </message>
+    <message>
+      <location line="-195"/>
+      <location line="+70"/>
+      <location line="+130"/>
+      <source>Z -ve</source>
+      <translation type="unfinished">Z -ve</translation>
+    </message>
+    <message>
+      <location line="-188"/>
+      <source>Isometric</source>
+      <translation type="unfinished">Isometric</translation>
+    </message>
+    <message>
+      <location line="+5"/>
+      <source>Dimetric</source>
+      <translation type="unfinished">Dimetric</translation>
+    </message>
+    <message>
+      <location line="+5"/>
+      <source>Trimetric</source>
+      <translation type="unfinished">Trimetric</translation>
+    </message>
+    <message>
+      <location line="+8"/>
+      <source> Scale</source>
+      <translation type="unfinished"> Scale</translation>
+    </message>
+    <message>
+      <location line="+7"/>
+      <source> View projection   </source>
+      <translation type="unfinished"> View projection   </translation>
+    </message>
+    <message>
+      <location line="+7"/>
+      <source> Axis aligned up</source>
+      <translation type="unfinished"> Axis aligned up</translation>
+    </message>
+    <message>
+      <location line="+41"/>
+      <location line="+23"/>
+      <source>Flip</source>
+      <translation type="unfinished">Flip</translation>
+    </message>
+    <message>
+      <location line="-10"/>
+      <source> Trimetric</source>
+      <translation type="unfinished"> Trimetric</translation>
+    </message>
+    <message>
+      <location line="+28"/>
       <source>Projection</source>
       <translation>Проекция</translation>
     </message>
     <message>
+      <location line="+11"/>
       <source>Third Angle</source>
       <translation>Третий угол</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>First Angle</source>
       <translation>Первый угол</translation>
     </message>
+    <message>
+      <location line="+19"/>
+      <source>View from:</source>
+      <translation type="unfinished">View from:</translation>
+    </message>
+    <message>
+      <location line="+47"/>
+      <source>Axis aligned right:</source>
+      <translation type="unfinished">Axis aligned right:</translation>
+    </message>
     <message>
       <source>Primary View</source>
-      <translation>Главный вид</translation>
+      <translation type="obsolete">Главный вид</translation>
     </message>
     <message>
       <source>Front</source>
-      <translation>Спереди</translation>
+      <translation type="obsolete">Спереди</translation>
     </message>
     <message>
       <source>Right</source>
-      <translation>Вправо</translation>
+      <translation type="obsolete">Вправо</translation>
     </message>
     <message>
       <source>Back</source>
-      <translation>Назад</translation>
+      <translation type="obsolete">Назад</translation>
     </message>
     <message>
       <source>Left</source>
-      <translation>Слева</translation>
+      <translation type="obsolete">Слева</translation>
     </message>
     <message>
       <source>Top</source>
-      <translation>Вверх</translation>
+      <translation type="obsolete">Вверх</translation>
     </message>
     <message>
       <source>Bottom</source>
-      <translation>Дно</translation>
+      <translation type="obsolete">Дно</translation>
     </message>
     <message>
       <source>- Rotate</source>
-      <translation>Вращение</translation>
+      <translation type="obsolete">Вращение</translation>
     </message>
     <message>
       <source>90</source>
-      <translation>90</translation>
+      <translation type="obsolete">90</translation>
     </message>
     <message>
       <source>180</source>
-      <translation>180</translation>
+      <translation type="obsolete">180</translation>
     </message>
     <message>
       <source>270</source>
-      <translation>270</translation>
+      <translation type="obsolete">270</translation>
     </message>
     <message>
+      <location line="-514"/>
       <source>Primary view</source>
       <translation>Главный вид</translation>
     </message>
     <message>
+      <location line="+16"/>
       <source>Secondary Views</source>
       <translation>Дополнительные виды</translation>
     </message>
     <message>
+      <location line="+72"/>
       <source>General</source>
       <translation>Основные</translation>
     </message>
     <message>
+      <location line="+9"/>
       <source>Auto scale / position</source>
-      <translation>Auto scale / position</translation>
+      <translation>Автоматический масштаб / положение</translation>
     </message>
     <message>
+      <location line="+15"/>
       <source>Scale</source>
       <translation>Масштаб</translation>
     </message>
     <message>
       <source>Primary x / y</source>
-      <translation>Primary x / y</translation>
+      <translation type="obsolete">Основные x / y</translation>
     </message>
     <message>
       <source>Secondary dx / dy</source>
-      <translation>Secondary dx / dy</translation>
+      <translation type="obsolete">Вторичные dx / dy</translation>
     </message>
     <message>
+      <location line="+125"/>
       <source>Show hidden</source>
       <translation>Показать скрытое</translation>
     </message>
     <message>
+      <location line="+7"/>
       <source>Show smooth</source>
-      <translation>Show smooth</translation>
+      <translation>Показать сглаживание</translation>
     </message>
     <message>
+      <location line="+11"/>
       <source>Axonometric</source>
       <translation>Аксонометрия</translation>
     </message>
@@ -332,42 +540,52 @@
       <translation>Видимые резкие края</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Visible smooth edges</source>
       <translation>Видимые плавные края</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Visible sewn edges</source>
       <translation>Показать пришитые края</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Visible outline edges</source>
       <translation>Видимые края контура</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Visible isoparameters</source>
       <translation>Видимые изопараметры</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Hidden sharp edges</source>
       <translation>Скрытые резкие края</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Hidden smooth edges</source>
       <translation>Скрытые плавные края</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Hidden sewn edges</source>
       <translation>Скрыть пришитые края</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Hidden outline edges</source>
       <translation>Скрытые края контура</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Hidden isoparameters</source>
       <translation>Скрытые изопараметры</translation>
     </message>
     <message>
+      <location line="+17"/>
       <source>Project shapes</source>
       <translation>Проекция фигуры</translation>
     </message>
@@ -376,103 +594,148 @@
     <name>Drawing_NewPage</name>
     <message>
       <source>A0 landscape</source>
-      <translation>А0 альбомный</translation>
+      <translation type="obsolete">А0 альбомный</translation>
     </message>
     <message>
       <source>Insert new A0 landscape drawing</source>
-      <translation>Вставить новый альбомный чертеж А0</translation>
+      <translation type="obsolete">Вставить новый альбомный чертеж А0</translation>
     </message>
     <message>
       <source>A1 landscape</source>
-      <translation>А1 альбомный</translation>
+      <translation type="obsolete">А1 альбомный</translation>
     </message>
     <message>
       <source>Insert new A1 landscape drawing</source>
-      <translation>Вставить новый альбомный чертеж А1</translation>
+      <translation type="obsolete">Вставить новый альбомный чертеж А1</translation>
     </message>
     <message>
       <source>A2 landscape</source>
-      <translation>А2 альбомный</translation>
+      <translation type="obsolete">А2 альбомный</translation>
     </message>
     <message>
       <source>Insert new A2 landscape drawing</source>
-      <translation>Вставить новый альбомный чертеж А2</translation>
+      <translation type="obsolete">Вставить новый альбомный чертеж А2</translation>
     </message>
     <message>
       <source>A3 landscape</source>
-      <translation>А3 альбомный</translation>
+      <translation type="obsolete">А3 альбомный</translation>
     </message>
     <message>
       <source>Insert new A3 landscape drawing</source>
-      <translation>Вставить новый фоновый чертеж А3</translation>
+      <translation type="obsolete">Вставить новый фоновый чертеж А3</translation>
     </message>
     <message>
       <source>A4 landscape</source>
-      <translation>А4 альбомный</translation>
+      <translation type="obsolete">А4 альбомный</translation>
     </message>
     <message>
       <source>Insert new A4 landscape drawing</source>
-      <translation>Вставить новый альбомный чертеж А4</translation>
+      <translation type="obsolete">Вставить новый альбомный чертеж А4</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="-327"/>
       <source>Insert new A%1 landscape drawing</source>
-      <translation>Insert new A%1 landscape drawing</translation>
+      <translation type="obsolete">Вставить новый чертёж A%1 (альбомный)</translation>
     </message>
     <message>
       <source>A%1 landscape</source>
-      <translation>A%1 landscape</translation>
+      <translation type="obsolete">A%1 (альбомный)</translation>
+    </message>
+    <message>
+      <location filename="../../Command.cpp" line="-298"/>
+      <source>Landscape</source>
+      <translation type="unfinished">Landscape</translation>
+    </message>
+    <message>
+      <location line="+2"/>
+      <source>Portrait</source>
+      <translation type="unfinished">Portrait</translation>
+    </message>
+    <message>
+      <location line="+2"/>
+      <source>%1%2 %3</source>
+      <translation type="unfinished">%1%2 %3</translation>
+    </message>
+    <message>
+      <location line="+6"/>
+      <source>Insert new %1%2 %3 drawing</source>
+      <translation type="unfinished">Insert new %1%2 %3 drawing</translation>
     </message>
   </context>
   <context>
     <name>QObject</name>
     <message>
+      <location line="-124"/>
+      <location line="+426"/>
       <source>Choose an SVG file to open</source>
       <translation>Выберите SVG-файл для открытия</translation>
     </message>
     <message>
       <location filename="../../AppDrawingGuiPy.cpp" line="+64"/>
+      <location line="+30"/>
+      <location filename="../../ViewProviderPage.cpp" line="+139"/>
       <source>Drawing viewer</source>
       <translation>Вид чертежа</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="+1"/>
+      <location filename="../../Command.cpp" line="-425"/>
+      <location line="+426"/>
       <source>Scalable Vector Graphics (*.svg *.svgz)</source>
       <translation>Масштабируемая векторная графика (*.svg *.svgz)</translation>
     </message>
     <message>
+      <location line="-227"/>
+      <location line="+51"/>
+      <location line="+45"/>
+      <location line="+177"/>
       <source>Wrong selection</source>
       <translation>Неправильный выбор</translation>
     </message>
     <message>
+      <location line="-272"/>
+      <location line="+51"/>
       <source>Select a Part object.</source>
       <translation>Выберите часть объекта.</translation>
     </message>
     <message>
+      <location line="-45"/>
+      <location line="+51"/>
+      <location line="+76"/>
+      <location line="+45"/>
+      <location line="+42"/>
       <source>No page to insert</source>
       <translation>Нет страницы для вставки</translation>
     </message>
     <message>
+      <location line="-213"/>
+      <location line="+127"/>
+      <location line="+45"/>
+      <location line="+42"/>
       <source>Create a page to insert.</source>
       <translation>Создать страницу для вставки.</translation>
     </message>
     <message>
+      <location line="-163"/>
       <source>Create a page to insert views into.</source>
       <translation>Создайте страницу для вставки видов</translation>
     </message>
     <message>
+      <location line="+38"/>
+      <location line="+177"/>
       <source>Select one Page object.</source>
       <translation>Выберите одну страницу объекта.</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>SVG(*.svg)</source>
       <translation>SVG(*.svg)</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>All Files (*.*)</source>
       <translation>Все файлы (*.*)</translation>
     </message>
     <message>
+      <location line="+2"/>
       <source>Export page</source>
       <translation>Экспортировать страницу</translation>
     </message>
@@ -482,29 +745,46 @@
       <translation>Показать чертеж</translation>
     </message>
     <message>
-      <location filename="../../TaskOrthoViews.cpp" line="+49"/>
       <source>Front</source>
-      <translation>Спереди</translation>
+      <translation type="obsolete">Спереди</translation>
     </message>
     <message>
       <source>Back</source>
-      <translation>Назад</translation>
+      <translation type="obsolete">Назад</translation>
     </message>
     <message>
       <source>Right</source>
-      <translation>Вправо</translation>
+      <translation type="obsolete">Вправо</translation>
     </message>
     <message>
       <source>Left</source>
-      <translation>Слева</translation>
+      <translation type="obsolete">Слева</translation>
     </message>
     <message>
       <source>Top</source>
-      <translation>Вверх</translation>
+      <translation type="obsolete">Вверх</translation>
     </message>
     <message>
       <source>Bottom</source>
-      <translation>Дно</translation>
+      <translation type="obsolete">Дно</translation>
+    </message>
+    <message>
+      <location filename="../../TaskOrthoViews.cpp" line="+45"/>
+      <location line="+908"/>
+      <source>Make axonometric...</source>
+      <translation type="unfinished">Make axonometric...</translation>
+    </message>
+    <message>
+      <location line="-907"/>
+      <location line="+908"/>
+      <source>Edit axonometric settings...</source>
+      <translation type="unfinished">Edit axonometric settings...</translation>
+    </message>
+    <message>
+      <location line="-907"/>
+      <location line="+908"/>
+      <source>Make orthographic</source>
+      <translation type="unfinished">Make orthographic</translation>
     </message>
   </context>
   <context>
