@@ -29,8 +29,7 @@ This Script includes the GUI Commands of the OpenSCAD module
 '''
 
 import FreeCAD,FreeCADGui
-from PyQt4 import QtGui, QtCore
-
+from PySide import QtCore, QtGui
 def translate(context,text):
     "convenience function for Qt translator"
     return QtGui.QApplication.translate(context, text, None, \
@@ -38,6 +37,52 @@ def translate(context,text):
 def utf8(unio):
     return unicode(unio).encode('UTF8')
 
+class ExplodeGroup:
+    "Ungroup Objects"
+    def IsActive(self):
+        return FreeCADGui.Selection.countObjectsOfType('Part::Feature') > 0
+
+    def Activated(self):
+        def isgrey(shapecolor):
+            defaultcolor=(float.fromhex('0x1.99999ap-1'),float.fromhex('0x1.99999ap-1'),\
+                float.fromhex('0x1.99999ap-1'),0.0)
+            return all(facecolor == defaultcolor  for facecolor in shapecolor)
+
+        def randomcolor(transp=0.0):
+            import random
+            return (random.random(),random.random(),random.random(),transp)
+
+        def explode(obj,color=True):
+            if obj.isDerivedFrom('Part::Fuse') or \
+                    obj.isDerivedFrom('Part::MultiFuse') or \
+                    obj.isDerivedFrom('Part::Compound'):
+                plm = obj.Placement
+                outlist = obj.OutList[:]
+                if plm.isNull() or all(len(oo.InList)==1 for oo in obj.OutList):
+                    obj.Document.removeObject(obj.Name)
+                    for oo in outlist:
+                        if not plm.isNull():
+                            oo.Placement=plm.multiply(oo.Placement)
+                        if FreeCAD.GuiUp:
+                            import FreeCADGui
+                            oo.ViewObject.show()
+                            if color and isgrey(oo.ViewObject.DiffuseColor):
+                                if color == True:
+                                    oo.ViewObject.DiffuseColor=randomcolor()
+                                else:
+                                    oo.ViewObject.DiffuseColor=color
+
+        for obj in FreeCADGui.Selection.getSelection():
+            if len(obj.InList) == 0: # allowed only for for top level objects
+                explode(obj)
+
+    def GetResources(self):
+        return {'Pixmap'  : 'OpenSCAD_Explode_Group', 'MenuText': \
+                QtCore.QT_TRANSLATE_NOOP('OpenSCAD_ExplodeGroup',\
+                'Explode Group'), 'ToolTip': \
+                QtCore.QT_TRANSLATE_NOOP('OpenSCAD_ExplodeGroup',\
+                'remove fusion, apply placement to children and color randomly')}
+
 class ColorCodeShape:
     "Change the Color of selected or all Shapes based on their validity"
     def Activated(self):
@@ -58,7 +103,7 @@ class ColorCodeShape:
 
 class Edgestofaces:
     def IsActive(self):
-        return bool(FreeCADGui.Selection.getSelectionEx())
+        return FreeCADGui.Selection.countObjectsOfType('Part::Feature') > 0
 
     def Activated(self):
         from OpenSCAD2Dgeom import edgestofaces,Overlappingfaces
@@ -79,13 +124,12 @@ class Edgestofaces:
 
 class RefineShapeFeature:
     def IsActive(self):
-        return bool(FreeCADGui.Selection.getSelectionEx())
+        return FreeCADGui.Selection.countObjectsOfType('Part::Feature') > 0
 
     def Activated(self):
         import Part,OpenSCADFeatures
         selection=FreeCADGui.Selection.getSelectionEx()
         for selobj in selection:
-            #newobj=FreeCAD.ActiveDocument.addObject("Part::FeaturePython",'refine')
             newobj=selobj.Document.addObject("Part::FeaturePython",'refine')
             OpenSCADFeatures.RefineShape(newobj,selobj.Object)
             OpenSCADFeatures.ViewProviderTree(newobj.ViewObject)
@@ -99,13 +143,34 @@ class RefineShapeFeature:
                 QtCore.QT_TRANSLATE_NOOP('OpenSCAD_RefineShapeFeature',\
                 'Create Refine Shape Feature')}
 
+class IncreaseToleranceFeature:
+    def IsActive(self):
+        return FreeCADGui.Selection.countObjectsOfType('Part::Feature') > 0
+
+    def Activated(self):
+        import Part,OpenSCADFeatures
+        selection=FreeCADGui.Selection.getSelectionEx()
+        for selobj in selection:
+            newobj=selobj.Document.addObject("Part::FeaturePython",'tolerance')
+            OpenSCADFeatures.IncreaseTolerance(newobj,selobj.Object)
+            OpenSCADFeatures.ViewProviderTree(newobj.ViewObject)
+            newobj.Label='tolerance_%s' % selobj.Object.Label
+            selobj.Object.ViewObject.hide()
+        FreeCAD.ActiveDocument.recompute()
+    def GetResources(self):
+        return {'Pixmap'  : 'OpenSCAD_IncreaseToleranceFeature', 'MenuText': \
+                QtCore.QT_TRANSLATE_NOOP('OpenSCAD_IncreaseToleranceFeature',\
+                'Increase Tolerance Feature'), 'ToolTip': \
+                QtCore.QT_TRANSLATE_NOOP('OpenSCAD_IncreaseToleranceFeature',\
+                'Create Feature that allows to increase the tolerance')}
+
 
 class ExpandPlacements:
     '''This should aid interactive repair in the future
     but currently it breaks extrusions, as axis, base and so on have to be
     recalculated'''
     def IsActive(self):
-        return bool(FreeCADGui.Selection.getSelectionEx())
+        return FreeCADGui.Selection.countObjectsOfType('Part::Feature') > 0
 
     def Activated(self):
         import expandplacements
@@ -120,12 +185,17 @@ class ExpandPlacements:
 
 class ReplaceObject:
     def IsActive(self):
-        return len(FreeCADGui.Selection.getSelection()) == 3
+        nobj = FreeCADGui.Selection.countObjectsOfType('Part::Feature')
+        if nobj == 3: return True
+        elif nobj == 2: return tuple((len(obj.InList)) for obj in \
+                FreeCADGui.Selection.getSelection()) in ((0,1),(1,0))
+        #else: return False
+
     def Activated(self):
         import replaceobj
-        #objs=[selobj.Object for selobj in FreeCADGui.Selection.getSelectionEx()]
         objs=FreeCADGui.Selection.getSelection()
-        if len(objs)==3:
+        if len(objs)==3 or \
+                tuple((len(obj.InList)) for obj in objs) in ((0,1),(1,0)):
             replaceobj.replaceobjfromselection(objs)
         else:
             FreeCAD.Console.PrintError(unicode(translate('OpenSCAD',\
@@ -140,28 +210,11 @@ class ReplaceObject:
 
 class RemoveSubtree:
     def IsActive(self):
-        return bool(FreeCADGui.Selection.getSelectionEx())
+        return FreeCADGui.Selection.countObjectsOfType('Part::Feature') > 0
     def Activated(self):
-        def addsubobjs(obj,toremoveset):
-            toremove.add(obj)
-            for subobj in obj.OutList:
-                addsubobjs(subobj,toremoveset)
+        import OpenSCADUtils,FreeCADGui
+        OpenSCADUtils.removesubtree(FreeCADGui.Selection.getSelection())
 
-        import FreeCAD,FreeCADGui
-        objs=FreeCADGui.Selection.getSelection()
-        toremove=set()
-        for obj in objs:
-            addsubobjs(obj,toremove)
-        checkinlistcomplete =False
-        while not checkinlistcomplete:
-            for obj in toremove:
-                if (obj not in objs) and (frozenset(obj.InList) - toremove):
-                    toremove.remove(obj)
-                    break
-            else:
-                checkinlistcomplete = True
-        for obj in toremove:
-            obj.Document.removeObject(obj.Name)
     def GetResources(self):
         return {'Pixmap'  : 'OpenSCAD_RemoveSubtree', 'MenuText': \
                 QtCore.QT_TRANSLATE_NOOP('OpenSCAD_RemoveSubtree',\
@@ -369,8 +422,10 @@ class Minkowski:
                 'Perform Minkowski')}
 
 FreeCADGui.addCommand('OpenSCAD_ColorCodeShape',ColorCodeShape())
+FreeCADGui.addCommand('OpenSCAD_ExplodeGroup',ExplodeGroup())
 FreeCADGui.addCommand('OpenSCAD_Edgestofaces',Edgestofaces())
 FreeCADGui.addCommand('OpenSCAD_RefineShapeFeature',RefineShapeFeature())
+FreeCADGui.addCommand('OpenSCAD_IncreaseToleranceFeature',IncreaseToleranceFeature())
 FreeCADGui.addCommand('OpenSCAD_ExpandPlacements',ExpandPlacements())
 FreeCADGui.addCommand('OpenSCAD_ReplaceObject',ReplaceObject())
 FreeCADGui.addCommand('OpenSCAD_RemoveSubtree',RemoveSubtree())
