@@ -31,10 +31,13 @@
 # include <TopoDS.hxx>
 # include <TopoDS_Face.hxx>
 # include <TopoDS_Shell.hxx>
+# include <TopTools_HSequenceOfShape.hxx>
 # include <BRepBuilderAPI_MakeWire.hxx>
 # include <BRepOffsetAPI_MakePipeShell.hxx>
 # include <ShapeAnalysis.hxx>
+# include <ShapeAnalysis_FreeBounds.hxx>
 # include <TopTools_ListIteratorOfListOfShape.hxx>
+# include <TopoDS_Iterator.hxx>
 # include <TopExp_Explorer.hxx>
 # include <TopoDS.hxx>
 # include <Precision.hxx>
@@ -207,6 +210,7 @@ Loft::Loft()
     Sections.setSize(0);
     ADD_PROPERTY_TYPE(Solid,(false),"Loft",App::Prop_None,"Create solid");
     ADD_PROPERTY_TYPE(Ruled,(false),"Loft",App::Prop_None,"Ruled surface");
+    ADD_PROPERTY_TYPE(Closed,(false),"Loft",App::Prop_None,"Close Last to First Profile");
 }
 
 short Loft::mustExecute() const
@@ -217,6 +221,8 @@ short Loft::mustExecute() const
         return 1;
     if (Ruled.isTouched())
         return 1;
+    if (Closed.isTouched())
+        return 1;
     return 0;
 }
 
@@ -237,9 +243,20 @@ App::DocumentObjectExecReturn *Loft::execute(void)
         for (it = shapes.begin(); it != shapes.end(); ++it) {
             if (!(*it)->isDerivedFrom(Part::Feature::getClassTypeId()))
                 return new App::DocumentObjectExecReturn("Linked object is not a shape.");
-            const TopoDS_Shape& shape = static_cast<Part::Feature*>(*it)->Shape.getValue();
+            TopoDS_Shape shape = static_cast<Part::Feature*>(*it)->Shape.getValue();
             if (shape.IsNull())
                 return new App::DocumentObjectExecReturn("Linked shape is invalid.");
+
+            // Extract first element of a compound
+            if (shape.ShapeType() == TopAbs_COMPOUND) {
+                TopoDS_Iterator it(shape);
+                for (; it.More(); it.Next()) {
+                    if (!it.Value().IsNull()) {
+                        shape = it.Value();
+                        break;
+                    }
+                }
+            }
             if (shape.ShapeType() == TopAbs_FACE) {
                 TopoDS_Wire faceouterWire = ShapeAnalysis::OuterWire(TopoDS::Face(shape));
                 profiles.Append(faceouterWire);
@@ -262,9 +279,10 @@ App::DocumentObjectExecReturn *Loft::execute(void)
 
         Standard_Boolean isSolid = Solid.getValue() ? Standard_True : Standard_False;
         Standard_Boolean isRuled = Ruled.getValue() ? Standard_True : Standard_False;
+        Standard_Boolean isClosed = Closed.getValue() ? Standard_True : Standard_False;
 
         TopoShape myShape;
-        this->Shape.setValue(myShape.makeLoft(profiles, isSolid, isRuled));
+        this->Shape.setValue(myShape.makeLoft(profiles, isSolid, isRuled,isClosed));
         return App::DocumentObject::StdReturn;
     }
     catch (Standard_Failure) {
@@ -323,14 +341,14 @@ App::DocumentObjectExecReturn *Sweep::execute(void)
     const Part::TopoShape& shape = static_cast<Part::Feature*>(spine)->Shape.getValue();
     if (!shape._Shape.IsNull()) {
         try {
-            BRepBuilderAPI_MakeWire mkWire;
-            for (std::vector<std::string>::const_iterator it = subedge.begin(); it != subedge.end(); ++it) {
-                TopoDS_Shape subshape = shape.getSubShape(it->c_str());
-                mkWire.Add(TopoDS::Edge(subshape));
+            if (!subedge.empty()) {
+                BRepBuilderAPI_MakeWire mkWire;
+                for (std::vector<std::string>::const_iterator it = subedge.begin(); it != subedge.end(); ++it) {
+                    TopoDS_Shape subshape = shape.getSubShape(it->c_str());
+                    mkWire.Add(TopoDS::Edge(subshape));
+                }
+                path = mkWire.Wire();
             }
-            path = mkWire.Wire();
-        }
-        catch (Standard_Failure) {
             if (shape._Shape.ShapeType() == TopAbs_EDGE) {
                 path = shape._Shape;
             }
@@ -338,10 +356,35 @@ App::DocumentObjectExecReturn *Sweep::execute(void)
                 BRepBuilderAPI_MakeWire mkWire(TopoDS::Wire(shape._Shape));
                 path = mkWire.Wire();
             }
+            else if (shape._Shape.ShapeType() == TopAbs_COMPOUND) {
+                TopoDS_Iterator it(shape._Shape);
+                for (; it.More(); it.Next()) {
+                    if (it.Value().IsNull())
+                        return new App::DocumentObjectExecReturn("In valid element in spine.");
+                    if ((it.Value().ShapeType() != TopAbs_EDGE) &&
+                        (it.Value().ShapeType() != TopAbs_WIRE)) {
+                        return new App::DocumentObjectExecReturn("Element in spine is neither an edge nor a wire.");
+                    }
+                }
+
+                Handle(TopTools_HSequenceOfShape) hEdges = new TopTools_HSequenceOfShape();
+                Handle(TopTools_HSequenceOfShape) hWires = new TopTools_HSequenceOfShape();
+                for (TopExp_Explorer xp(shape._Shape, TopAbs_EDGE); xp.More(); xp.Next())
+                    hEdges->Append(xp.Current());
+
+                ShapeAnalysis_FreeBounds::ConnectEdgesToWires(hEdges, Precision::Confusion(), Standard_True, hWires);
+                int len = hWires->Length();
+                if (len != 1)
+                    return new App::DocumentObjectExecReturn("Spine is not connected.");
+                path = hWires->Value(1);
+            }
             else {
                 return new App::DocumentObjectExecReturn("Spine is neither an edge nor a wire.");
             }
         }
+        catch (Standard_Failure) {
+            return new App::DocumentObjectExecReturn("Invalid spine.");
+        }
     }
 
     try {
@@ -351,9 +394,20 @@ App::DocumentObjectExecReturn *Sweep::execute(void)
         for (it = shapes.begin(); it != shapes.end(); ++it) {
             if (!(*it)->isDerivedFrom(Part::Feature::getClassTypeId()))
                 return new App::DocumentObjectExecReturn("Linked object is not a shape.");
-            const TopoDS_Shape& shape = static_cast<Part::Feature*>(*it)->Shape.getValue();
+            TopoDS_Shape shape = static_cast<Part::Feature*>(*it)->Shape.getValue();
             if (shape.IsNull())
                 return new App::DocumentObjectExecReturn("Linked shape is invalid.");
+
+            // Extract first element of a compound
+            if (shape.ShapeType() == TopAbs_COMPOUND) {
+                TopoDS_Iterator it(shape);
+                for (; it.More(); it.Next()) {
+                    if (!it.Value().IsNull()) {
+                        shape = it.Value();
+                        break;
+                    }
+                }
+            }
             // There is a weird behaviour of BRepOffsetAPI_MakePipeShell when trying to add the wire as is.
             // If we re-create the wire then everything works fine.
             // http://forum.freecadweb.org/viewtopic.php?f=10&t=2673&sid=fbcd2ff4589f0b2f79ed899b0b990648#p20268
