@@ -27,6 +27,7 @@
 # include <cmath>
 # include <cstdlib>
 # include <sstream>
+# include <QString>
 # include <BRepLib.hxx>
 # include <BSplCLib.hxx>
 # include <Bnd_Box.hxx>
@@ -50,6 +51,7 @@
 # include <BRepBuilderAPI_MakeSolid.hxx>
 # include <BRepBuilderAPI_MakeVertex.hxx>
 # include <BRepBuilderAPI_MakeWire.hxx>
+# include <BRepBuilderAPI_MakeShell.hxx>
 # include <BRepBuilderAPI_NurbsConvert.hxx>
 # include <BRepBuilderAPI_FaceError.hxx>
 # include <BRepBuilderAPI_Copy.hxx>
@@ -73,6 +75,7 @@
 # include <BRepTools.hxx>
 # include <BRepTools_ReShape.hxx>
 # include <BRepTools_ShapeSet.hxx>
+# include <BRepFill_CompatibleWires.hxx>
 # include <GCE2d_MakeSegment.hxx>
 # include <Geom2d_Line.hxx>
 # include <Geom2d_TrimmedCurve.hxx>
@@ -88,6 +91,7 @@
 # include <Handle_Law_BSpline.hxx>
 # include <Handle_TopTools_HSequenceOfShape.hxx>
 # include <Law_BSpFunc.hxx>
+# include <Law_Constant.hxx>
 # include <Law_Linear.hxx>
 # include <Law_S.hxx>
 # include <TopTools_HSequenceOfShape.hxx>
@@ -153,6 +157,8 @@
 #include <Base/FileInfo.h>
 #include <Base/Exception.h>
 #include <Base/Tools.h>
+#include <Base/Console.h>
+
 
 #include "TopoShape.h"
 #include "CrossSection.h"
@@ -563,7 +569,8 @@ void TopoShape::importIges(const char *FileName)
         IGESControl_Controller::Init();
         Interface_Static::SetIVal("read.surfacecurve.mode",3);
         IGESControl_Reader aReader;
-        if (aReader.ReadFile((const Standard_CString)FileName) != IFSelect_RetDone)
+        QString fn = QString::fromUtf8(FileName);
+        if (aReader.ReadFile((const char*)fn.toLocal8Bit()) != IFSelect_RetDone)
             throw Base::Exception("Error in reading IGES");
 
         Handle_Message_ProgressIndicator pi = new ProgressIndicator(100);
@@ -588,7 +595,8 @@ void TopoShape::importStep(const char *FileName)
 {
     try {
         STEPControl_Reader aReader;
-        if (aReader.ReadFile((const Standard_CString)FileName) != IFSelect_RetDone)
+        QString fn = QString::fromUtf8(FileName);
+        if (aReader.ReadFile((const char*)fn.toLocal8Bit()) != IFSelect_RetDone)
             throw Base::Exception("Error in reading STEP");
 
         Handle_Message_ProgressIndicator pi = new ProgressIndicator(100);
@@ -618,7 +626,8 @@ void TopoShape::importBrep(const char *FileName)
         Handle_Message_ProgressIndicator pi = new ProgressIndicator(100);
         pi->NewScope(100, "Reading BREP file...");
         pi->Show();
-        BRepTools::Read(aShape,(const Standard_CString)FileName,aBuilder,pi);
+        QString fn = QString::fromUtf8(FileName);
+        BRepTools::Read(aShape,(const char*)fn.toLocal8Bit(),aBuilder,pi);
         pi->EndScope();
     #else
         BRepTools::Read(aShape,(const Standard_CString)FileName,aBuilder);
@@ -674,7 +683,7 @@ void TopoShape::write(const char *FileName) const
     }
     else if (File.hasExtension("stl")) {
         // read brep-file
-        exportStl(File.filePath().c_str());
+        exportStl(File.filePath().c_str(),0);
     }
     else{
         throw Base::Exception("Unknown extension");
@@ -691,7 +700,8 @@ void TopoShape::exportIges(const char *filename) const
         //IGESControl_Writer aWriter(Interface_Static::CVal("write.iges.unit"), 1);
         aWriter.AddShape(this->_Shape);
         aWriter.ComputeModel();
-        if (aWriter.Write((const Standard_CString)filename) != IFSelect_RetDone)
+        QString fn = QString::fromUtf8(filename);
+        if (aWriter.Write((const char*)fn.toLocal8Bit()) != IFSelect_RetDone)
             throw Base::Exception("Writing of IGES failed");
     }
     catch (Standard_Failure) {
@@ -721,7 +731,8 @@ void TopoShape::exportStep(const char *filename) const
         makeHeader.SetOriginatingSystem(new TCollection_HAsciiString("FreeCAD"));
         makeHeader.SetDescriptionValue(1, new TCollection_HAsciiString("FreeCAD Model"));
 
-        if (aWriter.Write((const Standard_CString)filename) != IFSelect_RetDone)
+        QString fn = QString::fromUtf8(filename);
+        if (aWriter.Write((const char*)fn.toLocal8Bit()) != IFSelect_RetDone)
             throw Base::Exception("Writing of STEP failed");
         pi->EndScope();
     }
@@ -733,21 +744,30 @@ void TopoShape::exportStep(const char *filename) const
 
 void TopoShape::exportBrep(const char *filename) const
 {
-    if (!BRepTools::Write(this->_Shape,(const Standard_CString)filename))
+    QString fn = QString::fromUtf8(filename);
+    if (!BRepTools::Write(this->_Shape,(const char*)fn.toLocal8Bit()))
         throw Base::Exception("Writing of BREP failed");
 }
 
-void TopoShape::exportBrep(std::ostream& out)
+void TopoShape::exportBrep(std::ostream& out) const
 {
     BRepTools::Write(this->_Shape, out);
 }
 
-void TopoShape::exportStl(const char *filename) const
+void TopoShape::dump(std::ostream& out) const
+{
+    BRepTools::Dump(this->_Shape, out);
+}
+
+void TopoShape::exportStl(const char *filename, double deflection) const
 {
     StlAPI_Writer writer;
-    //writer.RelativeMode() = false;
-    //writer.SetDeflection(0.1);
-    writer.Write(this->_Shape,(const Standard_CString)filename);
+    if (deflection > 0) {
+        writer.RelativeMode() = false;
+        writer.SetDeflection(deflection);
+    }
+    QString fn = QString::fromUtf8(filename);
+    writer.Write(this->_Shape,(const Standard_CString)fn.toLocal8Bit());
 }
 
 void TopoShape::exportFaceSet(double dev, double ca, std::ostream& str) const
@@ -998,12 +1018,13 @@ unsigned int TopoShape::getMemSize (void) const
                         break;
                     case GeomAbs_BezierSurface:
                         memsize += sizeof(Geom_BezierSurface);
-                        memsize += (surface.NbUKnots()+surface.NbVKnots()) * sizeof(Standard_Real);
+                        memsize += (surface.NbUPoles()*surface.NbVPoles()) * sizeof(Standard_Real);
                         memsize += (surface.NbUPoles()*surface.NbVPoles()) * sizeof(Geom_CartesianPoint);
                         break;
                     case GeomAbs_BSplineSurface:
                         memsize += sizeof(Geom_BSplineSurface);
                         memsize += (surface.NbUKnots()+surface.NbVKnots()) * sizeof(Standard_Real);
+                        memsize += (surface.NbUPoles()*surface.NbVPoles()) * sizeof(Standard_Real);
                         memsize += (surface.NbUPoles()*surface.NbVPoles()) * sizeof(Geom_CartesianPoint);
                         break;
                     case GeomAbs_SurfaceOfRevolution:
@@ -1045,12 +1066,13 @@ unsigned int TopoShape::getMemSize (void) const
                         break;
                     case GeomAbs_BezierCurve:
                         memsize += sizeof(Geom_BezierCurve);
-                        memsize += curve.NbKnots() * sizeof(Standard_Real);
+                        memsize += curve.NbPoles() * sizeof(Standard_Real);
                         memsize += curve.NbPoles() * sizeof(Geom_CartesianPoint);
                         break;
                     case GeomAbs_BSplineCurve:
                         memsize += sizeof(Geom_BSplineCurve);
                         memsize += curve.NbKnots() * sizeof(Standard_Real);
+                        memsize += curve.NbPoles() * sizeof(Standard_Real);
                         memsize += curve.NbPoles() * sizeof(Geom_CartesianPoint);
                         break;
                     case GeomAbs_OtherCurve:
@@ -1276,30 +1298,50 @@ bool TopoShape::isClosed() const
 
 TopoDS_Shape TopoShape::cut(TopoDS_Shape shape) const
 {
+    if (this->_Shape.IsNull())
+        Standard_Failure::Raise("Base shape is null");
+    if (shape.IsNull())
+        Standard_Failure::Raise("Tool shape is null");
     BRepAlgoAPI_Cut mkCut(this->_Shape, shape);
     return mkCut.Shape();
 }
 
 TopoDS_Shape TopoShape::common(TopoDS_Shape shape) const
 {
+    if (this->_Shape.IsNull())
+        Standard_Failure::Raise("Base shape is null");
+    if (shape.IsNull())
+        Standard_Failure::Raise("Tool shape is null");
     BRepAlgoAPI_Common mkCommon(this->_Shape, shape);
     return mkCommon.Shape();
 }
 
 TopoDS_Shape TopoShape::fuse(TopoDS_Shape shape) const
 {
+    if (this->_Shape.IsNull())
+        Standard_Failure::Raise("Base shape is null");
+    if (shape.IsNull())
+        Standard_Failure::Raise("Tool shape is null");
     BRepAlgoAPI_Fuse mkFuse(this->_Shape, shape);
     return mkFuse.Shape();
 }
 
 TopoDS_Shape TopoShape::oldFuse(TopoDS_Shape shape) const
 {
+    if (this->_Shape.IsNull())
+        Standard_Failure::Raise("Base shape is null");
+    if (shape.IsNull())
+        Standard_Failure::Raise("Tool shape is null");
     BRepAlgo_Fuse mkFuse(this->_Shape, shape);
     return mkFuse.Shape();
 }
 
 TopoDS_Shape TopoShape::section(TopoDS_Shape shape) const
 {
+    if (this->_Shape.IsNull())
+        Standard_Failure::Raise("Base shape is null");
+    if (shape.IsNull())
+        Standard_Failure::Raise("Tool shape is null");
     BRepAlgoAPI_Section mkSection(this->_Shape, shape);
     return mkSection.Shape();
 }
@@ -1422,8 +1464,8 @@ static Handle(Law_Function) CreateBsFunction (const Standard_Real theFirst, cons
 {
     //Handle_Law_BSpline aBs;
     //Handle_Law_BSpFunc aFunc = new Law_BSpFunc (aBs, theFirst, theLast);
-    Handle_Law_Linear aFunc = new Law_Linear();
-    aFunc->Set(theFirst, theRadius, theLast, theRadius);
+    Handle_Law_Constant aFunc = new Law_Constant();
+    aFunc->Set(1, theFirst, theLast);
     return aFunc;
 }
 
@@ -1431,6 +1473,7 @@ TopoDS_Shape TopoShape::makeTube(double radius, double tol, int cont, int maxdeg
 {
     // http://opencascade.blogspot.com/2009/11/surface-modeling-part3.html
     Standard_Real theTol = tol;
+    Standard_Real theRadius = radius;
     //Standard_Boolean theIsPolynomial = Standard_True;
     Standard_Boolean myIsElem = Standard_True;
     GeomAbs_Shape theContinuity = GeomAbs_Shape(cont);
@@ -1459,11 +1502,11 @@ TopoDS_Shape TopoShape::makeTube(double radius, double tol, int cont, int maxdeg
     }
 
     //circular profile
-    Handle(Geom_Circle) aCirc = new Geom_Circle (gp::XOY(), radius);
+    Handle(Geom_Circle) aCirc = new Geom_Circle (gp::XOY(), theRadius);
     aCirc->Rotate (gp::OZ(), M_PI/2.);
 
     //perpendicular section
-    Handle(Law_Function) myEvol = ::CreateBsFunction (myPath->FirstParameter(), myPath->LastParameter(), radius);
+    Handle(Law_Function) myEvol = ::CreateBsFunction (myPath->FirstParameter(), myPath->LastParameter(), theRadius);
     Handle(GeomFill_SectionLaw) aSec = new GeomFill_EvolvedSection(aCirc, myEvol);
     Handle(GeomFill_LocationLaw) aLoc = new GeomFill_CurveAndTrihedron(new GeomFill_CorrectedFrenet);
     aLoc->SetCurve (myPath);
@@ -1569,11 +1612,13 @@ TopoDS_Shape TopoShape::makeHelix(Standard_Real pitch, Standard_Real height,
 
     gp_Pnt2d aPnt(0, 0);
     gp_Dir2d aDir(2. * M_PI, pitch);
+    Standard_Real coneDir = 1.0;
     if (leftHanded) {
         //aPnt.SetCoord(0.0, height);
         //aDir.SetCoord(2.0 * PI, -pitch);
         aPnt.SetCoord(2. * M_PI, 0.0);
         aDir.SetCoord(-2. * M_PI, pitch);
+        coneDir = -1.0;
     }
     gp_Ax2d aAx2d(aPnt, aDir);
 
@@ -1586,7 +1631,7 @@ TopoDS_Shape TopoShape::makeHelix(Standard_Real pitch, Standard_Real height,
         if (angle >= Precision::Confusion()) {
             // calculate end point for conical helix
             Standard_Real v = height / cos(angle);
-            Standard_Real u = (height/pitch) * 2.0 * M_PI;
+            Standard_Real u = coneDir * (height/pitch) * 2.0 * M_PI;
             gp_Pnt2d cend(u, v);
             end = cend;
         }
@@ -1751,13 +1796,14 @@ TopoDS_Shape TopoShape::makeThread(Standard_Real pitch,
 
 TopoDS_Shape TopoShape::makeLoft(const TopTools_ListOfShape& profiles, 
                                  Standard_Boolean isSolid,
-                                 Standard_Boolean isRuled) const
+                                 Standard_Boolean isRuled,
+                                 Standard_Boolean isClosed) const
 {
     // http://opencascade.blogspot.com/2010/01/surface-modeling-part5.html
     BRepOffsetAPI_ThruSections aGenerator (isSolid,isRuled);
 
-    int countShapes = 0;
     TopTools_ListIteratorOfListOfShape it;
+    int countShapes = 0;
     for (it.Initialize(profiles); it.More(); it.Next()) {
         const TopoDS_Shape& item = it.Value();
         if (!item.IsNull() && item.ShapeType() == TopAbs_VERTEX) {
@@ -1775,15 +1821,44 @@ TopoDS_Shape TopoShape::makeLoft(const TopTools_ListOfShape& profiles,
         }
     }
 
-    if (countShapes < 2)
-        Standard_Failure::Raise("Need at least two vertices, edges or wires to create loft face");
+    if (countShapes < 2) {
+        Standard_Failure::Raise("Need at least two vertices, edges or wires to create loft face"); }
+    else {
+        // close loft by duplicating initial profile as last profile.  not perfect. 
+        if (isClosed) {
+        /* can only close loft in certain combinations of Vertex/Wire(Edge):
+            - V1-W1-W2-W3-V2  ==> V1-W1-W2-W3-V2-V1  invalid closed
+            - V1-W1-W2-W3     ==> V1-W1-W2-W3-V1     valid closed
+            - W1-W2-W3-V1     ==> W1-W2-W3-V1-W1     invalid closed
+            - W1-W2-W3        ==> W1-W2-W3-W1        valid closed*/
+            if (profiles.Last().ShapeType() == TopAbs_VERTEX)  {
+                Base::Console().Message("TopoShape::makeLoft: can't close Loft with Vertex as last profile. 'Closed' ignored.\n"); }
+            else {
+                // repeat Add logic above for first profile
+                const TopoDS_Shape& firstProfile = profiles.First();
+                if (firstProfile.ShapeType() == TopAbs_VERTEX)  {
+                    aGenerator.AddVertex(TopoDS::Vertex (firstProfile));
+                    countShapes++;
+                }
+                else if (firstProfile.ShapeType() == TopAbs_EDGE)  {
+                 aGenerator.AddWire(TopoDS::Wire (firstProfile));
+                 countShapes++;
+                }
+                else if (firstProfile.ShapeType() == TopAbs_WIRE)  {
+                 aGenerator.AddWire(TopoDS::Wire (firstProfile));
+                 countShapes++;
+                }
+            }     
+        }
+    }
 
     Standard_Boolean anIsCheck = Standard_True;
-    aGenerator.CheckCompatibility (anIsCheck);
+    aGenerator.CheckCompatibility (anIsCheck);   // use BRepFill_CompatibleWires on profiles. force #edges, orientation, "origin" to match.
     aGenerator.Build();
     if (!aGenerator.IsDone())
         Standard_Failure::Raise("Failed to create loft face");
-
+    
+    //Base::Console().Message("DEBUG: TopoShape::makeLoft returns.\n");
     return aGenerator.Shape();
 }
 
@@ -1794,10 +1869,41 @@ TopoDS_Shape TopoShape::makePrism(const gp_Vec& vec) const
     return mkPrism.Shape();
 }
 
-TopoDS_Shape TopoShape::revolve(const gp_Ax1& axis, double d) const
+TopoDS_Shape TopoShape::revolve(const gp_Ax1& axis, double d, Standard_Boolean isSolid) const
 {
-    if (this->_Shape.IsNull()) Standard_Failure::Raise("cannot sweep empty shape");
-    BRepPrimAPI_MakeRevol mkRevol(this->_Shape, axis,d);
+    if (this->_Shape.IsNull()) Standard_Failure::Raise("cannot revolve empty shape");
+
+    TopoDS_Face f; 
+    TopoDS_Wire w;
+    TopoDS_Edge e;
+    Standard_Boolean convertFailed = false;
+
+    TopoDS_Shape base = this->_Shape; 
+    if ((isSolid) && (BRep_Tool::IsClosed(base)) &&
+        ((base.ShapeType() == TopAbs_EDGE) || (base.ShapeType() == TopAbs_WIRE))) {
+        if (base.ShapeType() == TopAbs_EDGE) {
+            BRepBuilderAPI_MakeWire mkWire(TopoDS::Edge(base));
+            if (mkWire.IsDone()) {
+                w = mkWire.Wire(); }
+            else {
+                convertFailed = true; }
+        }
+        else {
+             w = TopoDS::Wire(base);}
+        if (!convertFailed) {       
+            BRepBuilderAPI_MakeFace mkFace(w);
+            if (mkFace.IsDone()) {
+                f = mkFace.Face(); 
+                base = f; }
+            else {
+                convertFailed = true; }
+        }  
+    }        
+    
+    if (convertFailed) {
+        Base::Console().Message("TopoShape::revolve could not make Solid from Wire/Edge.\n");}
+
+    BRepPrimAPI_MakeRevol mkRevol(base, axis,d);
     return mkRevol.Shape();
 }
 
@@ -1911,6 +2017,9 @@ void TopoShape::transformGeometry(const Base::Matrix4D &rclMat)
 
 TopoDS_Shape TopoShape::transformGShape(const Base::Matrix4D& rclTrf) const
 {
+    if (this->_Shape.IsNull())
+        Standard_Failure::Raise("Cannot transform null shape");
+
     gp_GTrsf mat;
     mat.SetValue(1,1,rclTrf[0][0]);
     mat.SetValue(2,1,rclTrf[1][0]);
@@ -1932,6 +2041,9 @@ TopoDS_Shape TopoShape::transformGShape(const Base::Matrix4D& rclTrf) const
 
 void TopoShape::transformShape(const Base::Matrix4D& rclTrf, bool copy)
 {
+    if (this->_Shape.IsNull())
+        Standard_Failure::Raise("Cannot transform null shape");
+
     gp_Trsf mat;
     mat.SetValues(rclTrf[0][0],rclTrf[0][1],rclTrf[0][2],rclTrf[0][3],
                   rclTrf[1][0],rclTrf[1][1],rclTrf[1][2],rclTrf[1][3],
