@@ -27,12 +27,16 @@
 # include <BRepMesh.hxx>
 # include <BRepBuilderAPI_Copy.hxx>
 # include <BRepBuilderAPI_Sewing.hxx>
+# include <BRepBuilderAPI_Transform.hxx>
 # include <BRepClass3d_SolidClassifier.hxx>
 # include <BRepFilletAPI_MakeFillet.hxx>
 # include <BRepFilletAPI_MakeChamfer.hxx>
 # include <BRepOffsetAPI_MakePipe.hxx>
 # include <BRepOffsetAPI_MakePipeShell.hxx>
+# include <BRepProj_Projection.hxx>
 # include <BRepTools.hxx>
+# include <BRepExtrema_DistShapeShape.hxx>
+# include <BRepExtrema_SupportType.hxx>
 # include <gp_Ax1.hxx>
 # include <gp_Ax2.hxx>
 # include <gp_Dir.hxx>
@@ -161,7 +165,10 @@ PyObject* TopoShapePy::copy(PyObject *args)
         return 0;
     }
 
-    static_cast<TopoShapePy*>(cpy)->getTopoShapePtr()->_Shape = shape;
+    if (!shape.IsNull()) {
+        BRepBuilderAPI_Copy c(shape);
+        static_cast<TopoShapePy*>(cpy)->getTopoShapePtr()->_Shape = c.Shape();
+    }
     return cpy;
 }
 
@@ -311,6 +318,31 @@ PyObject*  TopoShapePy::exportBrep(PyObject *args)
     Py_Return;
 }
 
+PyObject*  TopoShapePy::dumpToString(PyObject *args)
+{
+    if (!PyArg_ParseTuple(args, ""))
+        return NULL;
+
+    try {
+        std::stringstream str;
+        getTopoShapePtr()->dump(str);
+        return Py::new_reference_to(Py::String(str.str()));
+    }
+    catch (const Base::Exception& e) {
+        PyErr_SetString(PyExc_Exception,e.what());
+        return NULL;
+    }
+    catch (const std::exception& e) {
+        PyErr_SetString(PyExc_Exception,e.what());
+        return NULL;
+    }
+    catch (Standard_Failure) {
+        Handle_Standard_Failure e = Standard_Failure::Caught();
+        PyErr_SetString(PyExc_Exception, e->GetMessageString());
+        return 0;
+    }
+}
+
 PyObject*  TopoShapePy::exportBrepToString(PyObject *args)
 {
     if (!PyArg_ParseTuple(args, ""))
@@ -392,12 +424,13 @@ PyObject*  TopoShapePy::importBrepFromString(PyObject *args)
 PyObject*  TopoShapePy::exportStl(PyObject *args)
 {
     char* filename;
-    if (!PyArg_ParseTuple(args, "s", &filename))
+    double deflection = 0;
+    if (!PyArg_ParseTuple(args, "s|d", &filename, &deflection))
         return NULL;
 
     try {
         // write stl file
-        getTopoShapePtr()->exportStl(filename);
+        getTopoShapePtr()->exportStl(filename, deflection);
     }
     catch (const Base::Exception& e) {
         PyErr_SetString(PyExc_Exception,e.what());
@@ -724,6 +757,70 @@ PyObject*  TopoShapePy::sewShape(PyObject *args)
     }
 }
 
+PyObject* TopoShapePy::childShapes(PyObject *args)
+{
+    PyObject* cumOri = Py_True;
+    PyObject* cumLoc = Py_True;
+    if (!PyArg_ParseTuple(args, "|O!O!", &(PyBool_Type), &cumOri,
+                                         &(PyBool_Type), &cumLoc))
+        return NULL;
+
+    try {
+        TopoDS_Iterator it(getTopoShapePtr()->_Shape,
+            PyObject_IsTrue(cumOri) ? Standard_True : Standard_False,
+            PyObject_IsTrue(cumLoc) ? Standard_True : Standard_False);
+        Py::List list;
+        for (; it.More(); it.Next()) {
+            const TopoDS_Shape& aChild = it.Value();
+            if (!aChild.IsNull()) {
+                TopAbs_ShapeEnum type = aChild.ShapeType();
+                PyObject* pyChild = 0;
+                switch (type)
+                {
+                case TopAbs_COMPOUND:
+                    pyChild = new TopoShapeCompoundPy(new TopoShape(aChild));
+                    break;
+                case TopAbs_COMPSOLID:
+                    pyChild = new TopoShapeCompSolidPy(new TopoShape(aChild));
+                    break;
+                case TopAbs_SOLID:
+                    pyChild = new TopoShapeSolidPy(new TopoShape(aChild));
+                    break;
+                case TopAbs_SHELL:
+                    pyChild = new TopoShapeShellPy(new TopoShape(aChild));
+                    break;
+                case TopAbs_FACE:
+                    pyChild = new TopoShapeFacePy(new TopoShape(aChild));
+                    break;
+                case TopAbs_WIRE:
+                    pyChild = new TopoShapeWirePy(new TopoShape(aChild));
+                    break;
+                case TopAbs_EDGE:
+                    pyChild = new TopoShapeEdgePy(new TopoShape(aChild));
+                    break;
+                case TopAbs_VERTEX:
+                    pyChild = new TopoShapeVertexPy(new TopoShape(aChild));
+                    break;
+                case TopAbs_SHAPE:
+                    break;
+                default:
+                    break;
+                }
+
+                if (pyChild) {
+                    list.append(Py::Object(pyChild,true));
+                }
+            }
+        }
+        return Py::new_reference_to(list);
+    }
+    catch (Standard_Failure) {
+        Handle_Standard_Failure e = Standard_Failure::Caught();
+        PyErr_SetString(PyExc_Exception, e->GetMessageString());
+        return NULL;
+    }
+}
+
 PyObject*  TopoShapePy::removeInternalWires(PyObject *args)
 {
     double minArea;
@@ -879,8 +976,10 @@ PyObject*  TopoShapePy::scale(PyObject *args)
     try {
         gp_Trsf scl;
         scl.SetScale(pos, factor);
-        TopLoc_Location loc(scl);
-        getTopoShapePtr()->_Shape.Move(loc);
+        BRepBuilderAPI_Transform BRepScale(scl);
+        bool bCopy = true;
+        BRepScale.Perform(getTopoShapePtr()->_Shape,bCopy);
+        getTopoShapePtr()->_Shape = BRepScale.Shape();
         Py_Return;
     }
     catch (Standard_Failure) {
@@ -1056,14 +1155,15 @@ PyObject* TopoShapePy::makeThickness(PyObject *args)
     }
 }
 
-PyObject* TopoShapePy::makeOffsetShape(PyObject *args)
+PyObject* TopoShapePy::makeOffsetShape(PyObject *args, PyObject *keywds)
 {
+    static char *kwlist[] = {"offset", "tolerance", "inter", "self_inter", "offsetMode", "join", "fill", NULL};
     double offset, tolerance;
     PyObject* inter = Py_False;
     PyObject* self_inter = Py_False;
     PyObject* fill = Py_False;
     short offsetMode = 0, join = 0;
-    if (!PyArg_ParseTuple(args, "dd|O!O!hhO!",
+    if (!PyArg_ParseTupleAndKeywords(args, keywds, "dd|O!O!hhO!", kwlist,
         &offset, &tolerance,
         &(PyBool_Type), &inter,
         &(PyBool_Type), &self_inter,
@@ -1273,6 +1373,50 @@ PyObject* TopoShapePy::project(PyObject *args)
     return 0;
 }
 
+PyObject* TopoShapePy::makeParallelProjection(PyObject *args)
+{
+    PyObject *pShape, *pDir;
+    if (PyArg_ParseTuple(args, "O!O!", &(Part::TopoShapePy::Type), &pShape, &Base::VectorPy::Type, &pDir)) {
+        try {
+            const TopoDS_Shape& shape = this->getTopoShapePtr()->_Shape;
+            const TopoDS_Shape& wire = static_cast<TopoShapePy*>(pShape)->getTopoShapePtr()->_Shape;
+            Base::Vector3d vec = Py::Vector(pDir,false).toVector();
+            BRepProj_Projection proj(wire, shape, gp_Dir(vec.x,vec.y,vec.z));
+            TopoDS_Shape projected = proj.Shape();
+            return new TopoShapePy(new TopoShape(projected));
+        }
+        catch (Standard_Failure) {
+            Handle_Standard_Failure e = Standard_Failure::Caught();
+            PyErr_SetString(PyExc_Exception, e->GetMessageString());
+            return 0;
+        }
+    }
+
+    return 0;
+}
+
+PyObject* TopoShapePy::makePerspectiveProjection(PyObject *args)
+{
+    PyObject *pShape, *pDir;
+    if (PyArg_ParseTuple(args, "O!O!", &(Part::TopoShapePy::Type), &pShape, &Base::VectorPy::Type, &pDir)) {
+        try {
+            const TopoDS_Shape& shape = this->getTopoShapePtr()->_Shape;
+            const TopoDS_Shape& wire = static_cast<TopoShapePy*>(pShape)->getTopoShapePtr()->_Shape;
+            Base::Vector3d vec = Py::Vector(pDir,false).toVector();
+            BRepProj_Projection proj(wire, shape, gp_Pnt(vec.x,vec.y,vec.z));
+            TopoDS_Shape projected = proj.Shape();
+            return new TopoShapePy(new TopoShape(projected));
+        }
+        catch (Standard_Failure) {
+            Handle_Standard_Failure e = Standard_Failure::Caught();
+            PyErr_SetString(PyExc_Exception, e->GetMessageString());
+            return 0;
+        }
+    }
+
+    return 0;
+}
+
 PyObject* TopoShapePy::makeShapeFromMesh(PyObject *args)
 {
     PyObject *tup;
@@ -1407,6 +1551,142 @@ PyObject* TopoShapePy::getElement(PyObject *args)
     return 0;
 }
 
+PyObject* _getSupportIndex(char* suppStr, TopoShape* ts, TopoDS_Shape suppShape) {
+    std::stringstream ss;
+    TopoDS_Shape subShape;
+
+    unsigned long nSubShapes = ts->countSubShapes(suppStr);
+    long supportIndex = -1;
+    for (unsigned long j=1; j<=nSubShapes; j++){
+        ss.str("");
+        ss << suppStr << j;
+        subShape = ts->getSubShape(ss.str().c_str());
+        if (subShape.IsEqual(suppShape)) {
+            supportIndex = j-1;
+            break;
+        }
+    }
+    return PyInt_FromLong(supportIndex);
+}
+
+PyObject* TopoShapePy::distToShape(PyObject *args)
+{
+    PyObject* ps2;
+    PyObject *pts,*geom,*pPt1,*pPt2,*pSuppType1,*pSuppType2, 
+             *pSupportIndex1, *pSupportIndex2, *pParm1, *pParm2;
+    gp_Pnt P1,P2;
+    BRepExtrema_SupportType supportType1,supportType2;
+    TopoDS_Shape suppS1,suppS2;
+    Standard_Real minDist = -1, t1,t2,u1,v1,u2,v2;
+
+    if (!PyArg_ParseTuple(args, "O!",&(TopoShapePy::Type), &ps2))
+        return 0;
+
+    const TopoDS_Shape& s1 = getTopoShapePtr()->_Shape;
+    TopoShape* ts1 = getTopoShapePtr();
+    const TopoDS_Shape& s2 = static_cast<Part::TopoShapePy*>(ps2)->getTopoShapePtr()->_Shape;
+    TopoShape* ts2 = static_cast<Part::TopoShapePy*>(ps2)->getTopoShapePtr();
+
+    if (s2.IsNull()) {
+        PyErr_SetString(PyExc_TypeError, "distToShape: Shape parameter is invalid");
+        return 0;
+    }
+    BRepExtrema_DistShapeShape extss(s1, s2);
+    if (!extss.IsDone()) {
+        PyErr_SetString(PyExc_TypeError, "BRepExtrema_DistShapeShape failed");
+        return 0;
+    }
+    PyObject* solnPts = PyList_New(0);
+    PyObject* solnGeom = PyList_New(0);
+    int count = extss.NbSolution();
+    if (count != 0) {
+        minDist = extss.Value();
+        //extss.Dump(std::cout);
+        for (int i=1; i<= count; i++) {
+            P1 = extss.PointOnShape1(i);
+            pPt1 = new Base::VectorPy(new Base::Vector3d(P1.X(),P1.Y(),P1.Z()));
+            supportType1 = extss.SupportTypeShape1(i);
+            suppS1 = extss.SupportOnShape1(i);
+            switch (supportType1) {
+                case BRepExtrema_IsVertex:
+                    pSuppType1 = PyString_FromString("Vertex");
+                    pSupportIndex1 = _getSupportIndex("Vertex",ts1,suppS1);
+                    pParm1 = Py_None;
+                    break;
+                case BRepExtrema_IsOnEdge:
+                    pSuppType1 = PyString_FromString("Edge");
+                    pSupportIndex1 = _getSupportIndex("Edge",ts1,suppS1);
+                    extss.ParOnEdgeS1(i,t1);
+                    pParm1 = PyFloat_FromDouble(t1);
+                    break;
+                case BRepExtrema_IsInFace:
+                    pSuppType1 = PyString_FromString("Face");
+                    pSupportIndex1 = _getSupportIndex("Face",ts1,suppS1);
+                    extss.ParOnFaceS1(i,u1,v1);
+                    pParm1 = PyTuple_New(2);
+                    PyTuple_SetItem(pParm1,0,PyFloat_FromDouble(u1));
+                    PyTuple_SetItem(pParm1,1,PyFloat_FromDouble(v1));
+                    break;
+                default:
+                    Base::Console().Message("distToShape: supportType1 is unknown: %d \n",supportType1);
+                    pSuppType1 = PyString_FromString("Unknown");
+                    pSupportIndex1 = PyInt_FromLong(-1);
+                    pParm1 = Py_None;
+            }
+
+            P2 = extss.PointOnShape2(i);
+            pPt2 = new Base::VectorPy(new Base::Vector3d(P2.X(),P2.Y(),P2.Z()));
+            supportType2 = extss.SupportTypeShape2(i);
+            suppS2 = extss.SupportOnShape2(i);
+            switch (supportType2) {
+                case BRepExtrema_IsVertex:
+                    pSuppType2 = PyString_FromString("Vertex");
+                    pSupportIndex2 = _getSupportIndex("Vertex",ts2,suppS2);
+                    pParm2 = Py_None;
+                    break;
+                case BRepExtrema_IsOnEdge:
+                    pSuppType2 = PyString_FromString("Edge");
+                    pSupportIndex2 = _getSupportIndex("Edge",ts2,suppS2);
+                    extss.ParOnEdgeS2(i,t2);
+                    pParm2 = PyFloat_FromDouble(t2);
+                    break;
+                case BRepExtrema_IsInFace:
+                    pSuppType2 = PyString_FromString("Face");
+                    pSupportIndex2 = _getSupportIndex("Face",ts2,suppS2);
+                    extss.ParOnFaceS2(i,u2,v2);
+                    pParm2 = PyTuple_New(2);
+                    PyTuple_SetItem(pParm2,0,PyFloat_FromDouble(u2));
+                    PyTuple_SetItem(pParm2,1,PyFloat_FromDouble(v2));
+                    break;
+                default:
+                    Base::Console().Message("distToShape: supportType2 is unknown: %d \n",supportType1);
+                    pSuppType2 = PyString_FromString("Unknown");
+                    pSupportIndex2 = PyInt_FromLong(-1);
+            }
+            pts = PyTuple_New(2);
+            PyTuple_SetItem(pts,0,pPt1);
+            PyTuple_SetItem(pts,1,pPt2);
+            PyList_Append(solnPts, pts);
+
+            geom = PyTuple_New(6);
+            PyTuple_SetItem(geom,0,pSuppType1);
+            PyTuple_SetItem(geom,1,pSupportIndex1);
+            PyTuple_SetItem(geom,2,pParm1);
+            PyTuple_SetItem(geom,3,pSuppType2);
+            PyTuple_SetItem(geom,4,pSupportIndex2);
+            PyTuple_SetItem(geom,5,pParm2);
+            PyList_Append(solnGeom, geom);
+        }
+    }
+    else {
+        PyErr_SetString(PyExc_TypeError, "distToShape: No Solutions Found.");
+        return 0;
+    }
+    return Py_BuildValue("dOO", minDist, solnPts,solnGeom);
+}
+
+// End of Methods, Start of Attributes
+
 #if 0 // see ComplexGeoDataPy::Matrix which does the same
 Py::Object TopoShapePy::getLocation(void) const
 {
