@@ -260,6 +260,11 @@ DlgPrimitives::DlgPrimitives(QWidget* parent)
     ui.edgeZ2->setMaximum(INT_MAX);
     ui.edgeZ2->setMinimum(INT_MIN);
     // RegularPolygon
+
+    QList<Gui::InputField*> list = this->findChildren<Gui::InputField*>();
+    for (QList<Gui::InputField*>::iterator it = list.begin(); it != list.end(); ++it) {
+        (*it)->setValue((*it)->getQuantity());
+    }
 }
 
 /*  
@@ -309,7 +314,7 @@ void DlgPrimitives::executeCallback(Picker* p)
             viewer->setEditing(true);
             viewer->setRedirectToSceneGraph(true);
             SoNode* root = viewer->getSceneGraph();
-            int mode;
+            int mode = 0;
             if (root && root->getTypeId().isDerivedFrom(Gui::SoFCUnifiedSelection::getClassTypeId())) {
                 mode = static_cast<Gui::SoFCUnifiedSelection*>(root)->selectionMode.getValue();
                 static_cast<Gui::SoFCUnifiedSelection*>(root)->selectionMode.setValue(Gui::SoFCUnifiedSelection::OFF);
@@ -356,8 +361,8 @@ void DlgPrimitives::createPrimitive(const QString& placement)
                 "App.ActiveDocument.%1.Placement=%4\n"
                 "App.ActiveDocument.%1.Label='%5'\n")
                 .arg(name)
-                .arg(ui.planeLength->value(),0,'f',2)
-                .arg(ui.planeWidth->value(),0,'f',2)
+                .arg(ui.planeLength->getQuantity().getValue(),0,'f',2)
+                .arg(ui.planeWidth->getQuantity().getValue(),0,'f',2)
                 .arg(placement)
                 .arg(tr("Plane"));
         }
@@ -371,9 +376,9 @@ void DlgPrimitives::createPrimitive(const QString& placement)
                 "App.ActiveDocument.%1.Placement=%5\n"
                 "App.ActiveDocument.%1.Label='%6'\n")
                 .arg(name)
-                .arg(ui.boxLength->value(),0,'f',2)
-                .arg(ui.boxWidth->value(),0,'f',2)
-                .arg(ui.boxHeight->value(),0,'f',2)
+                .arg(ui.boxLength->getQuantity().getValue(),0,'f',2)
+                .arg(ui.boxWidth->getQuantity().getValue(),0,'f',2)
+                .arg(ui.boxHeight->getQuantity().getValue(),0,'f',2)
                 .arg(placement)
                 .arg(tr("Box"));
         }
@@ -387,9 +392,9 @@ void DlgPrimitives::createPrimitive(const QString& placement)
                 "App.ActiveDocument.%1.Placement=%5\n"
                 "App.ActiveDocument.%1.Label='%6'\n")
                 .arg(name)
-                .arg(ui.cylinderRadius->value(),0,'f',2)
-                .arg(ui.cylinderHeight->value(),0,'f',2)
-                .arg(ui.cylinderAngle->value(),0,'f',2)
+                .arg(ui.cylinderRadius->getQuantity().getValue(),0,'f',2)
+                .arg(ui.cylinderHeight->getQuantity().getValue(),0,'f',2)
+                .arg(ui.cylinderAngle->getQuantity().getValue(),0,'f',2)
                 .arg(placement)
                 .arg(tr("Cylinder"));
         }
@@ -404,10 +409,10 @@ void DlgPrimitives::createPrimitive(const QString& placement)
                 "App.ActiveDocument.%1.Placement=%6\n"
                 "App.ActiveDocument.%1.Label='%7'\n")
                 .arg(name)
-                .arg(ui.coneRadius1->value(),0,'f',2)
-                .arg(ui.coneRadius2->value(),0,'f',2)
-                .arg(ui.coneHeight->value(),0,'f',2)
-                .arg(ui.coneAngle->value(),0,'f',2)
+                .arg(ui.coneRadius1->getQuantity().getValue(),0,'f',2)
+                .arg(ui.coneRadius2->getQuantity().getValue(),0,'f',2)
+                .arg(ui.coneHeight->getQuantity().getValue(),0,'f',2)
+                .arg(ui.coneAngle->getQuantity().getValue(),0,'f',2)
                 .arg(placement)
                 .arg(tr("Cone"));
         }
@@ -422,10 +427,10 @@ void DlgPrimitives::createPrimitive(const QString& placement)
                 "App.ActiveDocument.%1.Placement=%6\n"
                 "App.ActiveDocument.%1.Label='%7'\n")
                 .arg(name)
-                .arg(ui.sphereRadius->value(),0,'f',2)
-                .arg(ui.sphereAngle1->value(),0,'f',2)
-                .arg(ui.sphereAngle2->value(),0,'f',2)
-                .arg(ui.sphereAngle3->value(),0,'f',2)
+                .arg(ui.sphereRadius->getQuantity().getValue(),0,'f',2)
+                .arg(ui.sphereAngle1->getQuantity().getValue(),0,'f',2)
+                .arg(ui.sphereAngle2->getQuantity().getValue(),0,'f',2)
+                .arg(ui.sphereAngle3->getQuantity().getValue(),0,'f',2)
                 .arg(placement)
                 .arg(tr("Sphere"));
         }
@@ -441,11 +446,11 @@ void DlgPrimitives::createPrimitive(const QString& placement)
                 "App.ActiveDocument.%1.Placement=%7\n"
                 "App.ActiveDocument.%1.Label='%8'\n")
                 .arg(name)
-                .arg(ui.ellipsoidRadius1->value(),0,'f',2)
-                .arg(ui.ellipsoidRadius2->value(),0,'f',2)
-                .arg(ui.ellipsoidAngle1->value(),0,'f',2)
-                .arg(ui.ellipsoidAngle2->value(),0,'f',2)
-                .arg(ui.ellipsoidAngle3->value(),0,'f',2)
+                .arg(ui.ellipsoidRadius1->getQuantity().getValue(),0,'f',2)
+                .arg(ui.ellipsoidRadius2->getQuantity().getValue(),0,'f',2)
+                .arg(ui.ellipsoidAngle1->getQuantity().getValue(),0,'f',2)
+                .arg(ui.ellipsoidAngle2->getQuantity().getValue(),0,'f',2)
+                .arg(ui.ellipsoidAngle3->getQuantity().getValue(),0,'f',2)
                 .arg(placement)
                 .arg(tr("Ellipsoid"));
         }
@@ -461,11 +466,11 @@ void DlgPrimitives::createPrimitive(const QString& placement)
                 "App.ActiveDocument.%1.Placement=%7\n"
                 "App.ActiveDocument.%1.Label='%8'\n")
                 .arg(name)
-                .arg(ui.torusRadius1->value(),0,'f',2)
-                .arg(ui.torusRadius2->value(),0,'f',2)
-                .arg(ui.torusAngle1->value(),0,'f',2)
-                .arg(ui.torusAngle2->value(),0,'f',2)
-                .arg(ui.torusAngle3->value(),0,'f',2)
+                .arg(ui.torusRadius1->getQuantity().getValue(),0,'f',2)
+                .arg(ui.torusRadius2->getQuantity().getValue(),0,'f',2)
+                .arg(ui.torusAngle1->getQuantity().getValue(),0,'f',2)
+                .arg(ui.torusAngle2->getQuantity().getValue(),0,'f',2)
+                .arg(ui.torusAngle3->getQuantity().getValue(),0,'f',2)
                 .arg(placement)
                 .arg(tr("Torus"));
         }
@@ -480,8 +485,8 @@ void DlgPrimitives::createPrimitive(const QString& placement)
                 "App.ActiveDocument.%1.Label='%6'\n")
                 .arg(name)
                 .arg(ui.prismPolygon->value())
-                .arg(ui.prismCircumradius->value(),0,'f',2)
-                .arg(ui.prismHeight->value(),0,'f',2)
+                .arg(ui.prismCircumradius->getQuantity().getValue(),0,'f',2)
+                .arg(ui.prismHeight->getQuantity().getValue(),0,'f',2)
                 .arg(placement)
                 .arg(tr("Prism"));
         }
@@ -502,16 +507,16 @@ void DlgPrimitives::createPrimitive(const QString& placement)
                 "App.ActiveDocument.%1.Placement=%12\n"
                 "App.ActiveDocument.%1.Label='%13'\n")
                 .arg(name)
-                .arg(ui.wedgeXmin->value(),0,'f',2)
-                .arg(ui.wedgeYmin->value(),0,'f',2)
-                .arg(ui.wedgeZmin->value(),0,'f',2)
-                .arg(ui.wedgeX2min->value(),0,'f',2)
-                .arg(ui.wedgeZ2min->value(),0,'f',2)
-                .arg(ui.wedgeXmax->value(),0,'f',2)
-                .arg(ui.wedgeYmax->value(),0,'f',2)
-                .arg(ui.wedgeZmax->value(),0,'f',2)
-                .arg(ui.wedgeX2max->value(),0,'f',2)
-                .arg(ui.wedgeZ2max->value(),0,'f',2)
+                .arg(ui.wedgeXmin->getQuantity().getValue(),0,'f',2)
+                .arg(ui.wedgeYmin->getQuantity().getValue(),0,'f',2)
+                .arg(ui.wedgeZmin->getQuantity().getValue(),0,'f',2)
+                .arg(ui.wedgeX2min->getQuantity().getValue(),0,'f',2)
+                .arg(ui.wedgeZ2min->getQuantity().getValue(),0,'f',2)
+                .arg(ui.wedgeXmax->getQuantity().getValue(),0,'f',2)
+                .arg(ui.wedgeYmax->getQuantity().getValue(),0,'f',2)
+                .arg(ui.wedgeZmax->getQuantity().getValue(),0,'f',2)
+                .arg(ui.wedgeX2max->getQuantity().getValue(),0,'f',2)
+                .arg(ui.wedgeZ2max->getQuantity().getValue(),0,'f',2)
                 .arg(placement)
                 .arg(tr("Wedge"));
         }
@@ -528,10 +533,10 @@ void DlgPrimitives::createPrimitive(const QString& placement)
                 "App.ActiveDocument.%1.Placement=%7\n"
                 "App.ActiveDocument.%1.Label='%8'\n")
                 .arg(name)
-                .arg(ui.helixPitch->value(),0,'f',2)
-                .arg(ui.helixHeight->value(),0,'f',2)
-                .arg(ui.helixRadius->value(),0,'f',2)
-                .arg(ui.helixAngle->value(),0,'f',2)
+                .arg(ui.helixPitch->getQuantity().getValue(),0,'f',2)
+                .arg(ui.helixHeight->getQuantity().getValue(),0,'f',2)
+                .arg(ui.helixRadius->getQuantity().getValue(),0,'f',2)
+                .arg(ui.helixAngle->getQuantity().getValue(),0,'f',2)
                 .arg(ui.helixLocalCS->currentIndex())
                 .arg(placement)
                 .arg(tr("Helix"));
@@ -546,9 +551,9 @@ void DlgPrimitives::createPrimitive(const QString& placement)
                 "App.ActiveDocument.%1.Placement=%5\n"
                 "App.ActiveDocument.%1.Label='%6'\n")
                 .arg(name)
-                .arg(ui.spiralGrowth->value(),0,'f',2)
+                .arg(ui.spiralGrowth->getQuantity().getValue(),0,'f',2)
                 .arg(ui.spiralRotation->value(),0,'f',2)
-                .arg(ui.spiralRadius->value(),0,'f',2)
+                .arg(ui.spiralRadius->getQuantity().getValue(),0,'f',2)
                 .arg(placement)
                 .arg(tr("Spiral"));
         }
@@ -562,9 +567,9 @@ void DlgPrimitives::createPrimitive(const QString& placement)
                 "App.ActiveDocument.%1.Placement=%5\n"
                 "App.ActiveDocument.%1.Label='%6'\n")
                 .arg(name)
-                .arg(ui.circleRadius->value(),0,'f',2)
-                .arg(ui.circleAngle0->value(),0,'f',2)
-                .arg(ui.circleAngle1->value(),0,'f',2)
+                .arg(ui.circleRadius->getQuantity().getValue(),0,'f',2)
+                .arg(ui.circleAngle0->getQuantity().getValue(),0,'f',2)
+                .arg(ui.circleAngle1->getQuantity().getValue(),0,'f',2)
                 .arg(placement)
                 .arg(tr("Circle"));
         }
@@ -579,10 +584,10 @@ void DlgPrimitives::createPrimitive(const QString& placement)
                 "App.ActiveDocument.%1.Placement=%6\n"
                 "App.ActiveDocument.%1.Label='%7'\n")
                 .arg(name)
-                .arg(ui.ellipseMajorRadius->value(),0,'f',2)
-                .arg(ui.ellipseMinorRadius->value(),0,'f',2)
-                .arg(ui.ellipseAngle0->value(),0,'f',2)
-                .arg(ui.ellipseAngle1->value(),0,'f',2)
+                .arg(ui.ellipseMajorRadius->getQuantity().getValue(),0,'f',2)
+                .arg(ui.ellipseMinorRadius->getQuantity().getValue(),0,'f',2)
+                .arg(ui.ellipseAngle0->getQuantity().getValue(),0,'f',2)
+                .arg(ui.ellipseAngle1->getQuantity().getValue(),0,'f',2)
                 .arg(placement)
                 .arg(tr("Ellipse"));
         }
@@ -596,9 +601,9 @@ void DlgPrimitives::createPrimitive(const QString& placement)
                 "App.ActiveDocument.%1.Placement=%5\n"
                 "App.ActiveDocument.%1.Label='%6'\n")
                 .arg(name)
-                .arg(ui.vertexX->value(),0,'f',2)
-                .arg(ui.vertexY->value(),0,'f',2)
-                .arg(ui.vertexZ->value(),0,'f',2)
+                .arg(ui.vertexX->getQuantity().getValue(),0,'f',2)
+                .arg(ui.vertexY->getQuantity().getValue(),0,'f',2)
+                .arg(ui.vertexZ->getQuantity().getValue(),0,'f',2)
                 .arg(placement)
                 .arg(tr("Vertex"));
         }
@@ -615,12 +620,12 @@ void DlgPrimitives::createPrimitive(const QString& placement)
                 "App.ActiveDocument.%1.Placement=%8\n"
                 "App.ActiveDocument.%1.Label='%9'\n")
                 .arg(name)
-                .arg(ui.edgeX1->value(),0,'f',2)
-                .arg(ui.edgeY1->value(),0,'f',2)
-                .arg(ui.edgeZ1->value(),0,'f',2)
-                .arg(ui.edgeX2->value(),0,'f',2)
-                .arg(ui.edgeY2->value(),0,'f',2)
-                .arg(ui.edgeZ2->value(),0,'f',2)
+                .arg(ui.edgeX1->getQuantity().getValue(),0,'f',2)
+                .arg(ui.edgeY1->getQuantity().getValue(),0,'f',2)
+                .arg(ui.edgeZ1->getQuantity().getValue(),0,'f',2)
+                .arg(ui.edgeX2->getQuantity().getValue(),0,'f',2)
+                .arg(ui.edgeY2->getQuantity().getValue(),0,'f',2)
+                .arg(ui.edgeZ2->getQuantity().getValue(),0,'f',2)
                 .arg(placement)
                 .arg(tr("Line"));
         }
@@ -634,7 +639,7 @@ void DlgPrimitives::createPrimitive(const QString& placement)
                 "App.ActiveDocument.%1.Label='%5'\n")
                 .arg(name)
                 .arg(ui.regularPolygonPolygon->value())
-                .arg(ui.regularPolygonCircumradius->value(),0,'f',2)
+                .arg(ui.regularPolygonCircumradius->getQuantity().getValue(),0,'f',2)
                 .arg(placement)
                 .arg(tr("Regular polygon"));
         }
@@ -660,6 +665,9 @@ void DlgPrimitives::createPrimitive(const QString& placement)
 Location::Location(QWidget* parent)
 {
     ui.setupUi(this);
+    QList<QDoubleSpinBox*> list = this->findChildren<QDoubleSpinBox*>();
+    for (QList<QDoubleSpinBox*>::iterator it = list.begin(); it != list.end(); ++it)
+        (*it)->setDecimals(Base::UnitsApi::getDecimals());
 }
 
 Location::~Location()
