@@ -47,6 +47,7 @@
 # include <Handle_Poly_Triangulation.hxx>
 # include <Poly_Array1OfTriangle.hxx>
 # include <Poly_Triangulation.hxx>
+# include <Standard_Version.hxx>
 # include <TColgp_Array1OfPnt.hxx>
 # include <TopoDS.hxx>
 # include <TopoDS_Edge.hxx>
@@ -639,7 +640,7 @@ void ViewProviderPartExt::updateVisual(const TopoDS_Shape& inputShape)
 
     // time measurement and book keeping
     Base::TimeInfo start_time;
-    int nbrTriangles=0,nbrNodes=0,nbrNorms=0,nbrFaces=0,nbrEdges=0,nbrLines=0;
+    int numTriangles=0,numNodes=0,numNorms=0,numFaces=0,numEdges=0,numLines=0;
     std::set<int> faceEdges;
 
     try {
@@ -653,7 +654,11 @@ void ViewProviderPartExt::updateVisual(const TopoDS_Shape& inputShape)
             Deviation.getValue();
 
         // create or use the mesh on the data structure
+#if OCC_VERSION_HEX >= 0x060600
+        BRepMesh_IncrementalMesh myMesh(cShape,deflection,Standard_False,0.5,Standard_True);
+#else
         BRepMesh_IncrementalMesh myMesh(cShape,deflection);
+#endif
         // We must reset the location here because the transformation data
         // are set in the placement property
         TopLoc_Location aLoc;
@@ -665,31 +670,32 @@ void ViewProviderPartExt::updateVisual(const TopoDS_Shape& inputShape)
             Handle (Poly_Triangulation) mesh = BRep_Tool::Triangulation(TopoDS::Face(Ex.Current()), aLoc);
             // Note: we must also count empty faces
             if (!mesh.IsNull()) {
-                nbrTriangles += mesh->NbTriangles();
-                nbrNodes     += mesh->NbNodes();
-                nbrNorms     += mesh->NbNodes();
+                numTriangles += mesh->NbTriangles();
+                numNodes     += mesh->NbNodes();
+                numNorms     += mesh->NbNodes();
             }
 
             TopExp_Explorer xp;
             for (xp.Init(Ex.Current(),TopAbs_EDGE);xp.More();xp.Next())
                 faceEdges.insert(xp.Current().HashCode(INT_MAX));
-            nbrFaces++;
+            numFaces++;
         }
 
         // get an indexed map of edges
-        TopTools_IndexedMapOfShape M;
-        TopExp::MapShapes(cShape, TopAbs_EDGE, M);
+        TopTools_IndexedMapOfShape edgeMap;
+        TopExp::MapShapes(cShape, TopAbs_EDGE, edgeMap);
 
-        std::set<int>         edgeIdxSet;
-        std::vector<int32_t>  indxVector;
-        std::vector<int32_t>  edgeVector;
+         // key is the edge number, value the coord indexes. This is needed to keep the same order as the edges.
+        std::map<int, std::vector<int32_t> > lineSetMap;
+        std::set<int>          edgeIdxSet;
+        std::vector<int32_t>   edgeVector;
 
         // count and index the edges
-        for (int i=1; i <= M.Extent(); i++) {
+        for (int i=1; i <= edgeMap.Extent(); i++) {
             edgeIdxSet.insert(i);
-            nbrEdges++;
+            numEdges++;
 
-            const TopoDS_Edge& aEdge = TopoDS::Edge(M(i));
+            const TopoDS_Edge& aEdge = TopoDS::Edge(edgeMap(i));
             TopLoc_Location aLoc;
 
             // handling of the free edge that are not associated to a face
@@ -704,23 +710,21 @@ void ViewProviderPartExt::updateVisual(const TopoDS_Shape& inputShape)
                 Handle(Poly_Polygon3D) aPoly = BRep_Tool::Polygon3D(aEdge, aLoc);
                 if (!aPoly.IsNull()) {
                     int nbNodesInEdge = aPoly->NbNodes();
-                    nbrNodes += nbNodesInEdge;
+                    numNodes += nbNodesInEdge;
                 }
             }
         }
-        // reserve some memory
-        indxVector.reserve(nbrEdges*8);
 
         // handling of the vertices
-        TopTools_IndexedMapOfShape V;
-        TopExp::MapShapes(cShape, TopAbs_VERTEX, V);
-        nbrNodes += V.Extent();
+        TopTools_IndexedMapOfShape vertexMap;
+        TopExp::MapShapes(cShape, TopAbs_VERTEX, vertexMap);
+        numNodes += vertexMap.Extent();
 
         // create memory for the nodes and indexes
-        coords  ->point      .setNum(nbrNodes);
-        norm    ->vector     .setNum(nbrNorms);
-        faceset ->coordIndex .setNum(nbrTriangles*4);
-        faceset ->partIndex  .setNum(nbrFaces);
+        coords  ->point      .setNum(numNodes);
+        norm    ->vector     .setNum(numNorms);
+        faceset ->coordIndex .setNum(numTriangles*4);
+        faceset ->partIndex  .setNum(numFaces);
         // get the raw memory for fast fill up
         SbVec3f* verts = coords  ->point       .startEditing();
         SbVec3f* norms = norm    ->vector      .startEditing();
@@ -728,10 +732,10 @@ void ViewProviderPartExt::updateVisual(const TopoDS_Shape& inputShape)
         int32_t* parts = faceset ->partIndex   .startEditing();
 
         // preset the normal vector with null vector
-        for (int i=0;i < nbrNorms;i++) 
+        for (int i=0;i < numNorms;i++)
             norms[i]= SbVec3f(0.0,0.0,0.0);
 
-        int ii = 0,FaceNodeOffset=0,FaceTriaOffset=0;
+        int ii = 0,faceNodeOffset=0,faceTriaOffset=0;
         for (Ex.Init(cShape, TopAbs_FACE); Ex.More(); Ex.Next(),ii++) {
             TopLoc_Location aLoc;
             const TopoDS_Face &actFace = TopoDS::Face(Ex.Current());
@@ -779,26 +783,26 @@ void ViewProviderPartExt::updateVisual(const TopoDS_Shape& inputShape)
                     V3.Transform(myTransf);
                 }
                 
-                // calculating per vertex normals                    
+                // calculating per vertex normals
                 // Calculate triangle normal
                 gp_Vec v1(V1.X(),V1.Y(),V1.Z()),v2(V2.X(),V2.Y(),V2.Z()),v3(V3.X(),V3.Y(),V3.Z());
                 gp_Vec Normal = (v2-v1)^(v3-v1); 
 
                 // add the triangle normal to the vertex normal for all points of this triangle
-                norms[FaceNodeOffset+N1-1] += SbVec3f(Normal.X(),Normal.Y(),Normal.Z());
-                norms[FaceNodeOffset+N2-1] += SbVec3f(Normal.X(),Normal.Y(),Normal.Z());
-                norms[FaceNodeOffset+N3-1] += SbVec3f(Normal.X(),Normal.Y(),Normal.Z());                 
+                norms[faceNodeOffset+N1-1] += SbVec3f(Normal.X(),Normal.Y(),Normal.Z());
+                norms[faceNodeOffset+N2-1] += SbVec3f(Normal.X(),Normal.Y(),Normal.Z());
+                norms[faceNodeOffset+N3-1] += SbVec3f(Normal.X(),Normal.Y(),Normal.Z());
 
                 // set the vertices
-                verts[FaceNodeOffset+N1-1].setValue((float)(V1.X()),(float)(V1.Y()),(float)(V1.Z()));
-                verts[FaceNodeOffset+N2-1].setValue((float)(V2.X()),(float)(V2.Y()),(float)(V2.Z()));
-                verts[FaceNodeOffset+N3-1].setValue((float)(V3.X()),(float)(V3.Y()),(float)(V3.Z()));
+                verts[faceNodeOffset+N1-1].setValue((float)(V1.X()),(float)(V1.Y()),(float)(V1.Z()));
+                verts[faceNodeOffset+N2-1].setValue((float)(V2.X()),(float)(V2.Y()),(float)(V2.Z()));
+                verts[faceNodeOffset+N3-1].setValue((float)(V3.X()),(float)(V3.Y()),(float)(V3.Z()));
 
                 // set the index vector with the 3 point indexes and the end delimiter
-                index[FaceTriaOffset*4+4*(g-1)]   = FaceNodeOffset+N1-1; 
-                index[FaceTriaOffset*4+4*(g-1)+1] = FaceNodeOffset+N2-1; 
-                index[FaceTriaOffset*4+4*(g-1)+2] = FaceNodeOffset+N3-1; 
-                index[FaceTriaOffset*4+4*(g-1)+3] = SO_END_FACE_INDEX;
+                index[faceTriaOffset*4+4*(g-1)]   = faceNodeOffset+N1-1;
+                index[faceTriaOffset*4+4*(g-1)+1] = faceNodeOffset+N2-1;
+                index[faceTriaOffset*4+4*(g-1)+2] = faceNodeOffset+N3-1;
+                index[faceTriaOffset*4+4*(g-1)+3] = SO_END_FACE_INDEX;
             }
 
             parts[ii] = nbTriInFace; // new part
@@ -806,51 +810,51 @@ void ViewProviderPartExt::updateVisual(const TopoDS_Shape& inputShape)
             // handling the edges lying on this face
             TopExp_Explorer Exp;
             for(Exp.Init(actFace,TopAbs_EDGE);Exp.More();Exp.Next()) {
-                const TopoDS_Edge &actEdge = TopoDS::Edge(Exp.Current());
+                const TopoDS_Edge &curEdge = TopoDS::Edge(Exp.Current());
                 // get the overall index of this edge
-                int idx = M.FindIndex(actEdge);
-                edgeVector.push_back((int32_t)idx-1);
+                int edgeIndex = edgeMap.FindIndex(curEdge);
+                edgeVector.push_back((int32_t)edgeIndex-1);
                 // already processed this index ?
-                if (edgeIdxSet.find(idx)!=edgeIdxSet.end()) {
+                if (edgeIdxSet.find(edgeIndex)!=edgeIdxSet.end()) {
                     
                     // this holds the indices of the edge's triangulation to the current polygon
-                    Handle(Poly_PolygonOnTriangulation) aPoly = BRep_Tool::PolygonOnTriangulation(actEdge, mesh, aLoc);
+                    Handle(Poly_PolygonOnTriangulation) aPoly = BRep_Tool::PolygonOnTriangulation(curEdge, mesh, aLoc);
                     if (aPoly.IsNull())
                         continue; // polygon does not exist
                     
                     // getting the indexes of the edge polygon
                     const TColStd_Array1OfInteger& indices = aPoly->Nodes();
                     for (Standard_Integer i=indices.Lower();i <= indices.Upper();i++) {
-                        int inx = indices(i);
-                        indxVector.push_back(FaceNodeOffset+inx-1);
+                        int nodeIndex = indices(i);
+                        int index = faceNodeOffset+nodeIndex-1;
+                        lineSetMap[edgeIndex].push_back(index);
 
                         // usually the coordinates for this edge are already set by the
                         // triangles of the face this edge belongs to. However, there are
                         // rare cases where some points are only referenced by the polygon
                         // but not by any triangle. Thus, we must apply the coordinates to
                         // make sure that everything is properly set.
-                        gp_Pnt p(Nodes(inx));
+                        gp_Pnt p(Nodes(nodeIndex));
                         if (!identity)
                             p.Transform(myTransf);
-                        verts[FaceNodeOffset+inx-1].setValue((float)(p.X()),(float)(p.Y()),(float)(p.Z()));
+                        verts[index].setValue((float)(p.X()),(float)(p.Y()),(float)(p.Z()));
                     }
-                    indxVector.push_back(-1);
 
                     // remove the handled edge index from the set
-                    edgeIdxSet.erase(idx);
+                    edgeIdxSet.erase(edgeIndex);
                 }
             }
 
             edgeVector.push_back(-1);
             
             // counting up the per Face offsets
-            FaceNodeOffset += nbNodesInFace;
-            FaceTriaOffset += nbTriInFace;
+            faceNodeOffset += nbNodesInFace;
+            faceTriaOffset += nbTriInFace;
         }
 
         // handling of the free edges
-        for (int i=1; i <= M.Extent(); i++) {
-            const TopoDS_Edge& aEdge = TopoDS::Edge(M(i));
+        for (int i=1; i <= edgeMap.Extent(); i++) {
+            const TopoDS_Edge& aEdge = TopoDS::Edge(edgeMap(i));
             Standard_Boolean identity = true;
             gp_Trsf myTransf;
             TopLoc_Location aLoc;
@@ -873,34 +877,40 @@ void ViewProviderPartExt::updateVisual(const TopoDS_Shape& inputShape)
                         pnt = aNodes(j);
                         if (!identity)
                             pnt.Transform(myTransf);
-                        verts[FaceNodeOffset+j-1].setValue((float)(pnt.X()),(float)(pnt.Y()),(float)(pnt.Z()));
-                        indxVector.push_back(FaceNodeOffset+j-1);
+                        int index = faceNodeOffset+j-1;
+                        verts[index].setValue((float)(pnt.X()),(float)(pnt.Y()),(float)(pnt.Z()));
+                        lineSetMap[i].push_back(index);
                     }
 
-                    indxVector.push_back(-1);
-                    FaceNodeOffset += nbNodesInEdge;
+                    faceNodeOffset += nbNodesInEdge;
                 }
             }
         }
 
-        nodeset->startIndex.setValue(FaceNodeOffset);
-        for (int i=0; i<V.Extent(); i++) {
-            const TopoDS_Vertex& aVertex = TopoDS::Vertex(V(i+1));
+        nodeset->startIndex.setValue(faceNodeOffset);
+        for (int i=0; i<vertexMap.Extent(); i++) {
+            const TopoDS_Vertex& aVertex = TopoDS::Vertex(vertexMap(i+1));
             gp_Pnt pnt = BRep_Tool::Pnt(aVertex);
-            verts[FaceNodeOffset+i].setValue((float)(pnt.X()),(float)(pnt.Y()),(float)(pnt.Z()));
+            verts[faceNodeOffset+i].setValue((float)(pnt.X()),(float)(pnt.Y()),(float)(pnt.Z()));
         }
 
         // normalize all normals 
-        for (int i = 0; i< nbrNorms ;i++)
+        for (int i = 0; i< numNorms ;i++)
             norms[i].normalize();
         
+        std::vector<int32_t> lineSetCoords;
+        for (std::map<int, std::vector<int32_t> >::iterator it = lineSetMap.begin(); it != lineSetMap.end(); ++it) {
+            lineSetCoords.insert(lineSetCoords.end(), it->second.begin(), it->second.end());
+            lineSetCoords.push_back(-1);
+        }
+
         // preset the index vector size
-        nbrLines =  indxVector.size();
-        lineset ->coordIndex .setNum(nbrLines);
+        numLines =  lineSetCoords.size();
+        lineset ->coordIndex .setNum(numLines);
         int32_t* lines = lineset ->coordIndex  .startEditing();
 
         int l=0;
-        for (std::vector<int32_t>::const_iterator it=indxVector.begin();it!=indxVector.end();++it,l++)
+        for (std::vector<int32_t>::const_iterator it=lineSetCoords.begin();it!=lineSetCoords.end();++it,l++)
             lines[l] = *it;
 
         // end the editing of the nodes
@@ -917,7 +927,7 @@ void ViewProviderPartExt::updateVisual(const TopoDS_Shape& inputShape)
 #   ifdef FC_DEBUG
         // printing some informations
         Base::Console().Log("ViewProvider update time: %f s\n",Base::TimeInfo::diffTimeF(start_time,Base::TimeInfo()));
-        Base::Console().Log("Shape tria info: Faces:%d Edges:%d Nodes:%d Triangles:%d IdxVec:%d\n",nbrFaces,nbrEdges,nbrNodes,nbrTriangles,nbrLines);
-#   endif 
+        Base::Console().Log("Shape tria info: Faces:%d Edges:%d Nodes:%d Triangles:%d IdxVec:%d\n",numFaces,numEdges,numNodes,numTriangles,numLines);
+#   endif
     VisualTouched = false;
 }
