@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS>
+<TS version="2.0" language="ja" sourcelanguage="en">
   <context>
     <name>CmdApproxPlane</name>
     <message>
@@ -9,25 +9,30 @@
       <translation>リバースエンジニアリング</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Approximate plane...</source>
-      <translation>Approximate plane...</translation>
+      <translation>平面に近似...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Approximate a plane</source>
-      <translation>Approximate a plane</translation>
+      <translation>平面に近似する</translation>
     </message>
   </context>
   <context>
     <name>CmdApproxSurface</name>
     <message>
+      <location line="-62"/>
       <source>Reverse Engineering</source>
       <translation>リバースエンジニアリング</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Approximate surface...</source>
       <translation>おおよその表面...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Approximate a B-Spline surface</source>
       <translation>B-スプライン曲面を近似</translation>
     </message>
