@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS>
+<TS version="2.0" language="cs" sourcelanguage="en">
   <context>
     <name>CmdRobotAddToolShape</name>
     <message>
@@ -9,10 +9,12 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Add tool</source>
-      <translation>Add tool</translation>
+      <translation>Přidat nástroj</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Add a tool shape to the robot</source>
       <translation>Add a tool shape to the robot</translation>
     </message>
@@ -25,12 +27,14 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Place robot...</source>
-      <translation>Place robot...</translation>
+      <translation>Umístit robota...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Place a robot (experimental!)</source>
-      <translation>Place a robot (experimental!)</translation>
+      <translation>Unístit robota (experimentální!)</translation>
     </message>
   </context>
   <context>
@@ -41,27 +45,32 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Create trajectory</source>
-      <translation>Create trajectory</translation>
+      <translation>Vytvořit trajektorii</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Create a new empty trajectory </source>
-      <translation>Create a new empty trajectory </translation>
+      <translation>Vytvořit novou prázdnou trajektorii </translation>
     </message>
   </context>
   <context>
     <name>CmdRobotEdge2Trac</name>
     <message>
+      <location line="+257"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Edge to Trajectory...</source>
       <translation>Edge to Trajectory...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Generate a Trajectory from a set of edges</source>
-      <translation>Generate a Trajectory from a set of edges</translation>
+      <translation>Vytvořit trajektorii z množiny hran</translation>
     </message>
   </context>
   <context>
@@ -72,10 +81,12 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Kuka compact subroutine...</source>
       <translation>Kuka compact subroutine...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Export the trajectory as a compact KRL subroutine.</source>
       <translation>Export the trajectory as a compact KRL subroutine.</translation>
     </message>
@@ -83,14 +94,17 @@
   <context>
     <name>CmdRobotExportKukaFull</name>
     <message>
+      <location line="+63"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Kuka full subroutine...</source>
       <translation>Kuka full subroutine...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Export the trajectory as a full KRL subroutine.</source>
       <translation>Export the trajectory as a full KRL subroutine.</translation>
     </message>
@@ -103,57 +117,68 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Kuka IR125</source>
       <translation>Kuka IR125</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert a Kuka IR125 into the document.</source>
-      <translation>Insert a Kuka IR125 into the document.</translation>
+      <translation>Vložit Kuka IR125 do dokumentu.</translation>
     </message>
   </context>
   <context>
     <name>CmdRobotInsertKukaIR16</name>
     <message>
+      <location line="-83"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Kuka IR16</source>
       <translation>Kuka IR16</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert a Kuka IR16 into the document.</source>
-      <translation>Insert a Kuka IR16 into the document.</translation>
+      <translation>Vložit Kuka IR16 do dokumentu.</translation>
     </message>
   </context>
   <context>
     <name>CmdRobotInsertKukaIR210</name>
     <message>
+      <location line="+39"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Kuka IR210</source>
       <translation>Kuka IR210</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert a Kuka IR210 into the document.</source>
-      <translation>Insert a Kuka IR210 into the document.</translation>
+      <translation>Vložit Kuka IR210 do dokumentu.</translation>
     </message>
   </context>
   <context>
     <name>CmdRobotInsertKukaIR500</name>
     <message>
+      <location line="-85"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Kuka IR500</source>
       <translation>Kuka IR500</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert a Kuka IR500 into the document.</source>
-      <translation>Insert a Kuka IR500 into the document.</translation>
+      <translation>Vložit Kuka IR500 do dokumentu.</translation>
     </message>
   </context>
   <context>
@@ -164,10 +189,12 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert in trajectory</source>
-      <translation>Insert in trajectory</translation>
+      <translation>Vložit do trajektorie</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert robot Tool location into trajectory</source>
       <translation>Insert robot Tool location into trajectory</translation>
     </message>
@@ -175,14 +202,17 @@
   <context>
     <name>CmdRobotInsertWaypointPreselect</name>
     <message>
+      <location line="+55"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert in trajectory</source>
-      <translation>Insert in trajectory</translation>
+      <translation>Vložit do trajektorie</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert preselection position into trajectory (W)</source>
       <translation>Insert preselection position into trajectory (W)</translation>
     </message>
@@ -195,8 +225,10 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+1"/>
       <source>Move to home</source>
-      <translation>Move to home</translation>
+      <translation>Posunout do počátku</translation>
     </message>
   </context>
   <context>
@@ -207,10 +239,12 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Set default orientation</source>
-      <translation>Set default orientation</translation>
+      <translation>Nastavit výchozí orientaci</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>set the default orientation for subsequent commands for waypoint creation</source>
       <translation>set the default orientation for subsequent commands for waypoint creation</translation>
     </message>
@@ -218,14 +252,17 @@
   <context>
     <name>CmdRobotSetDefaultValues</name>
     <message>
+      <location line="+37"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Set default values</source>
-      <translation>Set default values</translation>
+      <translation>Nastavit výchozí hodnoty</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>set the default values for speed, acceleration and continuity for subsequent commands of waypoint creation</source>
       <translation>set the default values for speed, acceleration and continuity for subsequent commands of waypoint creation</translation>
     </message>
@@ -238,6 +275,8 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+1"/>
       <source>Set the home position</source>
       <translation>Set the home position</translation>
     </message>
@@ -245,16 +284,19 @@
   <context>
     <name>CmdRobotSimulate</name>
     <message>
+      <location line="+142"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Simulate a trajectory</source>
-      <translation>Simulate a trajectory</translation>
+      <translation>Simulovat trajektorii</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Run a simulation on a trajectory</source>
-      <translation>Run a simulation on a trajectory</translation>
+      <translation>Spustit simulaci na trajektorii</translation>
     </message>
   </context>
   <context>
@@ -265,25 +307,30 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Trajectory compound...</source>
       <translation>Trajectory compound...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Group and connect some trajectories to one</source>
-      <translation>Group and connect some trajectories to one</translation>
+      <translation>Seskupit a propojit trajektorie do jedné</translation>
     </message>
   </context>
   <context>
     <name>CmdRobotTrajectoryDressUp</name>
     <message>
+      <location line="-49"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Dress up trajectory...</source>
       <translation>Dress up trajectory...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Create a dress up object which overide som aspects of a trajectory</source>
       <translation>Create a dress up object which overide som aspects of a trajectory</translation>
     </message>
@@ -293,48 +340,72 @@
     <message>
       <location filename="../../Workbench.cpp" line="+52"/>
       <source>Trajectory tools</source>
-      <translation>Trajectory tools</translation>
+      <translation>Nástroje trajektorie</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Robot tools</source>
-      <translation>Robot tools</translation>
+      <translation>Nástroje robota</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert Robot</source>
-      <translation>Insert Robot</translation>
+      <translation>Vložit Robota</translation>
     </message>
   </context>
   <context>
     <name>QObject</name>
     <message>
       <location filename="../../Command.cpp" line="-126"/>
+      <location line="+49"/>
+      <location line="+100"/>
+      <location line="+29"/>
+      <location filename="../../CommandExport.cpp" line="-52"/>
+      <location line="+65"/>
+      <location filename="../../CommandInsertRobot.cpp" line="+181"/>
+      <location filename="../../CommandTrajectory.cpp" line="-276"/>
+      <location line="+56"/>
+      <location line="+17"/>
+      <location line="+229"/>
       <source>Wrong selection</source>
       <translation>Neplatný výběr</translation>
     </message>
     <message>
+      <location line="-28"/>
+      <location line="+29"/>
+      <location filename="../../CommandExport.cpp" line="-64"/>
+      <location line="+65"/>
+      <location filename="../../CommandTrajectory.cpp" line="-301"/>
       <source>Select one Robot and one Trajectory object.</source>
       <translation>Select one Robot and one Trajectory object.</translation>
     </message>
     <message>
+      <location line="-24"/>
       <source>Trajectory not valid</source>
-      <translation>Trajectory not valid</translation>
+      <translation>Trajektorie není platná</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>You need at least two way points in a trajectory to simulate.</source>
       <translation>You need at least two way points in a trajectory to simulate.</translation>
     </message>
     <message>
       <location filename="../../CommandExport.cpp" line="-43"/>
+      <location line="+65"/>
       <source>KRL file(*.src)</source>
-      <translation>KRL file(*.src)</translation>
+      <translation>soubor KRL (*.src)</translation>
     </message>
     <message>
+      <location line="-64"/>
+      <location line="+65"/>
       <source>All Files (*.*)</source>
       <translation>Všechny soubory (*.*)</translation>
     </message>
     <message>
+      <location line="-64"/>
+      <location line="+65"/>
       <source>Export program</source>
-      <translation>Export program</translation>
+      <translation>Exportovat program</translation>
     </message>
     <message>
       <location filename="../../CommandInsertRobot.cpp" line="+1"/>
@@ -347,6 +418,7 @@
       <translation>No preselection</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>You have to hover above a geometry (Preselection) with the mouse to use this command. See documentation for details.</source>
       <translation>You have to hover above a geometry (Preselection) with the mouse to use this command. See documentation for details.</translation>
     </message>
@@ -356,39 +428,48 @@
       <translation>Select one Robot to set home postion</translation>
     </message>
     <message>
+      <location line="+49"/>
       <source>Select one Robot</source>
-      <translation>Select one Robot</translation>
+      <translation>Vyberte robota</translation>
     </message>
     <message>
       <location filename="../../CommandTrajectory.cpp" line="-24"/>
+      <location line="+17"/>
       <source>Select one Trajectory object.</source>
-      <translation>Select one Trajectory object.</translation>
+      <translation>Vyberte jeden objekt trajektorie.</translation>
     </message>
     <message>
+      <location line="+84"/>
       <source>set default speed</source>
-      <translation>set default speed</translation>
+      <translation>nastavit výchozí rychlost</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>speed: (e.g. 1 m/s or 3 cm/s)</source>
-      <translation>speed: (e.g. 1 m/s or 3 cm/s)</translation>
+      <translation>rychlost: (např. 1 m/s nebo 3 cm/s)</translation>
     </message>
     <message>
+      <location line="+9"/>
       <source>set default continuity</source>
       <translation>set default continuity</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>continuous ?</source>
-      <translation>continuous ?</translation>
+      <translation>kontinuální?</translation>
     </message>
     <message>
+      <location line="+6"/>
       <source>set default acceleration</source>
-      <translation>set default acceleration</translation>
+      <translation>nastavit výchozí zrychlení</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>acceleration: (e.g. 1 m/s^2 or 3 cm/s^2)</source>
-      <translation>acceleration: (e.g. 1 m/s^2 or 3 cm/s^2)</translation>
+      <translation>zrychlení: (např. 1 m/s^2 nebo 3 cm/s^2)</translation>
     </message>
     <message>
+      <location line="+127"/>
       <source>Select the Trajectory which you want to dress up.</source>
       <translation>Select the Trajectory which you want to dress up.</translation>
     </message>
@@ -398,8 +479,9 @@
       <translation>No robot files installed</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Please visit %1 and copy the files to %2</source>
-      <translation>Please visit %1 and copy the files to %2</translation>
+      <translation>Prosím, navštivte %1 a zkopírujte soubory do %2</translation>
     </message>
   </context>
   <context>
@@ -410,50 +492,62 @@
       <translation>Simulace</translation>
     </message>
     <message>
+      <location line="+38"/>
       <source>|&lt;</source>
       <translation>|&lt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>&lt;</source>
       <translation>&lt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>||</source>
       <translation>||</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>|&gt;</source>
       <translation>|&gt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>&gt;</source>
       <translation>&gt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>&gt;|</source>
       <translation>&gt;|</translation>
     </message>
     <message>
+      <location line="+24"/>
       <source>%</source>
       <translation>%</translation>
     </message>
     <message>
+      <location line="+35"/>
       <source>Type</source>
       <translation>Typ</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Name</source>
       <translation>Jméno</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>C</source>
       <translation>C</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>V</source>
       <translation>V</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>A</source>
       <translation>A</translation>
     </message>
@@ -474,38 +568,47 @@
       <translation>Návrh</translation>
     </message>
     <message>
+      <location line="+8"/>
       <source>A1</source>
       <translation>A1</translation>
     </message>
     <message>
+      <location line="+47"/>
       <source>A2</source>
       <translation>A2</translation>
     </message>
     <message>
+      <location line="+47"/>
       <source>A3</source>
       <translation>A3</translation>
     </message>
     <message>
+      <location line="+47"/>
       <source>A4</source>
       <translation>A4</translation>
     </message>
     <message>
+      <location line="+47"/>
       <source>A5</source>
       <translation>A5</translation>
     </message>
     <message>
+      <location line="+47"/>
       <source>A6</source>
       <translation>A6</translation>
     </message>
     <message>
+      <location line="+57"/>
       <source>TCP: (200.23,300.23,400.23,234,343,343)</source>
       <translation>TCP: (200.23,300.23,400.23,234,343,343)</translation>
     </message>
     <message>
+      <location line="+17"/>
       <source>Tool: (0,0,400,0,0,0)</source>
-      <translation>Tool: (0,0,400,0,0,0)</translation>
+      <translation>Nástroj: (0,0,400,0,0,0)</translation>
     </message>
     <message>
+      <location line="+16"/>
       <source>...</source>
       <translation>...</translation>
     </message>
@@ -539,74 +642,92 @@
       <translation>Návrh</translation>
     </message>
     <message>
+      <location line="+38"/>
       <source>|&lt;</source>
       <translation>|&lt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>&lt;</source>
       <translation>&lt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>||</source>
       <translation>||</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>|&gt;</source>
       <translation>|&gt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>&gt;</source>
       <translation>&gt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>&gt;|</source>
       <translation>&gt;|</translation>
     </message>
     <message>
+      <location line="+24"/>
       <source>%</source>
       <translation>%</translation>
     </message>
     <message>
+      <location line="+17"/>
       <source>10 ms</source>
       <translation>10 ms</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>50 ms</source>
       <translation>50 ms</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>100 ms</source>
       <translation>100 ms</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>500 ms</source>
       <translation>500 ms</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>1 s</source>
       <translation>1 s</translation>
     </message>
     <message>
+      <location line="+18"/>
       <source>Pos: (200.23, 300.23, 400.23, 234, 343 ,343)</source>
       <translation>Pos: (200.23, 300.23, 400.23, 234, 343 ,343)</translation>
     </message>
     <message>
+      <location line="+26"/>
       <source>Type</source>
       <translation>Typ</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Name</source>
       <translation>Jméno</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>C</source>
       <translation>C</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>V</source>
       <translation>V</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>A</source>
       <translation>A</translation>
     </message>
@@ -632,35 +753,40 @@
       <translation>Návrh</translation>
     </message>
     <message>
+      <location line="+15"/>
       <source>Hide / Show</source>
       <translation>Skrýt / Zobrazit</translation>
     </message>
     <message>
+      <location line="+18"/>
       <source>Edges: 0</source>
-      <translation>Edges: 0</translation>
+      <translation>Hran: 0</translation>
     </message>
     <message>
+      <location line="+14"/>
       <source>Cluster: 0</source>
       <translation>Cluster: 0</translation>
     </message>
     <message>
+      <location line="+11"/>
       <source>Sizing Value:</source>
       <translation>Sizing Value:</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>Use orientation of edge</source>
-      <translation>Use orientation of edge</translation>
+      <translation>Použít orientaci hrany</translation>
     </message>
     <message>
       <source>TaskEdge2TracParameter</source>
-      <translation>TaskEdge2TracParameter</translation>
+      <translation type="obsolete">TaskEdge2TracParameter</translation>
     </message>
   </context>
   <context>
     <name>TaskRobot6Axis</name>
     <message>
       <source>TaskRobot6Axis</source>
-      <translation>TaskRobot6Axis</translation>
+      <translation type="obsolete">TaskRobot6Axis</translation>
     </message>
   </context>
   <context>
@@ -671,96 +797,118 @@
       <translation>Návrh</translation>
     </message>
     <message>
+      <location line="+23"/>
       <source>X+</source>
       <translation>X+</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>Y+</source>
       <translation>Y+</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>Z+</source>
       <translation>Z+</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>A+</source>
       <translation>A+</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>B+</source>
       <translation>B+</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>C+</source>
       <translation>C+</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>X-</source>
       <translation>X-</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>Y-</source>
       <translation>Y-</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>Z-</source>
       <translation>Z-</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>A-</source>
       <translation>A-</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>B-</source>
       <translation>B-</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>C-</source>
       <translation>C-</translation>
     </message>
     <message>
+      <location line="+12"/>
       <source>Tool 0</source>
-      <translation>Tool 0</translation>
+      <translation>Nástroj 0</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Tool</source>
-      <translation>Tool</translation>
+      <translation>Nástroj</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Base 0</source>
       <translation>Base 0</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Base</source>
-      <translation>Base</translation>
+      <translation>Základna</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>World</source>
       <translation>World</translation>
     </message>
-    <message>
+    <message utf8="true">
+      <location line="+9"/>
       <source>50mm / 5°</source>
       <translation>50mm / 5°</translation>
     </message>
-    <message>
+    <message utf8="true">
+      <location line="+5"/>
       <source>20mm / 2°</source>
       <translation>20mm / 2°</translation>
     </message>
-    <message>
+    <message utf8="true">
+      <location line="+5"/>
       <source>10mm / 1°</source>
       <translation>10mm / 1°</translation>
     </message>
-    <message>
+    <message utf8="true">
+      <location line="+5"/>
       <source>5mm / 0.5°</source>
       <translation>5mm / 0.5°</translation>
     </message>
-    <message>
+    <message utf8="true">
+      <location line="+5"/>
       <source>1mm / 0.1°</source>
       <translation>1mm / 0.1°</translation>
     </message>
     <message>
       <source>TaskRobotControl</source>
-      <translation>TaskRobotControl</translation>
+      <translation type="obsolete">TaskRobotControl</translation>
     </message>
   </context>
   <context>
@@ -771,19 +919,20 @@
       <translation>Návrh</translation>
     </message>
     <message>
+      <location line="+6"/>
       <source>clear</source>
-      <translation>clear</translation>
+      <translation>vymazat</translation>
     </message>
     <message>
       <source>TaskRobotMessages</source>
-      <translation>TaskRobotMessages</translation>
+      <translation type="obsolete">TaskRobotMessages</translation>
     </message>
   </context>
   <context>
     <name>TaskTrajectory</name>
     <message>
       <source>Trajectory</source>
-      <translation>Trajectory</translation>
+      <translation type="obsolete">Trajectory</translation>
     </message>
   </context>
   <context>
@@ -794,64 +943,79 @@
       <translation>Návrh</translation>
     </message>
     <message>
+      <location line="+6"/>
       <source>Speed &amp; Acceleration:</source>
-      <translation>Speed &amp; Acceleration:</translation>
+      <translation>Rychlost &amp; zrychlení:</translation>
     </message>
     <message>
+      <location line="+9"/>
       <source>Speed:</source>
       <translation>Rychlost:</translation>
     </message>
     <message>
+      <location line="+26"/>
+      <location line="+37"/>
       <source>Use</source>
       <translation>Použití</translation>
     </message>
     <message>
+      <location line="-26"/>
       <source>Accel:</source>
       <translation>Accel:</translation>
     </message>
     <message>
+      <location line="+36"/>
       <source>Don't change Cont</source>
       <translation>Don't change Cont</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Continues</source>
-      <translation>Continues</translation>
+      <translation>Pokračuje</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Discontinues</source>
-      <translation>Discontinues</translation>
+      <translation>Nepokračuje</translation>
     </message>
     <message>
+      <location line="+15"/>
       <source>Position and Orientation:</source>
-      <translation>Position and Orientation:</translation>
+      <translation>Umístění a orientace:</translation>
     </message>
     <message>
+      <location line="+9"/>
       <source>(0,0,0),(0,0,0)</source>
       <translation>(0,0,0),(0,0,0)</translation>
     </message>
     <message>
+      <location line="+13"/>
       <source>...</source>
       <translation>...</translation>
     </message>
     <message>
+      <location line="+10"/>
       <source>Don't change Position &amp; Orientation</source>
-      <translation>Don't change Position &amp; Orientation</translation>
+      <translation>Neměňte polohu a orientaci</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Use Orientation</source>
-      <translation>Use Orientation</translation>
+      <translation>Použít orientaci</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Add Position</source>
-      <translation>Add Position</translation>
+      <translation>Přidat pozici</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Add Orientation</source>
-      <translation>Add Orientation</translation>
+      <translation>Přidat orientaci</translation>
     </message>
     <message>
       <source>Dress Up Parameter</source>
-      <translation>Dress Up Parameter</translation>
+      <translation type="obsolete">Dress Up Parameter</translation>
     </message>
   </context>
   <context>
@@ -862,16 +1026,19 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert Robots</source>
-      <translation>Insert Robots</translation>
+      <translation>Vložit Robota</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>&amp;Robot</source>
       <translation>&amp;Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Export trajectory</source>
-      <translation>Export trajectory</translation>
+      <translation>Exportovat trajektorii</translation>
     </message>
   </context>
 </TS>
