@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS>
+<TS version="2.0" language="fr" sourcelanguage="en">
   <context>
     <name>CmdRobotAddToolShape</name>
     <message>
@@ -9,10 +9,12 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Add tool</source>
       <translation>Ajouter l'outil</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Add a tool shape to the robot</source>
       <translation>Ajouter une forme d'outil pour le robot</translation>
     </message>
@@ -25,10 +27,12 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Place robot...</source>
       <translation>Placer un robot...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Place a robot (experimental!)</source>
       <translation>Placez un robot (expérimental !)</translation>
     </message>
@@ -41,10 +45,12 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Create trajectory</source>
       <translation>Créer une trajectoire</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Create a new empty trajectory </source>
       <translation>Créer une nouvelle trajectoire vide </translation>
     </message>
@@ -52,14 +58,17 @@
   <context>
     <name>CmdRobotEdge2Trac</name>
     <message>
+      <location line="+257"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Edge to Trajectory...</source>
       <translation>Arête vers trajectoire ...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Generate a Trajectory from a set of edges</source>
       <translation>Générer une trajectoire à partir d'un ensemble d'arêtes</translation>
     </message>
@@ -72,10 +81,12 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Kuka compact subroutine...</source>
       <translation>sous-programme compressé Kuka...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Export the trajectory as a compact KRL subroutine.</source>
       <translation>Exporter la trajectoire comme un sous-programme compressé KRL.</translation>
     </message>
@@ -83,14 +94,17 @@
   <context>
     <name>CmdRobotExportKukaFull</name>
     <message>
+      <location line="+63"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Kuka full subroutine...</source>
       <translation>sous-programme complet Kuka...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Export the trajectory as a full KRL subroutine.</source>
       <translation>Exporter la trajectoire comme un sous-programme KRL intégral.</translation>
     </message>
@@ -103,10 +117,12 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Kuka IR125</source>
       <translation>Kuka IR125</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert a Kuka IR125 into the document.</source>
       <translation>Insérer un IR125 Kuka dans le document.</translation>
     </message>
@@ -114,14 +130,17 @@
   <context>
     <name>CmdRobotInsertKukaIR16</name>
     <message>
+      <location line="-83"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Kuka IR16</source>
       <translation>Kuka IR16</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert a Kuka IR16 into the document.</source>
       <translation>Insérer un IR500 Kuka dans le document.</translation>
     </message>
@@ -129,14 +148,17 @@
   <context>
     <name>CmdRobotInsertKukaIR210</name>
     <message>
+      <location line="+39"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Kuka IR210</source>
       <translation>Kuka IR210</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert a Kuka IR210 into the document.</source>
       <translation>Insérer un IR210 Kuka dans le document.</translation>
     </message>
@@ -144,14 +166,17 @@
   <context>
     <name>CmdRobotInsertKukaIR500</name>
     <message>
+      <location line="-85"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Kuka IR500</source>
       <translation>Kuka IR500</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert a Kuka IR500 into the document.</source>
       <translation>Insérer un IR500 Kuka dans le document.</translation>
     </message>
@@ -164,10 +189,12 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert in trajectory</source>
       <translation>Insérer dans la trajectoire</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert robot Tool location into trajectory</source>
       <translation>Insérer la position de l'outil robot dans la trajectoire</translation>
     </message>
@@ -175,14 +202,17 @@
   <context>
     <name>CmdRobotInsertWaypointPreselect</name>
     <message>
+      <location line="+55"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert in trajectory</source>
       <translation>Insérer dans la trajectoire</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert preselection position into trajectory (W)</source>
       <translation>Insérer la position de la présélection dans la trajectoire (W)</translation>
     </message>
@@ -195,6 +225,8 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+1"/>
       <source>Move to home</source>
       <translation>Passer à la position de départ</translation>
     </message>
@@ -207,10 +239,12 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Set default orientation</source>
       <translation>Définir l'orientation par défaut</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>set the default orientation for subsequent commands for waypoint creation</source>
       <translation>Définir l'orientation par défaut pour les commandes suivantes pour la création de points de passage</translation>
     </message>
@@ -218,14 +252,17 @@
   <context>
     <name>CmdRobotSetDefaultValues</name>
     <message>
+      <location line="+37"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Set default values</source>
       <translation>Définir les valeurs par défaut</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>set the default values for speed, acceleration and continuity for subsequent commands of waypoint creation</source>
       <translation>Définir les valeurs par défaut pour la vitesse, l'accélération et la continuité pour les commandes de création de points de passage suivants</translation>
     </message>
@@ -238,6 +275,8 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+1"/>
       <source>Set the home position</source>
       <translation>Définir la position de départ</translation>
     </message>
@@ -245,14 +284,17 @@
   <context>
     <name>CmdRobotSimulate</name>
     <message>
+      <location line="+142"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Simulate a trajectory</source>
       <translation>Simuler une trajectoire</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Run a simulation on a trajectory</source>
       <translation>Lancer une simulation sur une trajectoire</translation>
     </message>
@@ -265,10 +307,12 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Trajectory compound...</source>
       <translation>Composé de trajectoire...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Group and connect some trajectories to one</source>
       <translation>Grouper et connecter des trajectoires en une seule</translation>
     </message>
@@ -276,14 +320,17 @@
   <context>
     <name>CmdRobotTrajectoryDressUp</name>
     <message>
+      <location line="-49"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Dress up trajectory...</source>
       <translation>Habiller une trajectoire...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Create a dress up object which overide som aspects of a trajectory</source>
       <translation>Créer un habillage qui supplante certains aspects d'une trajectoire</translation>
     </message>
@@ -296,10 +343,12 @@
       <translation>Outils de trajectoire</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Robot tools</source>
       <translation>Outils de robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert Robot</source>
       <translation>Insérer un robot</translation>
     </message>
@@ -308,31 +357,53 @@
     <name>QObject</name>
     <message>
       <location filename="../../Command.cpp" line="-126"/>
+      <location line="+49"/>
+      <location line="+100"/>
+      <location line="+29"/>
+      <location filename="../../CommandExport.cpp" line="-52"/>
+      <location line="+65"/>
+      <location filename="../../CommandInsertRobot.cpp" line="+181"/>
+      <location filename="../../CommandTrajectory.cpp" line="-276"/>
+      <location line="+56"/>
+      <location line="+17"/>
+      <location line="+229"/>
       <source>Wrong selection</source>
       <translation>Mauvaise sélection</translation>
     </message>
     <message>
+      <location line="-28"/>
+      <location line="+29"/>
+      <location filename="../../CommandExport.cpp" line="-64"/>
+      <location line="+65"/>
+      <location filename="../../CommandTrajectory.cpp" line="-301"/>
       <source>Select one Robot and one Trajectory object.</source>
       <translation>Sélectionnez un robot et une trajectoire.</translation>
     </message>
     <message>
+      <location line="-24"/>
       <source>Trajectory not valid</source>
       <translation>Trajectoire non valide</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>You need at least two way points in a trajectory to simulate.</source>
       <translation>Vous avez besoin d'au moins deux points sur une trajectoire pour la simulation.</translation>
     </message>
     <message>
       <location filename="../../CommandExport.cpp" line="-43"/>
+      <location line="+65"/>
       <source>KRL file(*.src)</source>
       <translation>fichier KRL (*. src)</translation>
     </message>
     <message>
+      <location line="-64"/>
+      <location line="+65"/>
       <source>All Files (*.*)</source>
       <translation>Tous les fichiers (*.*)</translation>
     </message>
     <message>
+      <location line="-64"/>
+      <location line="+65"/>
       <source>Export program</source>
       <translation>Exporter le programme</translation>
     </message>
@@ -347,6 +418,7 @@
       <translation>Aucune présélection</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>You have to hover above a geometry (Preselection) with the mouse to use this command. See documentation for details.</source>
       <translation>Avec la souris, vous devez passer au-dessus d'une géométrie (présélection)
 pour utiliser cette commande. Consultez la documentation pour plus de détails.</translation>
@@ -357,39 +429,48 @@ pour utiliser cette commande. Consultez la documentation pour plus de détails.<
       <translation>Sélectionnez un robot pour définir la position d'origine</translation>
     </message>
     <message>
+      <location line="+49"/>
       <source>Select one Robot</source>
       <translation>Sélectionnez un robot</translation>
     </message>
     <message>
       <location filename="../../CommandTrajectory.cpp" line="-24"/>
+      <location line="+17"/>
       <source>Select one Trajectory object.</source>
       <translation>Sélectionnez un objet de trajectoire.</translation>
     </message>
     <message>
+      <location line="+84"/>
       <source>set default speed</source>
       <translation>définir la vitesse par défaut</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>speed: (e.g. 1 m/s or 3 cm/s)</source>
       <translation>Vitesse : (par exemple 1 m/s ou 3 cm/s)</translation>
     </message>
     <message>
+      <location line="+9"/>
       <source>set default continuity</source>
       <translation>définir la continuité par défaut</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>continuous ?</source>
       <translation>en continu ?</translation>
     </message>
     <message>
+      <location line="+6"/>
       <source>set default acceleration</source>
       <translation>définir l'accélération par défaut</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>acceleration: (e.g. 1 m/s^2 or 3 cm/s^2)</source>
       <translation>accélération : (p.ex. 1 m/s^2 or 3 cm/s^2)</translation>
     </message>
     <message>
+      <location line="+127"/>
       <source>Select the Trajectory which you want to dress up.</source>
       <translation>Sélectionnez la trajectoire que vous voulez habiller.</translation>
     </message>
@@ -399,6 +480,7 @@ pour utiliser cette commande. Consultez la documentation pour plus de détails.<
       <translation>Aucun fichier de robot installé</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Please visit %1 and copy the files to %2</source>
       <translation>Visitez %1 et copiez les fichiers vers %2</translation>
     </message>
@@ -411,50 +493,62 @@ pour utiliser cette commande. Consultez la documentation pour plus de détails.<
       <translation>Simulation</translation>
     </message>
     <message>
+      <location line="+38"/>
       <source>|&lt;</source>
       <translation>|&lt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>&lt;</source>
       <translation>&lt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>||</source>
       <translation>||</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>|&gt;</source>
       <translation>|&gt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>&gt;</source>
       <translation>&gt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>&gt;|</source>
       <translation>&gt;|</translation>
     </message>
     <message>
+      <location line="+24"/>
       <source>%</source>
       <translation>%</translation>
     </message>
     <message>
+      <location line="+35"/>
       <source>Type</source>
       <translation>Type</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Name</source>
       <translation>Nom</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>C</source>
       <translation>C</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>V</source>
       <translation>V</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>A</source>
       <translation>A</translation>
     </message>
@@ -475,38 +569,47 @@ pour utiliser cette commande. Consultez la documentation pour plus de détails.<
       <translation>Formulaire</translation>
     </message>
     <message>
+      <location line="+8"/>
       <source>A1</source>
       <translation>A1</translation>
     </message>
     <message>
+      <location line="+47"/>
       <source>A2</source>
       <translation>A2</translation>
     </message>
     <message>
+      <location line="+47"/>
       <source>A3</source>
       <translation>A3</translation>
     </message>
     <message>
+      <location line="+47"/>
       <source>A4</source>
       <translation>A4</translation>
     </message>
     <message>
+      <location line="+47"/>
       <source>A5</source>
       <translation>A5</translation>
     </message>
     <message>
+      <location line="+47"/>
       <source>A6</source>
       <translation>A6</translation>
     </message>
     <message>
+      <location line="+57"/>
       <source>TCP: (200.23,300.23,400.23,234,343,343)</source>
       <translation>TCP : (200.23,300.23,400.23,234,343,343)</translation>
     </message>
     <message>
+      <location line="+17"/>
       <source>Tool: (0,0,400,0,0,0)</source>
       <translation>Outil : (0,0,400,0,0,0)</translation>
     </message>
     <message>
+      <location line="+16"/>
       <source>...</source>
       <translation>...</translation>
     </message>
@@ -540,74 +643,92 @@ pour utiliser cette commande. Consultez la documentation pour plus de détails.<
       <translation>Formulaire</translation>
     </message>
     <message>
+      <location line="+38"/>
       <source>|&lt;</source>
       <translation>|&lt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>&lt;</source>
       <translation>&lt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>||</source>
       <translation>||</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>|&gt;</source>
       <translation>|&gt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>&gt;</source>
       <translation>&gt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>&gt;|</source>
       <translation>&gt;|</translation>
     </message>
     <message>
+      <location line="+24"/>
       <source>%</source>
       <translation>%</translation>
     </message>
     <message>
+      <location line="+17"/>
       <source>10 ms</source>
       <translation>10 ms</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>50 ms</source>
       <translation>50 ms</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>100 ms</source>
       <translation>100 ms</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>500 ms</source>
       <translation>500 ms</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>1 s</source>
       <translation>1 s</translation>
     </message>
     <message>
+      <location line="+18"/>
       <source>Pos: (200.23, 300.23, 400.23, 234, 343 ,343)</source>
       <translation>Pos : (200.23, 300.23, 400.23, 234, 343, 343)</translation>
     </message>
     <message>
+      <location line="+26"/>
       <source>Type</source>
       <translation>Type</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Name</source>
       <translation>Nom</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>C</source>
       <translation>C</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>V</source>
       <translation>V</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>A</source>
       <translation>A</translation>
     </message>
@@ -633,35 +754,40 @@ pour utiliser cette commande. Consultez la documentation pour plus de détails.<
       <translation>Formulaire</translation>
     </message>
     <message>
+      <location line="+15"/>
       <source>Hide / Show</source>
       <translation>Afficher / Masquer</translation>
     </message>
     <message>
+      <location line="+18"/>
       <source>Edges: 0</source>
       <translation>Arêtes : 0</translation>
     </message>
     <message>
+      <location line="+14"/>
       <source>Cluster: 0</source>
       <translation>Groupe : 0</translation>
     </message>
     <message>
+      <location line="+11"/>
       <source>Sizing Value:</source>
       <translation>Valeur de dimensionnement :</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>Use orientation of edge</source>
       <translation>Utiliser l'orientation de l'arête</translation>
     </message>
     <message>
       <source>TaskEdge2TracParameter</source>
-      <translation>TaskEdge2TracParameter</translation>
+      <translation type="obsolete">TaskEdge2TracParameter</translation>
     </message>
   </context>
   <context>
     <name>TaskRobot6Axis</name>
     <message>
       <source>TaskRobot6Axis</source>
-      <translation>TaskRobot6Axis</translation>
+      <translation type="obsolete">TaskRobot6Axis</translation>
     </message>
   </context>
   <context>
@@ -672,96 +798,118 @@ pour utiliser cette commande. Consultez la documentation pour plus de détails.<
       <translation>Formulaire</translation>
     </message>
     <message>
+      <location line="+23"/>
       <source>X+</source>
       <translation>X+</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>Y+</source>
       <translation>Y+</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>Z+</source>
       <translation>Z+</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>A+</source>
       <translation>A+</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>B+</source>
       <translation>B+</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>C+</source>
       <translation>C+</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>X-</source>
       <translation>X-</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>Y-</source>
       <translation>Y-</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>Z-</source>
       <translation>Z-</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>A-</source>
       <translation>A-</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>B-</source>
       <translation>B-</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>C-</source>
       <translation>C-</translation>
     </message>
     <message>
+      <location line="+12"/>
       <source>Tool 0</source>
       <translation>Outil 0</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Tool</source>
       <translation>Outil</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Base 0</source>
       <translation>Base 0</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Base</source>
       <translation>Base</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>World</source>
       <translation>Monde</translation>
     </message>
-    <message>
+    <message utf8="true">
+      <location line="+9"/>
       <source>50mm / 5°</source>
       <translation>50mm / 5°</translation>
     </message>
-    <message>
+    <message utf8="true">
+      <location line="+5"/>
       <source>20mm / 2°</source>
       <translation>20mm / 2°</translation>
     </message>
-    <message>
+    <message utf8="true">
+      <location line="+5"/>
       <source>10mm / 1°</source>
       <translation>10mm / 1°</translation>
     </message>
-    <message>
+    <message utf8="true">
+      <location line="+5"/>
       <source>5mm / 0.5°</source>
       <translation>5mm / 0,5°</translation>
     </message>
-    <message>
+    <message utf8="true">
+      <location line="+5"/>
       <source>1mm / 0.1°</source>
       <translation>1mm / 0,1°</translation>
     </message>
     <message>
       <source>TaskRobotControl</source>
-      <translation>TaskRobotControl</translation>
+      <translation type="obsolete">TaskRobotControl</translation>
     </message>
   </context>
   <context>
@@ -772,19 +920,20 @@ pour utiliser cette commande. Consultez la documentation pour plus de détails.<
       <translation>Formulaire</translation>
     </message>
     <message>
+      <location line="+6"/>
       <source>clear</source>
       <translation>Effacer</translation>
     </message>
     <message>
       <source>TaskRobotMessages</source>
-      <translation>TaskRobotMessages</translation>
+      <translation type="obsolete">TaskRobotMessages</translation>
     </message>
   </context>
   <context>
     <name>TaskTrajectory</name>
     <message>
       <source>Trajectory</source>
-      <translation>Trajectoire</translation>
+      <translation type="obsolete">Trajectoire</translation>
     </message>
   </context>
   <context>
@@ -795,64 +944,79 @@ pour utiliser cette commande. Consultez la documentation pour plus de détails.<
       <translation>Formulaire</translation>
     </message>
     <message>
+      <location line="+6"/>
       <source>Speed &amp; Acceleration:</source>
       <translation>Vitesse et accélération :</translation>
     </message>
     <message>
+      <location line="+9"/>
       <source>Speed:</source>
       <translation>Vitesse :</translation>
     </message>
     <message>
+      <location line="+26"/>
+      <location line="+37"/>
       <source>Use</source>
       <translation>Utilisation</translation>
     </message>
     <message>
+      <location line="-26"/>
       <source>Accel:</source>
       <translation>Accél :</translation>
     </message>
     <message>
+      <location line="+36"/>
       <source>Don't change Cont</source>
       <translation>Ne pas changer Cont</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Continues</source>
       <translation>Continu</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Discontinues</source>
       <translation>Interrompt</translation>
     </message>
     <message>
+      <location line="+15"/>
       <source>Position and Orientation:</source>
       <translation>Position et orientation :</translation>
     </message>
     <message>
+      <location line="+9"/>
       <source>(0,0,0),(0,0,0)</source>
       <translation>(0,0,0),(0,0,0)</translation>
     </message>
     <message>
+      <location line="+13"/>
       <source>...</source>
       <translation>...</translation>
     </message>
     <message>
+      <location line="+10"/>
       <source>Don't change Position &amp; Orientation</source>
       <translation>Ne pas changer la position ni l'orientation</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Use Orientation</source>
       <translation>Utiliser l'orientation</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Add Position</source>
       <translation>Ajouter la position</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Add Orientation</source>
       <translation>Ajouter l'orientation</translation>
     </message>
     <message>
       <source>Dress Up Parameter</source>
-      <translation>Paramètre d'habillage</translation>
+      <translation type="obsolete">Paramètre d'habillage</translation>
     </message>
   </context>
   <context>
@@ -863,14 +1027,17 @@ pour utiliser cette commande. Consultez la documentation pour plus de détails.<
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert Robots</source>
       <translation>Insérer des robots</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>&amp;Robot</source>
       <translation>&amp;Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Export trajectory</source>
       <translation>Exporter la trajectoire</translation>
     </message>
