@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS>
+<TS version="2.0" language="ja" sourcelanguage="en">
   <context>
     <name>CmdRobotAddToolShape</name>
     <message>
@@ -9,12 +9,14 @@
       <translation>ロボット</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Add tool</source>
       <translation>ツールを追加</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Add a tool shape to the robot</source>
-      <translation>Add a tool shape to the robot</translation>
+      <translation>工具のシェイプをロボットに追加</translation>
     </message>
   </context>
   <context>
@@ -25,12 +27,14 @@
       <translation>ロボット</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Place robot...</source>
       <translation>ロボットを配置...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Place a robot (experimental!)</source>
-      <translation>ロボットを配置（experimental!）</translation>
+      <translation>ロボットを配置（テスト中!）</translation>
     </message>
   </context>
   <context>
@@ -41,10 +45,12 @@
       <translation>ロボット</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Create trajectory</source>
       <translation>軌跡を作成</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Create a new empty trajectory </source>
       <translation>新しい空の軌跡を作成</translation>
     </message>
@@ -52,16 +58,19 @@
   <context>
     <name>CmdRobotEdge2Trac</name>
     <message>
+      <location line="+257"/>
       <source>Robot</source>
       <translation>ロボット</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Edge to Trajectory...</source>
-      <translation>Edge to Trajectory...</translation>
+      <translation>エッジから起動へ...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Generate a Trajectory from a set of edges</source>
-      <translation>Generate a Trajectory from a set of edges</translation>
+      <translation>エッジから軌道を生成</translation>
     </message>
   </context>
   <context>
@@ -72,27 +81,32 @@
       <translation>ロボット</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Kuka compact subroutine...</source>
-      <translation>Kuka compact subroutine...</translation>
+      <translation>Kukaのコンパクトサブルーチン...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Export the trajectory as a compact KRL subroutine.</source>
-      <translation>Export the trajectory as a compact KRL subroutine.</translation>
+      <translation>軌道をコンパクトKRLサブルーチンとしてエクスポート</translation>
     </message>
   </context>
   <context>
     <name>CmdRobotExportKukaFull</name>
     <message>
+      <location line="+63"/>
       <source>Robot</source>
       <translation>ロボット</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Kuka full subroutine...</source>
-      <translation>Kuka full subroutine...</translation>
+      <translation>Kukaのフルサブルーチン...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Export the trajectory as a full KRL subroutine.</source>
-      <translation>Export the trajectory as a full KRL subroutine.</translation>
+      <translation>軌道をフルKRLサブルーチンとしてエクスポート</translation>
     </message>
   </context>
   <context>
@@ -103,57 +117,68 @@
       <translation>ロボット</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Kuka IR125</source>
       <translation>Kuka IR125</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert a Kuka IR125 into the document.</source>
-      <translation>Kuka IR125　を挿入.</translation>
+      <translation>Kuka IR125をドキュメントに挿入.</translation>
     </message>
   </context>
   <context>
     <name>CmdRobotInsertKukaIR16</name>
     <message>
+      <location line="-83"/>
       <source>Robot</source>
       <translation>ロボット</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Kuka IR16</source>
       <translation>Kuka IR16</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert a Kuka IR16 into the document.</source>
-      <translation>Kuka IR16　を挿入</translation>
+      <translation>Kuka IR16をドキュメントに挿入</translation>
     </message>
   </context>
   <context>
     <name>CmdRobotInsertKukaIR210</name>
     <message>
+      <location line="+39"/>
       <source>Robot</source>
       <translation>ロボット</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Kuka IR210</source>
       <translation>Kuka IR210</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert a Kuka IR210 into the document.</source>
-      <translation>Kuka IR210　を挿入.</translation>
+      <translation>Kuka IR210をドキュメントに挿入</translation>
     </message>
   </context>
   <context>
     <name>CmdRobotInsertKukaIR500</name>
     <message>
+      <location line="-85"/>
       <source>Robot</source>
       <translation>ロボット</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Kuka IR500</source>
       <translation>Kuka IR500</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert a Kuka IR500 into the document.</source>
-      <translation>Kuka IR500　を挿入.</translation>
+      <translation>Kuka IR500をドキュメントに挿入</translation>
     </message>
   </context>
   <context>
@@ -164,27 +189,32 @@
       <translation>ロボット</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert in trajectory</source>
-      <translation>Insert in trajectory</translation>
+      <translation>軌道に挿入</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert robot Tool location into trajectory</source>
-      <translation>Insert robot Tool location into trajectory</translation>
+      <translation>軌道にロボットツール位置を挿入</translation>
     </message>
   </context>
   <context>
     <name>CmdRobotInsertWaypointPreselect</name>
     <message>
+      <location line="+55"/>
       <source>Robot</source>
       <translation>ロボット</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert in trajectory</source>
-      <translation>Insert in trajectory</translation>
+      <translation>軌道に挿入</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert preselection position into trajectory (W)</source>
-      <translation>Insert preselection position into trajectory (W)</translation>
+      <translation>プリセレクション位置を軌道に挿入 (W)</translation>
     </message>
   </context>
   <context>
@@ -195,6 +225,8 @@
       <translation>ロボット</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+1"/>
       <source>Move to home</source>
       <translation>ホームへ移動</translation>
     </message>
@@ -207,27 +239,32 @@
       <translation>ロボット</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Set default orientation</source>
       <translation>デフォルトの向きを設定</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>set the default orientation for subsequent commands for waypoint creation</source>
-      <translation>set the default orientation for subsequent commands for waypoint creation</translation>
+      <translation>以降の通過点作成用コマンドのデフォルト方向を設定</translation>
     </message>
   </context>
   <context>
     <name>CmdRobotSetDefaultValues</name>
     <message>
+      <location line="+37"/>
       <source>Robot</source>
       <translation>ロボット</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Set default values</source>
       <translation>デフォルト値を設定する</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>set the default values for speed, acceleration and continuity for subsequent commands of waypoint creation</source>
-      <translation>set the default values for speed, acceleration and continuity for subsequent commands of waypoint creation</translation>
+      <translation>以降の通過点作成用コマンドで使用される速度、加速度、連続性のデフォルト値を設定</translation>
     </message>
   </context>
   <context>
@@ -238,6 +275,8 @@
       <translation>ロボット</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+1"/>
       <source>Set the home position</source>
       <translation>ホームポジションを設定</translation>
     </message>
@@ -245,14 +284,17 @@
   <context>
     <name>CmdRobotSimulate</name>
     <message>
+      <location line="+142"/>
       <source>Robot</source>
       <translation>ロボット</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Simulate a trajectory</source>
       <translation>軌道をシミュレート</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Run a simulation on a trajectory</source>
       <translation>軌道のシミュレーションを実行</translation>
     </message>
@@ -265,27 +307,32 @@
       <translation>ロボット</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Trajectory compound...</source>
-      <translation>Trajectory compound...</translation>
+      <translation>軌道を合成...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Group and connect some trajectories to one</source>
-      <translation>Group and connect some trajectories to one</translation>
+      <translation>複数の軌道を一つに連結してグループ化</translation>
     </message>
   </context>
   <context>
     <name>CmdRobotTrajectoryDressUp</name>
     <message>
+      <location line="-49"/>
       <source>Robot</source>
       <translation>ロボット</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Dress up trajectory...</source>
-      <translation>Dress up trajectory...</translation>
+      <translation>軌道をドレスアップ...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Create a dress up object which overide som aspects of a trajectory</source>
-      <translation>Create a dress up object which overide som aspects of a trajectory</translation>
+      <translation>軌道のいくつかのプロパティーをオーバーライドしたドレスアップオブジェクトを作成</translation>
     </message>
   </context>
   <context>
@@ -296,10 +343,12 @@
       <translation>軌道ツール</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Robot tools</source>
       <translation>ロボットツール</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert Robot</source>
       <translation>ロボットを挿入</translation>
     </message>
@@ -308,31 +357,53 @@
     <name>QObject</name>
     <message>
       <location filename="../../Command.cpp" line="-126"/>
+      <location line="+49"/>
+      <location line="+100"/>
+      <location line="+29"/>
+      <location filename="../../CommandExport.cpp" line="-52"/>
+      <location line="+65"/>
+      <location filename="../../CommandInsertRobot.cpp" line="+181"/>
+      <location filename="../../CommandTrajectory.cpp" line="-276"/>
+      <location line="+56"/>
+      <location line="+17"/>
+      <location line="+229"/>
       <source>Wrong selection</source>
       <translation>誤った選択</translation>
     </message>
     <message>
+      <location line="-28"/>
+      <location line="+29"/>
+      <location filename="../../CommandExport.cpp" line="-64"/>
+      <location line="+65"/>
+      <location filename="../../CommandTrajectory.cpp" line="-301"/>
       <source>Select one Robot and one Trajectory object.</source>
-      <translation>Select one Robot and one Trajectory object.</translation>
+      <translation>1 つのロボットと軌道オブジェクトを 1 つ選択します。</translation>
     </message>
     <message>
+      <location line="-24"/>
       <source>Trajectory not valid</source>
       <translation>軌道が無効です。</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>You need at least two way points in a trajectory to simulate.</source>
-      <translation>You need at least two way points in a trajectory to simulate.</translation>
+      <translation>シミュレートするためには軌道内に少なくとも2つのway pointが必要です。</translation>
     </message>
     <message>
       <location filename="../../CommandExport.cpp" line="-43"/>
+      <location line="+65"/>
       <source>KRL file(*.src)</source>
       <translation>KRLファイル（*.SRC）</translation>
     </message>
     <message>
+      <location line="-64"/>
+      <location line="+65"/>
       <source>All Files (*.*)</source>
       <translation>すべてのファイル (*.*)</translation>
     </message>
     <message>
+      <location line="-64"/>
+      <location line="+65"/>
       <source>Export program</source>
       <translation>プログラムをエクスポート</translation>
     </message>
@@ -344,53 +415,63 @@
     <message>
       <location filename="../../CommandTrajectory.cpp" line="+79"/>
       <source>No preselection</source>
-      <translation>No preselection</translation>
+      <translation>プリセレクションがありません</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>You have to hover above a geometry (Preselection) with the mouse to use this command. See documentation for details.</source>
       <translation>このコマンドを使用するにはマウスを使ってジオメトリ（事前選択）の上にカーソルを移動する必要があります。詳細についてはマニュアルを参照してください。</translation>
     </message>
     <message>
       <location filename="../../Command.cpp" line="-155"/>
       <source>Select one Robot to set home postion</source>
-      <translation>Select one Robot to set home postion</translation>
+      <translation>ホームポジションを設定するロボットを1台選択</translation>
     </message>
     <message>
+      <location line="+49"/>
       <source>Select one Robot</source>
-      <translation>一台のロボットを選択する</translation>
+      <translation>1台のロボットを選択する</translation>
     </message>
     <message>
       <location filename="../../CommandTrajectory.cpp" line="-24"/>
+      <location line="+17"/>
       <source>Select one Trajectory object.</source>
       <translation>1 つの軌道のオブジェクトを選択します。</translation>
     </message>
     <message>
+      <location line="+84"/>
       <source>set default speed</source>
       <translation>既定の速度を設定します。</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>speed: (e.g. 1 m/s or 3 cm/s)</source>
       <translation>速度:(例 1m/s 3cm/s)</translation>
     </message>
     <message>
+      <location line="+9"/>
       <source>set default continuity</source>
-      <translation>set default continuity</translation>
+      <translation>デフォルトの連続性を設定</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>continuous ?</source>
-      <translation>続けかすか？</translation>
+      <translation>続けますか？</translation>
     </message>
     <message>
+      <location line="+6"/>
       <source>set default acceleration</source>
-      <translation>set default acceleration</translation>
+      <translation>デフォルトの加速度を設定</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>acceleration: (e.g. 1 m/s^2 or 3 cm/s^2)</source>
-      <translation>acceleration: (e.g. 1 m/s^2 or 3 cm/s^2)</translation>
+      <translation>加速度： (例: 1 m/s ^2 または 3 cm/s ^2)</translation>
     </message>
     <message>
+      <location line="+127"/>
       <source>Select the Trajectory which you want to dress up.</source>
-      <translation>Select the Trajectory which you want to dress up.</translation>
+      <translation>ドレスアップする軌道を選択</translation>
     </message>
     <message>
       <location filename="../../Workbench.cpp" line="+26"/>
@@ -398,8 +479,9 @@
       <translation>ロボットファイルがインストールされていません</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Please visit %1 and copy the files to %2</source>
-      <translation>Please visit %1 and copy the files to %2</translation>
+      <translation>%1 を見てファイルを %2 にコピーしてください</translation>
     </message>
   </context>
   <context>
@@ -410,50 +492,62 @@
       <translation>シミュレーション</translation>
     </message>
     <message>
+      <location line="+38"/>
       <source>|&lt;</source>
       <translation>|&lt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>&lt;</source>
       <translation>&lt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>||</source>
       <translation>||</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>|&gt;</source>
       <translation>|&gt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>&gt;</source>
       <translation>&gt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>&gt;|</source>
       <translation>&gt;|</translation>
     </message>
     <message>
+      <location line="+24"/>
       <source>%</source>
       <translation>%</translation>
     </message>
     <message>
+      <location line="+35"/>
       <source>Type</source>
       <translation>タイプ</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Name</source>
       <translation>名前</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>C</source>
       <translation>C</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>V</source>
       <translation>V</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>A</source>
       <translation>A</translation>
     </message>
@@ -471,41 +565,50 @@
     <message>
       <location filename="../../TaskRobot6Axis.ui" line="+14"/>
       <source>Form</source>
-      <translation>Form</translation>
+      <translation>フォーム</translation>
     </message>
     <message>
+      <location line="+8"/>
       <source>A1</source>
       <translation>A1</translation>
     </message>
     <message>
+      <location line="+47"/>
       <source>A2</source>
       <translation>A2</translation>
     </message>
     <message>
+      <location line="+47"/>
       <source>A3</source>
       <translation>A3</translation>
     </message>
     <message>
+      <location line="+47"/>
       <source>A4</source>
       <translation>A4</translation>
     </message>
     <message>
+      <location line="+47"/>
       <source>A5</source>
       <translation>A5</translation>
     </message>
     <message>
+      <location line="+47"/>
       <source>A6</source>
       <translation>A6</translation>
     </message>
     <message>
+      <location line="+57"/>
       <source>TCP: (200.23,300.23,400.23,234,343,343)</source>
       <translation>TCP: (200.23,300.23,400.23,234,343,343)</translation>
     </message>
     <message>
+      <location line="+17"/>
       <source>Tool: (0,0,400,0,0,0)</source>
       <translation>Tool: (0,0,400,0,0,0)</translation>
     </message>
     <message>
+      <location line="+16"/>
       <source>...</source>
       <translation>...</translation>
     </message>
@@ -536,77 +639,95 @@
     <message>
       <location filename="../../TaskTrajectory.ui" line="+20"/>
       <source>Form</source>
-      <translation>Form</translation>
+      <translation>フォーム</translation>
     </message>
     <message>
+      <location line="+38"/>
       <source>|&lt;</source>
       <translation>|&lt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>&lt;</source>
       <translation>&lt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>||</source>
       <translation>||</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>|&gt;</source>
       <translation>|&gt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>&gt;</source>
       <translation>&gt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>&gt;|</source>
       <translation>&gt;|</translation>
     </message>
     <message>
+      <location line="+24"/>
       <source>%</source>
       <translation>%</translation>
     </message>
     <message>
+      <location line="+17"/>
       <source>10 ms</source>
       <translation>10 ms</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>50 ms</source>
       <translation>50 ms</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>100 ms</source>
       <translation>100 ms</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>500 ms</source>
       <translation>500 ms</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>1 s</source>
       <translation>1 s</translation>
     </message>
     <message>
+      <location line="+18"/>
       <source>Pos: (200.23, 300.23, 400.23, 234, 343 ,343)</source>
       <translation>Pos: (200.23, 300.23, 400.23, 234, 343 ,343)</translation>
     </message>
     <message>
+      <location line="+26"/>
       <source>Type</source>
       <translation>タイプ</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Name</source>
       <translation>名前</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>C</source>
       <translation>C</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>V</source>
       <translation>V</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>A</source>
       <translation>A</translation>
     </message>
@@ -629,38 +750,43 @@
     <message>
       <location filename="../../TaskEdge2TracParameter.ui" line="+14"/>
       <source>Form</source>
-      <translation>Form</translation>
+      <translation>フォーム</translation>
     </message>
     <message>
+      <location line="+15"/>
       <source>Hide / Show</source>
       <translation>表示/非表示</translation>
     </message>
     <message>
+      <location line="+18"/>
       <source>Edges: 0</source>
       <translation>エッジ: 0</translation>
     </message>
     <message>
+      <location line="+14"/>
       <source>Cluster: 0</source>
       <translation>クラスタ: 0</translation>
     </message>
     <message>
+      <location line="+11"/>
       <source>Sizing Value:</source>
       <translation>サイジング値:</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>Use orientation of edge</source>
-      <translation>Use orientation of edge</translation>
+      <translation>エッジの方向を使用</translation>
     </message>
     <message>
       <source>TaskEdge2TracParameter</source>
-      <translation>TaskEdge2TracParameter</translation>
+      <translation type="obsolete">TaskEdge2TracParameter</translation>
     </message>
   </context>
   <context>
     <name>TaskRobot6Axis</name>
     <message>
       <source>TaskRobot6Axis</source>
-      <translation>TaskRobot6Axis</translation>
+      <translation type="obsolete">TaskRobot6Axis</translation>
     </message>
   </context>
   <context>
@@ -668,99 +794,121 @@
     <message>
       <location filename="../../TaskRobotControl.ui" line="+14"/>
       <source>Form</source>
-      <translation>Form</translation>
+      <translation>フォーム</translation>
     </message>
     <message>
+      <location line="+23"/>
       <source>X+</source>
       <translation>X+</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>Y+</source>
       <translation>Y+</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>Z+</source>
       <translation>Z+</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>A+</source>
       <translation>A+</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>B+</source>
       <translation>B+</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>C+</source>
       <translation>C+</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>X-</source>
       <translation>X-</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>Y-</source>
       <translation>Y-</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>Z-</source>
       <translation>Z-</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>A-</source>
       <translation>A-</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>B-</source>
       <translation>B-</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>C-</source>
       <translation>C-</translation>
     </message>
     <message>
+      <location line="+12"/>
       <source>Tool 0</source>
       <translation>Tool 0</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Tool</source>
       <translation>ツール</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Base 0</source>
       <translation>Base 0</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Base</source>
       <translation>Base</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>World</source>
       <translation>World</translation>
     </message>
-    <message>
+    <message utf8="true">
+      <location line="+9"/>
       <source>50mm / 5°</source>
       <translation>50mm / 5°</translation>
     </message>
-    <message>
+    <message utf8="true">
+      <location line="+5"/>
       <source>20mm / 2°</source>
       <translation>20mm / 2°</translation>
     </message>
-    <message>
+    <message utf8="true">
+      <location line="+5"/>
       <source>10mm / 1°</source>
       <translation>10mm / 1°</translation>
     </message>
-    <message>
+    <message utf8="true">
+      <location line="+5"/>
       <source>5mm / 0.5°</source>
       <translation>5mm / 0.5°</translation>
     </message>
-    <message>
+    <message utf8="true">
+      <location line="+5"/>
       <source>1mm / 0.1°</source>
       <translation>1mm / 0.1°</translation>
     </message>
     <message>
       <source>TaskRobotControl</source>
-      <translation>TaskRobotControl</translation>
+      <translation type="obsolete">TaskRobotControl</translation>
     </message>
   </context>
   <context>
@@ -768,22 +916,23 @@
     <message>
       <location filename="../../TaskRobotMessages.ui" line="+14"/>
       <source>Form</source>
-      <translation>Form</translation>
+      <translation>フォーム</translation>
     </message>
     <message>
+      <location line="+6"/>
       <source>clear</source>
-      <translation>clear</translation>
+      <translation>クリア</translation>
     </message>
     <message>
       <source>TaskRobotMessages</source>
-      <translation>TaskRobotMessages</translation>
+      <translation type="obsolete">TaskRobotMessages</translation>
     </message>
   </context>
   <context>
     <name>TaskTrajectory</name>
     <message>
       <source>Trajectory</source>
-      <translation>Trajectory</translation>
+      <translation type="obsolete">Trajectory</translation>
     </message>
   </context>
   <context>
@@ -791,67 +940,82 @@
     <message>
       <location filename="../../TaskTrajectoryDressUpParameter.ui" line="+14"/>
       <source>Form</source>
-      <translation>Form</translation>
+      <translation>フォーム</translation>
     </message>
     <message>
+      <location line="+6"/>
       <source>Speed &amp; Acceleration:</source>
       <translation>速度 ＆ 加速度:</translation>
     </message>
     <message>
+      <location line="+9"/>
       <source>Speed:</source>
       <translation>速度:</translation>
     </message>
     <message>
+      <location line="+26"/>
+      <location line="+37"/>
       <source>Use</source>
-      <translation>Use</translation>
+      <translation>使用する</translation>
     </message>
     <message>
+      <location line="-26"/>
       <source>Accel:</source>
       <translation>加速度:</translation>
     </message>
     <message>
+      <location line="+36"/>
       <source>Don't change Cont</source>
       <translation>Don't change Cont</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Continues</source>
       <translation>続ける</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Discontinues</source>
       <translation>中止</translation>
     </message>
     <message>
+      <location line="+15"/>
       <source>Position and Orientation:</source>
       <translation>位置と向き：</translation>
     </message>
     <message>
+      <location line="+9"/>
       <source>(0,0,0),(0,0,0)</source>
       <translation>(0,0,0),(0,0,0)</translation>
     </message>
     <message>
+      <location line="+13"/>
       <source>...</source>
       <translation>...</translation>
     </message>
     <message>
+      <location line="+10"/>
       <source>Don't change Position &amp; Orientation</source>
-      <translation>Don't change Position &amp; Orientation</translation>
+      <translation>位置と向きを変更しないでください</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Use Orientation</source>
-      <translation>Use Orientation</translation>
+      <translation>方向を使用</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Add Position</source>
       <translation>位置を追加します。</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Add Orientation</source>
       <translation>向きを追加します。</translation>
     </message>
     <message>
       <source>Dress Up Parameter</source>
-      <translation>Dress Up Parameter</translation>
+      <translation type="obsolete">Dress Up Parameter</translation>
     </message>
   </context>
   <context>
@@ -862,16 +1026,19 @@
       <translation>ロボット</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert Robots</source>
       <translation>ロボットを追加</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>&amp;Robot</source>
       <translation>ロボット (&amp;ｒ)</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Export trajectory</source>
-      <translation>Export trajectory</translation>
+      <translation>軌道をエクスポート</translation>
     </message>
   </context>
 </TS>
