@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS>
+<TS version="2.0" language="pl" sourcelanguage="en">
   <context>
     <name>CmdRobotAddToolShape</name>
     <message>
@@ -9,10 +9,12 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Add tool</source>
       <translation>Dodaj narzędzie</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Add a tool shape to the robot</source>
       <translation>Dodaj kształt narzędzia do robota</translation>
     </message>
@@ -25,10 +27,12 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Place robot...</source>
       <translation>Miejsce robota...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Place a robot (experimental!)</source>
       <translation>Miejsce robota (eksperymentalne!)</translation>
     </message>
@@ -41,10 +45,12 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Create trajectory</source>
       <translation>Utwórz trajektorię</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Create a new empty trajectory </source>
       <translation>Utwórz nową pustą trajektorię</translation>
     </message>
@@ -52,14 +58,17 @@
   <context>
     <name>CmdRobotEdge2Trac</name>
     <message>
+      <location line="+257"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Edge to Trajectory...</source>
       <translation>Krawędź na Trajektorię...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Generate a Trajectory from a set of edges</source>
       <translation>Generuj trajektorię z zestawu krawędzi</translation>
     </message>
@@ -72,27 +81,32 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Kuka compact subroutine...</source>
       <translation>Kuka kompaktowa funkcja...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Export the trajectory as a compact KRL subroutine.</source>
-      <translation>Export the trajectory as a compact KRL subroutine.</translation>
+      <translation>Eksportuj trajektorię jako uproszczoną procedurę KRL.</translation>
     </message>
   </context>
   <context>
     <name>CmdRobotExportKukaFull</name>
     <message>
+      <location line="+63"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Kuka full subroutine...</source>
       <translation>Kuka pełna funkcja...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Export the trajectory as a full KRL subroutine.</source>
-      <translation>Export the trajectory as a full KRL subroutine.</translation>
+      <translation>Eksportuj trajektorię jako pełną procedurę KRL.</translation>
     </message>
   </context>
   <context>
@@ -103,10 +117,12 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Kuka IR125</source>
       <translation>Kuka IR125</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert a Kuka IR125 into the document.</source>
       <translation>Wstaw Kuka IR125 do dokumentu.</translation>
     </message>
@@ -114,14 +130,17 @@
   <context>
     <name>CmdRobotInsertKukaIR16</name>
     <message>
+      <location line="-83"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Kuka IR16</source>
       <translation>Kuka IR16</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert a Kuka IR16 into the document.</source>
       <translation>Wstaw Kuka IR16 do dokumentu.</translation>
     </message>
@@ -129,14 +148,17 @@
   <context>
     <name>CmdRobotInsertKukaIR210</name>
     <message>
+      <location line="+39"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Kuka IR210</source>
       <translation>Kuka IR210</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert a Kuka IR210 into the document.</source>
       <translation>Wstaw Kuka IR210 do dokumentu.</translation>
     </message>
@@ -144,14 +166,17 @@
   <context>
     <name>CmdRobotInsertKukaIR500</name>
     <message>
+      <location line="-85"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Kuka IR500</source>
       <translation>Kuka IR500</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert a Kuka IR500 into the document.</source>
       <translation>Wstaw Kuka IR500 do dokumentu.</translation>
     </message>
@@ -164,10 +189,12 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert in trajectory</source>
       <translation>Wstaw na Trajektorię</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert robot Tool location into trajectory</source>
       <translation>Wstaw lokację narzędzia robota na trajektorię</translation>
     </message>
@@ -175,14 +202,17 @@
   <context>
     <name>CmdRobotInsertWaypointPreselect</name>
     <message>
+      <location line="+55"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert in trajectory</source>
       <translation>Wstaw na Trajektorię</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert preselection position into trajectory (W)</source>
       <translation>Wstaw pozycję preselekcji do trajektorii (W)</translation>
     </message>
@@ -195,6 +225,8 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+1"/>
       <source>Move to home</source>
       <translation>Przenieś do pozycji startowej</translation>
     </message>
@@ -207,27 +239,32 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Set default orientation</source>
       <translation>Ustaw domyślną orientację</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>set the default orientation for subsequent commands for waypoint creation</source>
-      <translation>set the default orientation for subsequent commands for waypoint creation</translation>
+      <translation>ustaw domyślną orientację kolejnych poleceń tworzenia punktu nawigacyjnego</translation>
     </message>
   </context>
   <context>
     <name>CmdRobotSetDefaultValues</name>
     <message>
+      <location line="+37"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Set default values</source>
       <translation>Ustaw domyślne wartości</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>set the default values for speed, acceleration and continuity for subsequent commands of waypoint creation</source>
-      <translation>set the default values for speed, acceleration and continuity for subsequent commands of waypoint creation</translation>
+      <translation>ustaw wartości domyślne prędkości, przyspieszenia i ciągłości kolejnych poleceń tworzenia punktu nawigacyjnego</translation>
     </message>
   </context>
   <context>
@@ -238,6 +275,8 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+1"/>
       <source>Set the home position</source>
       <translation>Ustaw pozycję startową</translation>
     </message>
@@ -245,14 +284,17 @@
   <context>
     <name>CmdRobotSimulate</name>
     <message>
+      <location line="+142"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Simulate a trajectory</source>
       <translation>Symulacja Trajektorii</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Run a simulation on a trajectory</source>
       <translation>Uruchom symulację na trajektorii</translation>
     </message>
@@ -265,27 +307,32 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Trajectory compound...</source>
-      <translation>Trajectory compound...</translation>
+      <translation>Skład trajektorii...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Group and connect some trajectories to one</source>
-      <translation>Group and connect some trajectories to one</translation>
+      <translation>Grupuj i połącz kilka trajektorii w jedną</translation>
     </message>
   </context>
   <context>
     <name>CmdRobotTrajectoryDressUp</name>
     <message>
+      <location line="-49"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Dress up trajectory...</source>
-      <translation>Dress up trajectory...</translation>
+      <translation>Złożenie trajektorii...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Create a dress up object which overide som aspects of a trajectory</source>
-      <translation>Create a dress up object which overide som aspects of a trajectory</translation>
+      <translation>Twórz złożenie obiektu, który przysłoni niektóre rodzaje trajektorii</translation>
     </message>
   </context>
   <context>
@@ -296,10 +343,12 @@
       <translation>Narzędzia Trajektoria</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Robot tools</source>
       <translation>Narzędzia Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert Robot</source>
       <translation>Wstaw Robot</translation>
     </message>
@@ -308,31 +357,53 @@
     <name>QObject</name>
     <message>
       <location filename="../../Command.cpp" line="-126"/>
+      <location line="+49"/>
+      <location line="+100"/>
+      <location line="+29"/>
+      <location filename="../../CommandExport.cpp" line="-52"/>
+      <location line="+65"/>
+      <location filename="../../CommandInsertRobot.cpp" line="+181"/>
+      <location filename="../../CommandTrajectory.cpp" line="-276"/>
+      <location line="+56"/>
+      <location line="+17"/>
+      <location line="+229"/>
       <source>Wrong selection</source>
       <translation>Niewłaściwy wybór</translation>
     </message>
     <message>
+      <location line="-28"/>
+      <location line="+29"/>
+      <location filename="../../CommandExport.cpp" line="-64"/>
+      <location line="+65"/>
+      <location filename="../../CommandTrajectory.cpp" line="-301"/>
       <source>Select one Robot and one Trajectory object.</source>
       <translation>Wybierz jednego robota i jedną trajektorię.</translation>
     </message>
     <message>
+      <location line="-24"/>
       <source>Trajectory not valid</source>
       <translation>Niewłaściwa Trajektoria</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>You need at least two way points in a trajectory to simulate.</source>
       <translation>Potrzebujesz do symulacji co najmniej dwóch punktów w trajektorii.</translation>
     </message>
     <message>
       <location filename="../../CommandExport.cpp" line="-43"/>
+      <location line="+65"/>
       <source>KRL file(*.src)</source>
       <translation>Plik KRL (*. src)</translation>
     </message>
     <message>
+      <location line="-64"/>
+      <location line="+65"/>
       <source>All Files (*.*)</source>
       <translation>Wszystkie pliki (*.*)</translation>
     </message>
     <message>
+      <location line="-64"/>
+      <location line="+65"/>
       <source>Export program</source>
       <translation>Eksport programu</translation>
     </message>
@@ -347,8 +418,9 @@
       <translation>Bez preselekcji</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>You have to hover above a geometry (Preselection) with the mouse to use this command. See documentation for details.</source>
-      <translation>You have to hover above a geometry (Preselection) with the mouse to use this command. See documentation for details.</translation>
+      <translation>Jeżeli chcesz użyć tego polecenia, musisz unieść powyżej geometrii (preselekcja) przy pomocy myszki. Aby uzyskać szczegółowe informacje na ten temat, sięgnij do dokumentacji.</translation>
     </message>
     <message>
       <location filename="../../Command.cpp" line="-155"/>
@@ -356,39 +428,48 @@
       <translation>Wybierz jednego robota, aby ustawić położenie wyjściowe</translation>
     </message>
     <message>
+      <location line="+49"/>
       <source>Select one Robot</source>
       <translation>Zaznacz jednego Robota</translation>
     </message>
     <message>
       <location filename="../../CommandTrajectory.cpp" line="-24"/>
+      <location line="+17"/>
       <source>Select one Trajectory object.</source>
       <translation>Zaznacz jeden obiekt Trajektoria</translation>
     </message>
     <message>
+      <location line="+84"/>
       <source>set default speed</source>
       <translation>Ustaw domyślną szybkość</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>speed: (e.g. 1 m/s or 3 cm/s)</source>
       <translation>prędkość: (np. 1 m/s lub 3 cm/s)</translation>
     </message>
     <message>
+      <location line="+9"/>
       <source>set default continuity</source>
       <translation>Ustaw domyślną ciągłość</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>continuous ?</source>
       <translation>ciągłe?</translation>
     </message>
     <message>
+      <location line="+6"/>
       <source>set default acceleration</source>
       <translation>Ustaw domyślne przyśpieszenie</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>acceleration: (e.g. 1 m/s^2 or 3 cm/s^2)</source>
       <translation>przyspieszenie: (przykład 1 m/s ^ 2 lub 3 cm/s ^ 2)</translation>
     </message>
     <message>
+      <location line="+127"/>
       <source>Select the Trajectory which you want to dress up.</source>
       <translation>Wybierz trajektorię, które chcesz wykonać.</translation>
     </message>
@@ -398,6 +479,7 @@
       <translation>Nie zainstalowane pliki robota</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Please visit %1 and copy the files to %2</source>
       <translation>Odwiedź %1 i kopiować pliki do %2</translation>
     </message>
@@ -410,50 +492,62 @@
       <translation>Symulacja</translation>
     </message>
     <message>
+      <location line="+38"/>
       <source>|&lt;</source>
       <translation>|&lt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>&lt;</source>
       <translation>&lt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>||</source>
       <translation>||</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>|&gt;</source>
       <translation>|&gt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>&gt;</source>
       <translation>&gt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>&gt;|</source>
       <translation>&gt;|</translation>
     </message>
     <message>
+      <location line="+24"/>
       <source>%</source>
       <translation>%</translation>
     </message>
     <message>
+      <location line="+35"/>
       <source>Type</source>
       <translation>Typ</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Name</source>
       <translation>Nazwa</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>C</source>
       <translation>C</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>V</source>
       <translation>V</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>A</source>
       <translation>A</translation>
     </message>
@@ -474,38 +568,47 @@
       <translation>Formularz</translation>
     </message>
     <message>
+      <location line="+8"/>
       <source>A1</source>
       <translation>A1</translation>
     </message>
     <message>
+      <location line="+47"/>
       <source>A2</source>
       <translation>A2</translation>
     </message>
     <message>
+      <location line="+47"/>
       <source>A3</source>
       <translation>A3</translation>
     </message>
     <message>
+      <location line="+47"/>
       <source>A4</source>
       <translation>A4</translation>
     </message>
     <message>
+      <location line="+47"/>
       <source>A5</source>
       <translation>A5</translation>
     </message>
     <message>
+      <location line="+47"/>
       <source>A6</source>
       <translation>A6</translation>
     </message>
     <message>
+      <location line="+57"/>
       <source>TCP: (200.23,300.23,400.23,234,343,343)</source>
       <translation>TCP: (200.23,300.23,400.23,234,343,343)</translation>
     </message>
     <message>
+      <location line="+17"/>
       <source>Tool: (0,0,400,0,0,0)</source>
       <translation>Narzędzie: (0,0,400,0,0,0)</translation>
     </message>
     <message>
+      <location line="+16"/>
       <source>...</source>
       <translation>...</translation>
     </message>
@@ -539,74 +642,92 @@
       <translation>Formularz</translation>
     </message>
     <message>
+      <location line="+38"/>
       <source>|&lt;</source>
       <translation>|&lt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>&lt;</source>
       <translation>&lt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>||</source>
       <translation>||</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>|&gt;</source>
       <translation>|&gt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>&gt;</source>
       <translation>&gt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>&gt;|</source>
       <translation>&gt;|</translation>
     </message>
     <message>
+      <location line="+24"/>
       <source>%</source>
       <translation>%</translation>
     </message>
     <message>
+      <location line="+17"/>
       <source>10 ms</source>
       <translation>10 ms</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>50 ms</source>
       <translation>50 ms</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>100 ms</source>
       <translation>100 ms</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>500 ms</source>
       <translation>500 ms</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>1 s</source>
       <translation>1 s</translation>
     </message>
     <message>
+      <location line="+18"/>
       <source>Pos: (200.23, 300.23, 400.23, 234, 343 ,343)</source>
       <translation>Pos: (200.23, 300.23, 400.23, 234, 343, 343)</translation>
     </message>
     <message>
+      <location line="+26"/>
       <source>Type</source>
       <translation>Typ</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Name</source>
       <translation>Nazwa</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>C</source>
       <translation>C</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>V</source>
       <translation>V</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>A</source>
       <translation>A</translation>
     </message>
@@ -632,35 +753,40 @@
       <translation>Formularz</translation>
     </message>
     <message>
+      <location line="+15"/>
       <source>Hide / Show</source>
       <translation>Ukryj / Pokaż</translation>
     </message>
     <message>
+      <location line="+18"/>
       <source>Edges: 0</source>
       <translation>Krawędzie: 0</translation>
     </message>
     <message>
+      <location line="+14"/>
       <source>Cluster: 0</source>
       <translation>Klaster: 0</translation>
     </message>
     <message>
+      <location line="+11"/>
       <source>Sizing Value:</source>
       <translation>Wartość zmiany rozmiaru:</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>Use orientation of edge</source>
       <translation>Użyj orientacji krawędzi</translation>
     </message>
     <message>
       <source>TaskEdge2TracParameter</source>
-      <translation>TaskEdge2TracParameter</translation>
+      <translation type="obsolete">TaskEdge2TracParameter</translation>
     </message>
   </context>
   <context>
     <name>TaskRobot6Axis</name>
     <message>
       <source>TaskRobot6Axis</source>
-      <translation>TaskRobot6Axis</translation>
+      <translation type="obsolete">TaskRobot6Axis</translation>
     </message>
   </context>
   <context>
@@ -671,96 +797,118 @@
       <translation>Formularz</translation>
     </message>
     <message>
+      <location line="+23"/>
       <source>X+</source>
       <translation>X +</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>Y+</source>
       <translation>Y +</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>Z+</source>
       <translation>Z +</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>A+</source>
       <translation>A +</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>B+</source>
       <translation>B +</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>C+</source>
       <translation>C +</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>X-</source>
       <translation>X-</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>Y-</source>
       <translation>Y-</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>Z-</source>
       <translation>Z-</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>A-</source>
       <translation>A-</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>B-</source>
       <translation>B-</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>C-</source>
       <translation>C-</translation>
     </message>
     <message>
+      <location line="+12"/>
       <source>Tool 0</source>
       <translation>Narzędzie 0</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Tool</source>
       <translation>Narzędzie</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Base 0</source>
       <translation>Baza 0</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Base</source>
       <translation>Baza</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>World</source>
       <translation>Świat</translation>
     </message>
-    <message>
+    <message utf8="true">
+      <location line="+9"/>
       <source>50mm / 5°</source>
       <translation>50mm / 5 °</translation>
     </message>
-    <message>
+    <message utf8="true">
+      <location line="+5"/>
       <source>20mm / 2°</source>
       <translation>20mm / 2 °</translation>
     </message>
-    <message>
+    <message utf8="true">
+      <location line="+5"/>
       <source>10mm / 1°</source>
       <translation>10mm / 1 °</translation>
     </message>
-    <message>
+    <message utf8="true">
+      <location line="+5"/>
       <source>5mm / 0.5°</source>
       <translation>5mm / 0,5 °</translation>
     </message>
-    <message>
+    <message utf8="true">
+      <location line="+5"/>
       <source>1mm / 0.1°</source>
       <translation>1 mm / 0,1 °</translation>
     </message>
     <message>
       <source>TaskRobotControl</source>
-      <translation>TaskRobotControl</translation>
+      <translation type="obsolete">TaskRobotControl</translation>
     </message>
   </context>
   <context>
@@ -771,19 +919,20 @@
       <translation>Formularz</translation>
     </message>
     <message>
+      <location line="+6"/>
       <source>clear</source>
       <translation>Wyczyść</translation>
     </message>
     <message>
       <source>TaskRobotMessages</source>
-      <translation>TaskRobotMessages</translation>
+      <translation type="obsolete">TaskRobotMessages</translation>
     </message>
   </context>
   <context>
     <name>TaskTrajectory</name>
     <message>
       <source>Trajectory</source>
-      <translation>Trajectory</translation>
+      <translation type="obsolete">Trajectory</translation>
     </message>
   </context>
   <context>
@@ -794,64 +943,79 @@
       <translation>Formularz</translation>
     </message>
     <message>
+      <location line="+6"/>
       <source>Speed &amp; Acceleration:</source>
       <translation>Prędkość &amp; Przyśpieszenie:</translation>
     </message>
     <message>
+      <location line="+9"/>
       <source>Speed:</source>
       <translation>Prędkość:</translation>
     </message>
     <message>
+      <location line="+26"/>
+      <location line="+37"/>
       <source>Use</source>
       <translation>Użyj</translation>
     </message>
     <message>
+      <location line="-26"/>
       <source>Accel:</source>
       <translation>Przyśp.:</translation>
     </message>
     <message>
+      <location line="+36"/>
       <source>Don't change Cont</source>
       <translation>Nie zmieniaj</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Continues</source>
       <translation>Kontynuuj</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Discontinues</source>
       <translation>Przerwij</translation>
     </message>
     <message>
+      <location line="+15"/>
       <source>Position and Orientation:</source>
       <translation>Pozycja &amp; Orientacja:</translation>
     </message>
     <message>
+      <location line="+9"/>
       <source>(0,0,0),(0,0,0)</source>
       <translation>(0,0,0),(0,0,0)</translation>
     </message>
     <message>
+      <location line="+13"/>
       <source>...</source>
       <translation>...</translation>
     </message>
     <message>
+      <location line="+10"/>
       <source>Don't change Position &amp; Orientation</source>
       <translation>Nie zmieniaj Pozycji &amp; Orientacji</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Use Orientation</source>
       <translation>Użyj orientacji</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Add Position</source>
       <translation>Dodaj pozycję</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Add Orientation</source>
       <translation>Dodaj orientację</translation>
     </message>
     <message>
       <source>Dress Up Parameter</source>
-      <translation>Dress Up Parameter</translation>
+      <translation type="obsolete">Dress Up Parameter</translation>
     </message>
   </context>
   <context>
@@ -862,14 +1026,17 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert Robots</source>
       <translation>Wstaw Roboty</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>&amp;Robot</source>
       <translation>&amp; Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Export trajectory</source>
       <translation>Eksport Trajektorii</translation>
     </message>
