@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS>
+<TS version="2.0" language="ro" sourcelanguage="en">
   <context>
     <name>CmdRobotAddToolShape</name>
     <message>
@@ -9,10 +9,12 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Add tool</source>
       <translation>Adaugă instrument</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Add a tool shape to the robot</source>
       <translation>Adăugaţi o formă de instrument la robot</translation>
     </message>
@@ -25,10 +27,12 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Place robot...</source>
       <translation>Plasaţi robotul...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Place a robot (experimental!)</source>
       <translation>Plasaţi robotul (experimental!)</translation>
     </message>
@@ -41,10 +45,12 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Create trajectory</source>
       <translation>Creeaţi o traiectorie</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Create a new empty trajectory </source>
       <translation>Creeaţi o nouă traiectorie goală </translation>
     </message>
@@ -52,14 +58,17 @@
   <context>
     <name>CmdRobotEdge2Trac</name>
     <message>
+      <location line="+257"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Edge to Trajectory...</source>
       <translation>Muchie la Traiectorie...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Generate a Trajectory from a set of edges</source>
       <translation>Generați o Traiectorie de la un set de muchii</translation>
     </message>
@@ -72,10 +81,12 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Kuka compact subroutine...</source>
       <translation>Subrutină compactă KUKA...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Export the trajectory as a compact KRL subroutine.</source>
       <translation>Exportaţi traiectoria ca o subrutina KRL compactă.</translation>
     </message>
@@ -83,14 +94,17 @@
   <context>
     <name>CmdRobotExportKukaFull</name>
     <message>
+      <location line="+63"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Kuka full subroutine...</source>
       <translation>Subrutină completă Kuka...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Export the trajectory as a full KRL subroutine.</source>
       <translation>Exportaţi traiectoria ca o subrutină KRL completă.</translation>
     </message>
@@ -103,10 +117,12 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Kuka IR125</source>
       <translation>Kuka IR125</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert a Kuka IR125 into the document.</source>
       <translation>Inserați un Kuka IR125 în document.</translation>
     </message>
@@ -114,14 +130,17 @@
   <context>
     <name>CmdRobotInsertKukaIR16</name>
     <message>
+      <location line="-83"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Kuka IR16</source>
       <translation>Kuka IR16</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert a Kuka IR16 into the document.</source>
       <translation>Inserați un Kuka IR16 în document.</translation>
     </message>
@@ -129,14 +148,17 @@
   <context>
     <name>CmdRobotInsertKukaIR210</name>
     <message>
+      <location line="+39"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Kuka IR210</source>
       <translation>Kuka IR210</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert a Kuka IR210 into the document.</source>
       <translation>Inserați un Kuka IR210 în document.</translation>
     </message>
@@ -144,14 +166,17 @@
   <context>
     <name>CmdRobotInsertKukaIR500</name>
     <message>
+      <location line="-85"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Kuka IR500</source>
       <translation>Kuka IR500</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert a Kuka IR500 into the document.</source>
       <translation>Inserați un Kuka IR500 în document.</translation>
     </message>
@@ -164,10 +189,12 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert in trajectory</source>
       <translation>Inseraţi în traiectorie</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert robot Tool location into trajectory</source>
       <translation>Introduceţi locaţia uneltei robotului în traiectorie</translation>
     </message>
@@ -175,14 +202,17 @@
   <context>
     <name>CmdRobotInsertWaypointPreselect</name>
     <message>
+      <location line="+55"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert in trajectory</source>
       <translation>Inseraţi în traiectorie</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert preselection position into trajectory (W)</source>
       <translation>Introduceţi poziţia preselectată în traiectorie (W)</translation>
     </message>
@@ -195,6 +225,8 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+1"/>
       <source>Move to home</source>
       <translation>Mută spre casă</translation>
     </message>
@@ -207,10 +239,12 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Set default orientation</source>
       <translation>Setați orientarea implicită</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>set the default orientation for subsequent commands for waypoint creation</source>
       <translation>Setați orientarea implicită pentru comezile de creeare a punctelor de referință ulterioare</translation>
     </message>
@@ -218,14 +252,17 @@
   <context>
     <name>CmdRobotSetDefaultValues</name>
     <message>
+      <location line="+37"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Set default values</source>
       <translation>Setați valorile implicite</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>set the default values for speed, acceleration and continuity for subsequent commands of waypoint creation</source>
       <translation>setaţi valorile implicite pentru viteză, acceleraţie şi continuitate pentru comenzi le de creare a punctelor de referinţă ulterioare</translation>
     </message>
@@ -238,6 +275,8 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
+      <location line="+1"/>
       <source>Set the home position</source>
       <translation>Setează poziţia de acasă</translation>
     </message>
@@ -245,14 +284,17 @@
   <context>
     <name>CmdRobotSimulate</name>
     <message>
+      <location line="+142"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Simulate a trajectory</source>
       <translation>Simulaţi o traiectorie</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Run a simulation on a trajectory</source>
       <translation>Rulaţi o simulare a traiectoriei</translation>
     </message>
@@ -265,10 +307,12 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Trajectory compound...</source>
       <translation>Traiectorie combinată...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Group and connect some trajectories to one</source>
       <translation>Grupați și uniți unele traiectorii într-una singură</translation>
     </message>
@@ -276,16 +320,19 @@
   <context>
     <name>CmdRobotTrajectoryDressUp</name>
     <message>
+      <location line="-49"/>
       <source>Robot</source>
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Dress up trajectory...</source>
-      <translation>Dress up trajectory...</translation>
+      <translation>Traiectorie de imbracare...</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Create a dress up object which overide som aspects of a trajectory</source>
-      <translation>Create a dress up object which overide som aspects of a trajectory</translation>
+      <translation>Creaza un obiect ce schimba unele aspecte ale traiectoriei</translation>
     </message>
   </context>
   <context>
@@ -296,10 +343,12 @@
       <translation>Instrumente pentru Traiectorii</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Robot tools</source>
       <translation>Instrumente pentru roboţi</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert Robot</source>
       <translation>Inserare Robot</translation>
     </message>
@@ -308,31 +357,53 @@
     <name>QObject</name>
     <message>
       <location filename="../../Command.cpp" line="-126"/>
+      <location line="+49"/>
+      <location line="+100"/>
+      <location line="+29"/>
+      <location filename="../../CommandExport.cpp" line="-52"/>
+      <location line="+65"/>
+      <location filename="../../CommandInsertRobot.cpp" line="+181"/>
+      <location filename="../../CommandTrajectory.cpp" line="-276"/>
+      <location line="+56"/>
+      <location line="+17"/>
+      <location line="+229"/>
       <source>Wrong selection</source>
       <translation>Selecţie greşită</translation>
     </message>
     <message>
+      <location line="-28"/>
+      <location line="+29"/>
+      <location filename="../../CommandExport.cpp" line="-64"/>
+      <location line="+65"/>
+      <location filename="../../CommandTrajectory.cpp" line="-301"/>
       <source>Select one Robot and one Trajectory object.</source>
       <translation>Selectaţi un obiect Robot şi un obiect de Traiectorie.</translation>
     </message>
     <message>
+      <location line="-24"/>
       <source>Trajectory not valid</source>
       <translation>Traiectoria nu este validă</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>You need at least two way points in a trajectory to simulate.</source>
       <translation>Aveţi nevoie de cel puţin două puncte într-o traiectorie pentru a o simula.</translation>
     </message>
     <message>
       <location filename="../../CommandExport.cpp" line="-43"/>
+      <location line="+65"/>
       <source>KRL file(*.src)</source>
       <translation>Fişier KRL(*.src)</translation>
     </message>
     <message>
+      <location line="-64"/>
+      <location line="+65"/>
       <source>All Files (*.*)</source>
       <translation>Toate fișierele (*.*)</translation>
     </message>
     <message>
+      <location line="-64"/>
+      <location line="+65"/>
       <source>Export program</source>
       <translation>Program de export</translation>
     </message>
@@ -347,6 +418,7 @@
       <translation>Nici o preselecţie</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>You have to hover above a geometry (Preselection) with the mouse to use this command. See documentation for details.</source>
       <translation>Va trebui să treceţi peste o formă geometrică (Preselectie) cu mouse-ul pentru a utiliza această comandă. Consultați documentaţia pentru mai multe detalii.</translation>
     </message>
@@ -356,39 +428,48 @@
       <translation>Selectaţi un Robot pentru a seta poziţia de acasă</translation>
     </message>
     <message>
+      <location line="+49"/>
       <source>Select one Robot</source>
       <translation>Selectaţi un Robot</translation>
     </message>
     <message>
       <location filename="../../CommandTrajectory.cpp" line="-24"/>
+      <location line="+17"/>
       <source>Select one Trajectory object.</source>
       <translation>Selectaţi un obiect Traiectorie.</translation>
     </message>
     <message>
+      <location line="+84"/>
       <source>set default speed</source>
       <translation>setați viteza implicită</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>speed: (e.g. 1 m/s or 3 cm/s)</source>
       <translation>viteza: (de ex: 1 m/s sau 3 cm/s)</translation>
     </message>
     <message>
+      <location line="+9"/>
       <source>set default continuity</source>
       <translation>setați continuitatea implicită</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>continuous ?</source>
       <translation>continuu?</translation>
     </message>
     <message>
+      <location line="+6"/>
       <source>set default acceleration</source>
       <translation>setați accelerația implicită</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>acceleration: (e.g. 1 m/s^2 or 3 cm/s^2)</source>
       <translation>accelerația: (ex. 1 m/s^2 sau 3 cm/s^2)</translation>
     </message>
     <message>
+      <location line="+127"/>
       <source>Select the Trajectory which you want to dress up.</source>
       <translation>Selectaţi traiectoria pe care doriţi să o îmbrăcaţi.</translation>
     </message>
@@ -398,6 +479,7 @@
       <translation>Nici un fișier pentru robot instalat</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Please visit %1 and copy the files to %2</source>
       <translation>Vă rugăm să vizitaţi %1 şi copiaţi fişierele în %2</translation>
     </message>
@@ -410,50 +492,62 @@
       <translation>Simulare</translation>
     </message>
     <message>
+      <location line="+38"/>
       <source>|&lt;</source>
       <translation>|&lt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>&lt;</source>
       <translation>&lt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>||</source>
       <translation>||</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>|&gt;</source>
       <translation>|&gt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>&gt;</source>
       <translation>&gt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>&gt;|</source>
       <translation>&gt;|</translation>
     </message>
     <message>
+      <location line="+24"/>
       <source>%</source>
       <translation>%</translation>
     </message>
     <message>
+      <location line="+35"/>
       <source>Type</source>
       <translation>Tip</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Name</source>
       <translation>Nume</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>C</source>
       <translation>C</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>V</source>
       <translation>V</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>A</source>
       <translation>A</translation>
     </message>
@@ -471,41 +565,50 @@
     <message>
       <location filename="../../TaskRobot6Axis.ui" line="+14"/>
       <source>Form</source>
-      <translation>Form</translation>
+      <translation>Formular</translation>
     </message>
     <message>
+      <location line="+8"/>
       <source>A1</source>
       <translation>A1</translation>
     </message>
     <message>
+      <location line="+47"/>
       <source>A2</source>
       <translation>A2</translation>
     </message>
     <message>
+      <location line="+47"/>
       <source>A3</source>
       <translation>A3</translation>
     </message>
     <message>
+      <location line="+47"/>
       <source>A4</source>
       <translation>A4</translation>
     </message>
     <message>
+      <location line="+47"/>
       <source>A5</source>
       <translation>A5</translation>
     </message>
     <message>
+      <location line="+47"/>
       <source>A6</source>
       <translation>A6</translation>
     </message>
     <message>
+      <location line="+57"/>
       <source>TCP: (200.23,300.23,400.23,234,343,343)</source>
       <translation>TCP: (200.23,300.23,400.23,234,343,343)</translation>
     </message>
     <message>
+      <location line="+17"/>
       <source>Tool: (0,0,400,0,0,0)</source>
       <translation>Instrument: (0,0,400,0,0,0)</translation>
     </message>
     <message>
+      <location line="+16"/>
       <source>...</source>
       <translation>...</translation>
     </message>
@@ -536,77 +639,95 @@
     <message>
       <location filename="../../TaskTrajectory.ui" line="+20"/>
       <source>Form</source>
-      <translation>Form</translation>
+      <translation>Formular</translation>
     </message>
     <message>
+      <location line="+38"/>
       <source>|&lt;</source>
       <translation>|&lt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>&lt;</source>
       <translation>&lt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>||</source>
       <translation>||</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>|&gt;</source>
       <translation>|&gt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>&gt;</source>
       <translation>&gt;</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>&gt;|</source>
       <translation>&gt;|</translation>
     </message>
     <message>
+      <location line="+24"/>
       <source>%</source>
       <translation>%</translation>
     </message>
     <message>
+      <location line="+17"/>
       <source>10 ms</source>
       <translation>10 ms</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>50 ms</source>
       <translation>50 ms</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>100 ms</source>
       <translation>100 ms</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>500 ms</source>
       <translation>500 ms</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>1 s</source>
       <translation>1 s</translation>
     </message>
     <message>
+      <location line="+18"/>
       <source>Pos: (200.23, 300.23, 400.23, 234, 343 ,343)</source>
       <translation>Poz: (200.23, 300.23, 400.23, 234, 343 ,343)</translation>
     </message>
     <message>
+      <location line="+26"/>
       <source>Type</source>
       <translation>Tip</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Name</source>
       <translation>Nume</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>C</source>
       <translation>C</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>V</source>
       <translation>V</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>A</source>
       <translation>A</translation>
     </message>
@@ -629,38 +750,43 @@
     <message>
       <location filename="../../TaskEdge2TracParameter.ui" line="+14"/>
       <source>Form</source>
-      <translation>Form</translation>
+      <translation>Formular</translation>
     </message>
     <message>
+      <location line="+15"/>
       <source>Hide / Show</source>
       <translation>Ascunde / Arată</translation>
     </message>
     <message>
+      <location line="+18"/>
       <source>Edges: 0</source>
       <translation>Muchii: 0</translation>
     </message>
     <message>
+      <location line="+14"/>
       <source>Cluster: 0</source>
       <translation>Cluster: 0</translation>
     </message>
     <message>
+      <location line="+11"/>
       <source>Sizing Value:</source>
       <translation>Valoarea de dimensionare:</translation>
     </message>
     <message>
+      <location line="+31"/>
       <source>Use orientation of edge</source>
       <translation>Folosiţi orientarea muchiei</translation>
     </message>
     <message>
       <source>TaskEdge2TracParameter</source>
-      <translation>TaskEdge2TracParameter</translation>
+      <translation type="obsolete">TaskEdge2TracParameter</translation>
     </message>
   </context>
   <context>
     <name>TaskRobot6Axis</name>
     <message>
       <source>TaskRobot6Axis</source>
-      <translation>TaskRobot6Axis</translation>
+      <translation type="obsolete">TaskRobot6Axis</translation>
     </message>
   </context>
   <context>
@@ -668,99 +794,121 @@
     <message>
       <location filename="../../TaskRobotControl.ui" line="+14"/>
       <source>Form</source>
-      <translation>Form</translation>
+      <translation>Formular</translation>
     </message>
     <message>
+      <location line="+23"/>
       <source>X+</source>
       <translation>X+</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>Y+</source>
       <translation>Y+</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>Z+</source>
       <translation>Z+</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>A+</source>
       <translation>A+</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>B+</source>
       <translation>B+</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>C+</source>
       <translation>C+</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>X-</source>
       <translation>X-</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>Y-</source>
       <translation>Y-</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>Z-</source>
       <translation>Z-</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>A-</source>
       <translation>A-</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>B-</source>
       <translation>B-</translation>
     </message>
     <message>
+      <location line="+19"/>
       <source>C-</source>
       <translation>C-</translation>
     </message>
     <message>
+      <location line="+12"/>
       <source>Tool 0</source>
       <translation>Instrument 0</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Tool</source>
       <translation>Instrument</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Base 0</source>
       <translation>Baza 0</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Base</source>
       <translation>Bază</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>World</source>
       <translation>Lumea</translation>
     </message>
-    <message>
+    <message utf8="true">
+      <location line="+9"/>
       <source>50mm / 5°</source>
       <translation>50mm / 5°</translation>
     </message>
-    <message>
+    <message utf8="true">
+      <location line="+5"/>
       <source>20mm / 2°</source>
       <translation>20mm / 2°</translation>
     </message>
-    <message>
+    <message utf8="true">
+      <location line="+5"/>
       <source>10mm / 1°</source>
       <translation>10mm / 1°</translation>
     </message>
-    <message>
+    <message utf8="true">
+      <location line="+5"/>
       <source>5mm / 0.5°</source>
       <translation>5mm / 0.5°</translation>
     </message>
-    <message>
+    <message utf8="true">
+      <location line="+5"/>
       <source>1mm / 0.1°</source>
       <translation>1mm / 0.1°</translation>
     </message>
     <message>
       <source>TaskRobotControl</source>
-      <translation>TaskRobotControl</translation>
+      <translation type="obsolete">TaskRobotControl</translation>
     </message>
   </context>
   <context>
@@ -768,22 +916,23 @@
     <message>
       <location filename="../../TaskRobotMessages.ui" line="+14"/>
       <source>Form</source>
-      <translation>Form</translation>
+      <translation>Formular</translation>
     </message>
     <message>
+      <location line="+6"/>
       <source>clear</source>
       <translation>clar</translation>
     </message>
     <message>
       <source>TaskRobotMessages</source>
-      <translation>TaskRobotMessages</translation>
+      <translation type="obsolete">TaskRobotMessages</translation>
     </message>
   </context>
   <context>
     <name>TaskTrajectory</name>
     <message>
       <source>Trajectory</source>
-      <translation>Trajectory</translation>
+      <translation type="obsolete">Trajectory</translation>
     </message>
   </context>
   <context>
@@ -791,67 +940,82 @@
     <message>
       <location filename="../../TaskTrajectoryDressUpParameter.ui" line="+14"/>
       <source>Form</source>
-      <translation>Form</translation>
+      <translation>Formular</translation>
     </message>
     <message>
+      <location line="+6"/>
       <source>Speed &amp; Acceleration:</source>
       <translation>Viteza &amp; accelerația:</translation>
     </message>
     <message>
+      <location line="+9"/>
       <source>Speed:</source>
       <translation>Viteza:</translation>
     </message>
     <message>
+      <location line="+26"/>
+      <location line="+37"/>
       <source>Use</source>
       <translation>Utilizarea</translation>
     </message>
     <message>
+      <location line="-26"/>
       <source>Accel:</source>
       <translation>Accel:</translation>
     </message>
     <message>
+      <location line="+36"/>
       <source>Don't change Cont</source>
       <translation>Nu schimba Cont</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Continues</source>
       <translation>Continuă</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Discontinues</source>
       <translation>Întrerupe</translation>
     </message>
     <message>
+      <location line="+15"/>
       <source>Position and Orientation:</source>
       <translation>Poziţie şi orientare:</translation>
     </message>
     <message>
+      <location line="+9"/>
       <source>(0,0,0),(0,0,0)</source>
       <translation>(0,0,0),(0,0,0)</translation>
     </message>
     <message>
+      <location line="+13"/>
       <source>...</source>
       <translation>...</translation>
     </message>
     <message>
+      <location line="+10"/>
       <source>Don't change Position &amp; Orientation</source>
       <translation>Nu modifica Poziţia şi Orientarea</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Use Orientation</source>
       <translation>Foloseşte Orientarea</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Add Position</source>
       <translation>Adaugă Poziţie</translation>
     </message>
     <message>
+      <location line="+5"/>
       <source>Add Orientation</source>
       <translation>Adaugă Orientare</translation>
     </message>
     <message>
       <source>Dress Up Parameter</source>
-      <translation>Dress Up Parameter</translation>
+      <translation type="obsolete">Dress Up Parameter</translation>
     </message>
   </context>
   <context>
@@ -862,14 +1026,17 @@
       <translation>Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Insert Robots</source>
       <translation>Inserare roboţi</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>&amp;Robot</source>
       <translation>&amp;Robot</translation>
     </message>
     <message>
+      <location line="+1"/>
       <source>Export trajectory</source>
       <translation>Exportă traiectoria</translation>
     </message>
