@@ -32,6 +32,7 @@
 # include <QMessageBox>
 #endif
 
+#include <App/DocumentObjectGroup.h>
 #include <Gui/Application.h>
 #include <Gui/Document.h>
 #include <Gui/Command.h>
@@ -82,7 +83,14 @@ void CmdSketcherNewSketch::activated(int iMsg)
         Part::Feature *part = static_cast<Part::Feature*>(FaceFilter.Result[0][0].getObject());
         Base::Placement ObjectPos = part->Placement.getValue();
         const std::vector<std::string> &sub = FaceFilter.Result[0][0].getSubNames();
-        if (sub.size() > 1){
+        if (sub.empty()) {
+            // No assert for wrong user input!
+            QMessageBox::warning(Gui::getMainWindow(),
+                qApp->translate(className(),"No sub-elements selected"),
+                qApp->translate(className(),"You have to select a single face as support for a sketch!"));
+            return;
+        }
+        else if (sub.size() > 1) {
             // No assert for wrong user input!
             QMessageBox::warning(Gui::getMainWindow(), QObject::tr("Several sub-elements selected"),
                 QObject::tr("You have to select a single face as support for a sketch!"));
@@ -117,6 +125,11 @@ void CmdSketcherNewSketch::activated(int iMsg)
         doCommand(Gui,"App.activeDocument().recompute()");  // recompute the sketch placement based on its support
         //doCommand(Gui,"Gui.activeDocument().activeView().setCamera('%s')",cam.c_str());
         doCommand(Gui,"Gui.activeDocument().setEdit('%s')",FeatName.c_str());
+        App::DocumentObjectGroup* grp = part->getGroup();
+        if (grp) {
+            doCommand(Doc,"App.activeDocument().%s.addObject(App.activeDocument().%s)"
+                         ,grp->getNameInDocument(),FeatName.c_str());
+        }
     }
     else {
         // ask user for orientation
@@ -293,7 +306,14 @@ void CmdSketcherMapSketch::activated(int iMsg)
         Part::Feature *part = static_cast<Part::Feature*>(FaceFilter.Result[0][0].getObject());
         Base::Placement ObjectPos = part->Placement.getValue();
         const std::vector<std::string> &sub = FaceFilter.Result[0][0].getSubNames();
-        if (sub.size() > 1){
+        if (sub.empty()) {
+            // No assert for wrong user input!
+            QMessageBox::warning(Gui::getMainWindow(),
+                qApp->translate(className(),"No sub-elements selected"),
+                qApp->translate(className(),"You have to select a single face as support for a sketch!"));
+            return;
+        }
+        else if (sub.size() > 1) {
             // No assert for wrong user input!
             QMessageBox::warning(Gui::getMainWindow(),
                 qApp->translate(className(),"Several sub-elements selected"),
