@@ -23,9 +23,12 @@
 
 #include "PreCompiled.h"
 #ifndef _PreComp_
+# include <cfloat>
 # include <QMessageBox>
+# include <Precision.hxx>
 #endif
 
+#include <App/Application.h>
 #include <Gui/Application.h>
 #include <Gui/Document.h>
 #include <Gui/Selection.h>
@@ -73,10 +76,15 @@ void finishDistanceConstraint(Gui::Command* cmd, Sketcher::SketchObject* sketch)
         vp->draw(); // Redraw
     }
 
+    ParameterGrp::handle hGrp = App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/Mod/Sketcher/General");
+    bool show = hGrp->GetBool("ShowDialogOnDistanceConstraint", true);
+
     // Ask for the value of the distance immediately
-    EditDatumDialog *editDatumDialog = new EditDatumDialog(sketch, ConStr.size() - 1);
-    editDatumDialog->exec(false);
-    delete editDatumDialog;
+    if (show) {
+        EditDatumDialog *editDatumDialog = new EditDatumDialog(sketch, ConStr.size() - 1);
+        editDatumDialog->exec(false);
+        delete editDatumDialog;
+    }
 
     //updateActive();
     cmd->getSelection().clearSelection();
@@ -102,7 +110,7 @@ void getIdsFromName(const std::string &name, const Sketcher::SketchObject* Obj,
     PosId = Sketcher::none;
 
     if (name.size() > 4 && name.substr(0,4) == "Edge") {
-        GeoId = std::atoi(name.substr(4,4000).c_str());
+        GeoId = std::atoi(name.substr(4,4000).c_str()) - 1;
     }
     else if (name.size() == 9 && name.substr(0,9) == "RootPoint") {
         GeoId = -1;
@@ -113,9 +121,9 @@ void getIdsFromName(const std::string &name, const Sketcher::SketchObject* Obj,
     else if (name.size() == 6 && name.substr(0,6) == "V_Axis")
         GeoId = -2;
     else if (name.size() > 12 && name.substr(0,12) == "ExternalEdge")
-        GeoId = -3 - std::atoi(name.substr(12,4000).c_str());
+        GeoId = -2 - std::atoi(name.substr(12,4000).c_str());
     else if (name.size() > 6 && name.substr(0,6) == "Vertex") {
-        int VtId = std::atoi(name.substr(6,4000).c_str());
+        int VtId = std::atoi(name.substr(6,4000).c_str()) - 1;
         Obj->getGeoVertexIndex(VtId,GeoId,PosId);
     }
 }
@@ -270,7 +278,7 @@ void CmdSketcherConstrainHorizontal::activated(int iMsg)
     for (std::vector<std::string>::const_iterator it=SubNames.begin(); it != SubNames.end(); ++it) {
         // only handle edges
         if (it->size() > 4 && it->substr(0,4) == "Edge") {
-            int GeoId=std::atoi(it->substr(4,4000).c_str());
+            int GeoId = std::atoi(it->substr(4,4000).c_str()) - 1;
 
             const Part::Geometry *geo = Obj->getGeometry(GeoId);
             if (geo->getTypeId() != Part::GeomLineSegment::getClassTypeId()) {
@@ -362,9 +370,9 @@ void CmdSketcherConstrainVertical::activated(int iMsg)
     for (std::vector<std::string>::const_iterator it=SubNames.begin();it!=SubNames.end();++it) {
         // only handle edges
         if (it->size() > 4 && it->substr(0,4) == "Edge") {
-            int index=std::atoi(it->substr(4,4000).c_str());
+            int GeoId = std::atoi(it->substr(4,4000).c_str()) - 1;
 
-            const Part::Geometry *geo = Obj->getGeometry(index);
+            const Part::Geometry *geo = Obj->getGeometry(GeoId);
             if (geo->getTypeId() != Part::GeomLineSegment::getClassTypeId()) {
                 QMessageBox::warning(Gui::getMainWindow(), QObject::tr("Impossible constraint"),
                                      QObject::tr("The selected edge is not a line segment"));
@@ -374,18 +382,18 @@ void CmdSketcherConstrainVertical::activated(int iMsg)
             // check if the edge has already a Horizontal or Vertical constraint
             for (std::vector< Sketcher::Constraint * >::const_iterator it= vals.begin();
                  it != vals.end(); ++it) {
-                if ((*it)->Type == Sketcher::Horizontal && (*it)->First == index) {
+                if ((*it)->Type == Sketcher::Horizontal && (*it)->First == GeoId) {
                     QMessageBox::warning(Gui::getMainWindow(), QObject::tr("Impossible constraint"),
                         QObject::tr("The selected edge has already a horizontal constraint!"));
                     return;
                 }
-                if ((*it)->Type == Sketcher::Vertical && (*it)->First == index) {
+                if ((*it)->Type == Sketcher::Vertical && (*it)->First == GeoId) {
                     QMessageBox::warning(Gui::getMainWindow(), QObject::tr("Double constraint"),
                         QObject::tr("The selected edge has already a vertical constraint!"));
                     return;
                 }
             }
-            ids.push_back(index);
+            ids.push_back(GeoId);
         }
     }
 
@@ -897,8 +905,8 @@ void CmdSketcherConstrainDistanceX::activated(int iMsg)
 
         if (GeoId1 < 0) {
             QMessageBox::warning(Gui::getMainWindow(), QObject::tr("Wrong selection"),
-                GeoId1 < -2 ? QObject::tr("Cannot add a fixed x-cootdinate constraint on an external geometry!")
-                            : QObject::tr("Cannot add a fixed x-cootdinate constraint on the root point!"));
+                GeoId1 < -2 ? QObject::tr("Cannot add a fixed x-coordinate constraint on an external geometry!")
+                            : QObject::tr("Cannot add a fixed x-coordinate constraint on the root point!"));
             return;
         }
 
@@ -1029,8 +1037,8 @@ void CmdSketcherConstrainDistanceY::activated(int iMsg)
 
         if (GeoId1 < 0) {
             QMessageBox::warning(Gui::getMainWindow(), QObject::tr("Wrong selection"),
-                GeoId1 < -2 ? QObject::tr("Cannot add a fixed y-cootdinate constraint on an external geometry!")
-                            : QObject::tr("Cannot add a fixed y-cootdinate constraint on the root point!"));
+                GeoId1 < -2 ? QObject::tr("Cannot add a fixed y-coordinate constraint on an external geometry!")
+                            : QObject::tr("Cannot add a fixed y-coordinate constraint on the root point!"));
             return;
         }
 
@@ -1160,7 +1168,7 @@ CmdSketcherConstrainPerpendicular::CmdSketcherConstrainPerpendicular()
     sAppModule      = "Sketcher";
     sGroup          = QT_TR_NOOP("Sketcher");
     sMenuText       = QT_TR_NOOP("Constrain perpendicular");
-    sToolTipText    = QT_TR_NOOP("Create a Perpendicular constraint between two lines");
+    sToolTipText    = QT_TR_NOOP("Create a perpendicular constraint between two lines");
     sWhatsThis      = sToolTipText;
     sStatusTip      = sToolTipText;
     sPixmap         = "Constraint_Perpendicular";
@@ -1447,7 +1455,7 @@ void CmdSketcherConstrainRadius::activated(int iMsg)
     }
 
     if (SubNames[0].size() > 4 && SubNames[0].substr(0,4) == "Edge") {
-        int GeoId = std::atoi(SubNames[0].substr(4,4000).c_str());
+        int GeoId = std::atoi(SubNames[0].substr(4,4000).c_str()) - 1;
 
         const Part::Geometry *geom = Obj->getGeometry(GeoId);
         if (geom->getTypeId() == Part::GeomArcOfCircle::getClassTypeId()) {
@@ -1556,8 +1564,8 @@ void CmdSketcherConstrainAngle::activated(int iMsg)
             Base::Vector3d p1b = lineSeg1->getEndPoint();
             Base::Vector3d p2a = lineSeg2->getStartPoint();
             Base::Vector3d p2b = lineSeg2->getEndPoint();
-            double length = 1e10;
-            for (int i=0; i <= 1; i++)
+            double length = DBL_MAX;
+            for (int i=0; i <= 1; i++) {
                 for (int j=0; j <= 1; j++) {
                     double tmp = ((j?p2a:p2b)-(i?p1a:p1b)).Length();
                     if (tmp < length) {
@@ -1566,12 +1574,24 @@ void CmdSketcherConstrainAngle::activated(int iMsg)
                         PosId2 = j ? Sketcher::start : Sketcher::end;
                     }
                 }
+            }
 
             Base::Vector3d dir1 = ((PosId1 == Sketcher::start) ? 1. : -1.) *
                                   (lineSeg1->getEndPoint()-lineSeg1->getStartPoint());
             Base::Vector3d dir2 = ((PosId2 == Sketcher::start) ? 1. : -1.) *
                                   (lineSeg2->getEndPoint()-lineSeg2->getStartPoint());
 
+            // check if the two lines are parallel, in this case an angle is not possible
+            Base::Vector3d dir3 = dir1 % dir2;
+            if (dir3.Length() < Precision::Intersection()) {
+                Base::Vector3d dist = (p1a - p2a) % dir1;
+                if (dist.Sqr() > Precision::Intersection()) {
+                    QMessageBox::warning(Gui::getMainWindow(), QObject::tr("Parallel lines"),
+                        QObject::tr("An angle constraint cannot be set for two parallel lines."));
+                    return;
+                }
+            }
+
             double ActAngle = atan2(-dir1.y*dir2.x+dir1.x*dir2.y,
                                     dir1.x*dir2.x+dir1.y*dir2.y);
             if (ActAngle < 0) {
@@ -1662,7 +1682,7 @@ void CmdSketcherConstrainEqual::activated(int iMsg)
 
     if (SubNames.size() < 2) {
         QMessageBox::warning(Gui::getMainWindow(), QObject::tr("Wrong selection"),
-            QObject::tr("Select atleast two lines from the sketch."));
+            QObject::tr("Select at least two lines from the sketch."));
         return;
     }
 
@@ -1744,7 +1764,7 @@ CmdSketcherConstrainSymmetric::CmdSketcherConstrainSymmetric()
     sAppModule      = "Sketcher";
     sGroup          = QT_TR_NOOP("Sketcher");
     sMenuText       = QT_TR_NOOP("Constrain symmetrical");
-    sToolTipText    = QT_TR_NOOP("Create an symmetry constraint between two points with respect to a line");
+    sToolTipText    = QT_TR_NOOP("Create a symmetry constraint between two points with respect to a line or a third point");
     sWhatsThis      = sToolTipText;
     sStatusTip      = sToolTipText;
     sPixmap         = "Constraint_Symmetric";
