@@ -24,7 +24,7 @@
 # This is the start page template
 
 import os,FreeCAD,FreeCADGui,tempfile,time,zipfile,urllib,re,cStringIO
-from PyQt4 import QtGui
+from PySide import QtGui
 from xml.etree.ElementTree import parse
 
 FreeCADGui.addLanguagePath(":/translations")
@@ -34,7 +34,7 @@ def translate(context,text):
     "convenience function for the Qt translator"
     # return str(QtGui.QApplication.translate(context, text, None, QtGui.QApplication.UnicodeUTF8).toUtf8())
     u = QtGui.QApplication.translate(context, text, None,
-                                     QtGui.QApplication.UnicodeUTF8).toUtf8()
+                                     QtGui.QApplication.UnicodeUTF8).encode("utf8")
     s = cStringIO.StringIO()
     for i in u:
         if ord(i) == 39:
@@ -71,7 +71,7 @@ text21 = translate("StartPage","Example workflow")
 text22 = translate("StartPage","Part Design")
 text23 = translate("StartPage","Designing architectural elements")
 text24 = translate("StartPage","The <b>Architectural Design</b> workbench is specially designed for working with architectural elements such as walls or windows. Start by drawing 2D shapes, and use them as guides to build architecutral objects.")
-text25 = translate("StartPage","Architectual Design")
+text25 = translate("StartPage","Architectural Design")
 text26 = translate("StartPage","Working with Meshes")
 text27 = translate("StartPage","The <b>Mesh Workbench</b> is used to work with Mesh objects. Meshes are simpler 3D objects than Part objects, but they are often easier to import and export to/from other applications.")
 text28 = translate("StartPage","FreeCAD offers you several tools to convert between Mesh and Part objects.")
@@ -93,15 +93,17 @@ text43 = translate("StartPage","The FreeCAD-tutorial blog")
 text44 = translate("StartPage","from <a href=http://www.youtube.com/user/FreeCADNews?feature=mhee>FreeCADNews channel</a>")
 text45 = translate("StartPage","This is the official user manual of FreeCAD, built, maintained and translated by the FreeCAD community.")
 text46 = translate("StartPage","The tutorials section on the FreeCAD website")
-text47 = translate("StartPage","The section of the FreeCAd website dedicate dto python scripting, with examples, explanations, and API commands.")
+text47 = translate("StartPage","The section of the FreeCAD website dedicated to python scripting, with examples, explanations, and API commands.")
 text48 = translate("StartPage","A blog dedicated to teaching FreeCAD, maintained by members of the FreeCAD community")
 text49 = translate("StartPage","Getting started")
 text50 = translate("StartPage","The FreeCAD interface is divided in workbenches, which are sets of tools suited for a specific task. You can start with one of the workbenches in this list, or with the complete workbench, which presents you with some of the most used tools gathered from other workbenches. Click to read more about workbenches on the FreeCAD website.")
-text51 = translate("StartPage","http://www.freecadweb.org/wiki/index.php?title=Workbench_Concept")
+text51 = translate("StartPage","http://www.freecadweb.org/wiki/index.php?title=Workbenches")
 text52 = translate("StartPage","Ship Design")
 text53 = translate("StartPage","Designing and calculating ships")
 text54 = translate("StartPage","The <b>Ship Design</b> module offers several tools to help ship designers to view, model and calculate profiles and other specific properties of ship hulls.")
 text55 = translate("StartPage","Load an Architectural example model")
+text56 = translate("StartPage","http://www.freecadweb.org/wiki/index.php?title=Tutorials")
+text57 = translate("StartPage","http://www.freecadweb.org/wiki/index.php?title=Power_users_hub")
 
 # here is the html page skeleton
 
@@ -112,6 +114,8 @@ page = """
 
     <script language="javascript">
 
+        var linkDescriptions = [];
+
         function JSONscriptRequest(fullUrl) {
             // REST request path
             this.fullUrl = fullUrl; 
@@ -150,58 +154,86 @@ page = """
             ddiv.innerHTML = theText;
         }
 
-        function loadFeeds() {
-            ddiv = document.getElementById("youtube");
-            ddiv.innerHTML = "Fetching data from the web...";
-            var obj=new JSONscriptRequest('http://gdata.youtube.com/feeds/base/users/FreeCADNews/favorites?alt=json-in-script&v=2&orderby=published&callback=showLinks');
-            obj.buildScriptTag(); // Build the script tag
-            obj.addScriptTag(); // Execute (add) the script tag
-            ddiv.innerHTML = "Done fetching";
+        function load() {
             ddiv = document.getElementById("news");
-            ddiv.innerHTML = "Fetching data from the web...";
+            ddiv.innerHTML = "Connecting...";
             var tobj=new JSONscriptRequest('http://pipes.yahoo.com/pipes/pipe.run?_id=da8b612e97a6bb4588b1ce27db30efd9&_render=json&_callback=showTweets');
             tobj.buildScriptTag(); // Build the script tag
             tobj.addScriptTag(); // Execute (add) the script tag
-            ddiv.innerHTML = "Done fetching";
+            ddiv.innerHTML = "Downloading latest news...";
         }
 
-        function showLinks(data) {
-            ddiv = document.getElementById('youtube');
-            ddiv.innerHTML = "Received";
-            var feed = data.feed;
-            var entries = feed.entry || [];
-            var html = ['<ul>'];
-            for (var i = 0; i < 5; i++) {
-                html.push('<li><a href="',entries[i].link[0].href,'">', entries[i].title.$t, '</a></li>');
-            }
-            html.push('</ul>');
-            ddiv.innerHTML = html.join('');
+        function stripTags(text) {
+            // from http://www.pagecolumn.com/tool/all_about_html_tags.htm /<\s*\/?\s*span\s*.*?>/g
+            stripped = text.replace("<table", "<div");
+            stripped = stripped.replace("</table", "</div");
+            stripped = stripped.replace("<tr", "<tr");
+            stripped = stripped.replace("</tr", "</tr");
+            stripped = stripped.replace("<td", "<td");
+            stripped = stripped.replace("</td", "</td");
+            stripped = stripped.replace("555px", "auto");
+            stripped = stripped.replace("border:1px", "border:0px");
+            stripped = stripped.replace("color:#000000;","");
+            return stripped;
         }
 
         function showTweets(data) {
             ddiv = document.getElementById('news');
             ddiv.innerHTML = "Received";
             var html = ['<ul>'];
-            for (var i = 0; i < 8; i++) {
-                html.push('<li><a href="', data.value.items[i].link, '">', data.value.items[i].title, '</a></li>');
+            for (var i = 0; i < 15; i++) {
+                html.push('<li><img src="web.png">&nbsp;<a href="ext', data.value.items[i].link, '" onMouseOver="showDescr(', i+1, ')" onMouseOut="showDescr()">', data.value.items[i].title, '</a></li>');
+                if ("description" in data.value.items[i]) {
+                    linkDescriptions.push(stripTags(data.value.items[i].description));
+                } else if ("content" in data.value.items[i]) {
+                    if ("content" in data.value.items[i].content) {
+                        linkDescriptions.push(data.value.items[i].content.content);
+                    } else {
+                        linkDescriptions.push(data.value.items[i].content);
+                    }
+                } else {
+                    linkDescriptions.push("");
+                }
+                
             }
             html.push('</ul>');
             ddiv.innerHTML = html.join('');
         }
 
+        function showDescr(d) {
+            if (d) {
+                show(linkDescriptions[d-1]);
+            } else {
+                show("");
+            }
+        }
+
+        function scroller() {
+            desc = document.getElementById("description");
+            base = document.getElementById("column").offsetTop;
+            scro = window.scrollY;
+            if (scro > base) {
+                desc.className = "stick";
+            } else {
+                desc.className = "";
+            }
+        }
+
+        document.onmousemove=scroller;
+
     </script>
 
     <style type="text/css">
 
         body {
-            background: #171A2B url(Background.jpg);
-            color: white;
+            background: #basecolor;
+            color: #textcolor;
             font-family: Arial, Helvetica, Sans;
             font-size: 11px;
         }
 
         a {
-            color: #0092E8;
+            color: #linkcolor;
             font-weight: bold;
             text-decoration: none;
             padding: 2px;
@@ -209,7 +241,7 @@ page = """
 
         a:hover {
             color: white;
-            background: #0092E8;
+            background: #linkcolor;
             border-radius: 5px;
         }
 
@@ -237,17 +269,21 @@ page = """
             padding: 0;
         }
 
-        .column {
-            width: 300px;
-            float: left;
-            margin-left: 10px;
+        #column {
+            margin: 0 350px 0 10px;
+        }
+
+        #column img {
+            max-width: 14px;
         }
 
         .block {
-            background: rgba(30,31,33,0.6);;
+            background: #windowcolor;
             border-radius: 5px;
             padding: 8px;
             margin-bottom: 10px;
+            color: #windowtextcolor;
+            width: auto;
         }
 
         .options {
@@ -259,15 +295,47 @@ page = """
             font-weight: normal;
         }
 
+        #description {
+            background: #windowcolor;
+            border-radius: 5px;
+            padding: 8px;
+            color: #windowtextcolor;
+            float: right;
+            width: 316px;
+            right: 10px;
+            height: 100%;
+            position: relative;
+        }
+
+        #description img {
+            max-width: 300px;
+            clear: both;
+        }
+
+        pre {
+            width: 300px !important;
+            white-space: pre-wrap;
+        }
+
+        .stick {
+            position: fixed !important;
+            top: 0px;
+            right: 18px !important;
+        }
+
     </style>
 
   </head>
 
-  <body onload="loadFeeds()">
+  <body onload="load()">
 
     <h1><img src="FreeCAD.png">&nbsp;""" + text01 + """</h1>
 
-    <div class="column">
+    <div id="description">
+      &nbsp;
+    </div>
+
+    <div id="column">
 
       <div class="block">
         <h2>""" + text02 + """</h2>
@@ -279,20 +347,11 @@ page = """
           recentfiles
       </div>
 
-      <div class="block">
-        <h2>""" + text04 + """</h2>
-        <div id="youtube">youtube videos</div>
-      </div>
-
       <div class="block">
         <h2>""" + text05 + """</h2>
         <div id="news">news feed</div>
       </div>
 
-    </div>
-
-    <div class="column">
-
       <div class="block">
         <h2>""" + text06 + """</h2>
             defaultlinks
@@ -303,15 +362,10 @@ page = """
             defaultexamples
       </div>
 
-
       customblocks
 
     </div>
 
-    <div class="column" id="description">
-      &nbsp;
-    </div>
-
     <!--
     <form class="options">
       <input type="checkbox" name="closeThisDialog">
@@ -356,15 +410,15 @@ def getLinks():
         <li><img src="web.png">&nbsp;
             <a onMouseover="show('<p>""" + text46 + """</p>')" 
                 onMouseout="show('')"
-                href="http://www.freecadweb.org/wiki/index.php?title=Tutorials">""" + text39 + """</a></li>
+                href=""" + text56 + """>""" + text39 + """</a></li>
         <li><img src="web.png">&nbsp;
             <a onMouseover="show('<p>""" + text47 + """</p>')" 
                 onMouseout="show('')"
-                href="http://www.freecadweb.org/wiki/index.php?title=Power_users_hub">""" + text40 + """</a></li>
+                href=""" + text57 + """>""" + text40 + """</a></li>
         <li><img src="web.png">&nbsp;
             <a onMouseover="show('<p>""" + text48 + """</p>')" 
                 onMouseout="show('')"
-                href="http://freecad-tutorial.blogspot.com/">""" + text43 + """</a></li>
+                href="exthttp://freecad-tutorial.blogspot.com/">""" + text43 + """</a></li>
     </ul>"""
 
 def getWorkbenches():
@@ -403,13 +457,6 @@ def getWorkbenches():
             onMouseout="show('')" 
             href="Mesh.py">""" + text29 + """</a>
         </li>
-        <li><img src="Complete.png">&nbsp;
-            <a onMouseover="show('<h3>""" + text30 +"""</h3> \
-            <p>This is the <b>""" + text31 + """</b>, \
-            """ + text32 + """</p><img src=complete.jpg>')" 
-            onMouseout="show('')" 
-            href="DefaultWorkbench.py">""" + text31 + """</a>
-        </li>
     </ul>"""
 
 def getInfo(filename):
@@ -468,18 +515,19 @@ def getRecentFiles():
     for i in range(3):
         if i < ct:
             mr = rf.GetString("MRU%d" % (i))
-            fn = os.path.basename(mr)
-            html += '<li>'
-            if mr[-5:].upper() == "FCSTD":
-                html += '<img src="FreeCAD.png" style="width: 16px">&nbsp;'
-            else:
-                html += '<img src="blank.png" style="width: 16px">&nbsp;'
-            html += '<a '
-            html += 'onMouseover="show(\''+getInfo(mr)+'\')" '
-            html += 'onMouseout="show(\'\')" '
-            html += 'href="LoadMRU'+str(i)+'.py">'
-            html += fn
-            html += '</a></li>'
+            if os.path.exists(mr):
+                fn = os.path.basename(mr)
+                html += '<li>'
+                if mr[-5:].upper() == "FCSTD":
+                    html += '<img src="freecad-doc.png" style="width: 16px">&nbsp;'
+                else:
+                    html += '<img src="blank.png" style="width: 16px">&nbsp;'
+                html += '<a '
+                html += 'onMouseover="show(\''+getInfo(mr)+'\')" '
+                html += 'onMouseout="show(\'\')" '
+                html += 'href="LoadMRU'+str(i)+'.py">'
+                html += fn
+                html += '</a></li>'
     html += '</ul>'
     return html
 
@@ -520,6 +568,28 @@ def getCustomBlocks():
     output = ""
     return output
 
+def setColors(html):
+    "gets theme colors from the system, and sets appropriate styles"
+    defaults = {"#basecolor":"#191B26",
+                "#linkcolor":"#0092E8",
+                "#textcolor":"#FFFFFF",
+                "#windowcolor":"#FFFFFF",
+                "#windowtextcolor":"#000000"}
+    try:
+        palette = QtGui.qApp.palette()
+    except:
+        pass
+    else:
+        #defaults["#basecolor"] = palette.base().color().name()
+        defaults["#basecolor"] = "#171A2B url(Background.jpg)"
+        #defaults["#linkcolor"] = palette.link().color().name() # UGLY!!
+        defaults["#textcolor"] = palette.text().color().name()
+        defaults["#windowcolor"] = palette.window().color().name()
+        defaults["#windowtextcolor"] = palette.windowText().color().name()
+    for k,v in defaults.iteritems():
+        html = html.replace(k,str(v))
+    return html
+
 def handle():
     "returns the complete html startpage"
     
@@ -541,6 +611,13 @@ def handle():
 
     # add custom blocks
     html = html.replace("customblocks",getCustomBlocks())
+
+    # fetches system colors
+    html = setColors(html)
     
     return html
 
+def exportTestFile():
+    f = open(os.path.expanduser("~")+os.sep+"freecad-startpage.html","wb")
+    f.write(handle())
+    f.close()
